C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp





C     Upper part.
      M(4, 91) = M(4, 91) / M(4, 4)

C     Upper part.
      M(5, 86) = M(5, 86) / M(5, 5)

C     Upper part.
      M(6, 86) = M(6, 86) / M(6, 6)

C     Upper part.
      M(7, 86) = M(7, 86) / M(7, 7)

C     Upper part.
      M(8, 86) = M(8, 86) / M(8, 8)

C     Upper part.
      M(9, 86) = M(9, 86) / M(9, 9)

C     Upper part.
      M(10, 86) = M(10, 86) / M(10, 10)

C     Upper part.
      temp = M(11, 10) * M(10, 86)
      M(11, 86) = ( M(11, 86) - temp ) / M(11, 11)

C     Upper part.
      M(12, 86) = M(12, 86) / M(12, 12)

C     Upper part.
      temp = M(13, 12) * M(12, 86)
      M(13, 86) = ( M(13, 86) - temp ) / M(13, 13)

C     Upper part.
      temp = M(14, 12) * M(12, 86)
      M(14, 86) = ( M(14, 86) - temp ) / M(14, 14)

C     Upper part.
      M(15, 86) = M(15, 86) / M(15, 15)

C     Upper part.
      M(16, 86) = M(16, 86) / M(16, 16)

C     Upper part.
      M(17, 86) = M(17, 86) / M(17, 17)

C     Upper part.
      temp = M(18, 15) * M(15, 86)
      M(18, 86) = ( M(18, 86) - temp ) / M(18, 18)

C     Upper part.
      temp = M(19, 16) * M(16, 86)
      M(19, 86) = ( M(19, 86) - temp ) / M(19, 19)

C     Upper part.
      temp = M(20, 17) * M(17, 86)
      M(20, 86) = ( M(20, 86) - temp ) / M(20, 20)

C     Upper part.
      M(21, 48) = M(21, 48) / M(21, 21)

C     Upper part.
      temp = M(22, 21) * M(21, 48)
      M(22, 48) = ( M(22, 48) - temp ) / M(22, 22)

C     Upper part.
      M(23, 84) = M(23, 84) / M(23, 23)
C     Upper part.
      M(23, 86) = M(23, 86) / M(23, 23)

C     Upper part.
      temp = M(24, 8) * M(8, 86)
      temp = temp + M(24, 9) * M(9, 86)
      M(24, 86) = ( M(24, 86) - temp ) / M(24, 24)
C     Upper part.
      M(24, 92) = M(24, 92) / M(24, 24)

C     Upper part.
      M(25, 87) = M(25, 87) / M(25, 25)
C     Upper part.
      M(25, 94) = M(25, 94) / M(25, 25)

C     Upper part.
      M(26, 57) = M(26, 57) / M(26, 26)
C     Upper part.
      M(26, 86) = M(26, 86) / M(26, 26)

C     Upper part.
      M(27, 57) = M(27, 57) / M(27, 27)
C     Upper part.
      M(27, 86) = M(27, 86) / M(27, 27)

C     Upper part.
      M(28, 80) = M(28, 80) / M(28, 28)
C     Upper part.
      M(28, 96) = M(28, 96) / M(28, 28)

C     Upper part.
      M(29, 80) = M(29, 80) / M(29, 29)
C     Upper part.
      M(29, 96) = M(29, 96) / M(29, 29)

C     Upper part.
      M(30, 70) = M(30, 70) / M(30, 30)
C     Upper part.
      M(30, 87) = M(30, 87) / M(30, 30)

C     Upper part.
      M(31, 93) = M(31, 93) / M(31, 31)
C     Upper part.
      M(31, 94) = M(31, 94) / M(31, 31)

C     Upper part.
      temp = M(32, 22) * M(22, 48)
      M(32, 48) = ( M(32, 48) - temp ) / M(32, 32)
C     Upper part.
      M(32, 52) = M(32, 52) / M(32, 32)
C     Upper part.
      M(32, 96) = M(32, 96) / M(32, 32)

C     Upper part.
      temp = M(33, 32) * M(32, 48)
      M(33, 48) = ( M(33, 48) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 32) * M(32, 52)
      M(33, 52) = ( M(33, 52) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 32) * M(32, 96)
      M(33, 96) = ( M(33, 96) - temp ) / M(33, 33)

C     Upper part.
      temp = M(34, 32) * M(32, 48)
      M(34, 48) = ( M(34, 48) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 32) * M(32, 52)
      M(34, 52) = ( M(34, 52) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 32) * M(32, 96)
      M(34, 96) = ( M(34, 96) - temp ) / M(34, 34)

C     Upper part.
      M(35, 50) = M(35, 50) / M(35, 35)
C     Upper part.
      M(35, 86) = M(35, 86) / M(35, 35)

C     Upper part.
      M(36, 86) = M(36, 86) / M(36, 36)
C     Upper part.
      M(36, 94) = M(36, 94) / M(36, 36)
C     Upper part.
      M(36, 96) = M(36, 96) / M(36, 36)

C     Upper part.
      M(37, 80) = M(37, 80) / M(37, 37)
C     Upper part.
      M(37, 84) = M(37, 84) / M(37, 37)
C     Upper part.
      M(37, 93) = M(37, 93) / M(37, 37)

C     Upper part.
      M(38, 86) = M(38, 86) / M(38, 38)
C     Upper part.
      M(38, 90) = M(38, 90) / M(38, 38)
C     Upper part.
      M(38, 94) = M(38, 94) / M(38, 38)

C     Upper part.
      M(39, 74) = M(39, 74) / M(39, 39)
C     Upper part.
      M(39, 86) = M(39, 86) / M(39, 39)
C     Upper part.
      M(39, 94) = M(39, 94) / M(39, 39)

C     Upper part.
      M(40, 86) = M(40, 86) / M(40, 40)
C     Upper part.
      M(40, 88) = M(40, 88) / M(40, 40)
C     Upper part.
      M(40, 96) = M(40, 96) / M(40, 40)

C     Upper part.
      M(41, 86) = M(41, 86) / M(41, 41)
C     Upper part.
      M(41, 92) = M(41, 92) / M(41, 41)
C     Upper part.
      M(41, 94) = M(41, 94) / M(41, 41)

C     Upper part.
      M(42, 85) = M(42, 85) / M(42, 42)
C     Upper part.
      M(42, 92) = M(42, 92) / M(42, 42)
C     Upper part.
      M(42, 96) = M(42, 96) / M(42, 42)

C     Upper part.
      M(43, 84) = M(43, 84) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 85)
      M(43, 85) = ( M(43, 85) - temp ) / M(43, 43)
C     Upper part.
      M(43, 86) = M(43, 86) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 92)
      M(43, 92) = ( M(43, 92) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 96)
      M(43, 96) = ( M(43, 96) - temp ) / M(43, 43)

C     Upper part.
      M(44, 63) = M(44, 63) / M(44, 44)
C     Upper part.
      temp = M(44, 24) * M(24, 86)
      M(44, 86) = ( M(44, 86) - temp ) / M(44, 44)
C     Upper part.
      M(44, 91) = M(44, 91) / M(44, 44)
C     Upper part.
      temp = M(44, 24) * M(24, 92)
      M(44, 92) = ( M(44, 92) - temp ) / M(44, 44)

C     Upper part.
      temp = M(45, 44) * M(44, 63)
      M(45, 63) = ( M(45, 63) - temp ) / M(45, 45)
C     Upper part.
      M(45, 72) = M(45, 72) / M(45, 45)
C     Upper part.
      temp = M(45, 9) * M(9, 86)
      temp = temp + M(45, 44) * M(44, 86)
      M(45, 86) = ( M(45, 86) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 91)
      M(45, 91) = ( M(45, 91) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 92)
      M(45, 92) = ( M(45, 92) - temp ) / M(45, 45)

C     Upper part.
      M(46, 86) = M(46, 86) / M(46, 46)
C     Upper part.
      M(46, 87) = M(46, 87) / M(46, 46)
C     Upper part.
      M(46, 88) = M(46, 88) / M(46, 46)
C     Upper part.
      M(46, 91) = M(46, 91) / M(46, 46)

C     Upper part.
      M(47, 49) = M(47, 49) / M(47, 47)
C     Upper part.
      M(47, 60) = M(47, 60) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 86)
      M(47, 86) = ( M(47, 86) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 87)
      M(47, 87) = ( M(47, 87) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 88)
      M(47, 88) = ( M(47, 88) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 91)
      M(47, 91) = ( M(47, 91) - temp ) / M(47, 47)

C     Lower part.
      temp = M(52, 32) * M(32, 48)
      M(52, 48) = M(52, 48) - temp
C     Upper part.
      M(48, 49) = M(48, 49) / M(48, 48)
C     Upper part.
      M(48, 52) = M(48, 52) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 86)
      M(48, 86) = ( M(48, 86) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 87)
      M(48, 87) = ( M(48, 87) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 88)
      M(48, 88) = ( M(48, 88) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 91)
      M(48, 91) = ( M(48, 91) - temp ) / M(48, 48)

C     Lower part.
      temp = M(52, 48) * M(48, 49)
      M(52, 49) = M(52, 49) - temp
C     Upper part.
      M(49, 86) = M(49, 86) / M(49, 49)
C     Upper part.
      M(49, 87) = M(49, 87) / M(49, 49)
C     Upper part.
      M(49, 88) = M(49, 88) / M(49, 49)
C     Upper part.
      M(49, 91) = M(49, 91) / M(49, 49)

C     Upper part.
      M(50, 60) = M(50, 60) / M(50, 50)
C     Upper part.
      temp = M(50, 46) * M(46, 86)
      temp = temp + M(50, 49) * M(49, 86)
      M(50, 86) = ( M(50, 86) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 46) * M(46, 87)
      temp = temp + M(50, 49) * M(49, 87)
      M(50, 87) = ( M(50, 87) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 46) * M(46, 88)
      temp = temp + M(50, 49) * M(49, 88)
      M(50, 88) = ( M(50, 88) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 46) * M(46, 91)
      temp = temp + M(50, 49) * M(49, 91)
      M(50, 91) = ( M(50, 91) - temp ) / M(50, 50)

C     Upper part.
      M(51, 60) = M(51, 60) / M(51, 51)
C     Upper part.
      temp = M(51, 46) * M(46, 86)
      temp = temp + M(51, 49) * M(49, 86)
      M(51, 86) = ( M(51, 86) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 46) * M(46, 87)
      temp = temp + M(51, 49) * M(49, 87)
      M(51, 87) = ( M(51, 87) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 46) * M(46, 88)
      temp = temp + M(51, 49) * M(49, 88)
      M(51, 88) = ( M(51, 88) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 46) * M(46, 91)
      temp = temp + M(51, 49) * M(49, 91)
      M(51, 91) = ( M(51, 91) - temp ) / M(51, 51)

C     Lower part.
      temp = M(52, 32) * M(32, 52)
      temp = temp + M(52, 48) * M(48, 52)
      M(52, 52) = M(52, 52) - temp
C     Upper part.
      temp = M(52, 46) * M(46, 86)
      temp = temp + M(52, 48) * M(48, 86)
      temp = temp + M(52, 49) * M(49, 86)
      M(52, 86) = ( M(52, 86) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 46) * M(46, 87)
      temp = temp + M(52, 48) * M(48, 87)
      temp = temp + M(52, 49) * M(49, 87)
      M(52, 87) = ( M(52, 87) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 46) * M(46, 88)
      temp = temp + M(52, 48) * M(48, 88)
      temp = temp + M(52, 49) * M(49, 88)
      M(52, 88) = ( M(52, 88) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 46) * M(46, 91)
      temp = temp + M(52, 48) * M(48, 91)
      temp = temp + M(52, 49) * M(49, 91)
      M(52, 91) = ( M(52, 91) - temp ) / M(52, 52)
C     Upper part.
      M(52, 92) = M(52, 92) / M(52, 52)
C     Upper part.
      temp = M(52, 32) * M(32, 96)
      M(52, 96) = ( M(52, 96) - temp ) / M(52, 52)

C     Upper part.
      M(53, 60) = M(53, 60) / M(53, 53)
C     Upper part.
      temp = M(53, 12) * M(12, 86)
      temp = temp + M(53, 46) * M(46, 86)
      temp = temp + M(53, 49) * M(49, 86)
      M(53, 86) = ( M(53, 86) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 46) * M(46, 87)
      temp = temp + M(53, 49) * M(49, 87)
      M(53, 87) = ( M(53, 87) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 46) * M(46, 88)
      temp = temp + M(53, 49) * M(49, 88)
      M(53, 88) = ( M(53, 88) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 46) * M(46, 91)
      temp = temp + M(53, 49) * M(49, 91)
      M(53, 91) = ( M(53, 91) - temp ) / M(53, 53)
C     Upper part.
      M(53, 92) = M(53, 92) / M(53, 53)

C     Upper part.
      M(54, 60) = M(54, 60) / M(54, 54)
C     Upper part.
      temp = M(54, 46) * M(46, 86)
      temp = temp + M(54, 49) * M(49, 86)
      M(54, 86) = ( M(54, 86) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 46) * M(46, 87)
      temp = temp + M(54, 49) * M(49, 87)
      M(54, 87) = ( M(54, 87) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 46) * M(46, 88)
      temp = temp + M(54, 49) * M(49, 88)
      M(54, 88) = ( M(54, 88) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 46) * M(46, 91)
      temp = temp + M(54, 49) * M(49, 91)
      M(54, 91) = ( M(54, 91) - temp ) / M(54, 54)

C     Upper part.
      M(55, 86) = M(55, 86) / M(55, 55)
C     Upper part.
      M(55, 87) = M(55, 87) / M(55, 55)
C     Upper part.
      M(55, 88) = M(55, 88) / M(55, 55)
C     Upper part.
      M(55, 91) = M(55, 91) / M(55, 55)

C     Upper part.
      temp = M(56, 42) * M(42, 85)
      M(56, 85) = ( M(56, 85) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 55) * M(55, 86)
      M(56, 86) = ( M(56, 86) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 55) * M(55, 87)
      M(56, 87) = ( M(56, 87) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 55) * M(55, 88)
      M(56, 88) = ( M(56, 88) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 55) * M(55, 91)
      M(56, 91) = ( M(56, 91) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 42) * M(42, 92)
      M(56, 92) = ( M(56, 92) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 42) * M(42, 96)
      M(56, 96) = ( M(56, 96) - temp ) / M(56, 56)

C     Upper part.
      M(57, 81) = M(57, 81) / M(57, 57)
C     Upper part.
      M(57, 86) = M(57, 86) / M(57, 57)
C     Upper part.
      M(57, 87) = M(57, 87) / M(57, 57)
C     Upper part.
      M(57, 94) = M(57, 94) / M(57, 57)

C     Upper part.
      M(58, 86) = M(58, 86) / M(58, 58)
C     Upper part.
      M(58, 87) = M(58, 87) / M(58, 58)
C     Upper part.
      M(58, 88) = M(58, 88) / M(58, 58)
C     Upper part.
      M(58, 91) = M(58, 91) / M(58, 58)

C     Upper part.
      M(59, 86) = M(59, 86) / M(59, 59)
C     Upper part.
      M(59, 87) = M(59, 87) / M(59, 59)
C     Upper part.
      M(59, 88) = M(59, 88) / M(59, 59)
C     Upper part.
      M(59, 91) = M(59, 91) / M(59, 59)

C     Lower part.
      temp = M(68, 53) * M(53, 60)
      M(68, 60) = M(68, 60) - temp
C     Upper part.
      M(60, 86) = M(60, 86) / M(60, 60)
C     Upper part.
      M(60, 87) = M(60, 87) / M(60, 60)
C     Upper part.
      M(60, 88) = M(60, 88) / M(60, 60)
C     Upper part.
      M(60, 91) = M(60, 91) / M(60, 60)

C     Upper part.
      M(61, 83) = M(61, 83) / M(61, 61)
C     Upper part.
      M(61, 86) = M(61, 86) / M(61, 61)
C     Upper part.
      M(61, 95) = M(61, 95) / M(61, 61)
C     Upper part.
      M(61, 96) = M(61, 96) / M(61, 61)

C     Upper part.
      M(62, 86) = M(62, 86) / M(62, 62)
C     Upper part.
      M(62, 90) = M(62, 90) / M(62, 62)
C     Upper part.
      M(62, 93) = M(62, 93) / M(62, 62)
C     Upper part.
      M(62, 96) = M(62, 96) / M(62, 62)

C     Lower part.
      temp = M(75, 44) * M(44, 63)
      M(75, 63) = M(75, 63) - temp
C     Lower part.
      temp = M(77, 44) * M(44, 63)
      temp = temp + M(77, 45) * M(45, 63)
      M(77, 63) = M(77, 63) - temp
C     Lower part.
      temp = M(85, 44) * M(44, 63)
      M(85, 63) = M(85, 63) - temp
C     Lower part.
      temp = M(86, 44) * M(44, 63)
      temp = temp + M(86, 45) * M(45, 63)
      M(86, 63) = M(86, 63) - temp
C     Lower part.
      temp = M(91, 44) * M(44, 63)
      M(91, 63) = M(91, 63) - temp
C     Lower part.
      temp = M(93, 44) * M(44, 63)
      temp = temp + M(93, 45) * M(45, 63)
      M(93, 63) = M(93, 63) - temp
C     Lower part.
      temp = M(95, 44) * M(44, 63)
      temp = temp + M(95, 45) * M(45, 63)
      M(95, 63) = M(95, 63) - temp
C     Lower part.
      temp = M(96, 44) * M(44, 63)
      temp = temp + M(96, 45) * M(45, 63)
      M(96, 63) = M(96, 63) - temp
C     Upper part.
      M(63, 64) = M(63, 64) / M(63, 63)
C     Upper part.
      temp = M(63, 8) * M(8, 86)
      temp = temp + M(63, 9) * M(9, 86)
      temp = temp + M(63, 24) * M(24, 86)
      M(63, 86) = ( M(63, 86) - temp ) / M(63, 63)
C     Upper part.
      M(63, 87) = M(63, 87) / M(63, 63)
C     Upper part.
      temp = M(63, 24) * M(24, 92)
      M(63, 92) = ( M(63, 92) - temp ) / M(63, 63)
C     Upper part.
      M(63, 96) = M(63, 96) / M(63, 63)

C     Lower part.
      temp = M(64, 63) * M(63, 64)
      M(64, 64) = M(64, 64) - temp
C     Lower part.
      temp = M(75, 63) * M(63, 64)
      M(75, 64) = M(75, 64) - temp
C     Lower part.
      temp = M(77, 63) * M(63, 64)
      M(77, 64) = M(77, 64) - temp
C     Lower part.
      temp = M(79, 63) * M(63, 64)
      M(79, 64) = M(79, 64) - temp
C     Lower part.
      temp = M(85, 63) * M(63, 64)
      M(85, 64) = M(85, 64) - temp
C     Lower part.
      temp = M(86, 63) * M(63, 64)
      M(86, 64) = M(86, 64) - temp
C     Lower part.
      temp = M(87, 63) * M(63, 64)
      M(87, 64) = M(87, 64) - temp
C     Lower part.
      temp = M(91, 63) * M(63, 64)
      M(91, 64) = M(91, 64) - temp
C     Lower part.
      temp = M(93, 63) * M(63, 64)
      M(93, 64) = M(93, 64) - temp
C     Lower part.
      temp = M(95, 63) * M(63, 64)
      M(95, 64) = M(95, 64) - temp
C     Lower part.
      temp = M(96, 63) * M(63, 64)
      M(96, 64) = M(96, 64) - temp
C     Upper part.
      temp = M(64, 63) * M(63, 86)
      M(64, 86) = ( M(64, 86) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 63) * M(63, 87)
      M(64, 87) = ( M(64, 87) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 63) * M(63, 92)
      M(64, 92) = ( M(64, 92) - temp ) / M(64, 64)
C     Upper part.
      M(64, 94) = M(64, 94) / M(64, 64)
C     Upper part.
      temp = M(64, 63) * M(63, 96)
      M(64, 96) = ( M(64, 96) - temp ) / M(64, 64)

C     Upper part.
      M(65, 78) = M(65, 78) / M(65, 65)
C     Upper part.
      M(65, 82) = M(65, 82) / M(65, 65)
C     Upper part.
      M(65, 87) = M(65, 87) / M(65, 65)
C     Upper part.
      M(65, 92) = M(65, 92) / M(65, 65)

C     Upper part.
      M(66, 78) = M(66, 78) / M(66, 66)
C     Upper part.
      M(66, 82) = M(66, 82) / M(66, 66)
C     Upper part.
      M(66, 87) = M(66, 87) / M(66, 66)
C     Upper part.
      M(66, 92) = M(66, 92) / M(66, 66)

C     Upper part.
      temp = M(67, 12) * M(12, 86)
      temp = temp + M(67, 46) * M(46, 86)
      temp = temp + M(67, 49) * M(49, 86)
      temp = temp + M(67, 60) * M(60, 86)
      M(67, 86) = ( M(67, 86) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 87)
      temp = temp + M(67, 49) * M(49, 87)
      temp = temp + M(67, 60) * M(60, 87)
      M(67, 87) = ( M(67, 87) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 88)
      temp = temp + M(67, 49) * M(49, 88)
      temp = temp + M(67, 60) * M(60, 88)
      M(67, 88) = ( M(67, 88) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 91)
      temp = temp + M(67, 49) * M(49, 91)
      temp = temp + M(67, 60) * M(60, 91)
      M(67, 91) = ( M(67, 91) - temp ) / M(67, 67)
C     Upper part.
      M(67, 92) = M(67, 92) / M(67, 67)
C     Upper part.
      M(67, 95) = M(67, 95) / M(67, 67)
C     Upper part.
      M(67, 96) = M(67, 96) / M(67, 67)

C     Upper part.
      temp = M(68, 53) * M(53, 86)
      temp = temp + M(68, 60) * M(60, 86)
      temp = temp + M(68, 67) * M(67, 86)
      M(68, 86) = ( M(68, 86) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 53) * M(53, 87)
      temp = temp + M(68, 60) * M(60, 87)
      temp = temp + M(68, 67) * M(67, 87)
      M(68, 87) = ( M(68, 87) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 53) * M(53, 88)
      temp = temp + M(68, 60) * M(60, 88)
      temp = temp + M(68, 67) * M(67, 88)
      M(68, 88) = ( M(68, 88) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 53) * M(53, 91)
      temp = temp + M(68, 60) * M(60, 91)
      temp = temp + M(68, 67) * M(67, 91)
      M(68, 91) = ( M(68, 91) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 53) * M(53, 92)
      temp = temp + M(68, 67) * M(67, 92)
      M(68, 92) = ( M(68, 92) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 67) * M(67, 95)
      M(68, 95) = ( M(68, 95) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 67) * M(67, 96)
      M(68, 96) = ( M(68, 96) - temp ) / M(68, 68)

C     Upper part.
      M(69, 78) = M(69, 78) / M(69, 69)
C     Upper part.
      M(69, 82) = M(69, 82) / M(69, 69)
C     Upper part.
      M(69, 84) = M(69, 84) / M(69, 69)
C     Upper part.
      M(69, 93) = M(69, 93) / M(69, 69)
C     Upper part.
      M(69, 96) = M(69, 96) / M(69, 69)

C     Upper part.
      M(70, 71) = M(70, 71) / M(70, 70)
C     Upper part.
      M(70, 80) = M(70, 80) / M(70, 70)
C     Upper part.
      M(70, 86) = M(70, 86) / M(70, 70)
C     Upper part.
      M(70, 87) = M(70, 87) / M(70, 70)
C     Upper part.
      M(70, 92) = M(70, 92) / M(70, 70)

C     Upper part.
      M(71, 86) = M(71, 86) / M(71, 71)
C     Upper part.
      M(71, 87) = M(71, 87) / M(71, 71)
C     Upper part.
      M(71, 88) = M(71, 88) / M(71, 71)
C     Upper part.
      M(71, 91) = M(71, 91) / M(71, 71)
C     Upper part.
      M(71, 94) = M(71, 94) / M(71, 71)

C     Lower part.
      temp = M(77, 45) * M(45, 72)
      M(77, 72) = M(77, 72) - temp
C     Lower part.
      temp = M(86, 45) * M(45, 72)
      M(86, 72) = M(86, 72) - temp
C     Lower part.
      temp = M(93, 45) * M(45, 72)
      M(93, 72) = M(93, 72) - temp
C     Lower part.
      temp = M(95, 45) * M(45, 72)
      M(95, 72) = M(95, 72) - temp
C     Lower part.
      temp = M(96, 45) * M(45, 72)
      M(96, 72) = M(96, 72) - temp
C     Upper part.
      temp = M(72, 71) * M(71, 86)
      M(72, 86) = ( M(72, 86) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 87)
      M(72, 87) = ( M(72, 87) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 88)
      M(72, 88) = ( M(72, 88) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 91)
      M(72, 91) = ( M(72, 91) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 94)
      M(72, 94) = ( M(72, 94) - temp ) / M(72, 72)

C     Upper part.
      temp = M(73, 39) * M(39, 74)
      M(73, 74) = ( M(73, 74) - temp ) / M(73, 73)
C     Upper part.
      M(73, 83) = M(73, 83) / M(73, 73)
C     Upper part.
      temp = M(73, 24) * M(24, 86)
      temp = temp + M(73, 39) * M(39, 86)
      temp = temp + M(73, 46) * M(46, 86)
      temp = temp + M(73, 49) * M(49, 86)
      temp = temp + M(73, 60) * M(60, 86)
      temp = temp + M(73, 64) * M(64, 86)
      temp = temp + M(73, 71) * M(71, 86)
      temp = temp + M(73, 72) * M(72, 86)
      M(73, 86) = ( M(73, 86) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 46) * M(46, 87)
      temp = temp + M(73, 49) * M(49, 87)
      temp = temp + M(73, 60) * M(60, 87)
      temp = temp + M(73, 64) * M(64, 87)
      temp = temp + M(73, 71) * M(71, 87)
      temp = temp + M(73, 72) * M(72, 87)
      M(73, 87) = ( M(73, 87) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 46) * M(46, 88)
      temp = temp + M(73, 49) * M(49, 88)
      temp = temp + M(73, 60) * M(60, 88)
      temp = temp + M(73, 71) * M(71, 88)
      temp = temp + M(73, 72) * M(72, 88)
      M(73, 88) = ( M(73, 88) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 46) * M(46, 91)
      temp = temp + M(73, 49) * M(49, 91)
      temp = temp + M(73, 60) * M(60, 91)
      temp = temp + M(73, 71) * M(71, 91)
      temp = temp + M(73, 72) * M(72, 91)
      M(73, 91) = ( M(73, 91) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 24) * M(24, 92)
      temp = temp + M(73, 64) * M(64, 92)
      M(73, 92) = ( M(73, 92) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 39) * M(39, 94)
      temp = temp + M(73, 64) * M(64, 94)
      temp = temp + M(73, 71) * M(71, 94)
      temp = temp + M(73, 72) * M(72, 94)
      M(73, 94) = ( M(73, 94) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 64) * M(64, 96)
      M(73, 96) = ( M(73, 96) - temp ) / M(73, 73)

C     Lower part.
      temp = M(74, 39) * M(39, 74)
      temp = temp + M(74, 73) * M(73, 74)
      M(74, 74) = M(74, 74) - temp
C     Lower part.
      temp = M(75, 39) * M(39, 74)
      temp = temp + M(75, 73) * M(73, 74)
      M(75, 74) = M(75, 74) - temp
C     Lower part.
      temp = M(79, 73) * M(73, 74)
      M(79, 74) = M(79, 74) - temp
C     Lower part.
      temp = M(83, 39) * M(39, 74)
      M(83, 74) = M(83, 74) - temp
C     Lower part.
      temp = M(85, 73) * M(73, 74)
      M(85, 74) = M(85, 74) - temp
C     Lower part.
      temp = M(86, 73) * M(73, 74)
      M(86, 74) = M(86, 74) - temp
C     Lower part.
      temp = M(89, 39) * M(39, 74)
      temp = temp + M(89, 73) * M(73, 74)
      M(89, 74) = M(89, 74) - temp
C     Lower part.
      temp = M(94, 39) * M(39, 74)
      temp = temp + M(94, 73) * M(73, 74)
      M(94, 74) = M(94, 74) - temp
C     Lower part.
      temp = M(95, 39) * M(39, 74)
      M(95, 74) = M(95, 74) - temp
C     Lower part.
      temp = M(96, 39) * M(39, 74)
      temp = temp + M(96, 73) * M(73, 74)
      M(96, 74) = M(96, 74) - temp
C     Upper part.
      temp = M(74, 73) * M(73, 83)
      M(74, 83) = ( M(74, 83) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 9) * M(9, 86)
      temp = temp + M(74, 12) * M(12, 86)
      temp = temp + M(74, 39) * M(39, 86)
      temp = temp + M(74, 46) * M(46, 86)
      temp = temp + M(74, 49) * M(49, 86)
      temp = temp + M(74, 58) * M(58, 86)
      temp = temp + M(74, 59) * M(59, 86)
      temp = temp + M(74, 60) * M(60, 86)
      temp = temp + M(74, 71) * M(71, 86)
      temp = temp + M(74, 72) * M(72, 86)
      temp = temp + M(74, 73) * M(73, 86)
      M(74, 86) = ( M(74, 86) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 46) * M(46, 87)
      temp = temp + M(74, 49) * M(49, 87)
      temp = temp + M(74, 58) * M(58, 87)
      temp = temp + M(74, 59) * M(59, 87)
      temp = temp + M(74, 60) * M(60, 87)
      temp = temp + M(74, 71) * M(71, 87)
      temp = temp + M(74, 72) * M(72, 87)
      temp = temp + M(74, 73) * M(73, 87)
      M(74, 87) = ( M(74, 87) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 46) * M(46, 88)
      temp = temp + M(74, 49) * M(49, 88)
      temp = temp + M(74, 58) * M(58, 88)
      temp = temp + M(74, 59) * M(59, 88)
      temp = temp + M(74, 60) * M(60, 88)
      temp = temp + M(74, 71) * M(71, 88)
      temp = temp + M(74, 72) * M(72, 88)
      temp = temp + M(74, 73) * M(73, 88)
      M(74, 88) = ( M(74, 88) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 46) * M(46, 91)
      temp = temp + M(74, 49) * M(49, 91)
      temp = temp + M(74, 58) * M(58, 91)
      temp = temp + M(74, 59) * M(59, 91)
      temp = temp + M(74, 60) * M(60, 91)
      temp = temp + M(74, 71) * M(71, 91)
      temp = temp + M(74, 72) * M(72, 91)
      temp = temp + M(74, 73) * M(73, 91)
      M(74, 91) = ( M(74, 91) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 73) * M(73, 92)
      M(74, 92) = ( M(74, 92) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 39) * M(39, 94)
      temp = temp + M(74, 71) * M(71, 94)
      temp = temp + M(74, 72) * M(72, 94)
      temp = temp + M(74, 73) * M(73, 94)
      M(74, 94) = ( M(74, 94) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 73) * M(73, 96)
      M(74, 96) = ( M(74, 96) - temp ) / M(74, 74)

C     Upper part.
      temp = M(75, 61) * M(61, 83)
      temp = temp + M(75, 73) * M(73, 83)
      temp = temp + M(75, 74) * M(74, 83)
      M(75, 83) = ( M(75, 83) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 5) * M(5, 86)
      temp = temp + M(75, 12) * M(12, 86)
      temp = temp + M(75, 39) * M(39, 86)
      temp = temp + M(75, 44) * M(44, 86)
      temp = temp + M(75, 46) * M(46, 86)
      temp = temp + M(75, 49) * M(49, 86)
      temp = temp + M(75, 55) * M(55, 86)
      temp = temp + M(75, 58) * M(58, 86)
      temp = temp + M(75, 59) * M(59, 86)
      temp = temp + M(75, 60) * M(60, 86)
      temp = temp + M(75, 61) * M(61, 86)
      temp = temp + M(75, 63) * M(63, 86)
      temp = temp + M(75, 64) * M(64, 86)
      temp = temp + M(75, 71) * M(71, 86)
      temp = temp + M(75, 72) * M(72, 86)
      temp = temp + M(75, 73) * M(73, 86)
      temp = temp + M(75, 74) * M(74, 86)
      M(75, 86) = ( M(75, 86) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 46) * M(46, 87)
      temp = temp + M(75, 49) * M(49, 87)
      temp = temp + M(75, 55) * M(55, 87)
      temp = temp + M(75, 58) * M(58, 87)
      temp = temp + M(75, 59) * M(59, 87)
      temp = temp + M(75, 60) * M(60, 87)
      temp = temp + M(75, 63) * M(63, 87)
      temp = temp + M(75, 64) * M(64, 87)
      temp = temp + M(75, 71) * M(71, 87)
      temp = temp + M(75, 72) * M(72, 87)
      temp = temp + M(75, 73) * M(73, 87)
      temp = temp + M(75, 74) * M(74, 87)
      M(75, 87) = ( M(75, 87) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 46) * M(46, 88)
      temp = temp + M(75, 49) * M(49, 88)
      temp = temp + M(75, 55) * M(55, 88)
      temp = temp + M(75, 58) * M(58, 88)
      temp = temp + M(75, 59) * M(59, 88)
      temp = temp + M(75, 60) * M(60, 88)
      temp = temp + M(75, 71) * M(71, 88)
      temp = temp + M(75, 72) * M(72, 88)
      temp = temp + M(75, 73) * M(73, 88)
      temp = temp + M(75, 74) * M(74, 88)
      M(75, 88) = ( M(75, 88) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 44) * M(44, 91)
      temp = temp + M(75, 46) * M(46, 91)
      temp = temp + M(75, 49) * M(49, 91)
      temp = temp + M(75, 55) * M(55, 91)
      temp = temp + M(75, 58) * M(58, 91)
      temp = temp + M(75, 59) * M(59, 91)
      temp = temp + M(75, 60) * M(60, 91)
      temp = temp + M(75, 71) * M(71, 91)
      temp = temp + M(75, 72) * M(72, 91)
      temp = temp + M(75, 73) * M(73, 91)
      temp = temp + M(75, 74) * M(74, 91)
      M(75, 91) = ( M(75, 91) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 44) * M(44, 92)
      temp = temp + M(75, 63) * M(63, 92)
      temp = temp + M(75, 64) * M(64, 92)
      temp = temp + M(75, 73) * M(73, 92)
      temp = temp + M(75, 74) * M(74, 92)
      M(75, 92) = ( M(75, 92) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 39) * M(39, 94)
      temp = temp + M(75, 64) * M(64, 94)
      temp = temp + M(75, 71) * M(71, 94)
      temp = temp + M(75, 72) * M(72, 94)
      temp = temp + M(75, 73) * M(73, 94)
      temp = temp + M(75, 74) * M(74, 94)
      M(75, 94) = ( M(75, 94) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 61) * M(61, 95)
      M(75, 95) = ( M(75, 95) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 61) * M(61, 96)
      temp = temp + M(75, 63) * M(63, 96)
      temp = temp + M(75, 64) * M(64, 96)
      temp = temp + M(75, 73) * M(73, 96)
      temp = temp + M(75, 74) * M(74, 96)
      M(75, 96) = ( M(75, 96) - temp ) / M(75, 75)

C     Upper part.
      M(76, 84) = M(76, 84) / M(76, 76)
C     Upper part.
      M(76, 86) = M(76, 86) / M(76, 76)
C     Upper part.
      M(76, 90) = M(76, 90) / M(76, 76)
C     Upper part.
      M(76, 93) = M(76, 93) / M(76, 76)
C     Upper part.
      M(76, 95) = M(76, 95) / M(76, 76)
C     Upper part.
      M(76, 96) = M(76, 96) / M(76, 76)

C     Upper part.
      temp = M(77, 75) * M(75, 83)
      M(77, 83) = ( M(77, 83) - temp ) / M(77, 77)
C     Upper part.
      M(77, 85) = M(77, 85) / M(77, 77)
C     Upper part.
      temp = M(77, 44) * M(44, 86)
      temp = temp + M(77, 45) * M(45, 86)
      temp = temp + M(77, 46) * M(46, 86)
      temp = temp + M(77, 49) * M(49, 86)
      temp = temp + M(77, 55) * M(55, 86)
      temp = temp + M(77, 58) * M(58, 86)
      temp = temp + M(77, 59) * M(59, 86)
      temp = temp + M(77, 60) * M(60, 86)
      temp = temp + M(77, 63) * M(63, 86)
      temp = temp + M(77, 64) * M(64, 86)
      temp = temp + M(77, 71) * M(71, 86)
      temp = temp + M(77, 72) * M(72, 86)
      temp = temp + M(77, 75) * M(75, 86)
      M(77, 86) = ( M(77, 86) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 46) * M(46, 87)
      temp = temp + M(77, 49) * M(49, 87)
      temp = temp + M(77, 55) * M(55, 87)
      temp = temp + M(77, 58) * M(58, 87)
      temp = temp + M(77, 59) * M(59, 87)
      temp = temp + M(77, 60) * M(60, 87)
      temp = temp + M(77, 63) * M(63, 87)
      temp = temp + M(77, 64) * M(64, 87)
      temp = temp + M(77, 71) * M(71, 87)
      temp = temp + M(77, 72) * M(72, 87)
      temp = temp + M(77, 75) * M(75, 87)
      M(77, 87) = ( M(77, 87) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 46) * M(46, 88)
      temp = temp + M(77, 49) * M(49, 88)
      temp = temp + M(77, 55) * M(55, 88)
      temp = temp + M(77, 58) * M(58, 88)
      temp = temp + M(77, 59) * M(59, 88)
      temp = temp + M(77, 60) * M(60, 88)
      temp = temp + M(77, 71) * M(71, 88)
      temp = temp + M(77, 72) * M(72, 88)
      temp = temp + M(77, 75) * M(75, 88)
      M(77, 88) = ( M(77, 88) - temp ) / M(77, 77)
C     Upper part.
      M(77, 89) = M(77, 89) / M(77, 77)
C     Upper part.
      temp = M(77, 44) * M(44, 91)
      temp = temp + M(77, 45) * M(45, 91)
      temp = temp + M(77, 46) * M(46, 91)
      temp = temp + M(77, 49) * M(49, 91)
      temp = temp + M(77, 55) * M(55, 91)
      temp = temp + M(77, 58) * M(58, 91)
      temp = temp + M(77, 59) * M(59, 91)
      temp = temp + M(77, 60) * M(60, 91)
      temp = temp + M(77, 71) * M(71, 91)
      temp = temp + M(77, 72) * M(72, 91)
      temp = temp + M(77, 75) * M(75, 91)
      M(77, 91) = ( M(77, 91) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 44) * M(44, 92)
      temp = temp + M(77, 45) * M(45, 92)
      temp = temp + M(77, 63) * M(63, 92)
      temp = temp + M(77, 64) * M(64, 92)
      temp = temp + M(77, 75) * M(75, 92)
      M(77, 92) = ( M(77, 92) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 64) * M(64, 94)
      temp = temp + M(77, 71) * M(71, 94)
      temp = temp + M(77, 72) * M(72, 94)
      temp = temp + M(77, 75) * M(75, 94)
      M(77, 94) = ( M(77, 94) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 75) * M(75, 95)
      M(77, 95) = ( M(77, 95) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 63) * M(63, 96)
      temp = temp + M(77, 64) * M(64, 96)
      temp = temp + M(77, 75) * M(75, 96)
      M(77, 96) = ( M(77, 96) - temp ) / M(77, 77)

C     Upper part.
      M(78, 84) = M(78, 84) / M(78, 78)
C     Upper part.
      temp = M(78, 9) * M(9, 86)
      M(78, 86) = ( M(78, 86) - temp ) / M(78, 78)
C     Upper part.
      M(78, 87) = M(78, 87) / M(78, 78)
C     Upper part.
      M(78, 92) = M(78, 92) / M(78, 78)
C     Upper part.
      M(78, 93) = M(78, 93) / M(78, 78)
C     Upper part.
      M(78, 96) = M(78, 96) / M(78, 78)

C     Upper part.
      temp = M(79, 73) * M(73, 83)
      temp = temp + M(79, 74) * M(74, 83)
      temp = temp + M(79, 75) * M(75, 83)
      M(79, 83) = ( M(79, 83) - temp ) / M(79, 79)
C     Upper part.
      M(79, 85) = M(79, 85) / M(79, 79)
C     Upper part.
      temp = M(79, 63) * M(63, 86)
      temp = temp + M(79, 64) * M(64, 86)
      temp = temp + M(79, 72) * M(72, 86)
      temp = temp + M(79, 73) * M(73, 86)
      temp = temp + M(79, 74) * M(74, 86)
      temp = temp + M(79, 75) * M(75, 86)
      M(79, 86) = ( M(79, 86) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 25) * M(25, 87)
      temp = temp + M(79, 63) * M(63, 87)
      temp = temp + M(79, 64) * M(64, 87)
      temp = temp + M(79, 72) * M(72, 87)
      temp = temp + M(79, 73) * M(73, 87)
      temp = temp + M(79, 74) * M(74, 87)
      temp = temp + M(79, 75) * M(75, 87)
      M(79, 87) = ( M(79, 87) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 72) * M(72, 88)
      temp = temp + M(79, 73) * M(73, 88)
      temp = temp + M(79, 74) * M(74, 88)
      temp = temp + M(79, 75) * M(75, 88)
      M(79, 88) = ( M(79, 88) - temp ) / M(79, 79)
C     Upper part.
      M(79, 89) = M(79, 89) / M(79, 79)
C     Upper part.
      temp = M(79, 72) * M(72, 91)
      temp = temp + M(79, 73) * M(73, 91)
      temp = temp + M(79, 74) * M(74, 91)
      temp = temp + M(79, 75) * M(75, 91)
      M(79, 91) = ( M(79, 91) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 63) * M(63, 92)
      temp = temp + M(79, 64) * M(64, 92)
      temp = temp + M(79, 73) * M(73, 92)
      temp = temp + M(79, 74) * M(74, 92)
      temp = temp + M(79, 75) * M(75, 92)
      M(79, 92) = ( M(79, 92) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 25) * M(25, 94)
      temp = temp + M(79, 64) * M(64, 94)
      temp = temp + M(79, 72) * M(72, 94)
      temp = temp + M(79, 73) * M(73, 94)
      temp = temp + M(79, 74) * M(74, 94)
      temp = temp + M(79, 75) * M(75, 94)
      M(79, 94) = ( M(79, 94) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 75) * M(75, 95)
      M(79, 95) = ( M(79, 95) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 63) * M(63, 96)
      temp = temp + M(79, 64) * M(64, 96)
      temp = temp + M(79, 73) * M(73, 96)
      temp = temp + M(79, 74) * M(74, 96)
      temp = temp + M(79, 75) * M(75, 96)
      M(79, 96) = ( M(79, 96) - temp ) / M(79, 79)

C     Upper part.
      M(80, 84) = M(80, 84) / M(80, 80)
C     Upper part.
      temp = M(80, 71) * M(71, 86)
      M(80, 86) = ( M(80, 86) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 71) * M(71, 87)
      M(80, 87) = ( M(80, 87) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 71) * M(71, 88)
      M(80, 88) = ( M(80, 88) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 71) * M(71, 91)
      M(80, 91) = ( M(80, 91) - temp ) / M(80, 80)
C     Upper part.
      M(80, 92) = M(80, 92) / M(80, 80)
C     Upper part.
      M(80, 93) = M(80, 93) / M(80, 80)
C     Upper part.
      temp = M(80, 71) * M(71, 94)
      M(80, 94) = ( M(80, 94) - temp ) / M(80, 80)
C     Upper part.
      M(80, 96) = M(80, 96) / M(80, 80)

C     Lower part.
      temp = M(81, 57) * M(57, 81)
      M(81, 81) = M(81, 81) - temp
C     Upper part.
      temp = M(81, 80) * M(80, 84)
      M(81, 84) = ( M(81, 84) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 57) * M(57, 86)
      temp = temp + M(81, 80) * M(80, 86)
      M(81, 86) = ( M(81, 86) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 57) * M(57, 87)
      temp = temp + M(81, 80) * M(80, 87)
      M(81, 87) = ( M(81, 87) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 88)
      M(81, 88) = ( M(81, 88) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 91)
      M(81, 91) = ( M(81, 91) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 92)
      M(81, 92) = ( M(81, 92) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 93)
      M(81, 93) = ( M(81, 93) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 57) * M(57, 94)
      temp = temp + M(81, 80) * M(80, 94)
      M(81, 94) = ( M(81, 94) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 96)
      M(81, 96) = ( M(81, 96) - temp ) / M(81, 81)

C     Upper part.
      M(82, 84) = M(82, 84) / M(82, 82)
C     Upper part.
      temp = M(82, 8) * M(8, 86)
      M(82, 86) = ( M(82, 86) - temp ) / M(82, 82)
C     Upper part.
      M(82, 87) = M(82, 87) / M(82, 82)
C     Upper part.
      M(82, 92) = M(82, 92) / M(82, 82)
C     Upper part.
      M(82, 93) = M(82, 93) / M(82, 82)
C     Upper part.
      M(82, 96) = M(82, 96) / M(82, 82)

C     Lower part.
      temp = M(83, 74) * M(74, 83)
      M(83, 83) = M(83, 83) - temp
C     Lower part.
      temp = M(84, 75) * M(75, 83)
      M(84, 83) = M(84, 83) - temp
C     Lower part.
      temp = M(85, 73) * M(73, 83)
      temp = temp + M(85, 74) * M(74, 83)
      M(85, 83) = M(85, 83) - temp
C     Lower part.
      temp = M(86, 61) * M(61, 83)
      temp = temp + M(86, 73) * M(73, 83)
      temp = temp + M(86, 74) * M(74, 83)
      temp = temp + M(86, 75) * M(75, 83)
      temp = temp + M(86, 77) * M(77, 83)
      temp = temp + M(86, 79) * M(79, 83)
      M(86, 83) = M(86, 83) - temp
C     Lower part.
      temp = M(87, 75) * M(75, 83)
      temp = temp + M(87, 79) * M(79, 83)
      M(87, 83) = M(87, 83) - temp
C     Lower part.
      temp = M(88, 75) * M(75, 83)
      M(88, 83) = M(88, 83) - temp
C     Lower part.
      temp = M(89, 61) * M(61, 83)
      temp = temp + M(89, 73) * M(73, 83)
      temp = temp + M(89, 74) * M(74, 83)
      M(89, 83) = M(89, 83) - temp
C     Lower part.
      temp = M(90, 75) * M(75, 83)
      M(90, 83) = M(90, 83) - temp
C     Lower part.
      temp = M(94, 73) * M(73, 83)
      temp = temp + M(94, 74) * M(74, 83)
      temp = temp + M(94, 79) * M(79, 83)
      M(94, 83) = M(94, 83) - temp
C     Lower part.
      temp = M(95, 61) * M(61, 83)
      temp = temp + M(95, 74) * M(74, 83)
      M(95, 83) = M(95, 83) - temp
C     Lower part.
      temp = M(96, 61) * M(61, 83)
      temp = temp + M(96, 73) * M(73, 83)
      temp = temp + M(96, 74) * M(74, 83)
      temp = temp + M(96, 75) * M(75, 83)
      temp = temp + M(96, 77) * M(77, 83)
      M(96, 83) = M(96, 83) - temp
C     Upper part.
      temp = M(83, 7) * M(7, 86)
      temp = temp + M(83, 12) * M(12, 86)
      temp = temp + M(83, 39) * M(39, 86)
      temp = temp + M(83, 46) * M(46, 86)
      temp = temp + M(83, 49) * M(49, 86)
      temp = temp + M(83, 58) * M(58, 86)
      temp = temp + M(83, 60) * M(60, 86)
      temp = temp + M(83, 71) * M(71, 86)
      temp = temp + M(83, 74) * M(74, 86)
      M(83, 86) = ( M(83, 86) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 46) * M(46, 87)
      temp = temp + M(83, 49) * M(49, 87)
      temp = temp + M(83, 58) * M(58, 87)
      temp = temp + M(83, 60) * M(60, 87)
      temp = temp + M(83, 71) * M(71, 87)
      temp = temp + M(83, 74) * M(74, 87)
      M(83, 87) = ( M(83, 87) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 46) * M(46, 88)
      temp = temp + M(83, 49) * M(49, 88)
      temp = temp + M(83, 58) * M(58, 88)
      temp = temp + M(83, 60) * M(60, 88)
      temp = temp + M(83, 71) * M(71, 88)
      temp = temp + M(83, 74) * M(74, 88)
      M(83, 88) = ( M(83, 88) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 46) * M(46, 91)
      temp = temp + M(83, 49) * M(49, 91)
      temp = temp + M(83, 58) * M(58, 91)
      temp = temp + M(83, 60) * M(60, 91)
      temp = temp + M(83, 71) * M(71, 91)
      temp = temp + M(83, 74) * M(74, 91)
      M(83, 91) = ( M(83, 91) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 74) * M(74, 92)
      M(83, 92) = ( M(83, 92) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 39) * M(39, 94)
      temp = temp + M(83, 71) * M(71, 94)
      temp = temp + M(83, 74) * M(74, 94)
      M(83, 94) = ( M(83, 94) - temp ) / M(83, 83)
C     Upper part.
      M(83, 95) = M(83, 95) / M(83, 83)
C     Upper part.
      temp = M(83, 74) * M(74, 96)
      M(83, 96) = ( M(83, 96) - temp ) / M(83, 83)

C     Lower part.
      temp = M(84, 43) * M(43, 84)
      temp = temp + M(84, 76) * M(76, 84)
      M(84, 84) = M(84, 84) - temp
C     Lower part.
      temp = M(85, 23) * M(23, 84)
      temp = temp + M(85, 43) * M(43, 84)
      M(85, 84) = M(85, 84) - temp
C     Lower part.
      temp = M(86, 23) * M(23, 84)
      temp = temp + M(86, 43) * M(43, 84)
      temp = temp + M(86, 76) * M(76, 84)
      M(86, 84) = M(86, 84) - temp
C     Lower part.
      temp = M(95, 43) * M(43, 84)
      M(95, 84) = M(95, 84) - temp
C     Lower part.
      temp = M(96, 23) * M(23, 84)
      temp = temp + M(96, 43) * M(43, 84)
      M(96, 84) = M(96, 84) - temp
C     Upper part.
      temp = M(84, 43) * M(43, 85)
      M(84, 85) = ( M(84, 85) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 6) * M(6, 86)
      temp = temp + M(84, 43) * M(43, 86)
      temp = temp + M(84, 62) * M(62, 86)
      temp = temp + M(84, 75) * M(75, 86)
      temp = temp + M(84, 76) * M(76, 86)
      temp = temp + M(84, 83) * M(83, 86)
      M(84, 86) = ( M(84, 86) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 75) * M(75, 87)
      temp = temp + M(84, 83) * M(83, 87)
      M(84, 87) = ( M(84, 87) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 75) * M(75, 88)
      temp = temp + M(84, 83) * M(83, 88)
      M(84, 88) = ( M(84, 88) - temp ) / M(84, 84)
C     Upper part.
      M(84, 89) = M(84, 89) / M(84, 84)
C     Upper part.
      temp = M(84, 62) * M(62, 90)
      temp = temp + M(84, 76) * M(76, 90)
      M(84, 90) = ( M(84, 90) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 75) * M(75, 91)
      temp = temp + M(84, 83) * M(83, 91)
      M(84, 91) = ( M(84, 91) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 43) * M(43, 92)
      temp = temp + M(84, 75) * M(75, 92)
      temp = temp + M(84, 83) * M(83, 92)
      M(84, 92) = ( M(84, 92) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 62) * M(62, 93)
      temp = temp + M(84, 76) * M(76, 93)
      M(84, 93) = ( M(84, 93) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 75) * M(75, 94)
      temp = temp + M(84, 83) * M(83, 94)
      M(84, 94) = ( M(84, 94) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 75) * M(75, 95)
      temp = temp + M(84, 76) * M(76, 95)
      temp = temp + M(84, 83) * M(83, 95)
      M(84, 95) = ( M(84, 95) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 43) * M(43, 96)
      temp = temp + M(84, 62) * M(62, 96)
      temp = temp + M(84, 75) * M(75, 96)
      temp = temp + M(84, 76) * M(76, 96)
      temp = temp + M(84, 83) * M(83, 96)
      M(84, 96) = ( M(84, 96) - temp ) / M(84, 84)

C     Lower part.
      temp = M(85, 42) * M(42, 85)
      temp = temp + M(85, 43) * M(43, 85)
      temp = temp + M(85, 84) * M(84, 85)
      M(85, 85) = M(85, 85) - temp
C     Lower part.
      temp = M(86, 43) * M(43, 85)
      temp = temp + M(86, 56) * M(56, 85)
      temp = temp + M(86, 77) * M(77, 85)
      temp = temp + M(86, 79) * M(79, 85)
      temp = temp + M(86, 84) * M(84, 85)
      M(86, 85) = M(86, 85) - temp
C     Lower part.
      temp = M(87, 79) * M(79, 85)
      M(87, 85) = M(87, 85) - temp
C     Lower part.
      temp = M(89, 84) * M(84, 85)
      M(89, 85) = M(89, 85) - temp
C     Lower part.
      temp = M(92, 42) * M(42, 85)
      temp = temp + M(92, 84) * M(84, 85)
      M(92, 85) = M(92, 85) - temp
C     Lower part.
      temp = M(93, 84) * M(84, 85)
      M(93, 85) = M(93, 85) - temp
C     Lower part.
      temp = M(94, 42) * M(42, 85)
      temp = temp + M(94, 79) * M(79, 85)
      temp = temp + M(94, 84) * M(84, 85)
      M(94, 85) = M(94, 85) - temp
C     Lower part.
      temp = M(95, 43) * M(43, 85)
      temp = temp + M(95, 84) * M(84, 85)
      M(95, 85) = M(95, 85) - temp
C     Lower part.
      temp = M(96, 42) * M(42, 85)
      temp = temp + M(96, 43) * M(43, 85)
      temp = temp + M(96, 56) * M(56, 85)
      temp = temp + M(96, 77) * M(77, 85)
      temp = temp + M(96, 84) * M(84, 85)
      M(96, 85) = M(96, 85) - temp
C     Upper part.
      temp = M(85, 5) * M(5, 86)
      temp = temp + M(85, 12) * M(12, 86)
      temp = temp + M(85, 23) * M(23, 86)
      temp = temp + M(85, 43) * M(43, 86)
      temp = temp + M(85, 44) * M(44, 86)
      temp = temp + M(85, 46) * M(46, 86)
      temp = temp + M(85, 49) * M(49, 86)
      temp = temp + M(85, 55) * M(55, 86)
      temp = temp + M(85, 58) * M(58, 86)
      temp = temp + M(85, 59) * M(59, 86)
      temp = temp + M(85, 60) * M(60, 86)
      temp = temp + M(85, 63) * M(63, 86)
      temp = temp + M(85, 64) * M(64, 86)
      temp = temp + M(85, 71) * M(71, 86)
      temp = temp + M(85, 72) * M(72, 86)
      temp = temp + M(85, 73) * M(73, 86)
      temp = temp + M(85, 74) * M(74, 86)
      temp = temp + M(85, 83) * M(83, 86)
      temp = temp + M(85, 84) * M(84, 86)
      M(85, 86) = ( M(85, 86) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 46) * M(46, 87)
      temp = temp + M(85, 49) * M(49, 87)
      temp = temp + M(85, 55) * M(55, 87)
      temp = temp + M(85, 58) * M(58, 87)
      temp = temp + M(85, 59) * M(59, 87)
      temp = temp + M(85, 60) * M(60, 87)
      temp = temp + M(85, 63) * M(63, 87)
      temp = temp + M(85, 64) * M(64, 87)
      temp = temp + M(85, 71) * M(71, 87)
      temp = temp + M(85, 72) * M(72, 87)
      temp = temp + M(85, 73) * M(73, 87)
      temp = temp + M(85, 74) * M(74, 87)
      temp = temp + M(85, 83) * M(83, 87)
      temp = temp + M(85, 84) * M(84, 87)
      M(85, 87) = ( M(85, 87) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 46) * M(46, 88)
      temp = temp + M(85, 49) * M(49, 88)
      temp = temp + M(85, 55) * M(55, 88)
      temp = temp + M(85, 58) * M(58, 88)
      temp = temp + M(85, 59) * M(59, 88)
      temp = temp + M(85, 60) * M(60, 88)
      temp = temp + M(85, 71) * M(71, 88)
      temp = temp + M(85, 72) * M(72, 88)
      temp = temp + M(85, 73) * M(73, 88)
      temp = temp + M(85, 74) * M(74, 88)
      temp = temp + M(85, 83) * M(83, 88)
      temp = temp + M(85, 84) * M(84, 88)
      M(85, 88) = ( M(85, 88) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 84) * M(84, 89)
      M(85, 89) = ( M(85, 89) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 84) * M(84, 90)
      M(85, 90) = ( M(85, 90) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 44) * M(44, 91)
      temp = temp + M(85, 46) * M(46, 91)
      temp = temp + M(85, 49) * M(49, 91)
      temp = temp + M(85, 55) * M(55, 91)
      temp = temp + M(85, 58) * M(58, 91)
      temp = temp + M(85, 59) * M(59, 91)
      temp = temp + M(85, 60) * M(60, 91)
      temp = temp + M(85, 71) * M(71, 91)
      temp = temp + M(85, 72) * M(72, 91)
      temp = temp + M(85, 73) * M(73, 91)
      temp = temp + M(85, 74) * M(74, 91)
      temp = temp + M(85, 83) * M(83, 91)
      temp = temp + M(85, 84) * M(84, 91)
      M(85, 91) = ( M(85, 91) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 42) * M(42, 92)
      temp = temp + M(85, 43) * M(43, 92)
      temp = temp + M(85, 44) * M(44, 92)
      temp = temp + M(85, 63) * M(63, 92)
      temp = temp + M(85, 64) * M(64, 92)
      temp = temp + M(85, 73) * M(73, 92)
      temp = temp + M(85, 74) * M(74, 92)
      temp = temp + M(85, 83) * M(83, 92)
      temp = temp + M(85, 84) * M(84, 92)
      M(85, 92) = ( M(85, 92) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 84) * M(84, 93)
      M(85, 93) = ( M(85, 93) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 64) * M(64, 94)
      temp = temp + M(85, 71) * M(71, 94)
      temp = temp + M(85, 72) * M(72, 94)
      temp = temp + M(85, 73) * M(73, 94)
      temp = temp + M(85, 74) * M(74, 94)
      temp = temp + M(85, 83) * M(83, 94)
      temp = temp + M(85, 84) * M(84, 94)
      M(85, 94) = ( M(85, 94) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 83) * M(83, 95)
      temp = temp + M(85, 84) * M(84, 95)
      M(85, 95) = ( M(85, 95) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 42) * M(42, 96)
      temp = temp + M(85, 43) * M(43, 96)
      temp = temp + M(85, 63) * M(63, 96)
      temp = temp + M(85, 64) * M(64, 96)
      temp = temp + M(85, 73) * M(73, 96)
      temp = temp + M(85, 74) * M(74, 96)
      temp = temp + M(85, 83) * M(83, 96)
      temp = temp + M(85, 84) * M(84, 96)
      M(85, 96) = ( M(85, 96) - temp ) / M(85, 85)

C     Lower part.
      temp = M(86, 5) * M(5, 86)
      temp = temp + M(86, 6) * M(6, 86)
      temp = temp + M(86, 7) * M(7, 86)
      temp = temp + M(86, 8) * M(8, 86)
      temp = temp + M(86, 9) * M(9, 86)
      temp = temp + M(86, 10) * M(10, 86)
      temp = temp + M(86, 12) * M(12, 86)
      temp = temp + M(86, 23) * M(23, 86)
      temp = temp + M(86, 36) * M(36, 86)
      temp = temp + M(86, 38) * M(38, 86)
      temp = temp + M(86, 40) * M(40, 86)
      temp = temp + M(86, 41) * M(41, 86)
      temp = temp + M(86, 43) * M(43, 86)
      temp = temp + M(86, 44) * M(44, 86)
      temp = temp + M(86, 45) * M(45, 86)
      temp = temp + M(86, 46) * M(46, 86)
      temp = temp + M(86, 49) * M(49, 86)
      temp = temp + M(86, 55) * M(55, 86)
      temp = temp + M(86, 56) * M(56, 86)
      temp = temp + M(86, 58) * M(58, 86)
      temp = temp + M(86, 59) * M(59, 86)
      temp = temp + M(86, 60) * M(60, 86)
      temp = temp + M(86, 61) * M(61, 86)
      temp = temp + M(86, 62) * M(62, 86)
      temp = temp + M(86, 63) * M(63, 86)
      temp = temp + M(86, 64) * M(64, 86)
      temp = temp + M(86, 71) * M(71, 86)
      temp = temp + M(86, 72) * M(72, 86)
      temp = temp + M(86, 73) * M(73, 86)
      temp = temp + M(86, 74) * M(74, 86)
      temp = temp + M(86, 75) * M(75, 86)
      temp = temp + M(86, 76) * M(76, 86)
      temp = temp + M(86, 77) * M(77, 86)
      temp = temp + M(86, 79) * M(79, 86)
      temp = temp + M(86, 83) * M(83, 86)
      temp = temp + M(86, 84) * M(84, 86)
      temp = temp + M(86, 85) * M(85, 86)
      M(86, 86) = M(86, 86) - temp
C     Lower part.
      temp = M(87, 36) * M(36, 86)
      temp = temp + M(87, 46) * M(46, 86)
      temp = temp + M(87, 49) * M(49, 86)
      temp = temp + M(87, 55) * M(55, 86)
      temp = temp + M(87, 58) * M(58, 86)
      temp = temp + M(87, 59) * M(59, 86)
      temp = temp + M(87, 60) * M(60, 86)
      temp = temp + M(87, 63) * M(63, 86)
      temp = temp + M(87, 64) * M(64, 86)
      temp = temp + M(87, 71) * M(71, 86)
      temp = temp + M(87, 72) * M(72, 86)
      temp = temp + M(87, 75) * M(75, 86)
      temp = temp + M(87, 79) * M(79, 86)
      temp = temp + M(87, 83) * M(83, 86)
      temp = temp + M(87, 85) * M(85, 86)
      M(87, 86) = M(87, 86) - temp
C     Lower part.
      temp = M(88, 40) * M(40, 86)
      temp = temp + M(88, 46) * M(46, 86)
      temp = temp + M(88, 49) * M(49, 86)
      temp = temp + M(88, 55) * M(55, 86)
      temp = temp + M(88, 58) * M(58, 86)
      temp = temp + M(88, 59) * M(59, 86)
      temp = temp + M(88, 60) * M(60, 86)
      temp = temp + M(88, 71) * M(71, 86)
      temp = temp + M(88, 75) * M(75, 86)
      temp = temp + M(88, 83) * M(83, 86)
      temp = temp + M(88, 85) * M(85, 86)
      M(88, 86) = M(88, 86) - temp
C     Lower part.
      temp = M(89, 5) * M(5, 86)
      temp = temp + M(89, 7) * M(7, 86)
      temp = temp + M(89, 38) * M(38, 86)
      temp = temp + M(89, 39) * M(39, 86)
      temp = temp + M(89, 58) * M(58, 86)
      temp = temp + M(89, 59) * M(59, 86)
      temp = temp + M(89, 61) * M(61, 86)
      temp = temp + M(89, 72) * M(72, 86)
      temp = temp + M(89, 73) * M(73, 86)
      temp = temp + M(89, 74) * M(74, 86)
      temp = temp + M(89, 83) * M(83, 86)
      temp = temp + M(89, 84) * M(84, 86)
      temp = temp + M(89, 85) * M(85, 86)
      M(89, 86) = M(89, 86) - temp
C     Lower part.
      temp = M(90, 38) * M(38, 86)
      temp = temp + M(90, 46) * M(46, 86)
      temp = temp + M(90, 49) * M(49, 86)
      temp = temp + M(90, 60) * M(60, 86)
      temp = temp + M(90, 71) * M(71, 86)
      temp = temp + M(90, 72) * M(72, 86)
      temp = temp + M(90, 75) * M(75, 86)
      temp = temp + M(90, 83) * M(83, 86)
      M(90, 86) = M(90, 86) - temp
C     Lower part.
      temp = M(91, 44) * M(44, 86)
      temp = temp + M(91, 46) * M(46, 86)
      temp = temp + M(91, 49) * M(49, 86)
      temp = temp + M(91, 55) * M(55, 86)
      temp = temp + M(91, 58) * M(58, 86)
      temp = temp + M(91, 59) * M(59, 86)
      temp = temp + M(91, 60) * M(60, 86)
      temp = temp + M(91, 63) * M(63, 86)
      temp = temp + M(91, 64) * M(64, 86)
      temp = temp + M(91, 71) * M(71, 86)
      temp = temp + M(91, 72) * M(72, 86)
      M(91, 86) = M(91, 86) - temp
C     Lower part.
      temp = M(92, 24) * M(24, 86)
      temp = temp + M(92, 41) * M(41, 86)
      temp = temp + M(92, 71) * M(71, 86)
      temp = temp + M(92, 83) * M(83, 86)
      temp = temp + M(92, 84) * M(84, 86)
      temp = temp + M(92, 85) * M(85, 86)
      M(92, 86) = M(92, 86) - temp
C     Lower part.
      temp = M(93, 44) * M(44, 86)
      temp = temp + M(93, 45) * M(45, 86)
      temp = temp + M(93, 62) * M(62, 86)
      temp = temp + M(93, 63) * M(63, 86)
      temp = temp + M(93, 64) * M(64, 86)
      temp = temp + M(93, 72) * M(72, 86)
      temp = temp + M(93, 84) * M(84, 86)
      temp = temp + M(93, 85) * M(85, 86)
      M(93, 86) = M(93, 86) - temp
C     Lower part.
      temp = M(94, 24) * M(24, 86)
      temp = temp + M(94, 36) * M(36, 86)
      temp = temp + M(94, 38) * M(38, 86)
      temp = temp + M(94, 39) * M(39, 86)
      temp = temp + M(94, 41) * M(41, 86)
      temp = temp + M(94, 46) * M(46, 86)
      temp = temp + M(94, 49) * M(49, 86)
      temp = temp + M(94, 55) * M(55, 86)
      temp = temp + M(94, 58) * M(58, 86)
      temp = temp + M(94, 59) * M(59, 86)
      temp = temp + M(94, 60) * M(60, 86)
      temp = temp + M(94, 64) * M(64, 86)
      temp = temp + M(94, 71) * M(71, 86)
      temp = temp + M(94, 73) * M(73, 86)
      temp = temp + M(94, 74) * M(74, 86)
      temp = temp + M(94, 79) * M(79, 86)
      temp = temp + M(94, 83) * M(83, 86)
      temp = temp + M(94, 84) * M(84, 86)
      temp = temp + M(94, 85) * M(85, 86)
      M(94, 86) = M(94, 86) - temp
C     Lower part.
      temp = M(95, 5) * M(5, 86)
      temp = temp + M(95, 7) * M(7, 86)
      temp = temp + M(95, 8) * M(8, 86)
      temp = temp + M(95, 9) * M(9, 86)
      temp = temp + M(95, 12) * M(12, 86)
      temp = temp + M(95, 39) * M(39, 86)
      temp = temp + M(95, 43) * M(43, 86)
      temp = temp + M(95, 44) * M(44, 86)
      temp = temp + M(95, 45) * M(45, 86)
      temp = temp + M(95, 46) * M(46, 86)
      temp = temp + M(95, 49) * M(49, 86)
      temp = temp + M(95, 55) * M(55, 86)
      temp = temp + M(95, 58) * M(58, 86)
      temp = temp + M(95, 59) * M(59, 86)
      temp = temp + M(95, 60) * M(60, 86)
      temp = temp + M(95, 61) * M(61, 86)
      temp = temp + M(95, 63) * M(63, 86)
      temp = temp + M(95, 64) * M(64, 86)
      temp = temp + M(95, 71) * M(71, 86)
      temp = temp + M(95, 72) * M(72, 86)
      temp = temp + M(95, 74) * M(74, 86)
      temp = temp + M(95, 83) * M(83, 86)
      temp = temp + M(95, 84) * M(84, 86)
      temp = temp + M(95, 85) * M(85, 86)
      M(95, 86) = M(95, 86) - temp
C     Lower part.
      temp = M(96, 5) * M(5, 86)
      temp = temp + M(96, 7) * M(7, 86)
      temp = temp + M(96, 8) * M(8, 86)
      temp = temp + M(96, 9) * M(9, 86)
      temp = temp + M(96, 10) * M(10, 86)
      temp = temp + M(96, 12) * M(12, 86)
      temp = temp + M(96, 23) * M(23, 86)
      temp = temp + M(96, 24) * M(24, 86)
      temp = temp + M(96, 36) * M(36, 86)
      temp = temp + M(96, 39) * M(39, 86)
      temp = temp + M(96, 40) * M(40, 86)
      temp = temp + M(96, 43) * M(43, 86)
      temp = temp + M(96, 44) * M(44, 86)
      temp = temp + M(96, 45) * M(45, 86)
      temp = temp + M(96, 46) * M(46, 86)
      temp = temp + M(96, 49) * M(49, 86)
      temp = temp + M(96, 55) * M(55, 86)
      temp = temp + M(96, 56) * M(56, 86)
      temp = temp + M(96, 58) * M(58, 86)
      temp = temp + M(96, 59) * M(59, 86)
      temp = temp + M(96, 60) * M(60, 86)
      temp = temp + M(96, 61) * M(61, 86)
      temp = temp + M(96, 63) * M(63, 86)
      temp = temp + M(96, 64) * M(64, 86)
      temp = temp + M(96, 71) * M(71, 86)
      temp = temp + M(96, 72) * M(72, 86)
      temp = temp + M(96, 73) * M(73, 86)
      temp = temp + M(96, 74) * M(74, 86)
      temp = temp + M(96, 75) * M(75, 86)
      temp = temp + M(96, 77) * M(77, 86)
      temp = temp + M(96, 83) * M(83, 86)
      temp = temp + M(96, 84) * M(84, 86)
      temp = temp + M(96, 85) * M(85, 86)
      M(96, 86) = M(96, 86) - temp
C     Upper part.
      temp = M(86, 46) * M(46, 87)
      temp = temp + M(86, 49) * M(49, 87)
      temp = temp + M(86, 55) * M(55, 87)
      temp = temp + M(86, 56) * M(56, 87)
      temp = temp + M(86, 58) * M(58, 87)
      temp = temp + M(86, 59) * M(59, 87)
      temp = temp + M(86, 60) * M(60, 87)
      temp = temp + M(86, 63) * M(63, 87)
      temp = temp + M(86, 64) * M(64, 87)
      temp = temp + M(86, 71) * M(71, 87)
      temp = temp + M(86, 72) * M(72, 87)
      temp = temp + M(86, 73) * M(73, 87)
      temp = temp + M(86, 74) * M(74, 87)
      temp = temp + M(86, 75) * M(75, 87)
      temp = temp + M(86, 77) * M(77, 87)
      temp = temp + M(86, 79) * M(79, 87)
      temp = temp + M(86, 83) * M(83, 87)
      temp = temp + M(86, 84) * M(84, 87)
      temp = temp + M(86, 85) * M(85, 87)
      M(86, 87) = ( M(86, 87) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 40) * M(40, 88)
      temp = temp + M(86, 46) * M(46, 88)
      temp = temp + M(86, 49) * M(49, 88)
      temp = temp + M(86, 55) * M(55, 88)
      temp = temp + M(86, 56) * M(56, 88)
      temp = temp + M(86, 58) * M(58, 88)
      temp = temp + M(86, 59) * M(59, 88)
      temp = temp + M(86, 60) * M(60, 88)
      temp = temp + M(86, 71) * M(71, 88)
      temp = temp + M(86, 72) * M(72, 88)
      temp = temp + M(86, 73) * M(73, 88)
      temp = temp + M(86, 74) * M(74, 88)
      temp = temp + M(86, 75) * M(75, 88)
      temp = temp + M(86, 77) * M(77, 88)
      temp = temp + M(86, 79) * M(79, 88)
      temp = temp + M(86, 83) * M(83, 88)
      temp = temp + M(86, 84) * M(84, 88)
      temp = temp + M(86, 85) * M(85, 88)
      M(86, 88) = ( M(86, 88) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 89)
      temp = temp + M(86, 79) * M(79, 89)
      temp = temp + M(86, 84) * M(84, 89)
      temp = temp + M(86, 85) * M(85, 89)
      M(86, 89) = ( M(86, 89) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 38) * M(38, 90)
      temp = temp + M(86, 62) * M(62, 90)
      temp = temp + M(86, 76) * M(76, 90)
      temp = temp + M(86, 84) * M(84, 90)
      temp = temp + M(86, 85) * M(85, 90)
      M(86, 90) = ( M(86, 90) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 4) * M(4, 91)
      temp = temp + M(86, 44) * M(44, 91)
      temp = temp + M(86, 45) * M(45, 91)
      temp = temp + M(86, 46) * M(46, 91)
      temp = temp + M(86, 49) * M(49, 91)
      temp = temp + M(86, 55) * M(55, 91)
      temp = temp + M(86, 56) * M(56, 91)
      temp = temp + M(86, 58) * M(58, 91)
      temp = temp + M(86, 59) * M(59, 91)
      temp = temp + M(86, 60) * M(60, 91)
      temp = temp + M(86, 71) * M(71, 91)
      temp = temp + M(86, 72) * M(72, 91)
      temp = temp + M(86, 73) * M(73, 91)
      temp = temp + M(86, 74) * M(74, 91)
      temp = temp + M(86, 75) * M(75, 91)
      temp = temp + M(86, 77) * M(77, 91)
      temp = temp + M(86, 79) * M(79, 91)
      temp = temp + M(86, 83) * M(83, 91)
      temp = temp + M(86, 84) * M(84, 91)
      temp = temp + M(86, 85) * M(85, 91)
      M(86, 91) = ( M(86, 91) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 41) * M(41, 92)
      temp = temp + M(86, 43) * M(43, 92)
      temp = temp + M(86, 44) * M(44, 92)
      temp = temp + M(86, 45) * M(45, 92)
      temp = temp + M(86, 56) * M(56, 92)
      temp = temp + M(86, 63) * M(63, 92)
      temp = temp + M(86, 64) * M(64, 92)
      temp = temp + M(86, 73) * M(73, 92)
      temp = temp + M(86, 74) * M(74, 92)
      temp = temp + M(86, 75) * M(75, 92)
      temp = temp + M(86, 77) * M(77, 92)
      temp = temp + M(86, 79) * M(79, 92)
      temp = temp + M(86, 83) * M(83, 92)
      temp = temp + M(86, 84) * M(84, 92)
      temp = temp + M(86, 85) * M(85, 92)
      M(86, 92) = ( M(86, 92) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 62) * M(62, 93)
      temp = temp + M(86, 76) * M(76, 93)
      temp = temp + M(86, 84) * M(84, 93)
      temp = temp + M(86, 85) * M(85, 93)
      M(86, 93) = ( M(86, 93) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 36) * M(36, 94)
      temp = temp + M(86, 38) * M(38, 94)
      temp = temp + M(86, 41) * M(41, 94)
      temp = temp + M(86, 64) * M(64, 94)
      temp = temp + M(86, 71) * M(71, 94)
      temp = temp + M(86, 72) * M(72, 94)
      temp = temp + M(86, 73) * M(73, 94)
      temp = temp + M(86, 74) * M(74, 94)
      temp = temp + M(86, 75) * M(75, 94)
      temp = temp + M(86, 77) * M(77, 94)
      temp = temp + M(86, 79) * M(79, 94)
      temp = temp + M(86, 83) * M(83, 94)
      temp = temp + M(86, 84) * M(84, 94)
      temp = temp + M(86, 85) * M(85, 94)
      M(86, 94) = ( M(86, 94) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 61) * M(61, 95)
      temp = temp + M(86, 75) * M(75, 95)
      temp = temp + M(86, 76) * M(76, 95)
      temp = temp + M(86, 77) * M(77, 95)
      temp = temp + M(86, 79) * M(79, 95)
      temp = temp + M(86, 83) * M(83, 95)
      temp = temp + M(86, 84) * M(84, 95)
      temp = temp + M(86, 85) * M(85, 95)
      M(86, 95) = ( M(86, 95) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 36) * M(36, 96)
      temp = temp + M(86, 40) * M(40, 96)
      temp = temp + M(86, 43) * M(43, 96)
      temp = temp + M(86, 56) * M(56, 96)
      temp = temp + M(86, 61) * M(61, 96)
      temp = temp + M(86, 62) * M(62, 96)
      temp = temp + M(86, 63) * M(63, 96)
      temp = temp + M(86, 64) * M(64, 96)
      temp = temp + M(86, 73) * M(73, 96)
      temp = temp + M(86, 74) * M(74, 96)
      temp = temp + M(86, 75) * M(75, 96)
      temp = temp + M(86, 76) * M(76, 96)
      temp = temp + M(86, 77) * M(77, 96)
      temp = temp + M(86, 79) * M(79, 96)
      temp = temp + M(86, 83) * M(83, 96)
      temp = temp + M(86, 84) * M(84, 96)
      temp = temp + M(86, 85) * M(85, 96)
      M(86, 96) = ( M(86, 96) - temp ) / M(86, 86)

C     Lower part.
      temp = M(87, 25) * M(25, 87)
      temp = temp + M(87, 46) * M(46, 87)
      temp = temp + M(87, 49) * M(49, 87)
      temp = temp + M(87, 55) * M(55, 87)
      temp = temp + M(87, 58) * M(58, 87)
      temp = temp + M(87, 59) * M(59, 87)
      temp = temp + M(87, 60) * M(60, 87)
      temp = temp + M(87, 63) * M(63, 87)
      temp = temp + M(87, 64) * M(64, 87)
      temp = temp + M(87, 71) * M(71, 87)
      temp = temp + M(87, 72) * M(72, 87)
      temp = temp + M(87, 75) * M(75, 87)
      temp = temp + M(87, 79) * M(79, 87)
      temp = temp + M(87, 83) * M(83, 87)
      temp = temp + M(87, 85) * M(85, 87)
      temp = temp + M(87, 86) * M(86, 87)
      M(87, 87) = M(87, 87) - temp
C     Lower part.
      temp = M(88, 46) * M(46, 87)
      temp = temp + M(88, 49) * M(49, 87)
      temp = temp + M(88, 55) * M(55, 87)
      temp = temp + M(88, 58) * M(58, 87)
      temp = temp + M(88, 59) * M(59, 87)
      temp = temp + M(88, 60) * M(60, 87)
      temp = temp + M(88, 71) * M(71, 87)
      temp = temp + M(88, 75) * M(75, 87)
      temp = temp + M(88, 83) * M(83, 87)
      temp = temp + M(88, 85) * M(85, 87)
      temp = temp + M(88, 86) * M(86, 87)
      M(88, 87) = M(88, 87) - temp
C     Lower part.
      temp = M(89, 58) * M(58, 87)
      temp = temp + M(89, 59) * M(59, 87)
      temp = temp + M(89, 72) * M(72, 87)
      temp = temp + M(89, 73) * M(73, 87)
      temp = temp + M(89, 74) * M(74, 87)
      temp = temp + M(89, 83) * M(83, 87)
      temp = temp + M(89, 84) * M(84, 87)
      temp = temp + M(89, 85) * M(85, 87)
      temp = temp + M(89, 86) * M(86, 87)
      M(89, 87) = M(89, 87) - temp
C     Lower part.
      temp = M(90, 46) * M(46, 87)
      temp = temp + M(90, 49) * M(49, 87)
      temp = temp + M(90, 60) * M(60, 87)
      temp = temp + M(90, 71) * M(71, 87)
      temp = temp + M(90, 72) * M(72, 87)
      temp = temp + M(90, 75) * M(75, 87)
      temp = temp + M(90, 83) * M(83, 87)
      temp = temp + M(90, 86) * M(86, 87)
      M(90, 87) = M(90, 87) - temp
C     Lower part.
      temp = M(91, 46) * M(46, 87)
      temp = temp + M(91, 49) * M(49, 87)
      temp = temp + M(91, 55) * M(55, 87)
      temp = temp + M(91, 58) * M(58, 87)
      temp = temp + M(91, 59) * M(59, 87)
      temp = temp + M(91, 60) * M(60, 87)
      temp = temp + M(91, 63) * M(63, 87)
      temp = temp + M(91, 64) * M(64, 87)
      temp = temp + M(91, 71) * M(71, 87)
      temp = temp + M(91, 72) * M(72, 87)
      temp = temp + M(91, 86) * M(86, 87)
      M(91, 87) = M(91, 87) - temp
C     Lower part.
      temp = M(92, 71) * M(71, 87)
      temp = temp + M(92, 83) * M(83, 87)
      temp = temp + M(92, 84) * M(84, 87)
      temp = temp + M(92, 85) * M(85, 87)
      temp = temp + M(92, 86) * M(86, 87)
      M(92, 87) = M(92, 87) - temp
C     Lower part.
      temp = M(93, 63) * M(63, 87)
      temp = temp + M(93, 64) * M(64, 87)
      temp = temp + M(93, 72) * M(72, 87)
      temp = temp + M(93, 84) * M(84, 87)
      temp = temp + M(93, 85) * M(85, 87)
      temp = temp + M(93, 86) * M(86, 87)
      M(93, 87) = M(93, 87) - temp
C     Lower part.
      temp = M(94, 25) * M(25, 87)
      temp = temp + M(94, 46) * M(46, 87)
      temp = temp + M(94, 49) * M(49, 87)
      temp = temp + M(94, 55) * M(55, 87)
      temp = temp + M(94, 58) * M(58, 87)
      temp = temp + M(94, 59) * M(59, 87)
      temp = temp + M(94, 60) * M(60, 87)
      temp = temp + M(94, 64) * M(64, 87)
      temp = temp + M(94, 71) * M(71, 87)
      temp = temp + M(94, 73) * M(73, 87)
      temp = temp + M(94, 74) * M(74, 87)
      temp = temp + M(94, 79) * M(79, 87)
      temp = temp + M(94, 83) * M(83, 87)
      temp = temp + M(94, 84) * M(84, 87)
      temp = temp + M(94, 85) * M(85, 87)
      temp = temp + M(94, 86) * M(86, 87)
      M(94, 87) = M(94, 87) - temp
C     Lower part.
      temp = M(95, 46) * M(46, 87)
      temp = temp + M(95, 49) * M(49, 87)
      temp = temp + M(95, 55) * M(55, 87)
      temp = temp + M(95, 58) * M(58, 87)
      temp = temp + M(95, 59) * M(59, 87)
      temp = temp + M(95, 60) * M(60, 87)
      temp = temp + M(95, 63) * M(63, 87)
      temp = temp + M(95, 64) * M(64, 87)
      temp = temp + M(95, 71) * M(71, 87)
      temp = temp + M(95, 72) * M(72, 87)
      temp = temp + M(95, 74) * M(74, 87)
      temp = temp + M(95, 83) * M(83, 87)
      temp = temp + M(95, 84) * M(84, 87)
      temp = temp + M(95, 85) * M(85, 87)
      temp = temp + M(95, 86) * M(86, 87)
      M(95, 87) = M(95, 87) - temp
C     Lower part.
      temp = M(96, 46) * M(46, 87)
      temp = temp + M(96, 49) * M(49, 87)
      temp = temp + M(96, 55) * M(55, 87)
      temp = temp + M(96, 56) * M(56, 87)
      temp = temp + M(96, 58) * M(58, 87)
      temp = temp + M(96, 59) * M(59, 87)
      temp = temp + M(96, 60) * M(60, 87)
      temp = temp + M(96, 63) * M(63, 87)
      temp = temp + M(96, 64) * M(64, 87)
      temp = temp + M(96, 71) * M(71, 87)
      temp = temp + M(96, 72) * M(72, 87)
      temp = temp + M(96, 73) * M(73, 87)
      temp = temp + M(96, 74) * M(74, 87)
      temp = temp + M(96, 75) * M(75, 87)
      temp = temp + M(96, 77) * M(77, 87)
      temp = temp + M(96, 83) * M(83, 87)
      temp = temp + M(96, 84) * M(84, 87)
      temp = temp + M(96, 85) * M(85, 87)
      temp = temp + M(96, 86) * M(86, 87)
      M(96, 87) = M(96, 87) - temp
C     Upper part.
      temp = M(87, 46) * M(46, 88)
      temp = temp + M(87, 49) * M(49, 88)
      temp = temp + M(87, 55) * M(55, 88)
      temp = temp + M(87, 58) * M(58, 88)
      temp = temp + M(87, 59) * M(59, 88)
      temp = temp + M(87, 60) * M(60, 88)
      temp = temp + M(87, 71) * M(71, 88)
      temp = temp + M(87, 72) * M(72, 88)
      temp = temp + M(87, 75) * M(75, 88)
      temp = temp + M(87, 79) * M(79, 88)
      temp = temp + M(87, 83) * M(83, 88)
      temp = temp + M(87, 85) * M(85, 88)
      temp = temp + M(87, 86) * M(86, 88)
      M(87, 88) = ( M(87, 88) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 79) * M(79, 89)
      temp = temp + M(87, 85) * M(85, 89)
      temp = temp + M(87, 86) * M(86, 89)
      M(87, 89) = ( M(87, 89) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 90)
      temp = temp + M(87, 86) * M(86, 90)
      M(87, 90) = ( M(87, 90) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 46) * M(46, 91)
      temp = temp + M(87, 49) * M(49, 91)
      temp = temp + M(87, 55) * M(55, 91)
      temp = temp + M(87, 58) * M(58, 91)
      temp = temp + M(87, 59) * M(59, 91)
      temp = temp + M(87, 60) * M(60, 91)
      temp = temp + M(87, 71) * M(71, 91)
      temp = temp + M(87, 72) * M(72, 91)
      temp = temp + M(87, 75) * M(75, 91)
      temp = temp + M(87, 79) * M(79, 91)
      temp = temp + M(87, 83) * M(83, 91)
      temp = temp + M(87, 85) * M(85, 91)
      temp = temp + M(87, 86) * M(86, 91)
      M(87, 91) = ( M(87, 91) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 63) * M(63, 92)
      temp = temp + M(87, 64) * M(64, 92)
      temp = temp + M(87, 75) * M(75, 92)
      temp = temp + M(87, 79) * M(79, 92)
      temp = temp + M(87, 83) * M(83, 92)
      temp = temp + M(87, 85) * M(85, 92)
      temp = temp + M(87, 86) * M(86, 92)
      M(87, 92) = ( M(87, 92) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 93)
      temp = temp + M(87, 86) * M(86, 93)
      M(87, 93) = ( M(87, 93) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 25) * M(25, 94)
      temp = temp + M(87, 36) * M(36, 94)
      temp = temp + M(87, 64) * M(64, 94)
      temp = temp + M(87, 71) * M(71, 94)
      temp = temp + M(87, 72) * M(72, 94)
      temp = temp + M(87, 75) * M(75, 94)
      temp = temp + M(87, 79) * M(79, 94)
      temp = temp + M(87, 83) * M(83, 94)
      temp = temp + M(87, 85) * M(85, 94)
      temp = temp + M(87, 86) * M(86, 94)
      M(87, 94) = ( M(87, 94) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 75) * M(75, 95)
      temp = temp + M(87, 79) * M(79, 95)
      temp = temp + M(87, 83) * M(83, 95)
      temp = temp + M(87, 85) * M(85, 95)
      temp = temp + M(87, 86) * M(86, 95)
      M(87, 95) = ( M(87, 95) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 36) * M(36, 96)
      temp = temp + M(87, 63) * M(63, 96)
      temp = temp + M(87, 64) * M(64, 96)
      temp = temp + M(87, 75) * M(75, 96)
      temp = temp + M(87, 79) * M(79, 96)
      temp = temp + M(87, 83) * M(83, 96)
      temp = temp + M(87, 85) * M(85, 96)
      temp = temp + M(87, 86) * M(86, 96)
      M(87, 96) = ( M(87, 96) - temp ) / M(87, 87)

C     Lower part.
      temp = M(88, 40) * M(40, 88)
      temp = temp + M(88, 46) * M(46, 88)
      temp = temp + M(88, 49) * M(49, 88)
      temp = temp + M(88, 55) * M(55, 88)
      temp = temp + M(88, 58) * M(58, 88)
      temp = temp + M(88, 59) * M(59, 88)
      temp = temp + M(88, 60) * M(60, 88)
      temp = temp + M(88, 71) * M(71, 88)
      temp = temp + M(88, 75) * M(75, 88)
      temp = temp + M(88, 83) * M(83, 88)
      temp = temp + M(88, 85) * M(85, 88)
      temp = temp + M(88, 86) * M(86, 88)
      temp = temp + M(88, 87) * M(87, 88)
      M(88, 88) = M(88, 88) - temp
C     Lower part.
      temp = M(89, 58) * M(58, 88)
      temp = temp + M(89, 59) * M(59, 88)
      temp = temp + M(89, 72) * M(72, 88)
      temp = temp + M(89, 73) * M(73, 88)
      temp = temp + M(89, 74) * M(74, 88)
      temp = temp + M(89, 83) * M(83, 88)
      temp = temp + M(89, 84) * M(84, 88)
      temp = temp + M(89, 85) * M(85, 88)
      temp = temp + M(89, 86) * M(86, 88)
      temp = temp + M(89, 87) * M(87, 88)
      M(89, 88) = M(89, 88) - temp
C     Lower part.
      temp = M(90, 46) * M(46, 88)
      temp = temp + M(90, 49) * M(49, 88)
      temp = temp + M(90, 60) * M(60, 88)
      temp = temp + M(90, 71) * M(71, 88)
      temp = temp + M(90, 72) * M(72, 88)
      temp = temp + M(90, 75) * M(75, 88)
      temp = temp + M(90, 83) * M(83, 88)
      temp = temp + M(90, 86) * M(86, 88)
      temp = temp + M(90, 87) * M(87, 88)
      M(90, 88) = M(90, 88) - temp
C     Lower part.
      temp = M(91, 46) * M(46, 88)
      temp = temp + M(91, 49) * M(49, 88)
      temp = temp + M(91, 55) * M(55, 88)
      temp = temp + M(91, 58) * M(58, 88)
      temp = temp + M(91, 59) * M(59, 88)
      temp = temp + M(91, 60) * M(60, 88)
      temp = temp + M(91, 71) * M(71, 88)
      temp = temp + M(91, 72) * M(72, 88)
      temp = temp + M(91, 86) * M(86, 88)
      temp = temp + M(91, 87) * M(87, 88)
      M(91, 88) = M(91, 88) - temp
C     Lower part.
      temp = M(92, 71) * M(71, 88)
      temp = temp + M(92, 83) * M(83, 88)
      temp = temp + M(92, 84) * M(84, 88)
      temp = temp + M(92, 85) * M(85, 88)
      temp = temp + M(92, 86) * M(86, 88)
      temp = temp + M(92, 87) * M(87, 88)
      M(92, 88) = M(92, 88) - temp
C     Lower part.
      temp = M(93, 72) * M(72, 88)
      temp = temp + M(93, 84) * M(84, 88)
      temp = temp + M(93, 85) * M(85, 88)
      temp = temp + M(93, 86) * M(86, 88)
      temp = temp + M(93, 87) * M(87, 88)
      M(93, 88) = M(93, 88) - temp
C     Lower part.
      temp = M(94, 46) * M(46, 88)
      temp = temp + M(94, 49) * M(49, 88)
      temp = temp + M(94, 55) * M(55, 88)
      temp = temp + M(94, 58) * M(58, 88)
      temp = temp + M(94, 59) * M(59, 88)
      temp = temp + M(94, 60) * M(60, 88)
      temp = temp + M(94, 71) * M(71, 88)
      temp = temp + M(94, 73) * M(73, 88)
      temp = temp + M(94, 74) * M(74, 88)
      temp = temp + M(94, 79) * M(79, 88)
      temp = temp + M(94, 83) * M(83, 88)
      temp = temp + M(94, 84) * M(84, 88)
      temp = temp + M(94, 85) * M(85, 88)
      temp = temp + M(94, 86) * M(86, 88)
      temp = temp + M(94, 87) * M(87, 88)
      M(94, 88) = M(94, 88) - temp
C     Lower part.
      temp = M(95, 46) * M(46, 88)
      temp = temp + M(95, 49) * M(49, 88)
      temp = temp + M(95, 55) * M(55, 88)
      temp = temp + M(95, 58) * M(58, 88)
      temp = temp + M(95, 59) * M(59, 88)
      temp = temp + M(95, 60) * M(60, 88)
      temp = temp + M(95, 71) * M(71, 88)
      temp = temp + M(95, 72) * M(72, 88)
      temp = temp + M(95, 74) * M(74, 88)
      temp = temp + M(95, 83) * M(83, 88)
      temp = temp + M(95, 84) * M(84, 88)
      temp = temp + M(95, 85) * M(85, 88)
      temp = temp + M(95, 86) * M(86, 88)
      temp = temp + M(95, 87) * M(87, 88)
      M(95, 88) = M(95, 88) - temp
C     Lower part.
      temp = M(96, 40) * M(40, 88)
      temp = temp + M(96, 46) * M(46, 88)
      temp = temp + M(96, 49) * M(49, 88)
      temp = temp + M(96, 55) * M(55, 88)
      temp = temp + M(96, 56) * M(56, 88)
      temp = temp + M(96, 58) * M(58, 88)
      temp = temp + M(96, 59) * M(59, 88)
      temp = temp + M(96, 60) * M(60, 88)
      temp = temp + M(96, 71) * M(71, 88)
      temp = temp + M(96, 72) * M(72, 88)
      temp = temp + M(96, 73) * M(73, 88)
      temp = temp + M(96, 74) * M(74, 88)
      temp = temp + M(96, 75) * M(75, 88)
      temp = temp + M(96, 77) * M(77, 88)
      temp = temp + M(96, 83) * M(83, 88)
      temp = temp + M(96, 84) * M(84, 88)
      temp = temp + M(96, 85) * M(85, 88)
      temp = temp + M(96, 86) * M(86, 88)
      temp = temp + M(96, 87) * M(87, 88)
      M(96, 88) = M(96, 88) - temp
C     Upper part.
      temp = M(88, 85) * M(85, 89)
      temp = temp + M(88, 86) * M(86, 89)
      temp = temp + M(88, 87) * M(87, 89)
      M(88, 89) = ( M(88, 89) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 85) * M(85, 90)
      temp = temp + M(88, 86) * M(86, 90)
      temp = temp + M(88, 87) * M(87, 90)
      M(88, 90) = ( M(88, 90) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 4) * M(4, 91)
      temp = temp + M(88, 46) * M(46, 91)
      temp = temp + M(88, 49) * M(49, 91)
      temp = temp + M(88, 55) * M(55, 91)
      temp = temp + M(88, 58) * M(58, 91)
      temp = temp + M(88, 59) * M(59, 91)
      temp = temp + M(88, 60) * M(60, 91)
      temp = temp + M(88, 71) * M(71, 91)
      temp = temp + M(88, 75) * M(75, 91)
      temp = temp + M(88, 83) * M(83, 91)
      temp = temp + M(88, 85) * M(85, 91)
      temp = temp + M(88, 86) * M(86, 91)
      temp = temp + M(88, 87) * M(87, 91)
      M(88, 91) = ( M(88, 91) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 75) * M(75, 92)
      temp = temp + M(88, 83) * M(83, 92)
      temp = temp + M(88, 85) * M(85, 92)
      temp = temp + M(88, 86) * M(86, 92)
      temp = temp + M(88, 87) * M(87, 92)
      M(88, 92) = ( M(88, 92) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 85) * M(85, 93)
      temp = temp + M(88, 86) * M(86, 93)
      temp = temp + M(88, 87) * M(87, 93)
      M(88, 93) = ( M(88, 93) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 71) * M(71, 94)
      temp = temp + M(88, 75) * M(75, 94)
      temp = temp + M(88, 83) * M(83, 94)
      temp = temp + M(88, 85) * M(85, 94)
      temp = temp + M(88, 86) * M(86, 94)
      temp = temp + M(88, 87) * M(87, 94)
      M(88, 94) = ( M(88, 94) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 75) * M(75, 95)
      temp = temp + M(88, 83) * M(83, 95)
      temp = temp + M(88, 85) * M(85, 95)
      temp = temp + M(88, 86) * M(86, 95)
      temp = temp + M(88, 87) * M(87, 95)
      M(88, 95) = ( M(88, 95) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 40) * M(40, 96)
      temp = temp + M(88, 75) * M(75, 96)
      temp = temp + M(88, 83) * M(83, 96)
      temp = temp + M(88, 85) * M(85, 96)
      temp = temp + M(88, 86) * M(86, 96)
      temp = temp + M(88, 87) * M(87, 96)
      M(88, 96) = ( M(88, 96) - temp ) / M(88, 88)

C     Lower part.
      temp = M(89, 84) * M(84, 89)
      temp = temp + M(89, 85) * M(85, 89)
      temp = temp + M(89, 86) * M(86, 89)
      temp = temp + M(89, 87) * M(87, 89)
      temp = temp + M(89, 88) * M(88, 89)
      M(89, 89) = M(89, 89) - temp
C     Lower part.
      temp = M(90, 86) * M(86, 89)
      temp = temp + M(90, 87) * M(87, 89)
      temp = temp + M(90, 88) * M(88, 89)
      M(90, 89) = M(90, 89) - temp
C     Lower part.
      temp = M(91, 86) * M(86, 89)
      temp = temp + M(91, 87) * M(87, 89)
      temp = temp + M(91, 88) * M(88, 89)
      M(91, 89) = M(91, 89) - temp
C     Lower part.
      temp = M(92, 84) * M(84, 89)
      temp = temp + M(92, 85) * M(85, 89)
      temp = temp + M(92, 86) * M(86, 89)
      temp = temp + M(92, 87) * M(87, 89)
      temp = temp + M(92, 88) * M(88, 89)
      M(92, 89) = M(92, 89) - temp
C     Lower part.
      temp = M(93, 84) * M(84, 89)
      temp = temp + M(93, 85) * M(85, 89)
      temp = temp + M(93, 86) * M(86, 89)
      temp = temp + M(93, 87) * M(87, 89)
      temp = temp + M(93, 88) * M(88, 89)
      M(93, 89) = M(93, 89) - temp
C     Lower part.
      temp = M(94, 79) * M(79, 89)
      temp = temp + M(94, 84) * M(84, 89)
      temp = temp + M(94, 85) * M(85, 89)
      temp = temp + M(94, 86) * M(86, 89)
      temp = temp + M(94, 87) * M(87, 89)
      temp = temp + M(94, 88) * M(88, 89)
      M(94, 89) = M(94, 89) - temp
C     Lower part.
      temp = M(95, 84) * M(84, 89)
      temp = temp + M(95, 85) * M(85, 89)
      temp = temp + M(95, 86) * M(86, 89)
      temp = temp + M(95, 87) * M(87, 89)
      temp = temp + M(95, 88) * M(88, 89)
      M(95, 89) = M(95, 89) - temp
C     Lower part.
      temp = M(96, 77) * M(77, 89)
      temp = temp + M(96, 84) * M(84, 89)
      temp = temp + M(96, 85) * M(85, 89)
      temp = temp + M(96, 86) * M(86, 89)
      temp = temp + M(96, 87) * M(87, 89)
      temp = temp + M(96, 88) * M(88, 89)
      M(96, 89) = M(96, 89) - temp
C     Upper part.
      temp = M(89, 38) * M(38, 90)
      temp = temp + M(89, 84) * M(84, 90)
      temp = temp + M(89, 85) * M(85, 90)
      temp = temp + M(89, 86) * M(86, 90)
      temp = temp + M(89, 87) * M(87, 90)
      temp = temp + M(89, 88) * M(88, 90)
      M(89, 90) = ( M(89, 90) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 58) * M(58, 91)
      temp = temp + M(89, 59) * M(59, 91)
      temp = temp + M(89, 72) * M(72, 91)
      temp = temp + M(89, 73) * M(73, 91)
      temp = temp + M(89, 74) * M(74, 91)
      temp = temp + M(89, 83) * M(83, 91)
      temp = temp + M(89, 84) * M(84, 91)
      temp = temp + M(89, 85) * M(85, 91)
      temp = temp + M(89, 86) * M(86, 91)
      temp = temp + M(89, 87) * M(87, 91)
      temp = temp + M(89, 88) * M(88, 91)
      M(89, 91) = ( M(89, 91) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 73) * M(73, 92)
      temp = temp + M(89, 74) * M(74, 92)
      temp = temp + M(89, 83) * M(83, 92)
      temp = temp + M(89, 84) * M(84, 92)
      temp = temp + M(89, 85) * M(85, 92)
      temp = temp + M(89, 86) * M(86, 92)
      temp = temp + M(89, 87) * M(87, 92)
      temp = temp + M(89, 88) * M(88, 92)
      M(89, 92) = ( M(89, 92) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 84) * M(84, 93)
      temp = temp + M(89, 85) * M(85, 93)
      temp = temp + M(89, 86) * M(86, 93)
      temp = temp + M(89, 87) * M(87, 93)
      temp = temp + M(89, 88) * M(88, 93)
      M(89, 93) = ( M(89, 93) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 38) * M(38, 94)
      temp = temp + M(89, 39) * M(39, 94)
      temp = temp + M(89, 72) * M(72, 94)
      temp = temp + M(89, 73) * M(73, 94)
      temp = temp + M(89, 74) * M(74, 94)
      temp = temp + M(89, 83) * M(83, 94)
      temp = temp + M(89, 84) * M(84, 94)
      temp = temp + M(89, 85) * M(85, 94)
      temp = temp + M(89, 86) * M(86, 94)
      temp = temp + M(89, 87) * M(87, 94)
      temp = temp + M(89, 88) * M(88, 94)
      M(89, 94) = ( M(89, 94) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 61) * M(61, 95)
      temp = temp + M(89, 83) * M(83, 95)
      temp = temp + M(89, 84) * M(84, 95)
      temp = temp + M(89, 85) * M(85, 95)
      temp = temp + M(89, 86) * M(86, 95)
      temp = temp + M(89, 87) * M(87, 95)
      temp = temp + M(89, 88) * M(88, 95)
      M(89, 95) = ( M(89, 95) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 61) * M(61, 96)
      temp = temp + M(89, 73) * M(73, 96)
      temp = temp + M(89, 74) * M(74, 96)
      temp = temp + M(89, 83) * M(83, 96)
      temp = temp + M(89, 84) * M(84, 96)
      temp = temp + M(89, 85) * M(85, 96)
      temp = temp + M(89, 86) * M(86, 96)
      temp = temp + M(89, 87) * M(87, 96)
      temp = temp + M(89, 88) * M(88, 96)
      M(89, 96) = ( M(89, 96) - temp ) / M(89, 89)

C     Lower part.
      temp = M(90, 38) * M(38, 90)
      temp = temp + M(90, 86) * M(86, 90)
      temp = temp + M(90, 87) * M(87, 90)
      temp = temp + M(90, 88) * M(88, 90)
      temp = temp + M(90, 89) * M(89, 90)
      M(90, 90) = M(90, 90) - temp
C     Lower part.
      temp = M(91, 86) * M(86, 90)
      temp = temp + M(91, 87) * M(87, 90)
      temp = temp + M(91, 88) * M(88, 90)
      temp = temp + M(91, 89) * M(89, 90)
      M(91, 90) = M(91, 90) - temp
C     Lower part.
      temp = M(92, 84) * M(84, 90)
      temp = temp + M(92, 85) * M(85, 90)
      temp = temp + M(92, 86) * M(86, 90)
      temp = temp + M(92, 87) * M(87, 90)
      temp = temp + M(92, 88) * M(88, 90)
      temp = temp + M(92, 89) * M(89, 90)
      M(92, 90) = M(92, 90) - temp
C     Lower part.
      temp = M(93, 62) * M(62, 90)
      temp = temp + M(93, 84) * M(84, 90)
      temp = temp + M(93, 85) * M(85, 90)
      temp = temp + M(93, 86) * M(86, 90)
      temp = temp + M(93, 87) * M(87, 90)
      temp = temp + M(93, 88) * M(88, 90)
      temp = temp + M(93, 89) * M(89, 90)
      M(93, 90) = M(93, 90) - temp
C     Lower part.
      temp = M(94, 38) * M(38, 90)
      temp = temp + M(94, 84) * M(84, 90)
      temp = temp + M(94, 85) * M(85, 90)
      temp = temp + M(94, 86) * M(86, 90)
      temp = temp + M(94, 87) * M(87, 90)
      temp = temp + M(94, 88) * M(88, 90)
      temp = temp + M(94, 89) * M(89, 90)
      M(94, 90) = M(94, 90) - temp
C     Lower part.
      temp = M(95, 84) * M(84, 90)
      temp = temp + M(95, 85) * M(85, 90)
      temp = temp + M(95, 86) * M(86, 90)
      temp = temp + M(95, 87) * M(87, 90)
      temp = temp + M(95, 88) * M(88, 90)
      temp = temp + M(95, 89) * M(89, 90)
      M(95, 90) = M(95, 90) - temp
C     Lower part.
      temp = M(96, 84) * M(84, 90)
      temp = temp + M(96, 85) * M(85, 90)
      temp = temp + M(96, 86) * M(86, 90)
      temp = temp + M(96, 87) * M(87, 90)
      temp = temp + M(96, 88) * M(88, 90)
      temp = temp + M(96, 89) * M(89, 90)
      M(96, 90) = M(96, 90) - temp
C     Upper part.
      temp = M(90, 46) * M(46, 91)
      temp = temp + M(90, 49) * M(49, 91)
      temp = temp + M(90, 60) * M(60, 91)
      temp = temp + M(90, 71) * M(71, 91)
      temp = temp + M(90, 72) * M(72, 91)
      temp = temp + M(90, 75) * M(75, 91)
      temp = temp + M(90, 83) * M(83, 91)
      temp = temp + M(90, 86) * M(86, 91)
      temp = temp + M(90, 87) * M(87, 91)
      temp = temp + M(90, 88) * M(88, 91)
      temp = temp + M(90, 89) * M(89, 91)
      M(90, 91) = ( M(90, 91) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 75) * M(75, 92)
      temp = temp + M(90, 83) * M(83, 92)
      temp = temp + M(90, 86) * M(86, 92)
      temp = temp + M(90, 87) * M(87, 92)
      temp = temp + M(90, 88) * M(88, 92)
      temp = temp + M(90, 89) * M(89, 92)
      M(90, 92) = ( M(90, 92) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 86) * M(86, 93)
      temp = temp + M(90, 87) * M(87, 93)
      temp = temp + M(90, 88) * M(88, 93)
      temp = temp + M(90, 89) * M(89, 93)
      M(90, 93) = ( M(90, 93) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 38) * M(38, 94)
      temp = temp + M(90, 71) * M(71, 94)
      temp = temp + M(90, 72) * M(72, 94)
      temp = temp + M(90, 75) * M(75, 94)
      temp = temp + M(90, 83) * M(83, 94)
      temp = temp + M(90, 86) * M(86, 94)
      temp = temp + M(90, 87) * M(87, 94)
      temp = temp + M(90, 88) * M(88, 94)
      temp = temp + M(90, 89) * M(89, 94)
      M(90, 94) = ( M(90, 94) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 75) * M(75, 95)
      temp = temp + M(90, 83) * M(83, 95)
      temp = temp + M(90, 86) * M(86, 95)
      temp = temp + M(90, 87) * M(87, 95)
      temp = temp + M(90, 88) * M(88, 95)
      temp = temp + M(90, 89) * M(89, 95)
      M(90, 95) = ( M(90, 95) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 75) * M(75, 96)
      temp = temp + M(90, 83) * M(83, 96)
      temp = temp + M(90, 86) * M(86, 96)
      temp = temp + M(90, 87) * M(87, 96)
      temp = temp + M(90, 88) * M(88, 96)
      temp = temp + M(90, 89) * M(89, 96)
      M(90, 96) = ( M(90, 96) - temp ) / M(90, 90)

C     Lower part.
      temp = M(91, 44) * M(44, 91)
      temp = temp + M(91, 46) * M(46, 91)
      temp = temp + M(91, 49) * M(49, 91)
      temp = temp + M(91, 55) * M(55, 91)
      temp = temp + M(91, 58) * M(58, 91)
      temp = temp + M(91, 59) * M(59, 91)
      temp = temp + M(91, 60) * M(60, 91)
      temp = temp + M(91, 71) * M(71, 91)
      temp = temp + M(91, 72) * M(72, 91)
      temp = temp + M(91, 86) * M(86, 91)
      temp = temp + M(91, 87) * M(87, 91)
      temp = temp + M(91, 88) * M(88, 91)
      temp = temp + M(91, 89) * M(89, 91)
      temp = temp + M(91, 90) * M(90, 91)
      M(91, 91) = M(91, 91) - temp
C     Lower part.
      temp = M(92, 71) * M(71, 91)
      temp = temp + M(92, 83) * M(83, 91)
      temp = temp + M(92, 84) * M(84, 91)
      temp = temp + M(92, 85) * M(85, 91)
      temp = temp + M(92, 86) * M(86, 91)
      temp = temp + M(92, 87) * M(87, 91)
      temp = temp + M(92, 88) * M(88, 91)
      temp = temp + M(92, 89) * M(89, 91)
      temp = temp + M(92, 90) * M(90, 91)
      M(92, 91) = M(92, 91) - temp
C     Lower part.
      temp = M(93, 44) * M(44, 91)
      temp = temp + M(93, 45) * M(45, 91)
      temp = temp + M(93, 72) * M(72, 91)
      temp = temp + M(93, 84) * M(84, 91)
      temp = temp + M(93, 85) * M(85, 91)
      temp = temp + M(93, 86) * M(86, 91)
      temp = temp + M(93, 87) * M(87, 91)
      temp = temp + M(93, 88) * M(88, 91)
      temp = temp + M(93, 89) * M(89, 91)
      temp = temp + M(93, 90) * M(90, 91)
      M(93, 91) = M(93, 91) - temp
C     Lower part.
      temp = M(94, 46) * M(46, 91)
      temp = temp + M(94, 49) * M(49, 91)
      temp = temp + M(94, 55) * M(55, 91)
      temp = temp + M(94, 58) * M(58, 91)
      temp = temp + M(94, 59) * M(59, 91)
      temp = temp + M(94, 60) * M(60, 91)
      temp = temp + M(94, 71) * M(71, 91)
      temp = temp + M(94, 73) * M(73, 91)
      temp = temp + M(94, 74) * M(74, 91)
      temp = temp + M(94, 79) * M(79, 91)
      temp = temp + M(94, 83) * M(83, 91)
      temp = temp + M(94, 84) * M(84, 91)
      temp = temp + M(94, 85) * M(85, 91)
      temp = temp + M(94, 86) * M(86, 91)
      temp = temp + M(94, 87) * M(87, 91)
      temp = temp + M(94, 88) * M(88, 91)
      temp = temp + M(94, 89) * M(89, 91)
      temp = temp + M(94, 90) * M(90, 91)
      M(94, 91) = M(94, 91) - temp
C     Lower part.
      temp = M(95, 44) * M(44, 91)
      temp = temp + M(95, 45) * M(45, 91)
      temp = temp + M(95, 46) * M(46, 91)
      temp = temp + M(95, 49) * M(49, 91)
      temp = temp + M(95, 55) * M(55, 91)
      temp = temp + M(95, 58) * M(58, 91)
      temp = temp + M(95, 59) * M(59, 91)
      temp = temp + M(95, 60) * M(60, 91)
      temp = temp + M(95, 71) * M(71, 91)
      temp = temp + M(95, 72) * M(72, 91)
      temp = temp + M(95, 74) * M(74, 91)
      temp = temp + M(95, 83) * M(83, 91)
      temp = temp + M(95, 84) * M(84, 91)
      temp = temp + M(95, 85) * M(85, 91)
      temp = temp + M(95, 86) * M(86, 91)
      temp = temp + M(95, 87) * M(87, 91)
      temp = temp + M(95, 88) * M(88, 91)
      temp = temp + M(95, 89) * M(89, 91)
      temp = temp + M(95, 90) * M(90, 91)
      M(95, 91) = M(95, 91) - temp
C     Lower part.
      temp = M(96, 4) * M(4, 91)
      temp = temp + M(96, 44) * M(44, 91)
      temp = temp + M(96, 45) * M(45, 91)
      temp = temp + M(96, 46) * M(46, 91)
      temp = temp + M(96, 49) * M(49, 91)
      temp = temp + M(96, 55) * M(55, 91)
      temp = temp + M(96, 56) * M(56, 91)
      temp = temp + M(96, 58) * M(58, 91)
      temp = temp + M(96, 59) * M(59, 91)
      temp = temp + M(96, 60) * M(60, 91)
      temp = temp + M(96, 71) * M(71, 91)
      temp = temp + M(96, 72) * M(72, 91)
      temp = temp + M(96, 73) * M(73, 91)
      temp = temp + M(96, 74) * M(74, 91)
      temp = temp + M(96, 75) * M(75, 91)
      temp = temp + M(96, 77) * M(77, 91)
      temp = temp + M(96, 83) * M(83, 91)
      temp = temp + M(96, 84) * M(84, 91)
      temp = temp + M(96, 85) * M(85, 91)
      temp = temp + M(96, 86) * M(86, 91)
      temp = temp + M(96, 87) * M(87, 91)
      temp = temp + M(96, 88) * M(88, 91)
      temp = temp + M(96, 89) * M(89, 91)
      temp = temp + M(96, 90) * M(90, 91)
      M(96, 91) = M(96, 91) - temp
C     Upper part.
      temp = M(91, 44) * M(44, 92)
      temp = temp + M(91, 63) * M(63, 92)
      temp = temp + M(91, 64) * M(64, 92)
      temp = temp + M(91, 86) * M(86, 92)
      temp = temp + M(91, 87) * M(87, 92)
      temp = temp + M(91, 88) * M(88, 92)
      temp = temp + M(91, 89) * M(89, 92)
      temp = temp + M(91, 90) * M(90, 92)
      M(91, 92) = ( M(91, 92) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 86) * M(86, 93)
      temp = temp + M(91, 87) * M(87, 93)
      temp = temp + M(91, 88) * M(88, 93)
      temp = temp + M(91, 89) * M(89, 93)
      temp = temp + M(91, 90) * M(90, 93)
      M(91, 93) = ( M(91, 93) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 64) * M(64, 94)
      temp = temp + M(91, 71) * M(71, 94)
      temp = temp + M(91, 72) * M(72, 94)
      temp = temp + M(91, 86) * M(86, 94)
      temp = temp + M(91, 87) * M(87, 94)
      temp = temp + M(91, 88) * M(88, 94)
      temp = temp + M(91, 89) * M(89, 94)
      temp = temp + M(91, 90) * M(90, 94)
      M(91, 94) = ( M(91, 94) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 86) * M(86, 95)
      temp = temp + M(91, 87) * M(87, 95)
      temp = temp + M(91, 88) * M(88, 95)
      temp = temp + M(91, 89) * M(89, 95)
      temp = temp + M(91, 90) * M(90, 95)
      M(91, 95) = ( M(91, 95) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 63) * M(63, 96)
      temp = temp + M(91, 64) * M(64, 96)
      temp = temp + M(91, 86) * M(86, 96)
      temp = temp + M(91, 87) * M(87, 96)
      temp = temp + M(91, 88) * M(88, 96)
      temp = temp + M(91, 89) * M(89, 96)
      temp = temp + M(91, 90) * M(90, 96)
      M(91, 96) = ( M(91, 96) - temp ) / M(91, 91)

C     Lower part.
      temp = M(92, 24) * M(24, 92)
      temp = temp + M(92, 41) * M(41, 92)
      temp = temp + M(92, 42) * M(42, 92)
      temp = temp + M(92, 83) * M(83, 92)
      temp = temp + M(92, 84) * M(84, 92)
      temp = temp + M(92, 85) * M(85, 92)
      temp = temp + M(92, 86) * M(86, 92)
      temp = temp + M(92, 87) * M(87, 92)
      temp = temp + M(92, 88) * M(88, 92)
      temp = temp + M(92, 89) * M(89, 92)
      temp = temp + M(92, 90) * M(90, 92)
      temp = temp + M(92, 91) * M(91, 92)
      M(92, 92) = M(92, 92) - temp
C     Lower part.
      temp = M(93, 44) * M(44, 92)
      temp = temp + M(93, 45) * M(45, 92)
      temp = temp + M(93, 63) * M(63, 92)
      temp = temp + M(93, 64) * M(64, 92)
      temp = temp + M(93, 84) * M(84, 92)
      temp = temp + M(93, 85) * M(85, 92)
      temp = temp + M(93, 86) * M(86, 92)
      temp = temp + M(93, 87) * M(87, 92)
      temp = temp + M(93, 88) * M(88, 92)
      temp = temp + M(93, 89) * M(89, 92)
      temp = temp + M(93, 90) * M(90, 92)
      temp = temp + M(93, 91) * M(91, 92)
      M(93, 92) = M(93, 92) - temp
C     Lower part.
      temp = M(94, 24) * M(24, 92)
      temp = temp + M(94, 41) * M(41, 92)
      temp = temp + M(94, 42) * M(42, 92)
      temp = temp + M(94, 64) * M(64, 92)
      temp = temp + M(94, 73) * M(73, 92)
      temp = temp + M(94, 74) * M(74, 92)
      temp = temp + M(94, 79) * M(79, 92)
      temp = temp + M(94, 83) * M(83, 92)
      temp = temp + M(94, 84) * M(84, 92)
      temp = temp + M(94, 85) * M(85, 92)
      temp = temp + M(94, 86) * M(86, 92)
      temp = temp + M(94, 87) * M(87, 92)
      temp = temp + M(94, 88) * M(88, 92)
      temp = temp + M(94, 89) * M(89, 92)
      temp = temp + M(94, 90) * M(90, 92)
      temp = temp + M(94, 91) * M(91, 92)
      M(94, 92) = M(94, 92) - temp
C     Lower part.
      temp = M(95, 43) * M(43, 92)
      temp = temp + M(95, 44) * M(44, 92)
      temp = temp + M(95, 45) * M(45, 92)
      temp = temp + M(95, 63) * M(63, 92)
      temp = temp + M(95, 64) * M(64, 92)
      temp = temp + M(95, 74) * M(74, 92)
      temp = temp + M(95, 83) * M(83, 92)
      temp = temp + M(95, 84) * M(84, 92)
      temp = temp + M(95, 85) * M(85, 92)
      temp = temp + M(95, 86) * M(86, 92)
      temp = temp + M(95, 87) * M(87, 92)
      temp = temp + M(95, 88) * M(88, 92)
      temp = temp + M(95, 89) * M(89, 92)
      temp = temp + M(95, 90) * M(90, 92)
      temp = temp + M(95, 91) * M(91, 92)
      M(95, 92) = M(95, 92) - temp
C     Lower part.
      temp = M(96, 24) * M(24, 92)
      temp = temp + M(96, 42) * M(42, 92)
      temp = temp + M(96, 43) * M(43, 92)
      temp = temp + M(96, 44) * M(44, 92)
      temp = temp + M(96, 45) * M(45, 92)
      temp = temp + M(96, 56) * M(56, 92)
      temp = temp + M(96, 63) * M(63, 92)
      temp = temp + M(96, 64) * M(64, 92)
      temp = temp + M(96, 73) * M(73, 92)
      temp = temp + M(96, 74) * M(74, 92)
      temp = temp + M(96, 75) * M(75, 92)
      temp = temp + M(96, 77) * M(77, 92)
      temp = temp + M(96, 83) * M(83, 92)
      temp = temp + M(96, 84) * M(84, 92)
      temp = temp + M(96, 85) * M(85, 92)
      temp = temp + M(96, 86) * M(86, 92)
      temp = temp + M(96, 87) * M(87, 92)
      temp = temp + M(96, 88) * M(88, 92)
      temp = temp + M(96, 89) * M(89, 92)
      temp = temp + M(96, 90) * M(90, 92)
      temp = temp + M(96, 91) * M(91, 92)
      M(96, 92) = M(96, 92) - temp
C     Upper part.
      temp = M(92, 84) * M(84, 93)
      temp = temp + M(92, 85) * M(85, 93)
      temp = temp + M(92, 86) * M(86, 93)
      temp = temp + M(92, 87) * M(87, 93)
      temp = temp + M(92, 88) * M(88, 93)
      temp = temp + M(92, 89) * M(89, 93)
      temp = temp + M(92, 90) * M(90, 93)
      temp = temp + M(92, 91) * M(91, 93)
      M(92, 93) = ( M(92, 93) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 41) * M(41, 94)
      temp = temp + M(92, 71) * M(71, 94)
      temp = temp + M(92, 83) * M(83, 94)
      temp = temp + M(92, 84) * M(84, 94)
      temp = temp + M(92, 85) * M(85, 94)
      temp = temp + M(92, 86) * M(86, 94)
      temp = temp + M(92, 87) * M(87, 94)
      temp = temp + M(92, 88) * M(88, 94)
      temp = temp + M(92, 89) * M(89, 94)
      temp = temp + M(92, 90) * M(90, 94)
      temp = temp + M(92, 91) * M(91, 94)
      M(92, 94) = ( M(92, 94) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 83) * M(83, 95)
      temp = temp + M(92, 84) * M(84, 95)
      temp = temp + M(92, 85) * M(85, 95)
      temp = temp + M(92, 86) * M(86, 95)
      temp = temp + M(92, 87) * M(87, 95)
      temp = temp + M(92, 88) * M(88, 95)
      temp = temp + M(92, 89) * M(89, 95)
      temp = temp + M(92, 90) * M(90, 95)
      temp = temp + M(92, 91) * M(91, 95)
      M(92, 95) = ( M(92, 95) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 42) * M(42, 96)
      temp = temp + M(92, 83) * M(83, 96)
      temp = temp + M(92, 84) * M(84, 96)
      temp = temp + M(92, 85) * M(85, 96)
      temp = temp + M(92, 86) * M(86, 96)
      temp = temp + M(92, 87) * M(87, 96)
      temp = temp + M(92, 88) * M(88, 96)
      temp = temp + M(92, 89) * M(89, 96)
      temp = temp + M(92, 90) * M(90, 96)
      temp = temp + M(92, 91) * M(91, 96)
      M(92, 96) = ( M(92, 96) - temp ) / M(92, 92)

C     Lower part.
      temp = M(93, 31) * M(31, 93)
      temp = temp + M(93, 62) * M(62, 93)
      temp = temp + M(93, 84) * M(84, 93)
      temp = temp + M(93, 85) * M(85, 93)
      temp = temp + M(93, 86) * M(86, 93)
      temp = temp + M(93, 87) * M(87, 93)
      temp = temp + M(93, 88) * M(88, 93)
      temp = temp + M(93, 89) * M(89, 93)
      temp = temp + M(93, 90) * M(90, 93)
      temp = temp + M(93, 91) * M(91, 93)
      temp = temp + M(93, 92) * M(92, 93)
      M(93, 93) = M(93, 93) - temp
C     Lower part.
      temp = M(94, 31) * M(31, 93)
      temp = temp + M(94, 84) * M(84, 93)
      temp = temp + M(94, 85) * M(85, 93)
      temp = temp + M(94, 86) * M(86, 93)
      temp = temp + M(94, 87) * M(87, 93)
      temp = temp + M(94, 88) * M(88, 93)
      temp = temp + M(94, 89) * M(89, 93)
      temp = temp + M(94, 90) * M(90, 93)
      temp = temp + M(94, 91) * M(91, 93)
      temp = temp + M(94, 92) * M(92, 93)
      M(94, 93) = M(94, 93) - temp
C     Lower part.
      temp = M(95, 84) * M(84, 93)
      temp = temp + M(95, 85) * M(85, 93)
      temp = temp + M(95, 86) * M(86, 93)
      temp = temp + M(95, 87) * M(87, 93)
      temp = temp + M(95, 88) * M(88, 93)
      temp = temp + M(95, 89) * M(89, 93)
      temp = temp + M(95, 90) * M(90, 93)
      temp = temp + M(95, 91) * M(91, 93)
      temp = temp + M(95, 92) * M(92, 93)
      M(95, 93) = M(95, 93) - temp
C     Lower part.
      temp = M(96, 84) * M(84, 93)
      temp = temp + M(96, 85) * M(85, 93)
      temp = temp + M(96, 86) * M(86, 93)
      temp = temp + M(96, 87) * M(87, 93)
      temp = temp + M(96, 88) * M(88, 93)
      temp = temp + M(96, 89) * M(89, 93)
      temp = temp + M(96, 90) * M(90, 93)
      temp = temp + M(96, 91) * M(91, 93)
      temp = temp + M(96, 92) * M(92, 93)
      M(96, 93) = M(96, 93) - temp
C     Upper part.
      temp = M(93, 31) * M(31, 94)
      temp = temp + M(93, 64) * M(64, 94)
      temp = temp + M(93, 72) * M(72, 94)
      temp = temp + M(93, 84) * M(84, 94)
      temp = temp + M(93, 85) * M(85, 94)
      temp = temp + M(93, 86) * M(86, 94)
      temp = temp + M(93, 87) * M(87, 94)
      temp = temp + M(93, 88) * M(88, 94)
      temp = temp + M(93, 89) * M(89, 94)
      temp = temp + M(93, 90) * M(90, 94)
      temp = temp + M(93, 91) * M(91, 94)
      temp = temp + M(93, 92) * M(92, 94)
      M(93, 94) = ( M(93, 94) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 84) * M(84, 95)
      temp = temp + M(93, 85) * M(85, 95)
      temp = temp + M(93, 86) * M(86, 95)
      temp = temp + M(93, 87) * M(87, 95)
      temp = temp + M(93, 88) * M(88, 95)
      temp = temp + M(93, 89) * M(89, 95)
      temp = temp + M(93, 90) * M(90, 95)
      temp = temp + M(93, 91) * M(91, 95)
      temp = temp + M(93, 92) * M(92, 95)
      M(93, 95) = ( M(93, 95) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 62) * M(62, 96)
      temp = temp + M(93, 63) * M(63, 96)
      temp = temp + M(93, 64) * M(64, 96)
      temp = temp + M(93, 84) * M(84, 96)
      temp = temp + M(93, 85) * M(85, 96)
      temp = temp + M(93, 86) * M(86, 96)
      temp = temp + M(93, 87) * M(87, 96)
      temp = temp + M(93, 88) * M(88, 96)
      temp = temp + M(93, 89) * M(89, 96)
      temp = temp + M(93, 90) * M(90, 96)
      temp = temp + M(93, 91) * M(91, 96)
      temp = temp + M(93, 92) * M(92, 96)
      M(93, 96) = ( M(93, 96) - temp ) / M(93, 93)

C     Lower part.
      temp = M(94, 25) * M(25, 94)
      temp = temp + M(94, 31) * M(31, 94)
      temp = temp + M(94, 36) * M(36, 94)
      temp = temp + M(94, 38) * M(38, 94)
      temp = temp + M(94, 39) * M(39, 94)
      temp = temp + M(94, 41) * M(41, 94)
      temp = temp + M(94, 64) * M(64, 94)
      temp = temp + M(94, 71) * M(71, 94)
      temp = temp + M(94, 73) * M(73, 94)
      temp = temp + M(94, 74) * M(74, 94)
      temp = temp + M(94, 79) * M(79, 94)
      temp = temp + M(94, 83) * M(83, 94)
      temp = temp + M(94, 84) * M(84, 94)
      temp = temp + M(94, 85) * M(85, 94)
      temp = temp + M(94, 86) * M(86, 94)
      temp = temp + M(94, 87) * M(87, 94)
      temp = temp + M(94, 88) * M(88, 94)
      temp = temp + M(94, 89) * M(89, 94)
      temp = temp + M(94, 90) * M(90, 94)
      temp = temp + M(94, 91) * M(91, 94)
      temp = temp + M(94, 92) * M(92, 94)
      temp = temp + M(94, 93) * M(93, 94)
      M(94, 94) = M(94, 94) - temp
C     Lower part.
      temp = M(95, 39) * M(39, 94)
      temp = temp + M(95, 64) * M(64, 94)
      temp = temp + M(95, 71) * M(71, 94)
      temp = temp + M(95, 72) * M(72, 94)
      temp = temp + M(95, 74) * M(74, 94)
      temp = temp + M(95, 83) * M(83, 94)
      temp = temp + M(95, 84) * M(84, 94)
      temp = temp + M(95, 85) * M(85, 94)
      temp = temp + M(95, 86) * M(86, 94)
      temp = temp + M(95, 87) * M(87, 94)
      temp = temp + M(95, 88) * M(88, 94)
      temp = temp + M(95, 89) * M(89, 94)
      temp = temp + M(95, 90) * M(90, 94)
      temp = temp + M(95, 91) * M(91, 94)
      temp = temp + M(95, 92) * M(92, 94)
      temp = temp + M(95, 93) * M(93, 94)
      M(95, 94) = M(95, 94) - temp
C     Lower part.
      temp = M(96, 36) * M(36, 94)
      temp = temp + M(96, 39) * M(39, 94)
      temp = temp + M(96, 64) * M(64, 94)
      temp = temp + M(96, 71) * M(71, 94)
      temp = temp + M(96, 72) * M(72, 94)
      temp = temp + M(96, 73) * M(73, 94)
      temp = temp + M(96, 74) * M(74, 94)
      temp = temp + M(96, 75) * M(75, 94)
      temp = temp + M(96, 77) * M(77, 94)
      temp = temp + M(96, 83) * M(83, 94)
      temp = temp + M(96, 84) * M(84, 94)
      temp = temp + M(96, 85) * M(85, 94)
      temp = temp + M(96, 86) * M(86, 94)
      temp = temp + M(96, 87) * M(87, 94)
      temp = temp + M(96, 88) * M(88, 94)
      temp = temp + M(96, 89) * M(89, 94)
      temp = temp + M(96, 90) * M(90, 94)
      temp = temp + M(96, 91) * M(91, 94)
      temp = temp + M(96, 92) * M(92, 94)
      temp = temp + M(96, 93) * M(93, 94)
      M(96, 94) = M(96, 94) - temp
C     Upper part.
      temp = M(94, 79) * M(79, 95)
      temp = temp + M(94, 83) * M(83, 95)
      temp = temp + M(94, 84) * M(84, 95)
      temp = temp + M(94, 85) * M(85, 95)
      temp = temp + M(94, 86) * M(86, 95)
      temp = temp + M(94, 87) * M(87, 95)
      temp = temp + M(94, 88) * M(88, 95)
      temp = temp + M(94, 89) * M(89, 95)
      temp = temp + M(94, 90) * M(90, 95)
      temp = temp + M(94, 91) * M(91, 95)
      temp = temp + M(94, 92) * M(92, 95)
      temp = temp + M(94, 93) * M(93, 95)
      M(94, 95) = ( M(94, 95) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 36) * M(36, 96)
      temp = temp + M(94, 42) * M(42, 96)
      temp = temp + M(94, 64) * M(64, 96)
      temp = temp + M(94, 73) * M(73, 96)
      temp = temp + M(94, 74) * M(74, 96)
      temp = temp + M(94, 79) * M(79, 96)
      temp = temp + M(94, 83) * M(83, 96)
      temp = temp + M(94, 84) * M(84, 96)
      temp = temp + M(94, 85) * M(85, 96)
      temp = temp + M(94, 86) * M(86, 96)
      temp = temp + M(94, 87) * M(87, 96)
      temp = temp + M(94, 88) * M(88, 96)
      temp = temp + M(94, 89) * M(89, 96)
      temp = temp + M(94, 90) * M(90, 96)
      temp = temp + M(94, 91) * M(91, 96)
      temp = temp + M(94, 92) * M(92, 96)
      temp = temp + M(94, 93) * M(93, 96)
      M(94, 96) = ( M(94, 96) - temp ) / M(94, 94)

C     Lower part.
      temp = M(95, 61) * M(61, 95)
      temp = temp + M(95, 83) * M(83, 95)
      temp = temp + M(95, 84) * M(84, 95)
      temp = temp + M(95, 85) * M(85, 95)
      temp = temp + M(95, 86) * M(86, 95)
      temp = temp + M(95, 87) * M(87, 95)
      temp = temp + M(95, 88) * M(88, 95)
      temp = temp + M(95, 89) * M(89, 95)
      temp = temp + M(95, 90) * M(90, 95)
      temp = temp + M(95, 91) * M(91, 95)
      temp = temp + M(95, 92) * M(92, 95)
      temp = temp + M(95, 93) * M(93, 95)
      temp = temp + M(95, 94) * M(94, 95)
      M(95, 95) = M(95, 95) - temp
C     Lower part.
      temp = M(96, 61) * M(61, 95)
      temp = temp + M(96, 75) * M(75, 95)
      temp = temp + M(96, 77) * M(77, 95)
      temp = temp + M(96, 83) * M(83, 95)
      temp = temp + M(96, 84) * M(84, 95)
      temp = temp + M(96, 85) * M(85, 95)
      temp = temp + M(96, 86) * M(86, 95)
      temp = temp + M(96, 87) * M(87, 95)
      temp = temp + M(96, 88) * M(88, 95)
      temp = temp + M(96, 89) * M(89, 95)
      temp = temp + M(96, 90) * M(90, 95)
      temp = temp + M(96, 91) * M(91, 95)
      temp = temp + M(96, 92) * M(92, 95)
      temp = temp + M(96, 93) * M(93, 95)
      temp = temp + M(96, 94) * M(94, 95)
      M(96, 95) = M(96, 95) - temp
C     Upper part.
      temp = M(95, 43) * M(43, 96)
      temp = temp + M(95, 61) * M(61, 96)
      temp = temp + M(95, 63) * M(63, 96)
      temp = temp + M(95, 64) * M(64, 96)
      temp = temp + M(95, 74) * M(74, 96)
      temp = temp + M(95, 83) * M(83, 96)
      temp = temp + M(95, 84) * M(84, 96)
      temp = temp + M(95, 85) * M(85, 96)
      temp = temp + M(95, 86) * M(86, 96)
      temp = temp + M(95, 87) * M(87, 96)
      temp = temp + M(95, 88) * M(88, 96)
      temp = temp + M(95, 89) * M(89, 96)
      temp = temp + M(95, 90) * M(90, 96)
      temp = temp + M(95, 91) * M(91, 96)
      temp = temp + M(95, 92) * M(92, 96)
      temp = temp + M(95, 93) * M(93, 96)
      temp = temp + M(95, 94) * M(94, 96)
      M(95, 96) = ( M(95, 96) - temp ) / M(95, 95)

C     Lower part.
      temp = M(96, 36) * M(36, 96)
      temp = temp + M(96, 40) * M(40, 96)
      temp = temp + M(96, 42) * M(42, 96)
      temp = temp + M(96, 43) * M(43, 96)
      temp = temp + M(96, 56) * M(56, 96)
      temp = temp + M(96, 61) * M(61, 96)
      temp = temp + M(96, 63) * M(63, 96)
      temp = temp + M(96, 64) * M(64, 96)
      temp = temp + M(96, 73) * M(73, 96)
      temp = temp + M(96, 74) * M(74, 96)
      temp = temp + M(96, 75) * M(75, 96)
      temp = temp + M(96, 77) * M(77, 96)
      temp = temp + M(96, 83) * M(83, 96)
      temp = temp + M(96, 84) * M(84, 96)
      temp = temp + M(96, 85) * M(85, 96)
      temp = temp + M(96, 86) * M(86, 96)
      temp = temp + M(96, 87) * M(87, 96)
      temp = temp + M(96, 88) * M(88, 96)
      temp = temp + M(96, 89) * M(89, 96)
      temp = temp + M(96, 90) * M(90, 96)
      temp = temp + M(96, 91) * M(91, 96)
      temp = temp + M(96, 92) * M(92, 96)
      temp = temp + M(96, 93) * M(93, 96)
      temp = temp + M(96, 94) * M(94, 96)
      temp = temp + M(96, 95) * M(95, 96)
      M(96, 96) = M(96, 96) - temp


      END
