C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve_tr (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M^t * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      temp = M(21, 48) * x(21)
      temp = temp + M(22, 48) * x(22)
      temp = temp + M(32, 48) * x(32)
      temp = temp + M(33, 48) * x(33)
      temp = temp + M(34, 48) * x(34)
      x(48) = x(48) - temp

      temp = M(47, 49) * x(47)
      temp = temp + M(48, 49) * x(48)
      x(49) = x(49) - temp

      temp = M(35, 50) * x(35)
      x(50) = x(50) - temp

      temp = M(32, 52) * x(32)
      temp = temp + M(33, 52) * x(33)
      temp = temp + M(34, 52) * x(34)
      temp = temp + M(48, 52) * x(48)
      x(52) = x(52) - temp

      temp = M(26, 57) * x(26)
      temp = temp + M(27, 57) * x(27)
      x(57) = x(57) - temp

      temp = M(47, 60) * x(47)
      temp = temp + M(50, 60) * x(50)
      temp = temp + M(51, 60) * x(51)
      temp = temp + M(53, 60) * x(53)
      temp = temp + M(54, 60) * x(54)
      x(60) = x(60) - temp

      temp = M(44, 63) * x(44)
      temp = temp + M(45, 63) * x(45)
      x(63) = x(63) - temp

      temp = M(63, 64) * x(63)
      x(64) = x(64) - temp

      temp = M(30, 70) * x(30)
      x(70) = x(70) - temp

      temp = M(70, 71) * x(70)
      x(71) = x(71) - temp

      temp = M(45, 72) * x(45)
      x(72) = x(72) - temp

      temp = M(39, 74) * x(39)
      temp = temp + M(73, 74) * x(73)
      x(74) = x(74) - temp

      temp = M(65, 78) * x(65)
      temp = temp + M(66, 78) * x(66)
      temp = temp + M(69, 78) * x(69)
      x(78) = x(78) - temp

      temp = M(28, 80) * x(28)
      temp = temp + M(29, 80) * x(29)
      temp = temp + M(37, 80) * x(37)
      temp = temp + M(70, 80) * x(70)
      x(80) = x(80) - temp

      temp = M(57, 81) * x(57)
      x(81) = x(81) - temp

      temp = M(65, 82) * x(65)
      temp = temp + M(66, 82) * x(66)
      temp = temp + M(69, 82) * x(69)
      x(82) = x(82) - temp

      temp = M(61, 83) * x(61)
      temp = temp + M(73, 83) * x(73)
      temp = temp + M(74, 83) * x(74)
      temp = temp + M(75, 83) * x(75)
      temp = temp + M(77, 83) * x(77)
      temp = temp + M(79, 83) * x(79)
      x(83) = x(83) - temp

      temp = M(23, 84) * x(23)
      temp = temp + M(37, 84) * x(37)
      temp = temp + M(43, 84) * x(43)
      temp = temp + M(69, 84) * x(69)
      temp = temp + M(76, 84) * x(76)
      temp = temp + M(78, 84) * x(78)
      temp = temp + M(80, 84) * x(80)
      temp = temp + M(81, 84) * x(81)
      temp = temp + M(82, 84) * x(82)
      x(84) = x(84) - temp

      temp = M(42, 85) * x(42)
      temp = temp + M(43, 85) * x(43)
      temp = temp + M(56, 85) * x(56)
      temp = temp + M(77, 85) * x(77)
      temp = temp + M(79, 85) * x(79)
      temp = temp + M(84, 85) * x(84)
      x(85) = x(85) - temp

      temp = M(5, 86) * x(5)
      temp = temp + M(6, 86) * x(6)
      temp = temp + M(7, 86) * x(7)
      temp = temp + M(8, 86) * x(8)
      temp = temp + M(9, 86) * x(9)
      temp = temp + M(10, 86) * x(10)
      temp = temp + M(11, 86) * x(11)
      temp = temp + M(12, 86) * x(12)
      temp = temp + M(13, 86) * x(13)
      temp = temp + M(14, 86) * x(14)
      temp = temp + M(15, 86) * x(15)
      temp = temp + M(16, 86) * x(16)
      temp = temp + M(17, 86) * x(17)
      temp = temp + M(18, 86) * x(18)
      temp = temp + M(19, 86) * x(19)
      temp = temp + M(20, 86) * x(20)
      temp = temp + M(23, 86) * x(23)
      temp = temp + M(24, 86) * x(24)
      temp = temp + M(26, 86) * x(26)
      temp = temp + M(27, 86) * x(27)
      temp = temp + M(35, 86) * x(35)
      temp = temp + M(36, 86) * x(36)
      temp = temp + M(38, 86) * x(38)
      temp = temp + M(39, 86) * x(39)
      temp = temp + M(40, 86) * x(40)
      temp = temp + M(41, 86) * x(41)
      temp = temp + M(43, 86) * x(43)
      temp = temp + M(44, 86) * x(44)
      temp = temp + M(45, 86) * x(45)
      temp = temp + M(46, 86) * x(46)
      temp = temp + M(47, 86) * x(47)
      temp = temp + M(48, 86) * x(48)
      temp = temp + M(49, 86) * x(49)
      temp = temp + M(50, 86) * x(50)
      temp = temp + M(51, 86) * x(51)
      temp = temp + M(52, 86) * x(52)
      temp = temp + M(53, 86) * x(53)
      temp = temp + M(54, 86) * x(54)
      temp = temp + M(55, 86) * x(55)
      temp = temp + M(56, 86) * x(56)
      temp = temp + M(57, 86) * x(57)
      temp = temp + M(58, 86) * x(58)
      temp = temp + M(59, 86) * x(59)
      temp = temp + M(60, 86) * x(60)
      temp = temp + M(61, 86) * x(61)
      temp = temp + M(62, 86) * x(62)
      temp = temp + M(63, 86) * x(63)
      temp = temp + M(64, 86) * x(64)
      temp = temp + M(67, 86) * x(67)
      temp = temp + M(68, 86) * x(68)
      temp = temp + M(70, 86) * x(70)
      temp = temp + M(71, 86) * x(71)
      temp = temp + M(72, 86) * x(72)
      temp = temp + M(73, 86) * x(73)
      temp = temp + M(74, 86) * x(74)
      temp = temp + M(75, 86) * x(75)
      temp = temp + M(76, 86) * x(76)
      temp = temp + M(77, 86) * x(77)
      temp = temp + M(78, 86) * x(78)
      temp = temp + M(79, 86) * x(79)
      temp = temp + M(80, 86) * x(80)
      temp = temp + M(81, 86) * x(81)
      temp = temp + M(82, 86) * x(82)
      temp = temp + M(83, 86) * x(83)
      temp = temp + M(84, 86) * x(84)
      temp = temp + M(85, 86) * x(85)
      x(86) = x(86) - temp

      temp = M(25, 87) * x(25)
      temp = temp + M(30, 87) * x(30)
      temp = temp + M(46, 87) * x(46)
      temp = temp + M(47, 87) * x(47)
      temp = temp + M(48, 87) * x(48)
      temp = temp + M(49, 87) * x(49)
      temp = temp + M(50, 87) * x(50)
      temp = temp + M(51, 87) * x(51)
      temp = temp + M(52, 87) * x(52)
      temp = temp + M(53, 87) * x(53)
      temp = temp + M(54, 87) * x(54)
      temp = temp + M(55, 87) * x(55)
      temp = temp + M(56, 87) * x(56)
      temp = temp + M(57, 87) * x(57)
      temp = temp + M(58, 87) * x(58)
      temp = temp + M(59, 87) * x(59)
      temp = temp + M(60, 87) * x(60)
      temp = temp + M(63, 87) * x(63)
      temp = temp + M(64, 87) * x(64)
      temp = temp + M(65, 87) * x(65)
      temp = temp + M(66, 87) * x(66)
      temp = temp + M(67, 87) * x(67)
      temp = temp + M(68, 87) * x(68)
      temp = temp + M(70, 87) * x(70)
      temp = temp + M(71, 87) * x(71)
      temp = temp + M(72, 87) * x(72)
      temp = temp + M(73, 87) * x(73)
      temp = temp + M(74, 87) * x(74)
      temp = temp + M(75, 87) * x(75)
      temp = temp + M(77, 87) * x(77)
      temp = temp + M(78, 87) * x(78)
      temp = temp + M(79, 87) * x(79)
      temp = temp + M(80, 87) * x(80)
      temp = temp + M(81, 87) * x(81)
      temp = temp + M(82, 87) * x(82)
      temp = temp + M(83, 87) * x(83)
      temp = temp + M(84, 87) * x(84)
      temp = temp + M(85, 87) * x(85)
      temp = temp + M(86, 87) * x(86)
      x(87) = x(87) - temp

      temp = M(40, 88) * x(40)
      temp = temp + M(46, 88) * x(46)
      temp = temp + M(47, 88) * x(47)
      temp = temp + M(48, 88) * x(48)
      temp = temp + M(49, 88) * x(49)
      temp = temp + M(50, 88) * x(50)
      temp = temp + M(51, 88) * x(51)
      temp = temp + M(52, 88) * x(52)
      temp = temp + M(53, 88) * x(53)
      temp = temp + M(54, 88) * x(54)
      temp = temp + M(55, 88) * x(55)
      temp = temp + M(56, 88) * x(56)
      temp = temp + M(58, 88) * x(58)
      temp = temp + M(59, 88) * x(59)
      temp = temp + M(60, 88) * x(60)
      temp = temp + M(67, 88) * x(67)
      temp = temp + M(68, 88) * x(68)
      temp = temp + M(71, 88) * x(71)
      temp = temp + M(72, 88) * x(72)
      temp = temp + M(73, 88) * x(73)
      temp = temp + M(74, 88) * x(74)
      temp = temp + M(75, 88) * x(75)
      temp = temp + M(77, 88) * x(77)
      temp = temp + M(79, 88) * x(79)
      temp = temp + M(80, 88) * x(80)
      temp = temp + M(81, 88) * x(81)
      temp = temp + M(83, 88) * x(83)
      temp = temp + M(84, 88) * x(84)
      temp = temp + M(85, 88) * x(85)
      temp = temp + M(86, 88) * x(86)
      temp = temp + M(87, 88) * x(87)
      x(88) = x(88) - temp

      temp = M(77, 89) * x(77)
      temp = temp + M(79, 89) * x(79)
      temp = temp + M(84, 89) * x(84)
      temp = temp + M(85, 89) * x(85)
      temp = temp + M(86, 89) * x(86)
      temp = temp + M(87, 89) * x(87)
      temp = temp + M(88, 89) * x(88)
      x(89) = x(89) - temp

      temp = M(38, 90) * x(38)
      temp = temp + M(62, 90) * x(62)
      temp = temp + M(76, 90) * x(76)
      temp = temp + M(84, 90) * x(84)
      temp = temp + M(85, 90) * x(85)
      temp = temp + M(86, 90) * x(86)
      temp = temp + M(87, 90) * x(87)
      temp = temp + M(88, 90) * x(88)
      temp = temp + M(89, 90) * x(89)
      x(90) = x(90) - temp

      temp = M(4, 91) * x(4)
      temp = temp + M(44, 91) * x(44)
      temp = temp + M(45, 91) * x(45)
      temp = temp + M(46, 91) * x(46)
      temp = temp + M(47, 91) * x(47)
      temp = temp + M(48, 91) * x(48)
      temp = temp + M(49, 91) * x(49)
      temp = temp + M(50, 91) * x(50)
      temp = temp + M(51, 91) * x(51)
      temp = temp + M(52, 91) * x(52)
      temp = temp + M(53, 91) * x(53)
      temp = temp + M(54, 91) * x(54)
      temp = temp + M(55, 91) * x(55)
      temp = temp + M(56, 91) * x(56)
      temp = temp + M(58, 91) * x(58)
      temp = temp + M(59, 91) * x(59)
      temp = temp + M(60, 91) * x(60)
      temp = temp + M(67, 91) * x(67)
      temp = temp + M(68, 91) * x(68)
      temp = temp + M(71, 91) * x(71)
      temp = temp + M(72, 91) * x(72)
      temp = temp + M(73, 91) * x(73)
      temp = temp + M(74, 91) * x(74)
      temp = temp + M(75, 91) * x(75)
      temp = temp + M(77, 91) * x(77)
      temp = temp + M(79, 91) * x(79)
      temp = temp + M(80, 91) * x(80)
      temp = temp + M(81, 91) * x(81)
      temp = temp + M(83, 91) * x(83)
      temp = temp + M(84, 91) * x(84)
      temp = temp + M(85, 91) * x(85)
      temp = temp + M(86, 91) * x(86)
      temp = temp + M(87, 91) * x(87)
      temp = temp + M(88, 91) * x(88)
      temp = temp + M(89, 91) * x(89)
      temp = temp + M(90, 91) * x(90)
      x(91) = x(91) - temp

      temp = M(24, 92) * x(24)
      temp = temp + M(41, 92) * x(41)
      temp = temp + M(42, 92) * x(42)
      temp = temp + M(43, 92) * x(43)
      temp = temp + M(44, 92) * x(44)
      temp = temp + M(45, 92) * x(45)
      temp = temp + M(52, 92) * x(52)
      temp = temp + M(53, 92) * x(53)
      temp = temp + M(56, 92) * x(56)
      temp = temp + M(63, 92) * x(63)
      temp = temp + M(64, 92) * x(64)
      temp = temp + M(65, 92) * x(65)
      temp = temp + M(66, 92) * x(66)
      temp = temp + M(67, 92) * x(67)
      temp = temp + M(68, 92) * x(68)
      temp = temp + M(70, 92) * x(70)
      temp = temp + M(73, 92) * x(73)
      temp = temp + M(74, 92) * x(74)
      temp = temp + M(75, 92) * x(75)
      temp = temp + M(77, 92) * x(77)
      temp = temp + M(78, 92) * x(78)
      temp = temp + M(79, 92) * x(79)
      temp = temp + M(80, 92) * x(80)
      temp = temp + M(81, 92) * x(81)
      temp = temp + M(82, 92) * x(82)
      temp = temp + M(83, 92) * x(83)
      temp = temp + M(84, 92) * x(84)
      temp = temp + M(85, 92) * x(85)
      temp = temp + M(86, 92) * x(86)
      temp = temp + M(87, 92) * x(87)
      temp = temp + M(88, 92) * x(88)
      temp = temp + M(89, 92) * x(89)
      temp = temp + M(90, 92) * x(90)
      temp = temp + M(91, 92) * x(91)
      x(92) = x(92) - temp

      temp = M(31, 93) * x(31)
      temp = temp + M(37, 93) * x(37)
      temp = temp + M(62, 93) * x(62)
      temp = temp + M(69, 93) * x(69)
      temp = temp + M(76, 93) * x(76)
      temp = temp + M(78, 93) * x(78)
      temp = temp + M(80, 93) * x(80)
      temp = temp + M(81, 93) * x(81)
      temp = temp + M(82, 93) * x(82)
      temp = temp + M(84, 93) * x(84)
      temp = temp + M(85, 93) * x(85)
      temp = temp + M(86, 93) * x(86)
      temp = temp + M(87, 93) * x(87)
      temp = temp + M(88, 93) * x(88)
      temp = temp + M(89, 93) * x(89)
      temp = temp + M(90, 93) * x(90)
      temp = temp + M(91, 93) * x(91)
      temp = temp + M(92, 93) * x(92)
      x(93) = x(93) - temp

      temp = M(25, 94) * x(25)
      temp = temp + M(31, 94) * x(31)
      temp = temp + M(36, 94) * x(36)
      temp = temp + M(38, 94) * x(38)
      temp = temp + M(39, 94) * x(39)
      temp = temp + M(41, 94) * x(41)
      temp = temp + M(57, 94) * x(57)
      temp = temp + M(64, 94) * x(64)
      temp = temp + M(71, 94) * x(71)
      temp = temp + M(72, 94) * x(72)
      temp = temp + M(73, 94) * x(73)
      temp = temp + M(74, 94) * x(74)
      temp = temp + M(75, 94) * x(75)
      temp = temp + M(77, 94) * x(77)
      temp = temp + M(79, 94) * x(79)
      temp = temp + M(80, 94) * x(80)
      temp = temp + M(81, 94) * x(81)
      temp = temp + M(83, 94) * x(83)
      temp = temp + M(84, 94) * x(84)
      temp = temp + M(85, 94) * x(85)
      temp = temp + M(86, 94) * x(86)
      temp = temp + M(87, 94) * x(87)
      temp = temp + M(88, 94) * x(88)
      temp = temp + M(89, 94) * x(89)
      temp = temp + M(90, 94) * x(90)
      temp = temp + M(91, 94) * x(91)
      temp = temp + M(92, 94) * x(92)
      temp = temp + M(93, 94) * x(93)
      x(94) = x(94) - temp

      temp = M(61, 95) * x(61)
      temp = temp + M(67, 95) * x(67)
      temp = temp + M(68, 95) * x(68)
      temp = temp + M(75, 95) * x(75)
      temp = temp + M(76, 95) * x(76)
      temp = temp + M(77, 95) * x(77)
      temp = temp + M(79, 95) * x(79)
      temp = temp + M(83, 95) * x(83)
      temp = temp + M(84, 95) * x(84)
      temp = temp + M(85, 95) * x(85)
      temp = temp + M(86, 95) * x(86)
      temp = temp + M(87, 95) * x(87)
      temp = temp + M(88, 95) * x(88)
      temp = temp + M(89, 95) * x(89)
      temp = temp + M(90, 95) * x(90)
      temp = temp + M(91, 95) * x(91)
      temp = temp + M(92, 95) * x(92)
      temp = temp + M(93, 95) * x(93)
      temp = temp + M(94, 95) * x(94)
      x(95) = x(95) - temp

      temp = M(28, 96) * x(28)
      temp = temp + M(29, 96) * x(29)
      temp = temp + M(32, 96) * x(32)
      temp = temp + M(33, 96) * x(33)
      temp = temp + M(34, 96) * x(34)
      temp = temp + M(36, 96) * x(36)
      temp = temp + M(40, 96) * x(40)
      temp = temp + M(42, 96) * x(42)
      temp = temp + M(43, 96) * x(43)
      temp = temp + M(52, 96) * x(52)
      temp = temp + M(56, 96) * x(56)
      temp = temp + M(61, 96) * x(61)
      temp = temp + M(62, 96) * x(62)
      temp = temp + M(63, 96) * x(63)
      temp = temp + M(64, 96) * x(64)
      temp = temp + M(67, 96) * x(67)
      temp = temp + M(68, 96) * x(68)
      temp = temp + M(69, 96) * x(69)
      temp = temp + M(73, 96) * x(73)
      temp = temp + M(74, 96) * x(74)
      temp = temp + M(75, 96) * x(75)
      temp = temp + M(76, 96) * x(76)
      temp = temp + M(77, 96) * x(77)
      temp = temp + M(78, 96) * x(78)
      temp = temp + M(79, 96) * x(79)
      temp = temp + M(80, 96) * x(80)
      temp = temp + M(81, 96) * x(81)
      temp = temp + M(82, 96) * x(82)
      temp = temp + M(83, 96) * x(83)
      temp = temp + M(84, 96) * x(84)
      temp = temp + M(85, 96) * x(85)
      temp = temp + M(86, 96) * x(86)
      temp = temp + M(87, 96) * x(87)
      temp = temp + M(88, 96) * x(88)
      temp = temp + M(89, 96) * x(89)
      temp = temp + M(90, 96) * x(90)
      temp = temp + M(91, 96) * x(91)
      temp = temp + M(92, 96) * x(92)
      temp = temp + M(93, 96) * x(93)
      temp = temp + M(94, 96) * x(94)
      temp = temp + M(95, 96) * x(95)
      x(96) = x(96) - temp


C     Backward substitution.

      x(96) = x(96) / M(96, 96)

      temp = M(96, 95) * x(96)
      x(95) = ( x(95) - temp ) / M(95, 95)

      temp = M(95, 94) * x(95)
      temp = temp + M(96, 94) * x(96)
      x(94) = ( x(94) - temp ) / M(94, 94)

      temp = M(94, 93) * x(94)
      temp = temp + M(95, 93) * x(95)
      temp = temp + M(96, 93) * x(96)
      x(93) = ( x(93) - temp ) / M(93, 93)

      temp = M(93, 92) * x(93)
      temp = temp + M(94, 92) * x(94)
      temp = temp + M(95, 92) * x(95)
      temp = temp + M(96, 92) * x(96)
      x(92) = ( x(92) - temp ) / M(92, 92)

      temp = M(92, 91) * x(92)
      temp = temp + M(93, 91) * x(93)
      temp = temp + M(94, 91) * x(94)
      temp = temp + M(95, 91) * x(95)
      temp = temp + M(96, 91) * x(96)
      x(91) = ( x(91) - temp ) / M(91, 91)

      temp = M(91, 90) * x(91)
      temp = temp + M(92, 90) * x(92)
      temp = temp + M(93, 90) * x(93)
      temp = temp + M(94, 90) * x(94)
      temp = temp + M(95, 90) * x(95)
      temp = temp + M(96, 90) * x(96)
      x(90) = ( x(90) - temp ) / M(90, 90)

      temp = M(90, 89) * x(90)
      temp = temp + M(91, 89) * x(91)
      temp = temp + M(92, 89) * x(92)
      temp = temp + M(93, 89) * x(93)
      temp = temp + M(94, 89) * x(94)
      temp = temp + M(95, 89) * x(95)
      temp = temp + M(96, 89) * x(96)
      x(89) = ( x(89) - temp ) / M(89, 89)

      temp = M(89, 88) * x(89)
      temp = temp + M(90, 88) * x(90)
      temp = temp + M(91, 88) * x(91)
      temp = temp + M(92, 88) * x(92)
      temp = temp + M(93, 88) * x(93)
      temp = temp + M(94, 88) * x(94)
      temp = temp + M(95, 88) * x(95)
      temp = temp + M(96, 88) * x(96)
      x(88) = ( x(88) - temp ) / M(88, 88)

      temp = M(88, 87) * x(88)
      temp = temp + M(89, 87) * x(89)
      temp = temp + M(90, 87) * x(90)
      temp = temp + M(91, 87) * x(91)
      temp = temp + M(92, 87) * x(92)
      temp = temp + M(93, 87) * x(93)
      temp = temp + M(94, 87) * x(94)
      temp = temp + M(95, 87) * x(95)
      temp = temp + M(96, 87) * x(96)
      x(87) = ( x(87) - temp ) / M(87, 87)

      temp = M(87, 86) * x(87)
      temp = temp + M(88, 86) * x(88)
      temp = temp + M(89, 86) * x(89)
      temp = temp + M(90, 86) * x(90)
      temp = temp + M(91, 86) * x(91)
      temp = temp + M(92, 86) * x(92)
      temp = temp + M(93, 86) * x(93)
      temp = temp + M(94, 86) * x(94)
      temp = temp + M(95, 86) * x(95)
      temp = temp + M(96, 86) * x(96)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(86, 85) * x(86)
      temp = temp + M(87, 85) * x(87)
      temp = temp + M(88, 85) * x(88)
      temp = temp + M(89, 85) * x(89)
      temp = temp + M(92, 85) * x(92)
      temp = temp + M(93, 85) * x(93)
      temp = temp + M(94, 85) * x(94)
      temp = temp + M(95, 85) * x(95)
      temp = temp + M(96, 85) * x(96)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(85, 84) * x(85)
      temp = temp + M(86, 84) * x(86)
      temp = temp + M(89, 84) * x(89)
      temp = temp + M(92, 84) * x(92)
      temp = temp + M(93, 84) * x(93)
      temp = temp + M(94, 84) * x(94)
      temp = temp + M(95, 84) * x(95)
      temp = temp + M(96, 84) * x(96)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(84, 83) * x(84)
      temp = temp + M(85, 83) * x(85)
      temp = temp + M(86, 83) * x(86)
      temp = temp + M(87, 83) * x(87)
      temp = temp + M(88, 83) * x(88)
      temp = temp + M(89, 83) * x(89)
      temp = temp + M(90, 83) * x(90)
      temp = temp + M(92, 83) * x(92)
      temp = temp + M(94, 83) * x(94)
      temp = temp + M(95, 83) * x(95)
      temp = temp + M(96, 83) * x(96)
      x(83) = ( x(83) - temp ) / M(83, 83)

      x(82) = x(82) / M(82, 82)

      x(81) = x(81) / M(81, 81)

      temp = M(81, 80) * x(81)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(86, 79) * x(86)
      temp = temp + M(87, 79) * x(87)
      temp = temp + M(94, 79) * x(94)
      x(79) = ( x(79) - temp ) / M(79, 79)

      x(78) = x(78) / M(78, 78)

      temp = M(86, 77) * x(86)
      temp = temp + M(96, 77) * x(96)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(84, 76) * x(84)
      temp = temp + M(86, 76) * x(86)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(77, 75) * x(77)
      temp = temp + M(79, 75) * x(79)
      temp = temp + M(84, 75) * x(84)
      temp = temp + M(86, 75) * x(86)
      temp = temp + M(87, 75) * x(87)
      temp = temp + M(88, 75) * x(88)
      temp = temp + M(90, 75) * x(90)
      temp = temp + M(96, 75) * x(96)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(75, 74) * x(75)
      temp = temp + M(79, 74) * x(79)
      temp = temp + M(83, 74) * x(83)
      temp = temp + M(85, 74) * x(85)
      temp = temp + M(86, 74) * x(86)
      temp = temp + M(89, 74) * x(89)
      temp = temp + M(94, 74) * x(94)
      temp = temp + M(95, 74) * x(95)
      temp = temp + M(96, 74) * x(96)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(74, 73) * x(74)
      temp = temp + M(75, 73) * x(75)
      temp = temp + M(79, 73) * x(79)
      temp = temp + M(85, 73) * x(85)
      temp = temp + M(86, 73) * x(86)
      temp = temp + M(89, 73) * x(89)
      temp = temp + M(94, 73) * x(94)
      temp = temp + M(96, 73) * x(96)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(73, 72) * x(73)
      temp = temp + M(74, 72) * x(74)
      temp = temp + M(75, 72) * x(75)
      temp = temp + M(77, 72) * x(77)
      temp = temp + M(79, 72) * x(79)
      temp = temp + M(85, 72) * x(85)
      temp = temp + M(86, 72) * x(86)
      temp = temp + M(87, 72) * x(87)
      temp = temp + M(89, 72) * x(89)
      temp = temp + M(90, 72) * x(90)
      temp = temp + M(91, 72) * x(91)
      temp = temp + M(93, 72) * x(93)
      temp = temp + M(95, 72) * x(95)
      temp = temp + M(96, 72) * x(96)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(72, 71) * x(72)
      temp = temp + M(73, 71) * x(73)
      temp = temp + M(74, 71) * x(74)
      temp = temp + M(75, 71) * x(75)
      temp = temp + M(77, 71) * x(77)
      temp = temp + M(80, 71) * x(80)
      temp = temp + M(83, 71) * x(83)
      temp = temp + M(85, 71) * x(85)
      temp = temp + M(86, 71) * x(86)
      temp = temp + M(87, 71) * x(87)
      temp = temp + M(88, 71) * x(88)
      temp = temp + M(90, 71) * x(90)
      temp = temp + M(91, 71) * x(91)
      temp = temp + M(92, 71) * x(92)
      temp = temp + M(94, 71) * x(94)
      temp = temp + M(95, 71) * x(95)
      temp = temp + M(96, 71) * x(96)
      x(71) = ( x(71) - temp ) / M(71, 71)

      x(70) = x(70) / M(70, 70)

      x(69) = x(69) / M(69, 69)

      x(68) = x(68) / M(68, 68)

      temp = M(68, 67) * x(68)
      x(67) = ( x(67) - temp ) / M(67, 67)

      x(66) = x(66) / M(66, 66)

      x(65) = x(65) / M(65, 65)

      temp = M(73, 64) * x(73)
      temp = temp + M(75, 64) * x(75)
      temp = temp + M(77, 64) * x(77)
      temp = temp + M(79, 64) * x(79)
      temp = temp + M(85, 64) * x(85)
      temp = temp + M(86, 64) * x(86)
      temp = temp + M(87, 64) * x(87)
      temp = temp + M(91, 64) * x(91)
      temp = temp + M(93, 64) * x(93)
      temp = temp + M(94, 64) * x(94)
      temp = temp + M(95, 64) * x(95)
      temp = temp + M(96, 64) * x(96)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(64, 63) * x(64)
      temp = temp + M(75, 63) * x(75)
      temp = temp + M(77, 63) * x(77)
      temp = temp + M(79, 63) * x(79)
      temp = temp + M(85, 63) * x(85)
      temp = temp + M(86, 63) * x(86)
      temp = temp + M(87, 63) * x(87)
      temp = temp + M(91, 63) * x(91)
      temp = temp + M(93, 63) * x(93)
      temp = temp + M(95, 63) * x(95)
      temp = temp + M(96, 63) * x(96)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(84, 62) * x(84)
      temp = temp + M(86, 62) * x(86)
      temp = temp + M(93, 62) * x(93)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(75, 61) * x(75)
      temp = temp + M(86, 61) * x(86)
      temp = temp + M(89, 61) * x(89)
      temp = temp + M(95, 61) * x(95)
      temp = temp + M(96, 61) * x(96)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(67, 60) * x(67)
      temp = temp + M(68, 60) * x(68)
      temp = temp + M(73, 60) * x(73)
      temp = temp + M(74, 60) * x(74)
      temp = temp + M(75, 60) * x(75)
      temp = temp + M(77, 60) * x(77)
      temp = temp + M(83, 60) * x(83)
      temp = temp + M(85, 60) * x(85)
      temp = temp + M(86, 60) * x(86)
      temp = temp + M(87, 60) * x(87)
      temp = temp + M(88, 60) * x(88)
      temp = temp + M(90, 60) * x(90)
      temp = temp + M(91, 60) * x(91)
      temp = temp + M(94, 60) * x(94)
      temp = temp + M(95, 60) * x(95)
      temp = temp + M(96, 60) * x(96)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(74, 59) * x(74)
      temp = temp + M(75, 59) * x(75)
      temp = temp + M(77, 59) * x(77)
      temp = temp + M(85, 59) * x(85)
      temp = temp + M(86, 59) * x(86)
      temp = temp + M(87, 59) * x(87)
      temp = temp + M(88, 59) * x(88)
      temp = temp + M(89, 59) * x(89)
      temp = temp + M(91, 59) * x(91)
      temp = temp + M(94, 59) * x(94)
      temp = temp + M(95, 59) * x(95)
      temp = temp + M(96, 59) * x(96)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(74, 58) * x(74)
      temp = temp + M(75, 58) * x(75)
      temp = temp + M(77, 58) * x(77)
      temp = temp + M(83, 58) * x(83)
      temp = temp + M(85, 58) * x(85)
      temp = temp + M(86, 58) * x(86)
      temp = temp + M(87, 58) * x(87)
      temp = temp + M(88, 58) * x(88)
      temp = temp + M(89, 58) * x(89)
      temp = temp + M(91, 58) * x(91)
      temp = temp + M(94, 58) * x(94)
      temp = temp + M(95, 58) * x(95)
      temp = temp + M(96, 58) * x(96)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(81, 57) * x(81)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(86, 56) * x(86)
      temp = temp + M(96, 56) * x(96)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(56, 55) * x(56)
      temp = temp + M(75, 55) * x(75)
      temp = temp + M(77, 55) * x(77)
      temp = temp + M(85, 55) * x(85)
      temp = temp + M(86, 55) * x(86)
      temp = temp + M(87, 55) * x(87)
      temp = temp + M(88, 55) * x(88)
      temp = temp + M(91, 55) * x(91)
      temp = temp + M(94, 55) * x(94)
      temp = temp + M(95, 55) * x(95)
      temp = temp + M(96, 55) * x(96)
      x(55) = ( x(55) - temp ) / M(55, 55)

      x(54) = x(54) / M(54, 54)

      temp = M(68, 53) * x(68)
      x(53) = ( x(53) - temp ) / M(53, 53)

      x(52) = x(52) / M(52, 52)

      x(51) = x(51) / M(51, 51)

      x(50) = x(50) / M(50, 50)

      temp = M(50, 49) * x(50)
      temp = temp + M(51, 49) * x(51)
      temp = temp + M(52, 49) * x(52)
      temp = temp + M(53, 49) * x(53)
      temp = temp + M(54, 49) * x(54)
      temp = temp + M(67, 49) * x(67)
      temp = temp + M(73, 49) * x(73)
      temp = temp + M(74, 49) * x(74)
      temp = temp + M(75, 49) * x(75)
      temp = temp + M(77, 49) * x(77)
      temp = temp + M(83, 49) * x(83)
      temp = temp + M(85, 49) * x(85)
      temp = temp + M(86, 49) * x(86)
      temp = temp + M(87, 49) * x(87)
      temp = temp + M(88, 49) * x(88)
      temp = temp + M(90, 49) * x(90)
      temp = temp + M(91, 49) * x(91)
      temp = temp + M(94, 49) * x(94)
      temp = temp + M(95, 49) * x(95)
      temp = temp + M(96, 49) * x(96)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(52, 48) * x(52)
      x(48) = ( x(48) - temp ) / M(48, 48)

      x(47) = x(47) / M(47, 47)

      temp = M(47, 46) * x(47)
      temp = temp + M(48, 46) * x(48)
      temp = temp + M(50, 46) * x(50)
      temp = temp + M(51, 46) * x(51)
      temp = temp + M(52, 46) * x(52)
      temp = temp + M(53, 46) * x(53)
      temp = temp + M(54, 46) * x(54)
      temp = temp + M(67, 46) * x(67)
      temp = temp + M(73, 46) * x(73)
      temp = temp + M(74, 46) * x(74)
      temp = temp + M(75, 46) * x(75)
      temp = temp + M(77, 46) * x(77)
      temp = temp + M(83, 46) * x(83)
      temp = temp + M(85, 46) * x(85)
      temp = temp + M(86, 46) * x(86)
      temp = temp + M(87, 46) * x(87)
      temp = temp + M(88, 46) * x(88)
      temp = temp + M(90, 46) * x(90)
      temp = temp + M(91, 46) * x(91)
      temp = temp + M(94, 46) * x(94)
      temp = temp + M(95, 46) * x(95)
      temp = temp + M(96, 46) * x(96)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(77, 45) * x(77)
      temp = temp + M(86, 45) * x(86)
      temp = temp + M(93, 45) * x(93)
      temp = temp + M(95, 45) * x(95)
      temp = temp + M(96, 45) * x(96)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(45, 44) * x(45)
      temp = temp + M(75, 44) * x(75)
      temp = temp + M(77, 44) * x(77)
      temp = temp + M(85, 44) * x(85)
      temp = temp + M(86, 44) * x(86)
      temp = temp + M(91, 44) * x(91)
      temp = temp + M(93, 44) * x(93)
      temp = temp + M(95, 44) * x(95)
      temp = temp + M(96, 44) * x(96)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(84, 43) * x(84)
      temp = temp + M(85, 43) * x(85)
      temp = temp + M(86, 43) * x(86)
      temp = temp + M(95, 43) * x(95)
      temp = temp + M(96, 43) * x(96)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(43, 42) * x(43)
      temp = temp + M(56, 42) * x(56)
      temp = temp + M(85, 42) * x(85)
      temp = temp + M(92, 42) * x(92)
      temp = temp + M(94, 42) * x(94)
      temp = temp + M(96, 42) * x(96)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(86, 41) * x(86)
      temp = temp + M(92, 41) * x(92)
      temp = temp + M(94, 41) * x(94)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(86, 40) * x(86)
      temp = temp + M(88, 40) * x(88)
      temp = temp + M(96, 40) * x(96)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(73, 39) * x(73)
      temp = temp + M(74, 39) * x(74)
      temp = temp + M(75, 39) * x(75)
      temp = temp + M(83, 39) * x(83)
      temp = temp + M(89, 39) * x(89)
      temp = temp + M(94, 39) * x(94)
      temp = temp + M(95, 39) * x(95)
      temp = temp + M(96, 39) * x(96)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(86, 38) * x(86)
      temp = temp + M(89, 38) * x(89)
      temp = temp + M(90, 38) * x(90)
      temp = temp + M(94, 38) * x(94)
      x(38) = ( x(38) - temp ) / M(38, 38)

      x(37) = x(37) / M(37, 37)

      temp = M(86, 36) * x(86)
      temp = temp + M(87, 36) * x(87)
      temp = temp + M(94, 36) * x(94)
      temp = temp + M(96, 36) * x(96)
      x(36) = ( x(36) - temp ) / M(36, 36)

      x(35) = x(35) / M(35, 35)

      x(34) = x(34) / M(34, 34)

      x(33) = x(33) / M(33, 33)

      temp = M(33, 32) * x(33)
      temp = temp + M(34, 32) * x(34)
      temp = temp + M(52, 32) * x(52)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(93, 31) * x(93)
      temp = temp + M(94, 31) * x(94)
      x(31) = ( x(31) - temp ) / M(31, 31)

      x(30) = x(30) / M(30, 30)

      x(29) = x(29) / M(29, 29)

      x(28) = x(28) / M(28, 28)

      x(27) = x(27) / M(27, 27)

      x(26) = x(26) / M(26, 26)

      temp = M(79, 25) * x(79)
      temp = temp + M(87, 25) * x(87)
      temp = temp + M(94, 25) * x(94)
      x(25) = ( x(25) - temp ) / M(25, 25)

      temp = M(44, 24) * x(44)
      temp = temp + M(63, 24) * x(63)
      temp = temp + M(73, 24) * x(73)
      temp = temp + M(92, 24) * x(92)
      temp = temp + M(94, 24) * x(94)
      temp = temp + M(96, 24) * x(96)
      x(24) = ( x(24) - temp ) / M(24, 24)

      temp = M(85, 23) * x(85)
      temp = temp + M(86, 23) * x(86)
      temp = temp + M(96, 23) * x(96)
      x(23) = ( x(23) - temp ) / M(23, 23)

      temp = M(32, 22) * x(32)
      x(22) = ( x(22) - temp ) / M(22, 22)

      temp = M(22, 21) * x(22)
      x(21) = ( x(21) - temp ) / M(21, 21)

      x(20) = x(20) / M(20, 20)

      x(19) = x(19) / M(19, 19)

      x(18) = x(18) / M(18, 18)

      temp = M(20, 17) * x(20)
      x(17) = ( x(17) - temp ) / M(17, 17)

      temp = M(19, 16) * x(19)
      x(16) = ( x(16) - temp ) / M(16, 16)

      temp = M(18, 15) * x(18)
      x(15) = ( x(15) - temp ) / M(15, 15)

      x(14) = x(14) / M(14, 14)

      x(13) = x(13) / M(13, 13)

      temp = M(13, 12) * x(13)
      temp = temp + M(14, 12) * x(14)
      temp = temp + M(53, 12) * x(53)
      temp = temp + M(67, 12) * x(67)
      temp = temp + M(74, 12) * x(74)
      temp = temp + M(75, 12) * x(75)
      temp = temp + M(83, 12) * x(83)
      temp = temp + M(85, 12) * x(85)
      temp = temp + M(86, 12) * x(86)
      temp = temp + M(95, 12) * x(95)
      temp = temp + M(96, 12) * x(96)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(11) = x(11) / M(11, 11)

      temp = M(11, 10) * x(11)
      temp = temp + M(86, 10) * x(86)
      temp = temp + M(96, 10) * x(96)
      x(10) = ( x(10) - temp ) / M(10, 10)

      temp = M(24, 9) * x(24)
      temp = temp + M(45, 9) * x(45)
      temp = temp + M(63, 9) * x(63)
      temp = temp + M(74, 9) * x(74)
      temp = temp + M(78, 9) * x(78)
      temp = temp + M(86, 9) * x(86)
      temp = temp + M(95, 9) * x(95)
      temp = temp + M(96, 9) * x(96)
      x(9) = ( x(9) - temp ) / M(9, 9)

      temp = M(24, 8) * x(24)
      temp = temp + M(63, 8) * x(63)
      temp = temp + M(82, 8) * x(82)
      temp = temp + M(86, 8) * x(86)
      temp = temp + M(95, 8) * x(95)
      temp = temp + M(96, 8) * x(96)
      x(8) = ( x(8) - temp ) / M(8, 8)

      temp = M(83, 7) * x(83)
      temp = temp + M(86, 7) * x(86)
      temp = temp + M(89, 7) * x(89)
      temp = temp + M(95, 7) * x(95)
      temp = temp + M(96, 7) * x(96)
      x(7) = ( x(7) - temp ) / M(7, 7)

      temp = M(84, 6) * x(84)
      temp = temp + M(86, 6) * x(86)
      x(6) = ( x(6) - temp ) / M(6, 6)

      temp = M(75, 5) * x(75)
      temp = temp + M(85, 5) * x(85)
      temp = temp + M(86, 5) * x(86)
      temp = temp + M(89, 5) * x(89)
      temp = temp + M(95, 5) * x(95)
      temp = temp + M(96, 5) * x(96)
      x(5) = ( x(5) - temp ) / M(5, 5)

      temp = M(86, 4) * x(86)
      temp = temp + M(88, 4) * x(88)
      temp = temp + M(96, 4) * x(96)
      x(4) = ( x(4) - temp ) / M(4, 4)

      x(3) = x(3) / M(3, 3)

      x(2) = x(2) / M(2, 2)

      x(1) = x(1) / M(1, 1)


      END
