C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine fexchem                        (
     $    NS,Nr,nemis,y,rk,ZCsourc,convers_factor,chem)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_poa.reactions  
C     Species: _ciCB05_poa.species_
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     CHEM: array of chemical production terms.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nemis
      integer nr,ns,i
      double precision w(nr),rk(nr),y(ns),chem(ns),ZCsourc(ns)
      double precision conc(ns), convers_factor(ns)
 
      do i=1,ns
       chem(i)=0.d0
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
C     Compute reaction rates.
 
      call rates                        (
     $    ns,nr,rk,conc,w)
 
C     Chemical production terms.
 
      chem( 88) = chem( 88) + w(  1)
      chem( 92) = chem( 92) + w(  1)
      chem( 94) = chem( 94) - w(  1)
      chem( 88) = chem( 88) - w(  2)
      chem( 91) = chem( 91) + w(  2)
      chem( 91) = chem( 91) - w(  3)
      chem( 92) = chem( 92) - w(  3)
      chem( 94) = chem( 94) + w(  3)
      chem( 88) = chem( 88) - w(  4)
      chem( 92) = chem( 92) + w(  4)
      chem( 94) = chem( 94) - w(  4)
      chem( 87) = chem( 87) + w(  5)
      chem( 88) = chem( 88) - w(  5)
      chem( 94) = chem( 94) - w(  5)
      chem( 88) = chem( 88) - w(  6)
      chem( 92) = chem( 92) - w(  6)
      chem( 94) = chem( 94) + w(  6)
      chem( 87) = chem( 87) + w(  7)
      chem( 91) = chem( 91) - w(  7)
      chem( 94) = chem( 94) - w(  7)
      chem( 88) = chem( 88) + w(  8)
      chem( 91) = chem( 91) - w(  8)
      chem(  4) = chem(  4) + w(  9)
      chem( 91) = chem( 91) - w(  9)
      chem(  4) = chem(  4) - w( 10)
      chem( 88) = chem( 88) + w( 10)
      chem(  4) = chem(  4) - w( 11)
      chem( 86) = chem( 86) +  0.2000000000000000D+01 * w( 11)
      chem( 86) = chem( 86) - w( 12)
      chem( 91) = chem( 91) - w( 12)
      chem( 96) = chem( 96) + w( 12)
      chem( 86) = chem( 86) + w( 13)
      chem( 91) = chem( 91) - w( 13)
      chem( 96) = chem( 96) - w( 13)
      chem( 87) = chem( 87) - w( 14)
      chem( 88) = chem( 88) + w( 14)
      chem( 94) = chem( 94) + w( 14)
      chem( 87) = chem( 87) - w( 15)
      chem( 92) = chem( 92) + w( 15)
      chem( 87) = chem( 87) - w( 16)
      chem( 92) = chem( 92) - w( 16)
      chem( 94) = chem( 94) +  0.2000000000000000D+01 * w( 16)
      chem( 87) = chem( 87) - w( 17)
      chem( 92) = chem( 92) + w( 17)
      chem( 25) = chem( 25) + w( 18)
      chem( 87) = chem( 87) - w( 18)
      chem( 94) = chem( 94) - w( 18)
      chem( 25) = chem( 25) - w( 19)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w( 19)
      chem( 25) = chem( 25) - w( 20)
      chem( 87) = chem( 87) + w( 20)
      chem( 94) = chem( 94) + w( 20)
      chem( 92) = chem( 92) -  0.2000000000000000D+01 * w( 21)
      chem( 94) = chem( 94) +  0.2000000000000000D+01 * w( 21)
      chem( 41) = chem( 41) +  0.2000000000000000D+01 * w( 22)
      chem( 92) = chem( 92) - w( 22)
      chem( 94) = chem( 94) - w( 22)
      chem( 41) = chem( 41) + w( 23)
      chem( 86) = chem( 86) - w( 23)
      chem( 92) = chem( 92) - w( 23)
      chem( 41) = chem( 41) - w( 24)
      chem( 86) = chem( 86) + w( 24)
      chem( 92) = chem( 92) + w( 24)
      chem( 41) = chem( 41) - w( 25)
      chem( 86) = chem( 86) - w( 25)
      chem( 94) = chem( 94) + w( 25)
      chem( 41) = chem( 41) -  0.2000000000000000D+01 * w( 26)
      chem( 92) = chem( 92) + w( 26)
      chem( 94) = chem( 94) + w( 26)
      chem( 79) = chem( 79) + w( 27)
      chem( 86) = chem( 86) - w( 27)
      chem( 94) = chem( 94) - w( 27)
      chem( 79) = chem( 79) - w( 28)
      chem( 86) = chem( 86) - w( 28)
      chem( 87) = chem( 87) + w( 28)
      chem( 86) = chem( 86) + w( 29)
      chem( 92) = chem( 92) - w( 29)
      chem( 94) = chem( 94) + w( 29)
      chem( 96) = chem( 96) - w( 29)
      chem( 36) = chem( 36) + w( 30)
      chem( 94) = chem( 94) - w( 30)
      chem( 96) = chem( 96) - w( 30)
      chem( 36) = chem( 36) - w( 31)
      chem( 94) = chem( 94) + w( 31)
      chem( 96) = chem( 96) + w( 31)
      chem( 36) = chem( 36) - w( 32)
      chem( 86) = chem( 86) - w( 32)
      chem( 94) = chem( 94) + w( 32)
      chem( 40) = chem( 40) + w( 33)
      chem( 96) = chem( 96) -  0.2000000000000000D+01 * w( 33)
      chem( 40) = chem( 40) + w( 34)
      chem( 96) = chem( 96) -  0.2000000000000000D+01 * w( 34)
      chem( 40) = chem( 40) - w( 35)
      chem( 86) = chem( 86) +  0.2000000000000000D+01 * w( 35)
      chem( 40) = chem( 40) - w( 36)
      chem( 86) = chem( 86) - w( 36)
      chem( 96) = chem( 96) + w( 36)
      chem(  4) = chem(  4) - w( 37)
      chem( 86) = chem( 86) + w( 37)
      chem( 96) = chem( 96) + w( 37)
      chem( 86) = chem( 86) - w( 38)
      chem( 96) = chem( 96) + w( 38)
      chem( 86) = chem( 86) - w( 39)
      chem( 88) = chem( 88) - w( 39)
      chem( 96) = chem( 96) + w( 39)
      chem( 86) = chem( 86) -  0.2000000000000000D+01 * w( 40)
      chem( 88) = chem( 88) + w( 40)
      chem( 40) = chem( 40) + w( 41)
      chem( 86) = chem( 86) -  0.2000000000000000D+01 * w( 41)
      chem( 86) = chem( 86) - w( 42)
      chem( 96) = chem( 96) - w( 42)
      chem( 86) = chem( 86) + w( 43)
      chem( 88) = chem( 88) - w( 43)
      chem( 96) = chem( 96) - w( 43)
      chem( 40) = chem( 40) - w( 44)
      chem( 86) = chem( 86) + w( 44)
      chem( 88) = chem( 88) - w( 44)
      chem( 96) = chem( 96) + w( 44)
      chem( 87) = chem( 87) - w( 45)
      chem( 88) = chem( 88) - w( 45)
      chem( 94) = chem( 94) + w( 45)
      chem( 86) = chem( 86) - w( 46)
      chem( 87) = chem( 87) - w( 46)
      chem( 94) = chem( 94) + w( 46)
      chem( 96) = chem( 96) + w( 46)
      chem( 79) = chem( 79) + w( 47)
      chem( 87) = chem( 87) - w( 47)
      chem( 96) = chem( 96) - w( 47)
      chem( 87) = chem( 87) - w( 48)
      chem( 91) = chem( 91) - w( 48)
      chem( 94) = chem( 94) + w( 48)
      chem( 87) = chem( 87) -  0.2000000000000000D+01 * w( 49)
      chem( 94) = chem( 94) +  0.2000000000000000D+01 * w( 49)
      chem( 36) = chem( 36) - w( 50)
      chem( 86) = chem( 86) +  0.3900000000000000D+00 * w( 50)
      chem( 87) = chem( 87) +  0.3900000000000000D+00 * w( 50)
      chem( 94) = chem( 94) +  0.6100000000000000D+00 * w( 50)
      chem( 96) = chem( 96) +  0.6100000000000000D+00 * w( 50)
      chem( 79) = chem( 79) - w( 51)
      chem( 86) = chem( 86) + w( 51)
      chem( 94) = chem( 94) + w( 51)
      chem( 25) = chem( 25) - w( 52)
      chem( 87) = chem( 87) + w( 52)
      chem( 94) = chem( 94) + w( 52)
      chem( 92) = chem( 92) - w( 53)
      chem( 94) = chem( 94) + w( 53)
      chem( 95) = chem( 95) - w( 53)
      chem( 73) = chem( 73) + w( 54)
      chem( 83) = chem( 83) - w( 54)
      chem( 92) = chem( 92) - w( 54)
      chem( 61) = chem( 61) + w( 55)
      chem( 95) = chem( 95) - w( 55)
      chem( 96) = chem( 96) - w( 55)
      chem( 61) = chem( 61) + w( 56)
      chem( 83) = chem( 83) - w( 56)
      chem( 96) = chem( 96) - w( 56)
      chem( 95) = chem( 95) -  0.2000000000000000D+01 * w( 57)
      chem( 83) = chem( 83) -  0.2000000000000000D+01 * w( 58)
      chem( 83) = chem( 83) - w( 59)
      chem( 95) = chem( 95) - w( 59)
      chem( 73) = chem( 73) - w( 60)
      chem( 74) = chem( 74) +  0.6600000000000000D+00 * w( 60)
      chem( 75) = chem( 75) +  0.3300000000000000D+00 * w( 60)
      chem( 79) = chem( 79) + w( 60)
      chem( 85) = chem( 85) +  0.3300000000000000D+00 * w( 60)
      chem( 86) = chem( 86) - w( 60)
      chem( 89) = chem( 89) +  0.3300000000000000D+00 * w( 60)
      chem( 96) = chem( 96) + w( 60)
      chem( 73) = chem( 73) - w( 61)
      chem( 74) = chem( 74) +  0.6600000000000000D+00 * w( 61)
      chem( 75) = chem( 75) +  0.3300000000000000D+00 * w( 61)
      chem( 85) = chem( 85) +  0.3300000000000000D+00 * w( 61)
      chem( 89) = chem( 89) +  0.3300000000000000D+00 * w( 61)
      chem( 94) = chem( 94) + w( 61)
      chem( 96) = chem( 96) + w( 61)
      chem( 61) = chem( 61) - w( 62)
      chem( 75) = chem( 75) +  0.5000000000000000D+00 * w( 62)
      chem( 86) = chem( 86) - w( 62)
      chem( 89) = chem( 89) +  0.5000000000000000D+00 * w( 62)
      chem( 95) = chem( 95) + w( 62)
      chem( 61) = chem( 61) - w( 63)
      chem( 75) = chem( 75) +  0.5000000000000000D+00 * w( 63)
      chem( 86) = chem( 86) + w( 63)
      chem( 89) = chem( 89) +  0.5000000000000000D+00 * w( 63)
      chem( 96) = chem( 96) + w( 63)
      chem( 77) = chem( 77) - w( 64)
      chem( 86) = chem( 86) - w( 64)
      chem( 96) = chem( 96) + w( 64)
      chem(  6) = chem(  6) - w( 65)
      chem( 84) = chem( 84) + w( 65)
      chem( 86) = chem( 86) - w( 65)
      chem( 84) = chem( 84) - w( 66)
      chem( 85) = chem( 85) + w( 66)
      chem( 92) = chem( 92) - w( 66)
      chem( 94) = chem( 94) + w( 66)
      chem( 96) = chem( 96) + w( 66)
      chem( 43) = chem( 43) + w( 67)
      chem( 84) = chem( 84) - w( 67)
      chem( 96) = chem( 96) - w( 67)
      chem( 23) = chem( 23) +  0.6300000000000000D+00 * w( 68)
      chem( 84) = chem( 84) -  0.2000000000000000D+01 * w( 68)
      chem( 85) = chem( 85) +  0.1370000000000000D+01 * w( 68)
      chem( 96) = chem( 96) +  0.7400000000000000D+00 * w( 68)
      chem( 43) = chem( 43) - w( 69)
      chem( 84) = chem( 84) +  0.7000000000000000D+00 * w( 69)
      chem( 86) = chem( 86) - w( 69)
      chem( 95) = chem( 95) +  0.3000000000000000D+00 * w( 69)
      chem( 96) = chem( 96) +  0.3000000000000000D-01 * w( 69)
      chem( 43) = chem( 43) - w( 70)
      chem( 85) = chem( 85) + w( 70)
      chem( 86) = chem( 86) + w( 70)
      chem( 96) = chem( 96) + w( 70)
      chem( 23) = chem( 23) - w( 71)
      chem( 85) = chem( 85) + w( 71)
      chem( 86) = chem( 86) - w( 71)
      chem( 96) = chem( 96) + w( 71)
      chem( 77) = chem( 77) + w( 72)
      chem( 85) = chem( 85) - w( 72)
      chem( 86) = chem( 86) - w( 72)
      chem( 96) = chem( 96) + w( 72)
      chem( 77) = chem( 77) + w( 73)
      chem( 85) = chem( 85) - w( 73)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w( 73)
      chem( 77) = chem( 77) + w( 74)
      chem( 85) = chem( 85) - w( 74)
      chem( 77) = chem( 77) + w( 75)
      chem( 85) = chem( 85) - w( 75)
      chem( 86) = chem( 86) + w( 75)
      chem( 88) = chem( 88) - w( 75)
      chem( 96) = chem( 96) + w( 75)
      chem( 77) = chem( 77) + w( 76)
      chem( 79) = chem( 79) + w( 76)
      chem( 85) = chem( 85) - w( 76)
      chem( 87) = chem( 87) - w( 76)
      chem( 96) = chem( 96) + w( 76)
      chem( 42) = chem( 42) + w( 77)
      chem( 85) = chem( 85) - w( 77)
      chem( 96) = chem( 96) - w( 77)
      chem( 42) = chem( 42) - w( 78)
      chem( 85) = chem( 85) + w( 78)
      chem( 96) = chem( 96) + w( 78)
      chem( 42) = chem( 42) - w( 79)
      chem( 56) = chem( 56) + w( 79)
      chem( 92) = chem( 92) - w( 79)
      chem( 94) = chem( 94) + w( 79)
      chem( 96) = chem( 96) + w( 79)
      chem( 42) = chem( 42) - w( 80)
      chem( 43) = chem( 43) + w( 80)
      chem( 96) = chem( 96) - w( 80)
      chem( 56) = chem( 56) - w( 81)
      chem( 86) = chem( 86) - w( 81)
      chem( 96) = chem( 96) + w( 81)
      chem( 86) = chem( 86) + w( 82)
      chem( 88) = chem( 88) - w( 82)
      chem( 89) = chem( 89) - w( 82)
      chem( 93) = chem( 93) + w( 82)
      chem( 86) = chem( 86) - w( 83)
      chem( 89) = chem( 89) - w( 83)
      chem( 93) = chem( 93) + w( 83)
      chem( 79) = chem( 79) + w( 84)
      chem( 87) = chem( 87) - w( 84)
      chem( 89) = chem( 89) - w( 84)
      chem( 93) = chem( 93) + w( 84)
      chem( 77) = chem( 77) + w( 85)
      chem( 84) = chem( 84) + w( 85)
      chem( 89) = chem( 89) - w( 85)
      chem( 96) = chem( 96) + w( 85)
      chem( 84) = chem( 84) + w( 86)
      chem( 92) = chem( 92) - w( 86)
      chem( 93) = chem( 93) - w( 86)
      chem( 94) = chem( 94) + w( 86)
      chem( 31) = chem( 31) + w( 87)
      chem( 93) = chem( 93) - w( 87)
      chem( 94) = chem( 94) - w( 87)
      chem( 31) = chem( 31) - w( 88)
      chem( 93) = chem( 93) + w( 88)
      chem( 94) = chem( 94) + w( 88)
      chem( 31) = chem( 31) - w( 89)
      chem( 93) = chem( 93) + w( 89)
      chem( 94) = chem( 94) + w( 89)
      chem( 62) = chem( 62) +  0.8000000000000000D+00 * w( 90)
      chem( 76) = chem( 76) +  0.2000000000000000D+00 * w( 90)
      chem( 91) = chem( 91) +  0.2000000000000000D+00 * w( 90)
      chem( 93) = chem( 93) - w( 90)
      chem( 96) = chem( 96) - w( 90)
      chem( 76) = chem( 76) +  0.1000000000000000D+00 * w( 91)
      chem( 84) = chem( 84) -  0.9999999999999998D-01 * w( 91)
      chem( 85) = chem( 85) + w( 91)
      chem( 93) = chem( 93) - w( 91)
      chem( 96) = chem( 96) +  0.9000000000000000D+00 * w( 91)
      chem( 76) = chem( 76) +  0.1000000000000000D+00 * w( 92)
      chem( 84) = chem( 84) +  0.9000000000000000D+00 * w( 92)
      chem( 93) = chem( 93) - w( 92)
      chem( 95) = chem( 95) - w( 92)
      chem( 84) = chem( 84) +  0.2000000000000000D+01 * w( 93)
      chem( 93) = chem( 93) -  0.2000000000000000D+01 * w( 93)
      chem( 62) = chem( 62) - w( 94)
      chem( 86) = chem( 86) - w( 94)
      chem( 93) = chem( 93) + w( 94)
      chem( 62) = chem( 62) - w( 95)
      chem( 84) = chem( 84) + w( 95)
      chem( 86) = chem( 86) + w( 95)
      chem( 76) = chem( 76) - w( 96)
      chem( 84) = chem( 84) + w( 96)
      chem( 86) = chem( 86) - w( 96)
      chem( 75) = chem( 75) - w( 97)
      chem( 86) = chem( 86) + w( 97)
      chem( 88) = chem( 88) - w( 97)
      chem( 90) = chem( 90) + w( 97)
      chem( 75) = chem( 75) - w( 98)
      chem( 86) = chem( 86) - w( 98)
      chem( 90) = chem( 90) + w( 98)
      chem( 75) = chem( 75) - w( 99)
      chem( 79) = chem( 79) + w( 99)
      chem( 87) = chem( 87) - w( 99)
      chem( 90) = chem( 90) + w( 99)
      chem( 75) = chem( 75) - w(100)
      chem( 77) = chem( 77) + w(100)
      chem( 84) = chem( 84) + w(100)
      chem( 96) = chem( 96) + w(100)
      chem( 89) = chem( 89) + w(101)
      chem( 90) = chem( 90) - w(101)
      chem( 92) = chem( 92) - w(101)
      chem( 94) = chem( 94) + w(101)
      chem( 95) = chem( 95) + w(101)
      chem( 96) = chem( 96) + w(101)
      chem( 38) = chem( 38) + w(102)
      chem( 90) = chem( 90) - w(102)
      chem( 94) = chem( 94) - w(102)
      chem( 38) = chem( 38) - w(103)
      chem( 90) = chem( 90) + w(103)
      chem( 94) = chem( 94) + w(103)
      chem( 38) = chem( 38) - w(104)
      chem( 90) = chem( 90) + w(104)
      chem( 94) = chem( 94) + w(104)
      chem( 38) = chem( 38) - w(105)
      chem( 86) = chem( 86) - w(105)
      chem( 89) = chem( 89) + w(105)
      chem( 94) = chem( 94) + w(105)
      chem( 62) = chem( 62) +  0.8000000000000000D+00 * w(106)
      chem( 76) = chem( 76) +  0.2000000000000000D+00 * w(106)
      chem( 90) = chem( 90) - w(106)
      chem( 91) = chem( 91) +  0.2000000000000000D+00 * w(106)
      chem( 96) = chem( 96) - w(106)
      chem( 76) = chem( 76) +  0.1000000000000000D+00 * w(107)
      chem( 84) = chem( 84) - w(107)
      chem( 85) = chem( 85) +  0.1000000000000000D+00 * w(107)
      chem( 89) = chem( 89) +  0.9000000000000000D+00 * w(107)
      chem( 93) = chem( 93) - w(107)
      chem( 95) = chem( 95) +  0.9000000000000000D+00 * w(107)
      chem( 96) = chem( 96) + w(107)
      chem( 76) = chem( 76) +  0.1000000000000000D+00 * w(108)
      chem( 89) = chem( 89) +  0.9000000000000000D+00 * w(108)
      chem( 93) = chem( 93) - w(108)
      chem( 95) = chem( 95) - w(108)
      chem( 89) = chem( 89) +  0.2000000000000000D+01 * w(109)
      chem( 90) = chem( 90) -  0.2000000000000000D+01 * w(109)
      chem( 95) = chem( 95) +  0.2000000000000000D+01 * w(109)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w(109)
      chem( 84) = chem( 84) + w(110)
      chem( 89) = chem( 89) + w(110)
      chem( 90) = chem( 90) - w(110)
      chem( 93) = chem( 93) - w(110)
      chem( 95) = chem( 95) + w(110)
      chem( 96) = chem( 96) + w(110)
      chem( 39) = chem( 39) +  0.7600000000000000D+00 * w(111)
      chem( 74) = chem( 74) -  0.8900000000000000D+00 * w(111)
      chem( 75) = chem( 75) +  0.5000000000000000D-01 * w(111)
      chem( 83) = chem( 83) +  0.1300000000000000D+00 * w(111)
      chem( 86) = chem( 86) - w(111)
      chem( 89) = chem( 89) +  0.6000000000000000D-01 * w(111)
      chem( 95) = chem( 95) +  0.8700000000000000D+00 * w(111)
      chem( 96) = chem( 96) +  0.1100000000000000D+00 * w(111)
      chem( 39) = chem( 39) -  0.9800000000000000D+00 * w(112)
      chem( 74) = chem( 74) +  0.2100000000000000D+01 * w(112)
      chem( 75) = chem( 75) +  0.5000000000000000D+00 * w(112)
      chem( 83) = chem( 83) +  0.4000000000000000D-01 * w(112)
      chem( 89) = chem( 89) +  0.6000000000000000D+00 * w(112)
      chem( 95) = chem( 95) +  0.9600000000000000D+00 * w(112)
      chem( 96) = chem( 96) +  0.9399999999999999D+00 * w(112)
      chem( 39) = chem( 39) - w(113)
      chem( 96) = chem( 96) + w(113)
      chem( 39) = chem( 39) - w(114)
      chem( 73) = chem( 73) + w(114)
      chem( 94) = chem( 94) - w(114)
      chem( 58) = chem( 58) - w(115)
      chem( 74) = chem( 74) +  0.2000000000000000D+00 * w(115)
      chem( 75) = chem( 75) +  0.3000000000000000D+00 * w(115)
      chem( 77) = chem( 77) +  0.2000000000000000D+00 * w(115)
      chem( 83) = chem( 83) +  0.1000000000000000D-01 * w(115)
      chem( 85) = chem( 85) +  0.2000000000000000D+00 * w(115)
      chem( 86) = chem( 86) +  0.1000000000000000D+00 * w(115)
      chem( 88) = chem( 88) - w(115)
      chem( 89) = chem( 89) +  0.2000000000000000D+00 * w(115)
      chem( 95) = chem( 95) +  0.2000000000000000D+00 * w(115)
      chem( 96) = chem( 96) +  0.3000000000000000D+00 * w(115)
      chem( 58) = chem( 58) - w(116)
      chem( 74) = chem( 74) +  0.7000000000000000D+00 * w(116)
      chem( 75) = chem( 75) +  0.6200000000000000D+00 * w(116)
      chem( 85) = chem( 85) +  0.8000000000000000D+00 * w(116)
      chem( 86) = chem( 86) - w(116)
      chem( 89) = chem( 89) +  0.3300000000000000D+00 * w(116)
      chem( 95) = chem( 95) +  0.8000000000000000D+00 * w(116)
      chem( 96) = chem( 96) +  0.9500000000000000D+00 * w(116)
      chem( 58) = chem( 58) - w(117)
      chem( 74) = chem( 74) + w(117)
      chem( 75) = chem( 75) +  0.3200000000000000D+00 * w(117)
      chem( 77) = chem( 77) +  0.3300000000000000D+00 * w(117)
      chem( 85) = chem( 85) +  0.7400000000000000D+00 * w(117)
      chem( 86) = chem( 86) +  0.1000000000000000D+00 * w(117)
      chem( 89) = chem( 89) +  0.1800000000000000D+00 * w(117)
      chem( 91) = chem( 91) - w(117)
      chem( 95) = chem( 95) +  0.2200000000000000D+00 * w(117)
      chem( 96) = chem( 96) +  0.4400000000000000D+00 * w(117)
      chem( 58) = chem( 58) - w(118)
      chem( 74) = chem( 74) + w(118)
      chem( 75) = chem( 75) +  0.5600000000000001D+00 * w(118)
      chem( 83) = chem( 83) +  0.9000000000000000D-01 * w(118)
      chem( 85) = chem( 85) + w(118)
      chem( 87) = chem( 87) - w(118)
      chem( 89) = chem( 89) +  0.3500000000000000D+00 * w(118)
      chem( 94) = chem( 94) + w(118)
      chem( 95) = chem( 95) +  0.9100000000000000D+00 * w(118)
      chem( 55) = chem( 55) - w(119)
      chem( 77) = chem( 77) + w(119)
      chem( 85) = chem( 85) + w(119)
      chem( 86) = chem( 86) +  0.3000000000000000D+00 * w(119)
      chem( 88) = chem( 88) - w(119)
      chem( 95) = chem( 95) +  0.7000000000000000D+00 * w(119)
      chem( 96) = chem( 96) +  0.1700000000000000D+01 * w(119)
      chem( 55) = chem( 55) - w(120)
      chem( 75) = chem( 75) +  0.2200000000000000D+00 * w(120)
      chem( 85) = chem( 85) +  0.1560000000000000D+01 * w(120)
      chem( 86) = chem( 86) - w(120)
      chem( 95) = chem( 95) + w(120)
      chem( 96) = chem( 96) + w(120)
      chem( 55) = chem( 55) - w(121)
      chem( 56) = chem( 56) +  0.3700000000000000D+00 * w(121)
      chem( 77) = chem( 77) +  0.6300000000000000D+00 * w(121)
      chem( 85) = chem( 85) + w(121)
      chem( 86) = chem( 86) +  0.1300000000000000D+00 * w(121)
      chem( 91) = chem( 91) - w(121)
      chem( 96) = chem( 96) +  0.1300000000000000D+00 * w(121)
      chem( 55) = chem( 55) - w(122)
      chem( 85) = chem( 85) +  0.2000000000000000D+01 * w(122)
      chem( 87) = chem( 87) - w(122)
      chem( 94) = chem( 94) + w(122)
      chem( 95) = chem( 95) + w(122)
      chem( 59) = chem( 59) - w(123)
      chem( 74) = chem( 74) +  0.1000000000000000D+00 * w(123)
      chem( 75) = chem( 75) +  0.6600000000000000D+00 * w(123)
      chem( 77) = chem( 77) +  0.1000000000000000D+00 * w(123)
      chem( 88) = chem( 88) - w(123)
      chem( 89) = chem( 89) +  0.1240000000000000D+01 * w(123)
      chem( 95) = chem( 95) +  0.1000000000000000D+00 * w(123)
      chem( 96) = chem( 96) +  0.1000000000000000D+00 * w(123)
      chem( 59) = chem( 59) - w(124)
      chem( 75) = chem( 75) +  0.7000000000000000D+00 * w(124)
      chem( 86) = chem( 86) - w(124)
      chem( 89) = chem( 89) +  0.1300000000000000D+01 * w(124)
      chem( 95) = chem( 95) + w(124)
      chem( 96) = chem( 96) + w(124)
      chem( 59) = chem( 59) - w(125)
      chem( 75) = chem( 75) +  0.3500000000000000D+00 * w(125)
      chem( 77) = chem( 77) +  0.2500000000000000D+00 * w(125)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(125)
      chem( 86) = chem( 86) +  0.5000000000000000D+00 * w(125)
      chem( 88) = chem( 88) +  0.5000000000000000D+00 * w(125)
      chem( 89) = chem( 89) +  0.6500000000000000D+00 * w(125)
      chem( 91) = chem( 91) - w(125)
      chem( 96) = chem( 96) +  0.5000000000000000D+00 * w(125)
      chem( 59) = chem( 59) - w(126)
      chem( 75) = chem( 75) +  0.6400000000000000D+00 * w(126)
      chem( 87) = chem( 87) - w(126)
      chem( 89) = chem( 89) +  0.1180000000000000D+01 * w(126)
      chem( 94) = chem( 94) + w(126)
      chem( 96) = chem( 96) + w(126)
      chem(  8) = chem(  8) - w(127)
      chem( 24) = chem( 24) +  0.5600000000000001D+00 * w(127)
      chem( 63) = chem( 63) +  0.3600000000000000D+00 * w(127)
      chem( 82) = chem( 82) +  0.2500000000000000D+00 * w(127)
      chem( 86) = chem( 86) - w(127)
      chem( 95) = chem( 95) +  0.8000000000000000D-01 * w(127)
      chem( 96) = chem( 96) +  0.4400000000000000D+00 * w(127)
      chem( 24) = chem( 24) - w(128)
      chem( 44) = chem( 44) +  0.9000000000000000D+00 * w(128)
      chem( 73) = chem( 73) +  0.1000000000000000D+00 * w(128)
      chem( 92) = chem( 92) - w(128)
      chem( 94) = chem( 94) +  0.9000000000000000D+00 * w(128)
      chem( 96) = chem( 96) +  0.9000000000000000D+00 * w(128)
      chem( 24) = chem( 24) - w(129)
      chem( 63) = chem( 63) + w(129)
      chem( 96) = chem( 96) + w(129)
      chem( 44) = chem( 44) +  0.3000000000000000D+00 * w(130)
      chem( 63) = chem( 63) - w(130)
      chem( 64) = chem( 64) +  0.4000000000000000D+00 * w(130)
      chem( 86) = chem( 86) - w(130)
      chem( 95) = chem( 95) +  0.6000000000000000D+00 * w(130)
      chem( 96) = chem( 96) +  0.6000000000000000D+00 * w(130)
      chem( 63) = chem( 63) - w(131)
      chem( 64) = chem( 64) + w(131)
      chem( 79) = chem( 79) + w(131)
      chem( 87) = chem( 87) - w(131)
      chem( 64) = chem( 64) - w(132)
      chem( 73) = chem( 73) + w(132)
      chem( 94) = chem( 94) - w(132)
      chem( 63) = chem( 63) + w(133)
      chem( 64) = chem( 64) - w(133)
      chem( 96) = chem( 96) - w(133)
      chem( 44) = chem( 44) - w(134)
      chem( 77) = chem( 77) + w(134)
      chem( 93) = chem( 93) + w(134)
      chem( 96) = chem( 96) + w(134)
      chem( 44) = chem( 44) - w(135)
      chem( 77) = chem( 77) +  0.2000000000000000D+01 * w(135)
      chem( 85) = chem( 85) + w(135)
      chem( 86) = chem( 86) - w(135)
      chem( 93) = chem( 93) + w(135)
      chem( 95) = chem( 95) + w(135)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w(135)
      chem( 44) = chem( 44) - w(136)
      chem( 45) = chem( 45) +  0.2000000000000000D+00 * w(136)
      chem( 75) = chem( 75) +  0.3000000000000000D-01 * w(136)
      chem( 77) = chem( 77) +  0.6899999999999999D+00 * w(136)
      chem( 85) = chem( 85) +  0.7000000000000000D+00 * w(136)
      chem( 86) = chem( 86) +  0.8000000000000000D-01 * w(136)
      chem( 91) = chem( 91) - w(136)
      chem( 93) = chem( 93) +  0.6200000000000000D+00 * w(136)
      chem( 95) = chem( 95) +  0.3000000000000000D-01 * w(136)
      chem( 96) = chem( 96) +  0.7600000000000000D+00 * w(136)
      chem(  9) = chem(  9) - w(137)
      chem( 24) = chem( 24) +  0.3000000000000000D+00 * w(137)
      chem( 45) = chem( 45) +  0.8000000000000000D+00 * w(137)
      chem( 63) = chem( 63) +  0.2000000000000000D-01 * w(137)
      chem( 74) = chem( 74) +  0.1100000000000000D+01 * w(137)
      chem( 78) = chem( 78) +  0.2740000000000000D+00 * w(137)
      chem( 86) = chem( 86) - w(137)
      chem( 95) = chem( 95) +  0.5000000000000000D+00 * w(137)
      chem( 96) = chem( 96) +  0.7000000000000000D+00 * w(137)
      chem( 45) = chem( 45) - w(138)
      chem( 86) = chem( 86) - w(138)
      chem( 93) = chem( 93) + w(138)
      chem( 95) = chem( 95) + w(138)
      chem( 45) = chem( 45) - w(139)
      chem( 77) = chem( 77) + w(139)
      chem( 93) = chem( 93) + w(139)
      chem( 96) = chem( 96) + w(139)
      chem( 71) = chem( 71) - w(140)
      chem( 72) = chem( 72) +  0.7500000000000000D+00 * w(140)
      chem( 74) = chem( 74) +  0.2500000000000000D+00 * w(140)
      chem( 85) = chem( 85) +  0.5000000000000000D+00 * w(140)
      chem( 88) = chem( 88) - w(140)
      chem( 90) = chem( 90) +  0.2500000000000000D+00 * w(140)
      chem( 95) = chem( 95) +  0.2500000000000000D+00 * w(140)
      chem( 96) = chem( 96) +  0.2500000000000000D+00 * w(140)
      chem( 71) = chem( 71) - w(141)
      chem( 72) = chem( 72) +  0.9120000000000000D+00 * w(141)
      chem( 80) = chem( 80) + w(141)
      chem( 83) = chem( 83) +  0.8799999999999999D-01 * w(141)
      chem( 85) = chem( 85) +  0.6290000000000000D+00 * w(141)
      chem( 86) = chem( 86) - w(141)
      chem( 95) = chem( 95) +  0.9910000000000000D+00 * w(141)
      chem( 96) = chem( 96) +  0.9120000000000000D+00 * w(141)
      chem( 71) = chem( 71) - w(142)
      chem( 72) = chem( 72) +  0.6500000000000000D+00 * w(142)
      chem( 74) = chem( 74) +  0.3500000000000000D+00 * w(142)
      chem( 75) = chem( 75) +  0.1500000000000000D+00 * w(142)
      chem( 77) = chem( 77) +  0.6600000000000000D-01 * w(142)
      chem( 85) = chem( 85) +  0.6000000000000000D+00 * w(142)
      chem( 86) = chem( 86) +  0.2660000000000000D+00 * w(142)
      chem( 90) = chem( 90) +  0.2000000000000000D+00 * w(142)
      chem( 91) = chem( 91) - w(142)
      chem( 95) = chem( 95) +  0.2000000000000000D+00 * w(142)
      chem( 96) = chem( 96) +  0.6600000000000000D-01 * w(142)
      chem( 70) = chem( 70) + w(143)
      chem( 71) = chem( 71) - w(143)
      chem( 72) = chem( 72) +  0.2000000000000000D+00 * w(143)
      chem( 73) = chem( 73) +  0.8000000000000000D+00 * w(143)
      chem( 74) = chem( 74) +  0.2400000000000000D+01 * w(143)
      chem( 75) = chem( 75) +  0.8000000000000000D+00 * w(143)
      chem( 87) = chem( 87) - w(143)
      chem( 94) = chem( 94) +  0.2000000000000000D+00 * w(143)
      chem( 95) = chem( 95) + w(143)
      chem( 96) = chem( 96) +  0.8000000000000000D+00 * w(143)
      chem( 45) = chem( 45) +  0.1680000000000000D+00 * w(144)
      chem( 72) = chem( 72) - w(144)
      chem( 74) = chem( 74) +  0.1565000000000000D+01 * w(144)
      chem( 75) = chem( 75) +  0.1200000000000000D+00 * w(144)
      chem( 77) = chem( 77) +  0.3340000000000000D+00 * w(144)
      chem( 85) = chem( 85) +  0.1670000000000000D+00 * w(144)
      chem( 86) = chem( 86) - w(144)
      chem( 89) = chem( 89) +  0.2520000000000000D+00 * w(144)
      chem( 90) = chem( 90) +  0.2500000000000000D+00 * w(144)
      chem( 93) = chem( 93) +  0.2100000000000000D+00 * w(144)
      chem( 95) = chem( 95) +  0.7130000000000000D+00 * w(144)
      chem( 96) = chem( 96) +  0.5030000000000000D+00 * w(144)
      chem( 45) = chem( 45) +  0.8500000000000000D+00 * w(145)
      chem( 72) = chem( 72) - w(145)
      chem( 74) = chem( 74) +  0.3600000000000000D+00 * w(145)
      chem( 77) = chem( 77) +  0.2250000000000000D+00 * w(145)
      chem( 85) = chem( 85) +  0.1500000000000000D+00 * w(145)
      chem( 86) = chem( 86) +  0.2680000000000000D+00 * w(145)
      chem( 89) = chem( 89) +  0.2000000000000000D-01 * w(145)
      chem( 91) = chem( 91) - w(145)
      chem( 93) = chem( 93) +  0.1140000000000000D+00 * w(145)
      chem( 95) = chem( 95) +  0.6400000000000000D-01 * w(145)
      chem( 96) = chem( 96) +  0.1540000000000000D+00 * w(145)
      chem( 72) = chem( 72) - w(146)
      chem( 73) = chem( 73) +  0.8500000000000000D+00 * w(146)
      chem( 74) = chem( 74) +  0.1282000000000000D+01 * w(146)
      chem( 75) = chem( 75) +  0.3570000000000000D+00 * w(146)
      chem( 77) = chem( 77) +  0.6430000000000000D+00 * w(146)
      chem( 79) = chem( 79) +  0.1500000000000000D+00 * w(146)
      chem( 85) = chem( 85) +  0.2820000000000000D+00 * w(146)
      chem( 87) = chem( 87) - w(146)
      chem( 90) = chem( 90) +  0.7500000000000000D-01 * w(146)
      chem( 95) = chem( 95) +  0.7500000000000000D-01 * w(146)
      chem( 96) = chem( 96) +  0.9250000000000000D+00 * w(146)
      chem( 72) = chem( 72) - w(147)
      chem( 74) = chem( 74) +  0.8320000000000000D+00 * w(147)
      chem( 77) = chem( 77) +  0.3330000000000000D+00 * w(147)
      chem( 85) = chem( 85) +  0.9000000000000000D+00 * w(147)
      chem( 89) = chem( 89) +  0.6700000000000000D-01 * w(147)
      chem( 93) = chem( 93) +  0.9670000000000000D+00 * w(147)
      chem( 95) = chem( 95) +  0.7000000000000000D+00 * w(147)
      chem( 96) = chem( 96) +  0.1033000000000000D+01 * w(147)
      chem( 10) = chem( 10) - w(148)
      chem( 11) = chem( 11) + w(148)
      chem( 86) = chem( 86) - w(148)
      chem( 96) = chem( 96) + w(148)
      chem(  5) = chem(  5) - w(149)
      chem( 75) = chem( 75) +  0.5000000000000000D-01 * w(149)
      chem( 85) = chem( 85) +  0.1000000000000000D+00 * w(149)
      chem( 86) = chem( 86) - w(149)
      chem( 89) = chem( 89) +  0.9000000000000000D+00 * w(149)
      chem( 95) = chem( 95) +  0.1000000000000000D+00 * w(149)
      chem( 96) = chem( 96) + w(149)
      chem(  7) = chem(  7) - w(150)
      chem( 83) = chem( 83) +  0.8999999999999999D-02 * w(150)
      chem( 86) = chem( 86) - w(150)
      chem( 89) = chem( 89) +  0.9910000000000000D+00 * w(150)
      chem( 95) = chem( 95) +  0.9910000000000000D+00 * w(150)
      chem( 96) = chem( 96) + w(150)
      chem( 71) = chem( 71) - w(151)
      chem( 72) = chem( 72) +  0.2000000000000000D+00 * w(151)
      chem( 73) = chem( 73) +  0.8000000000000000D+00 * w(151)
      chem( 74) = chem( 74) +  0.2400000000000000D+01 * w(151)
      chem( 75) = chem( 75) +  0.8000000000000000D+00 * w(151)
      chem( 92) = chem( 92) +  0.2000000000000000D+00 * w(151)
      chem( 94) = chem( 94) - w(151)
      chem( 95) = chem( 95) + w(151)
      chem( 96) = chem( 96) +  0.8000000000000000D+00 * w(151)
      chem( 40) = chem( 40) +  0.5000000000000000D+00 * w(152)
      chem( 96) = chem( 96) - w(152)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(153)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(153)
      chem( 94) = chem( 94) - w(153)
      chem( 79) = chem( 79) + w(154)
      chem( 87) = chem( 87) - w(154)
      chem( 25) = chem( 25) - w(155)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w(155)
      chem( 46) = chem( 46) - w(156)
      chem( 50) = chem( 50) +  0.1700000000000000D+00 * w(156)
      chem( 51) = chem( 51) +  0.1000000000000000D+00 * w(156)
      chem( 53) = chem( 53) + w(156)
      chem( 54) = chem( 54) +  0.3000000000000000D+00 * w(156)
      chem( 74) = chem( 74) +  0.1660000000000000D+01 * w(156)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(156)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(156)
      chem( 85) = chem( 85) +  0.2800000000000000D+00 * w(156)
      chem( 86) = chem( 86) - w(156)
      chem( 95) = chem( 95) +  0.1250000000000000D+01 * w(156)
      chem( 96) = chem( 96) +  0.7500000000000000D+00 * w(156)
      chem( 46) = chem( 46) - w(157)
      chem( 48) = chem( 48) +  0.9000000000000000D+00 * w(157)
      chem( 50) = chem( 50) +  0.1600000000000000D+00 * w(157)
      chem( 51) = chem( 51) +  0.5000000000000000D-01 * w(157)
      chem( 52) = chem( 52) +  0.2000000000000000D-03 * w(157)
      chem( 54) = chem( 54) +  0.1800000000000000D+00 * w(157)
      chem( 74) = chem( 74) +  0.7000000000000000D+01 * w(157)
      chem( 75) = chem( 75) +  0.2100000000000000D+00 * w(157)
      chem( 77) = chem( 77) +  0.1000000000000000D-02 * w(157)
      chem( 83) = chem( 83) +  0.1800000000000000D+00 * w(157)
      chem( 85) = chem( 85) +  0.2400000000000000D+00 * w(157)
      chem( 86) = chem( 86) +  0.5700000000000000D+00 * w(157)
      chem( 90) = chem( 90) +  0.3900000000000000D+00 * w(157)
      chem( 91) = chem( 91) - w(157)
      chem( 95) = chem( 95) +  0.7600000000000000D+00 * w(157)
      chem( 96) = chem( 96) +  0.7000000000000001D-01 * w(157)
      chem( 46) = chem( 46) - w(158)
      chem( 47) = chem( 47) +  0.1000000000000000D+00 * w(158)
      chem( 54) = chem( 54) +  0.7000000000000000D+00 * w(158)
      chem( 67) = chem( 67) + w(158)
      chem( 73) = chem( 73) +  0.5300000000000000D+00 * w(158)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(158)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(158)
      chem( 87) = chem( 87) - w(158)
      chem( 94) = chem( 94) +  0.4700000000000000D+00 * w(158)
      chem( 95) = chem( 95) +  0.1030000000000000D+01 * w(158)
      chem( 96) = chem( 96) +  0.2800000000000000D+00 * w(158)
      chem( 49) = chem( 49) - w(159)
      chem( 50) = chem( 50) +  0.2000000000000000D+00 * w(159)
      chem( 51) = chem( 51) +  0.3500000000000000D-02 * w(159)
      chem( 53) = chem( 53) + w(159)
      chem( 54) = chem( 54) +  0.3500000000000000D+00 * w(159)
      chem( 74) = chem( 74) +  0.1660000000000000D+01 * w(159)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(159)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(159)
      chem( 85) = chem( 85) +  0.2800000000000000D+00 * w(159)
      chem( 86) = chem( 86) - w(159)
      chem( 95) = chem( 95) +  0.1250000000000000D+01 * w(159)
      chem( 96) = chem( 96) +  0.7500000000000000D+00 * w(159)
      chem( 48) = chem( 48) +  0.9000000000000000D+00 * w(160)
      chem( 49) = chem( 49) - w(160)
      chem( 50) = chem( 50) +  0.1000000000000000D+00 * w(160)
      chem( 52) = chem( 52) +  0.2000000000000000D-03 * w(160)
      chem( 54) = chem( 54) +  0.9000000000000000D-01 * w(160)
      chem( 74) = chem( 74) +  0.7000000000000000D+01 * w(160)
      chem( 75) = chem( 75) +  0.2100000000000000D+00 * w(160)
      chem( 77) = chem( 77) +  0.1000000000000000D-02 * w(160)
      chem( 83) = chem( 83) +  0.1800000000000000D+00 * w(160)
      chem( 85) = chem( 85) +  0.2400000000000000D+00 * w(160)
      chem( 86) = chem( 86) +  0.5700000000000000D+00 * w(160)
      chem( 90) = chem( 90) +  0.3900000000000000D+00 * w(160)
      chem( 91) = chem( 91) - w(160)
      chem( 95) = chem( 95) +  0.7600000000000000D+00 * w(160)
      chem( 96) = chem( 96) +  0.7000000000000001D-01 * w(160)
      chem( 47) = chem( 47) +  0.2700000000000000D+00 * w(161)
      chem( 49) = chem( 49) - w(161)
      chem( 54) = chem( 54) +  0.6899999999999999D+00 * w(161)
      chem( 67) = chem( 67) + w(161)
      chem( 73) = chem( 73) +  0.5300000000000000D+00 * w(161)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(161)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(161)
      chem( 87) = chem( 87) - w(161)
      chem( 94) = chem( 94) +  0.4700000000000000D+00 * w(161)
      chem( 95) = chem( 95) +  0.1030000000000000D+01 * w(161)
      chem( 96) = chem( 96) +  0.2800000000000000D+00 * w(161)
      chem( 69) = chem( 69) +  0.7800000000000000D+00 * w(162)
      chem( 82) = chem( 82) - w(162)
      chem( 69) = chem( 69) +  0.7800000000000000D+00 * w(163)
      chem( 82) = chem( 82) - w(163)
      chem( 69) = chem( 69) +  0.7800000000000000D+00 * w(164)
      chem( 82) = chem( 82) - w(164)
      chem( 65) = chem( 65) +  0.9700000000000000D-01 * w(165)
      chem( 66) = chem( 66) +  0.7480000000000000D+00 * w(165)
      chem( 82) = chem( 82) - w(165)
      chem( 65) = chem( 65) +  0.9700000000000000D-01 * w(166)
      chem( 66) = chem( 66) +  0.7480000000000000D+00 * w(166)
      chem( 82) = chem( 82) - w(166)
      chem( 69) = chem( 69) +  0.7100000000000000D+00 * w(167)
      chem( 78) = chem( 78) - w(167)
      chem( 69) = chem( 69) +  0.7100000000000000D+00 * w(168)
      chem( 78) = chem( 78) - w(168)
      chem( 69) = chem( 69) +  0.7100000000000000D+00 * w(169)
      chem( 78) = chem( 78) - w(169)
      chem( 65) = chem( 65) +  0.6300000000000000D-01 * w(170)
      chem( 66) = chem( 66) +  0.4240000000000000D+00 * w(170)
      chem( 78) = chem( 78) - w(170)
      chem( 65) = chem( 65) +  0.6300000000000000D-01 * w(171)
      chem( 66) = chem( 66) +  0.4240000000000000D+00 * w(171)
      chem( 78) = chem( 78) - w(171)
      chem( 28) = chem( 28) +  0.2818000000000000D+00 * w(172)
      chem( 29) = chem( 29) +  0.2970000000000000D-01 * w(172)
      chem( 80) = chem( 80) - w(172)
      chem( 37) = chem( 37) +  0.2560000000000000D-01 * w(173)
      chem( 80) = chem( 80) - w(173)
      chem( 81) = chem( 81) +  0.2190000000000000D+00 * w(173)
      chem( 37) = chem( 37) +  0.2560000000000000D-01 * w(174)
      chem( 80) = chem( 80) - w(174)
      chem( 81) = chem( 81) +  0.2190000000000000D+00 * w(174)
      chem( 80) = chem( 80) - w(175)
      chem( 81) = chem( 81) +  0.4380000000000000D+00 * w(175)
      chem( 70) = chem( 70) +  0.4600000000000000D-01 * w(176)
      chem( 80) = chem( 80) - w(176)
      chem( 81) = chem( 81) +  0.4180000000000000D+00 * w(176)
      chem( 70) = chem( 70) - w(177)
      chem( 30) = chem( 30) +  0.7385000000000000D-01 * w(178)
      chem( 70) = chem( 70) - w(178)
      chem( 81) = chem( 81) - w(179)
      chem( 81) = chem( 81) - w(180)
      chem( 81) = chem( 81) - w(181)
      chem( 57) = chem( 57) + w(182)
      chem( 81) = chem( 81) - w(182)
      chem( 57) = chem( 57) - w(183)
      chem( 81) = chem( 81) + w(183)
      chem( 26) = chem( 26) +  0.6741000000000000D-01 * w(184)
      chem( 27) = chem( 27) +  0.4706000000000000D-01 * w(184)
      chem( 57) = chem( 57) - w(184)
      chem( 57) = chem( 57) - w(185)
      chem( 81) = chem( 81) + w(185)
      chem( 28) = chem( 28) - w(186)
      chem( 12) = chem( 12) - w(187)
      chem( 13) = chem( 13) +  0.7400000000000000D+00 * w(187)
      chem( 14) = chem( 14) +  0.2600000000000000D+00 * w(187)
      chem( 53) = chem( 53) + w(187)
      chem( 74) = chem( 74) +  0.1660000000000000D+01 * w(187)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(187)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(187)
      chem( 85) = chem( 85) +  0.2800000000000000D+00 * w(187)
      chem( 86) = chem( 86) - w(187)
      chem( 95) = chem( 95) +  0.1250000000000000D+01 * w(187)
      chem( 96) = chem( 96) +  0.7500000000000000D+00 * w(187)
      chem( 50) = chem( 50) +  0.8000000000000000D-01 * w(188)
      chem( 51) = chem( 51) +  0.6000000000000000D-01 * w(188)
      chem( 53) = chem( 53) + w(188)
      chem( 54) = chem( 54) +  0.7000000000000001D-01 * w(188)
      chem( 60) = chem( 60) - w(188)
      chem( 74) = chem( 74) +  0.1660000000000000D+01 * w(188)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(188)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(188)
      chem( 85) = chem( 85) +  0.2800000000000000D+00 * w(188)
      chem( 86) = chem( 86) - w(188)
      chem( 95) = chem( 95) +  0.1250000000000000D+01 * w(188)
      chem( 96) = chem( 96) +  0.7500000000000000D+00 * w(188)
      chem( 47) = chem( 47) +  0.6300000000000000D+00 * w(189)
      chem( 54) = chem( 54) +  0.2000000000000000D-01 * w(189)
      chem( 60) = chem( 60) - w(189)
      chem( 67) = chem( 67) + w(189)
      chem( 73) = chem( 73) +  0.5300000000000000D+00 * w(189)
      chem( 75) = chem( 75) +  0.4700000000000000D+00 * w(189)
      chem( 83) = chem( 83) +  0.2500000000000000D+00 * w(189)
      chem( 87) = chem( 87) - w(189)
      chem( 94) = chem( 94) +  0.4700000000000000D+00 * w(189)
      chem( 95) = chem( 95) +  0.1030000000000000D+01 * w(189)
      chem( 96) = chem( 96) +  0.2800000000000000D+00 * w(189)
      chem( 50) = chem( 50) +  0.1300000000000000D+00 * w(190)
      chem( 51) = chem( 51) +  0.4000000000000000D-01 * w(190)
      chem( 54) = chem( 54) +  0.9000000000000000D-01 * w(190)
      chem( 60) = chem( 60) - w(190)
      chem( 74) = chem( 74) +  0.7000000000000000D+01 * w(190)
      chem( 75) = chem( 75) +  0.2100000000000000D+00 * w(190)
      chem( 77) = chem( 77) +  0.1000000000000000D-02 * w(190)
      chem( 83) = chem( 83) +  0.1800000000000000D+00 * w(190)
      chem( 85) = chem( 85) +  0.2400000000000000D+00 * w(190)
      chem( 86) = chem( 86) +  0.5700000000000000D+00 * w(190)
      chem( 90) = chem( 90) +  0.3900000000000000D+00 * w(190)
      chem( 91) = chem( 91) - w(190)
      chem( 95) = chem( 95) +  0.7600000000000000D+00 * w(190)
      chem( 96) = chem( 96) +  0.7000000000000001D-01 * w(190)
      chem( 15) = chem( 15) - w(191)
      chem( 18) = chem( 18) + w(191)
      chem( 16) = chem( 16) - w(192)
      chem( 19) = chem( 19) + w(192)
      chem( 17) = chem( 17) - w(193)
      chem( 20) = chem( 20) + w(193)
      chem( 46) = chem( 46) - w(194)
      chem( 74) = chem( 74) +  0.5120000000000000D+01 * w(194)
      chem( 75) = chem( 75) +  0.1500000000000000D+00 * w(194)
      chem( 88) = chem( 88) - w(194)
      chem( 49) = chem( 49) - w(195)
      chem( 74) = chem( 74) +  0.5120000000000000D+01 * w(195)
      chem( 75) = chem( 75) +  0.1500000000000000D+00 * w(195)
      chem( 88) = chem( 88) - w(195)
      chem( 60) = chem( 60) - w(196)
      chem( 74) = chem( 74) +  0.5120000000000000D+01 * w(196)
      chem( 75) = chem( 75) +  0.1500000000000000D+00 * w(196)
      chem( 88) = chem( 88) - w(196)
      chem( 21) = chem( 21) + w(197)
      chem( 48) = chem( 48) - w(197)
      chem( 21) = chem( 21) - w(198)
      chem( 22) = chem( 22) + w(198)
      chem( 22) = chem( 22) - w(199)
      chem( 32) = chem( 32) + w(199)
      chem( 32) = chem( 32) - w(200)
      chem( 48) = chem( 48) - w(201)
      chem( 52) = chem( 52) - w(201)
      chem( 52) = chem( 52) - w(202)
      chem( 52) = chem( 52) -  0.5000000000000004D-02 * w(203)
      chem( 32) = chem( 32) - w(204)
      chem( 33) = chem( 33) +  0.3480000000000000D+01 * w(204)
      chem( 34) = chem( 34) +  0.5160000000000000D+01 * w(204)
      chem( 52) = chem( 52) - w(204)
      chem( 32) = chem( 32) - w(205)
      chem( 33) = chem( 33) +  0.2640000000000000D+01 * w(205)
      chem( 34) = chem( 34) +  0.6000000000000000D+01 * w(205)
      chem( 35) = chem( 35) +  0.6100000000000000D-02 * w(206)
      chem( 50) = chem( 50) - w(206)
      chem( 53) = chem( 53) - w(207)
      chem( 68) = chem( 68) +  0.2010000000000000D+00 * w(207)
      chem( 67) = chem( 67) - w(208)
      chem( 68) = chem( 68) +  0.6879999999999999D+00 * w(208)
      chem( 67) = chem( 67) - w(209)
      chem( 68) = chem( 68) + w(209)
      chem( 67) = chem( 67) - w(210)
      chem( 68) = chem( 68) +  0.4220000000000000D+00 * w(210)
      chem( 67) = chem( 67) - w(211)
      chem( 68) = chem( 68) +  0.7110000000000000D+00 * w(211)
      chem( 67) = chem( 67) + w(212)
 
C    Conversion molecules/cm3 to mug/m3.
 
      do i = 1, ns
         chem(i) = chem(i) / convers_factor(i)
      enddo
 
C     Volumic source terms.
 
      IF(nemis.gt.0)THEN
      do i=1,ns
      chem(i)=chem(i)+ZCsourc(i)
      enddo
      endif
 
      RETURN
      END
 
