C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc                        (
     $    ns,nr,y,convers_factor,convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_poa.reactions  
C     Species: _ciCB05_poa.species_
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc                        (
     $    ns,nr,rk,conc,dw)
 
      JacC( 88, 94) = JacC( 88, 94) + dw(  1, 94)
      JacC( 92, 94) = JacC( 92, 94) + dw(  1, 94)
      JacC( 94, 94) = JacC( 94, 94) - dw(  1, 94)
      JacC( 88, 88) = JacC( 88, 88) - dw(  2, 88)
      JacC( 91, 88) = JacC( 91, 88) + dw(  2, 88)
      JacC( 91, 91) = JacC( 91, 91) - dw(  3, 91)
      JacC( 91, 92) = JacC( 91, 92) - dw(  3, 92)
      JacC( 92, 91) = JacC( 92, 91) - dw(  3, 91)
      JacC( 92, 92) = JacC( 92, 92) - dw(  3, 92)
      JacC( 94, 91) = JacC( 94, 91) + dw(  3, 91)
      JacC( 94, 92) = JacC( 94, 92) + dw(  3, 92)
      JacC( 88, 88) = JacC( 88, 88) - dw(  4, 88)
      JacC( 88, 94) = JacC( 88, 94) - dw(  4, 94)
      JacC( 92, 88) = JacC( 92, 88) + dw(  4, 88)
      JacC( 92, 94) = JacC( 92, 94) + dw(  4, 94)
      JacC( 94, 88) = JacC( 94, 88) - dw(  4, 88)
      JacC( 94, 94) = JacC( 94, 94) - dw(  4, 94)
      JacC( 87, 88) = JacC( 87, 88) + dw(  5, 88)
      JacC( 87, 94) = JacC( 87, 94) + dw(  5, 94)
      JacC( 88, 88) = JacC( 88, 88) - dw(  5, 88)
      JacC( 88, 94) = JacC( 88, 94) - dw(  5, 94)
      JacC( 94, 88) = JacC( 94, 88) - dw(  5, 88)
      JacC( 94, 94) = JacC( 94, 94) - dw(  5, 94)
      JacC( 88, 88) = JacC( 88, 88) - dw(  6, 88)
      JacC( 88, 92) = JacC( 88, 92) - dw(  6, 92)
      JacC( 92, 88) = JacC( 92, 88) - dw(  6, 88)
      JacC( 92, 92) = JacC( 92, 92) - dw(  6, 92)
      JacC( 94, 88) = JacC( 94, 88) + dw(  6, 88)
      JacC( 94, 92) = JacC( 94, 92) + dw(  6, 92)
      JacC( 87, 94) = JacC( 87, 94) + dw(  7, 94)
      JacC( 87, 91) = JacC( 87, 91) + dw(  7, 91)
      JacC( 91, 94) = JacC( 91, 94) - dw(  7, 94)
      JacC( 91, 91) = JacC( 91, 91) - dw(  7, 91)
      JacC( 94, 94) = JacC( 94, 94) - dw(  7, 94)
      JacC( 94, 91) = JacC( 94, 91) - dw(  7, 91)
      JacC( 88, 91) = JacC( 88, 91) + dw(  8, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw(  8, 91)
      JacC(  4, 91) = JacC(  4, 91) + dw(  9, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw(  9, 91)
      JacC(  4,  4) = JacC(  4,  4) - dw( 10,  4)
      JacC( 88,  4) = JacC( 88,  4) + dw( 10,  4)
      JacC(  4,  4) = JacC(  4,  4) - dw( 11,  4)
      JacC( 86,  4) = JacC( 86,  4)+ 0.2000000000000000D+01*dw( 11,  4)
      JacC( 86, 91) = JacC( 86, 91) - dw( 12, 91)
      JacC( 86, 86) = JacC( 86, 86) - dw( 12, 86)
      JacC( 91, 91) = JacC( 91, 91) - dw( 12, 91)
      JacC( 91, 86) = JacC( 91, 86) - dw( 12, 86)
      JacC( 96, 91) = JacC( 96, 91) + dw( 12, 91)
      JacC( 96, 86) = JacC( 96, 86) + dw( 12, 86)
      JacC( 86, 91) = JacC( 86, 91) + dw( 13, 91)
      JacC( 86, 96) = JacC( 86, 96) + dw( 13, 96)
      JacC( 91, 91) = JacC( 91, 91) - dw( 13, 91)
      JacC( 91, 96) = JacC( 91, 96) - dw( 13, 96)
      JacC( 96, 91) = JacC( 96, 91) - dw( 13, 91)
      JacC( 96, 96) = JacC( 96, 96) - dw( 13, 96)
      JacC( 87, 87) = JacC( 87, 87) - dw( 14, 87)
      JacC( 88, 87) = JacC( 88, 87) + dw( 14, 87)
      JacC( 94, 87) = JacC( 94, 87) + dw( 14, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw( 15, 87)
      JacC( 92, 87) = JacC( 92, 87) + dw( 15, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw( 16, 87)
      JacC( 87, 92) = JacC( 87, 92) - dw( 16, 92)
      JacC( 92, 87) = JacC( 92, 87) - dw( 16, 87)
      JacC( 92, 92) = JacC( 92, 92) - dw( 16, 92)
      JacC( 94, 87) = JacC( 94, 87)+ 0.2000000000000000D+01*dw( 16, 87)
      JacC( 94, 92) = JacC( 94, 92)+ 0.2000000000000000D+01*dw( 16, 92)
      JacC( 87, 87) = JacC( 87, 87) - dw( 17, 87)
      JacC( 87, 94) = JacC( 87, 94) - dw( 17, 94)
      JacC( 92, 87) = JacC( 92, 87) + dw( 17, 87)
      JacC( 92, 94) = JacC( 92, 94) + dw( 17, 94)
      JacC( 25, 87) = JacC( 25, 87) + dw( 18, 87)
      JacC( 25, 94) = JacC( 25, 94) + dw( 18, 94)
      JacC( 87, 87) = JacC( 87, 87) - dw( 18, 87)
      JacC( 87, 94) = JacC( 87, 94) - dw( 18, 94)
      JacC( 94, 87) = JacC( 94, 87) - dw( 18, 87)
      JacC( 94, 94) = JacC( 94, 94) - dw( 18, 94)
      JacC( 25, 25) = JacC( 25, 25) - dw( 19, 25)
      JacC( 79, 25) = JacC( 79, 25)+ 0.2000000000000000D+01*dw( 19, 25)
      JacC( 25, 25) = JacC( 25, 25) - dw( 20, 25)
      JacC( 87, 25) = JacC( 87, 25) + dw( 20, 25)
      JacC( 94, 25) = JacC( 94, 25) + dw( 20, 25)
      JacC( 92, 92) = JacC( 92, 92)- 0.2000000000000000D+01*dw( 21, 92)
      JacC( 92, 92) = JacC( 92, 92)- 0.2000000000000000D+01*dw( 21, 92)
      JacC( 94, 92) = JacC( 94, 92)+ 0.2000000000000000D+01*dw( 21, 92)
      JacC( 94, 92) = JacC( 94, 92)+ 0.2000000000000000D+01*dw( 21, 92)
      JacC( 41, 92) = JacC( 41, 92)+ 0.2000000000000000D+01*dw( 22, 92)
      JacC( 41, 94) = JacC( 41, 94)+ 0.2000000000000000D+01*dw( 22, 94)
      JacC( 92, 92) = JacC( 92, 92) - dw( 22, 92)
      JacC( 92, 94) = JacC( 92, 94) - dw( 22, 94)
      JacC( 94, 92) = JacC( 94, 92) - dw( 22, 92)
      JacC( 94, 94) = JacC( 94, 94) - dw( 22, 94)
      JacC( 41, 86) = JacC( 41, 86) + dw( 23, 86)
      JacC( 41, 92) = JacC( 41, 92) + dw( 23, 92)
      JacC( 86, 86) = JacC( 86, 86) - dw( 23, 86)
      JacC( 86, 92) = JacC( 86, 92) - dw( 23, 92)
      JacC( 92, 86) = JacC( 92, 86) - dw( 23, 86)
      JacC( 92, 92) = JacC( 92, 92) - dw( 23, 92)
      JacC( 41, 41) = JacC( 41, 41) - dw( 24, 41)
      JacC( 86, 41) = JacC( 86, 41) + dw( 24, 41)
      JacC( 92, 41) = JacC( 92, 41) + dw( 24, 41)
      JacC( 41, 86) = JacC( 41, 86) - dw( 25, 86)
      JacC( 41, 41) = JacC( 41, 41) - dw( 25, 41)
      JacC( 86, 86) = JacC( 86, 86) - dw( 25, 86)
      JacC( 86, 41) = JacC( 86, 41) - dw( 25, 41)
      JacC( 94, 86) = JacC( 94, 86) + dw( 25, 86)
      JacC( 94, 41) = JacC( 94, 41) + dw( 25, 41)
      JacC( 41, 41) = JacC( 41, 41)- 0.2000000000000000D+01*dw( 26, 41)
      JacC( 41, 41) = JacC( 41, 41)- 0.2000000000000000D+01*dw( 26, 41)
      JacC( 92, 41) = JacC( 92, 41) + dw( 26, 41)
      JacC( 92, 41) = JacC( 92, 41) + dw( 26, 41)
      JacC( 94, 41) = JacC( 94, 41) + dw( 26, 41)
      JacC( 94, 41) = JacC( 94, 41) + dw( 26, 41)
      JacC( 79, 94) = JacC( 79, 94) + dw( 27, 94)
      JacC( 79, 86) = JacC( 79, 86) + dw( 27, 86)
      JacC( 86, 94) = JacC( 86, 94) - dw( 27, 94)
      JacC( 86, 86) = JacC( 86, 86) - dw( 27, 86)
      JacC( 94, 94) = JacC( 94, 94) - dw( 27, 94)
      JacC( 94, 86) = JacC( 94, 86) - dw( 27, 86)
      JacC( 79, 86) = JacC( 79, 86) - dw( 28, 86)
      JacC( 79, 79) = JacC( 79, 79) - dw( 28, 79)
      JacC( 86, 86) = JacC( 86, 86) - dw( 28, 86)
      JacC( 86, 79) = JacC( 86, 79) - dw( 28, 79)
      JacC( 87, 86) = JacC( 87, 86) + dw( 28, 86)
      JacC( 87, 79) = JacC( 87, 79) + dw( 28, 79)
      JacC( 86, 96) = JacC( 86, 96) + dw( 29, 96)
      JacC( 86, 92) = JacC( 86, 92) + dw( 29, 92)
      JacC( 92, 96) = JacC( 92, 96) - dw( 29, 96)
      JacC( 92, 92) = JacC( 92, 92) - dw( 29, 92)
      JacC( 94, 96) = JacC( 94, 96) + dw( 29, 96)
      JacC( 94, 92) = JacC( 94, 92) + dw( 29, 92)
      JacC( 96, 96) = JacC( 96, 96) - dw( 29, 96)
      JacC( 96, 92) = JacC( 96, 92) - dw( 29, 92)
      JacC( 36, 96) = JacC( 36, 96) + dw( 30, 96)
      JacC( 36, 94) = JacC( 36, 94) + dw( 30, 94)
      JacC( 94, 96) = JacC( 94, 96) - dw( 30, 96)
      JacC( 94, 94) = JacC( 94, 94) - dw( 30, 94)
      JacC( 96, 96) = JacC( 96, 96) - dw( 30, 96)
      JacC( 96, 94) = JacC( 96, 94) - dw( 30, 94)
      JacC( 36, 36) = JacC( 36, 36) - dw( 31, 36)
      JacC( 94, 36) = JacC( 94, 36) + dw( 31, 36)
      JacC( 96, 36) = JacC( 96, 36) + dw( 31, 36)
      JacC( 36, 86) = JacC( 36, 86) - dw( 32, 86)
      JacC( 36, 36) = JacC( 36, 36) - dw( 32, 36)
      JacC( 86, 86) = JacC( 86, 86) - dw( 32, 86)
      JacC( 86, 36) = JacC( 86, 36) - dw( 32, 36)
      JacC( 94, 86) = JacC( 94, 86) + dw( 32, 86)
      JacC( 94, 36) = JacC( 94, 36) + dw( 32, 36)
      JacC( 40, 96) = JacC( 40, 96) + dw( 33, 96)
      JacC( 40, 96) = JacC( 40, 96) + dw( 33, 96)
      JacC( 96, 96) = JacC( 96, 96)- 0.2000000000000000D+01*dw( 33, 96)
      JacC( 96, 96) = JacC( 96, 96)- 0.2000000000000000D+01*dw( 33, 96)
      JacC( 40, 96) = JacC( 40, 96) + dw( 34, 96)
      JacC( 40, 96) = JacC( 40, 96) + dw( 34, 96)
      JacC( 96, 96) = JacC( 96, 96)- 0.2000000000000000D+01*dw( 34, 96)
      JacC( 96, 96) = JacC( 96, 96)- 0.2000000000000000D+01*dw( 34, 96)
      JacC( 40, 40) = JacC( 40, 40) - dw( 35, 40)
      JacC( 86, 40) = JacC( 86, 40)+ 0.2000000000000000D+01*dw( 35, 40)
      JacC( 40, 86) = JacC( 40, 86) - dw( 36, 86)
      JacC( 40, 40) = JacC( 40, 40) - dw( 36, 40)
      JacC( 86, 86) = JacC( 86, 86) - dw( 36, 86)
      JacC( 86, 40) = JacC( 86, 40) - dw( 36, 40)
      JacC( 96, 86) = JacC( 96, 86) + dw( 36, 86)
      JacC( 96, 40) = JacC( 96, 40) + dw( 36, 40)
      JacC(  4,  4) = JacC(  4,  4) - dw( 37,  4)
      JacC( 86,  4) = JacC( 86,  4) + dw( 37,  4)
      JacC( 96,  4) = JacC( 96,  4) + dw( 37,  4)
      JacC( 86, 86) = JacC( 86, 86) - dw( 38, 86)
      JacC( 96, 86) = JacC( 96, 86) + dw( 38, 86)
      JacC( 86, 86) = JacC( 86, 86) - dw( 39, 86)
      JacC( 86, 88) = JacC( 86, 88) - dw( 39, 88)
      JacC( 88, 86) = JacC( 88, 86) - dw( 39, 86)
      JacC( 88, 88) = JacC( 88, 88) - dw( 39, 88)
      JacC( 96, 86) = JacC( 96, 86) + dw( 39, 86)
      JacC( 96, 88) = JacC( 96, 88) + dw( 39, 88)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 40, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 40, 86)
      JacC( 88, 86) = JacC( 88, 86) + dw( 40, 86)
      JacC( 88, 86) = JacC( 88, 86) + dw( 40, 86)
      JacC( 40, 86) = JacC( 40, 86) + dw( 41, 86)
      JacC( 40, 86) = JacC( 40, 86) + dw( 41, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 41, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 41, 86)
      JacC( 86, 86) = JacC( 86, 86) - dw( 42, 86)
      JacC( 86, 96) = JacC( 86, 96) - dw( 42, 96)
      JacC( 96, 86) = JacC( 96, 86) - dw( 42, 86)
      JacC( 96, 96) = JacC( 96, 96) - dw( 42, 96)
      JacC( 86, 96) = JacC( 86, 96) + dw( 43, 96)
      JacC( 86, 88) = JacC( 86, 88) + dw( 43, 88)
      JacC( 88, 96) = JacC( 88, 96) - dw( 43, 96)
      JacC( 88, 88) = JacC( 88, 88) - dw( 43, 88)
      JacC( 96, 96) = JacC( 96, 96) - dw( 43, 96)
      JacC( 96, 88) = JacC( 96, 88) - dw( 43, 88)
      JacC( 40, 40) = JacC( 40, 40) - dw( 44, 40)
      JacC( 40, 88) = JacC( 40, 88) - dw( 44, 88)
      JacC( 86, 40) = JacC( 86, 40) + dw( 44, 40)
      JacC( 86, 88) = JacC( 86, 88) + dw( 44, 88)
      JacC( 88, 40) = JacC( 88, 40) - dw( 44, 40)
      JacC( 88, 88) = JacC( 88, 88) - dw( 44, 88)
      JacC( 96, 40) = JacC( 96, 40) + dw( 44, 40)
      JacC( 96, 88) = JacC( 96, 88) + dw( 44, 88)
      JacC( 87, 87) = JacC( 87, 87) - dw( 45, 87)
      JacC( 87, 88) = JacC( 87, 88) - dw( 45, 88)
      JacC( 88, 87) = JacC( 88, 87) - dw( 45, 87)
      JacC( 88, 88) = JacC( 88, 88) - dw( 45, 88)
      JacC( 94, 87) = JacC( 94, 87) + dw( 45, 87)
      JacC( 94, 88) = JacC( 94, 88) + dw( 45, 88)
      JacC( 86, 87) = JacC( 86, 87) - dw( 46, 87)
      JacC( 86, 86) = JacC( 86, 86) - dw( 46, 86)
      JacC( 87, 87) = JacC( 87, 87) - dw( 46, 87)
      JacC( 87, 86) = JacC( 87, 86) - dw( 46, 86)
      JacC( 94, 87) = JacC( 94, 87) + dw( 46, 87)
      JacC( 94, 86) = JacC( 94, 86) + dw( 46, 86)
      JacC( 96, 87) = JacC( 96, 87) + dw( 46, 87)
      JacC( 96, 86) = JacC( 96, 86) + dw( 46, 86)
      JacC( 79, 87) = JacC( 79, 87) + dw( 47, 87)
      JacC( 79, 96) = JacC( 79, 96) + dw( 47, 96)
      JacC( 87, 87) = JacC( 87, 87) - dw( 47, 87)
      JacC( 87, 96) = JacC( 87, 96) - dw( 47, 96)
      JacC( 96, 87) = JacC( 96, 87) - dw( 47, 87)
      JacC( 96, 96) = JacC( 96, 96) - dw( 47, 96)
      JacC( 87, 87) = JacC( 87, 87) - dw( 48, 87)
      JacC( 87, 91) = JacC( 87, 91) - dw( 48, 91)
      JacC( 91, 87) = JacC( 91, 87) - dw( 48, 87)
      JacC( 91, 91) = JacC( 91, 91) - dw( 48, 91)
      JacC( 94, 87) = JacC( 94, 87) + dw( 48, 87)
      JacC( 94, 91) = JacC( 94, 91) + dw( 48, 91)
      JacC( 87, 87) = JacC( 87, 87)- 0.2000000000000000D+01*dw( 49, 87)
      JacC( 87, 87) = JacC( 87, 87)- 0.2000000000000000D+01*dw( 49, 87)
      JacC( 94, 87) = JacC( 94, 87)+ 0.2000000000000000D+01*dw( 49, 87)
      JacC( 94, 87) = JacC( 94, 87)+ 0.2000000000000000D+01*dw( 49, 87)
      JacC( 36, 36) = JacC( 36, 36) - dw( 50, 36)
      JacC( 86, 36) = JacC( 86, 36)+ 0.3900000000000000D+00*dw( 50, 36)
      JacC( 87, 36) = JacC( 87, 36)+ 0.3900000000000000D+00*dw( 50, 36)
      JacC( 94, 36) = JacC( 94, 36)+ 0.6100000000000000D+00*dw( 50, 36)
      JacC( 96, 36) = JacC( 96, 36)+ 0.6100000000000000D+00*dw( 50, 36)
      JacC( 79, 79) = JacC( 79, 79) - dw( 51, 79)
      JacC( 86, 79) = JacC( 86, 79) + dw( 51, 79)
      JacC( 94, 79) = JacC( 94, 79) + dw( 51, 79)
      JacC( 25, 25) = JacC( 25, 25) - dw( 52, 25)
      JacC( 87, 25) = JacC( 87, 25) + dw( 52, 25)
      JacC( 94, 25) = JacC( 94, 25) + dw( 52, 25)
      JacC( 92, 95) = JacC( 92, 95) - dw( 53, 95)
      JacC( 92, 92) = JacC( 92, 92) - dw( 53, 92)
      JacC( 94, 95) = JacC( 94, 95) + dw( 53, 95)
      JacC( 94, 92) = JacC( 94, 92) + dw( 53, 92)
      JacC( 95, 95) = JacC( 95, 95) - dw( 53, 95)
      JacC( 95, 92) = JacC( 95, 92) - dw( 53, 92)
      JacC( 73, 83) = JacC( 73, 83) + dw( 54, 83)
      JacC( 73, 92) = JacC( 73, 92) + dw( 54, 92)
      JacC( 83, 83) = JacC( 83, 83) - dw( 54, 83)
      JacC( 83, 92) = JacC( 83, 92) - dw( 54, 92)
      JacC( 92, 83) = JacC( 92, 83) - dw( 54, 83)
      JacC( 92, 92) = JacC( 92, 92) - dw( 54, 92)
      JacC( 61, 95) = JacC( 61, 95) + dw( 55, 95)
      JacC( 61, 96) = JacC( 61, 96) + dw( 55, 96)
      JacC( 95, 95) = JacC( 95, 95) - dw( 55, 95)
      JacC( 95, 96) = JacC( 95, 96) - dw( 55, 96)
      JacC( 96, 95) = JacC( 96, 95) - dw( 55, 95)
      JacC( 96, 96) = JacC( 96, 96) - dw( 55, 96)
      JacC( 61, 83) = JacC( 61, 83) + dw( 56, 83)
      JacC( 61, 96) = JacC( 61, 96) + dw( 56, 96)
      JacC( 83, 83) = JacC( 83, 83) - dw( 56, 83)
      JacC( 83, 96) = JacC( 83, 96) - dw( 56, 96)
      JacC( 96, 83) = JacC( 96, 83) - dw( 56, 83)
      JacC( 96, 96) = JacC( 96, 96) - dw( 56, 96)
      JacC( 95, 95) = JacC( 95, 95)- 0.2000000000000000D+01*dw( 57, 95)
      JacC( 95, 95) = JacC( 95, 95)- 0.2000000000000000D+01*dw( 57, 95)
      JacC( 83, 83) = JacC( 83, 83)- 0.2000000000000000D+01*dw( 58, 83)
      JacC( 83, 83) = JacC( 83, 83)- 0.2000000000000000D+01*dw( 58, 83)
      JacC( 83, 95) = JacC( 83, 95) - dw( 59, 95)
      JacC( 83, 83) = JacC( 83, 83) - dw( 59, 83)
      JacC( 95, 95) = JacC( 95, 95) - dw( 59, 95)
      JacC( 95, 83) = JacC( 95, 83) - dw( 59, 83)
      JacC( 73, 73) = JacC( 73, 73) - dw( 60, 73)
      JacC( 73, 86) = JacC( 73, 86) - dw( 60, 86)
      JacC( 74, 73) = JacC( 74, 73)+ 0.6600000000000000D+00*dw( 60, 73)
      JacC( 74, 86) = JacC( 74, 86)+ 0.6600000000000000D+00*dw( 60, 86)
      JacC( 75, 73) = JacC( 75, 73)+ 0.3300000000000000D+00*dw( 60, 73)
      JacC( 75, 86) = JacC( 75, 86)+ 0.3300000000000000D+00*dw( 60, 86)
      JacC( 79, 73) = JacC( 79, 73) + dw( 60, 73)
      JacC( 79, 86) = JacC( 79, 86) + dw( 60, 86)
      JacC( 85, 73) = JacC( 85, 73)+ 0.3300000000000000D+00*dw( 60, 73)
      JacC( 85, 86) = JacC( 85, 86)+ 0.3300000000000000D+00*dw( 60, 86)
      JacC( 86, 73) = JacC( 86, 73) - dw( 60, 73)
      JacC( 86, 86) = JacC( 86, 86) - dw( 60, 86)
      JacC( 89, 73) = JacC( 89, 73)+ 0.3300000000000000D+00*dw( 60, 73)
      JacC( 89, 86) = JacC( 89, 86)+ 0.3300000000000000D+00*dw( 60, 86)
      JacC( 96, 73) = JacC( 96, 73) + dw( 60, 73)
      JacC( 96, 86) = JacC( 96, 86) + dw( 60, 86)
      JacC( 73, 73) = JacC( 73, 73) - dw( 61, 73)
      JacC( 74, 73) = JacC( 74, 73)+ 0.6600000000000000D+00*dw( 61, 73)
      JacC( 75, 73) = JacC( 75, 73)+ 0.3300000000000000D+00*dw( 61, 73)
      JacC( 85, 73) = JacC( 85, 73)+ 0.3300000000000000D+00*dw( 61, 73)
      JacC( 89, 73) = JacC( 89, 73)+ 0.3300000000000000D+00*dw( 61, 73)
      JacC( 94, 73) = JacC( 94, 73) + dw( 61, 73)
      JacC( 96, 73) = JacC( 96, 73) + dw( 61, 73)
      JacC( 61, 61) = JacC( 61, 61) - dw( 62, 61)
      JacC( 61, 86) = JacC( 61, 86) - dw( 62, 86)
      JacC( 75, 61) = JacC( 75, 61)+ 0.5000000000000000D+00*dw( 62, 61)
      JacC( 75, 86) = JacC( 75, 86)+ 0.5000000000000000D+00*dw( 62, 86)
      JacC( 86, 61) = JacC( 86, 61) - dw( 62, 61)
      JacC( 86, 86) = JacC( 86, 86) - dw( 62, 86)
      JacC( 89, 61) = JacC( 89, 61)+ 0.5000000000000000D+00*dw( 62, 61)
      JacC( 89, 86) = JacC( 89, 86)+ 0.5000000000000000D+00*dw( 62, 86)
      JacC( 95, 61) = JacC( 95, 61) + dw( 62, 61)
      JacC( 95, 86) = JacC( 95, 86) + dw( 62, 86)
      JacC( 61, 61) = JacC( 61, 61) - dw( 63, 61)
      JacC( 75, 61) = JacC( 75, 61)+ 0.5000000000000000D+00*dw( 63, 61)
      JacC( 86, 61) = JacC( 86, 61) + dw( 63, 61)
      JacC( 89, 61) = JacC( 89, 61)+ 0.5000000000000000D+00*dw( 63, 61)
      JacC( 96, 61) = JacC( 96, 61) + dw( 63, 61)
      JacC( 77, 86) = JacC( 77, 86) - dw( 64, 86)
      JacC( 77, 77) = JacC( 77, 77) - dw( 64, 77)
      JacC( 86, 86) = JacC( 86, 86) - dw( 64, 86)
      JacC( 86, 77) = JacC( 86, 77) - dw( 64, 77)
      JacC( 96, 86) = JacC( 96, 86) + dw( 64, 86)
      JacC( 96, 77) = JacC( 96, 77) + dw( 64, 77)
      JacC(  6, 86) = JacC(  6, 86) - dw( 65, 86)
      JacC(  6,  6) = JacC(  6,  6) - dw( 65,  6)
      JacC( 84, 86) = JacC( 84, 86) + dw( 65, 86)
      JacC( 84,  6) = JacC( 84,  6) + dw( 65,  6)
      JacC( 86, 86) = JacC( 86, 86) - dw( 65, 86)
      JacC( 86,  6) = JacC( 86,  6) - dw( 65,  6)
      JacC( 84, 84) = JacC( 84, 84) - dw( 66, 84)
      JacC( 84, 92) = JacC( 84, 92) - dw( 66, 92)
      JacC( 85, 84) = JacC( 85, 84) + dw( 66, 84)
      JacC( 85, 92) = JacC( 85, 92) + dw( 66, 92)
      JacC( 92, 84) = JacC( 92, 84) - dw( 66, 84)
      JacC( 92, 92) = JacC( 92, 92) - dw( 66, 92)
      JacC( 94, 84) = JacC( 94, 84) + dw( 66, 84)
      JacC( 94, 92) = JacC( 94, 92) + dw( 66, 92)
      JacC( 96, 84) = JacC( 96, 84) + dw( 66, 84)
      JacC( 96, 92) = JacC( 96, 92) + dw( 66, 92)
      JacC( 43, 84) = JacC( 43, 84) + dw( 67, 84)
      JacC( 43, 96) = JacC( 43, 96) + dw( 67, 96)
      JacC( 84, 84) = JacC( 84, 84) - dw( 67, 84)
      JacC( 84, 96) = JacC( 84, 96) - dw( 67, 96)
      JacC( 96, 84) = JacC( 96, 84) - dw( 67, 84)
      JacC( 96, 96) = JacC( 96, 96) - dw( 67, 96)
      JacC( 23, 84) = JacC( 23, 84)+ 0.6300000000000000D+00*dw( 68, 84)
      JacC( 23, 84) = JacC( 23, 84)+ 0.6300000000000000D+00*dw( 68, 84)
      JacC( 84, 84) = JacC( 84, 84)- 0.2000000000000000D+01*dw( 68, 84)
      JacC( 84, 84) = JacC( 84, 84)- 0.2000000000000000D+01*dw( 68, 84)
      JacC( 85, 84) = JacC( 85, 84)+ 0.1370000000000000D+01*dw( 68, 84)
      JacC( 85, 84) = JacC( 85, 84)+ 0.1370000000000000D+01*dw( 68, 84)
      JacC( 96, 84) = JacC( 96, 84)+ 0.7400000000000000D+00*dw( 68, 84)
      JacC( 96, 84) = JacC( 96, 84)+ 0.7400000000000000D+00*dw( 68, 84)
      JacC( 43, 43) = JacC( 43, 43) - dw( 69, 43)
      JacC( 43, 86) = JacC( 43, 86) - dw( 69, 86)
      JacC( 84, 43) = JacC( 84, 43)+ 0.7000000000000000D+00*dw( 69, 43)
      JacC( 84, 86) = JacC( 84, 86)+ 0.7000000000000000D+00*dw( 69, 86)
      JacC( 86, 43) = JacC( 86, 43) - dw( 69, 43)
      JacC( 86, 86) = JacC( 86, 86) - dw( 69, 86)
      JacC( 95, 43) = JacC( 95, 43)+ 0.3000000000000000D+00*dw( 69, 43)
      JacC( 95, 86) = JacC( 95, 86)+ 0.3000000000000000D+00*dw( 69, 86)
      JacC( 96, 43) = JacC( 96, 43)+ 0.3000000000000000D-01*dw( 69, 43)
      JacC( 96, 86) = JacC( 96, 86)+ 0.3000000000000000D-01*dw( 69, 86)
      JacC( 43, 43) = JacC( 43, 43) - dw( 70, 43)
      JacC( 85, 43) = JacC( 85, 43) + dw( 70, 43)
      JacC( 86, 43) = JacC( 86, 43) + dw( 70, 43)
      JacC( 96, 43) = JacC( 96, 43) + dw( 70, 43)
      JacC( 23, 23) = JacC( 23, 23) - dw( 71, 23)
      JacC( 23, 86) = JacC( 23, 86) - dw( 71, 86)
      JacC( 85, 23) = JacC( 85, 23) + dw( 71, 23)
      JacC( 85, 86) = JacC( 85, 86) + dw( 71, 86)
      JacC( 86, 23) = JacC( 86, 23) - dw( 71, 23)
      JacC( 86, 86) = JacC( 86, 86) - dw( 71, 86)
      JacC( 96, 23) = JacC( 96, 23) + dw( 71, 23)
      JacC( 96, 86) = JacC( 96, 86) + dw( 71, 86)
      JacC( 77, 85) = JacC( 77, 85) + dw( 72, 85)
      JacC( 77, 86) = JacC( 77, 86) + dw( 72, 86)
      JacC( 85, 85) = JacC( 85, 85) - dw( 72, 85)
      JacC( 85, 86) = JacC( 85, 86) - dw( 72, 86)
      JacC( 86, 85) = JacC( 86, 85) - dw( 72, 85)
      JacC( 86, 86) = JacC( 86, 86) - dw( 72, 86)
      JacC( 96, 85) = JacC( 96, 85) + dw( 72, 85)
      JacC( 96, 86) = JacC( 96, 86) + dw( 72, 86)
      JacC( 77, 85) = JacC( 77, 85) + dw( 73, 85)
      JacC( 85, 85) = JacC( 85, 85) - dw( 73, 85)
      JacC( 96, 85) = JacC( 96, 85)+ 0.2000000000000000D+01*dw( 73, 85)
      JacC( 77, 85) = JacC( 77, 85) + dw( 74, 85)
      JacC( 85, 85) = JacC( 85, 85) - dw( 74, 85)
      JacC( 77, 85) = JacC( 77, 85) + dw( 75, 85)
      JacC( 77, 88) = JacC( 77, 88) + dw( 75, 88)
      JacC( 85, 85) = JacC( 85, 85) - dw( 75, 85)
      JacC( 85, 88) = JacC( 85, 88) - dw( 75, 88)
      JacC( 86, 85) = JacC( 86, 85) + dw( 75, 85)
      JacC( 86, 88) = JacC( 86, 88) + dw( 75, 88)
      JacC( 88, 85) = JacC( 88, 85) - dw( 75, 85)
      JacC( 88, 88) = JacC( 88, 88) - dw( 75, 88)
      JacC( 96, 85) = JacC( 96, 85) + dw( 75, 85)
      JacC( 96, 88) = JacC( 96, 88) + dw( 75, 88)
      JacC( 77, 85) = JacC( 77, 85) + dw( 76, 85)
      JacC( 77, 87) = JacC( 77, 87) + dw( 76, 87)
      JacC( 79, 85) = JacC( 79, 85) + dw( 76, 85)
      JacC( 79, 87) = JacC( 79, 87) + dw( 76, 87)
      JacC( 85, 85) = JacC( 85, 85) - dw( 76, 85)
      JacC( 85, 87) = JacC( 85, 87) - dw( 76, 87)
      JacC( 87, 85) = JacC( 87, 85) - dw( 76, 85)
      JacC( 87, 87) = JacC( 87, 87) - dw( 76, 87)
      JacC( 96, 85) = JacC( 96, 85) + dw( 76, 85)
      JacC( 96, 87) = JacC( 96, 87) + dw( 76, 87)
      JacC( 42, 85) = JacC( 42, 85) + dw( 77, 85)
      JacC( 42, 96) = JacC( 42, 96) + dw( 77, 96)
      JacC( 85, 85) = JacC( 85, 85) - dw( 77, 85)
      JacC( 85, 96) = JacC( 85, 96) - dw( 77, 96)
      JacC( 96, 85) = JacC( 96, 85) - dw( 77, 85)
      JacC( 96, 96) = JacC( 96, 96) - dw( 77, 96)
      JacC( 42, 42) = JacC( 42, 42) - dw( 78, 42)
      JacC( 85, 42) = JacC( 85, 42) + dw( 78, 42)
      JacC( 96, 42) = JacC( 96, 42) + dw( 78, 42)
      JacC( 42, 42) = JacC( 42, 42) - dw( 79, 42)
      JacC( 42, 92) = JacC( 42, 92) - dw( 79, 92)
      JacC( 56, 42) = JacC( 56, 42) + dw( 79, 42)
      JacC( 56, 92) = JacC( 56, 92) + dw( 79, 92)
      JacC( 92, 42) = JacC( 92, 42) - dw( 79, 42)
      JacC( 92, 92) = JacC( 92, 92) - dw( 79, 92)
      JacC( 94, 42) = JacC( 94, 42) + dw( 79, 42)
      JacC( 94, 92) = JacC( 94, 92) + dw( 79, 92)
      JacC( 96, 42) = JacC( 96, 42) + dw( 79, 42)
      JacC( 96, 92) = JacC( 96, 92) + dw( 79, 92)
      JacC( 42, 42) = JacC( 42, 42) - dw( 80, 42)
      JacC( 42, 96) = JacC( 42, 96) - dw( 80, 96)
      JacC( 43, 42) = JacC( 43, 42) + dw( 80, 42)
      JacC( 43, 96) = JacC( 43, 96) + dw( 80, 96)
      JacC( 96, 42) = JacC( 96, 42) - dw( 80, 42)
      JacC( 96, 96) = JacC( 96, 96) - dw( 80, 96)
      JacC( 56, 56) = JacC( 56, 56) - dw( 81, 56)
      JacC( 56, 86) = JacC( 56, 86) - dw( 81, 86)
      JacC( 86, 56) = JacC( 86, 56) - dw( 81, 56)
      JacC( 86, 86) = JacC( 86, 86) - dw( 81, 86)
      JacC( 96, 56) = JacC( 96, 56) + dw( 81, 56)
      JacC( 96, 86) = JacC( 96, 86) + dw( 81, 86)
      JacC( 86, 89) = JacC( 86, 89) + dw( 82, 89)
      JacC( 86, 88) = JacC( 86, 88) + dw( 82, 88)
      JacC( 88, 89) = JacC( 88, 89) - dw( 82, 89)
      JacC( 88, 88) = JacC( 88, 88) - dw( 82, 88)
      JacC( 89, 89) = JacC( 89, 89) - dw( 82, 89)
      JacC( 89, 88) = JacC( 89, 88) - dw( 82, 88)
      JacC( 93, 89) = JacC( 93, 89) + dw( 82, 89)
      JacC( 93, 88) = JacC( 93, 88) + dw( 82, 88)
      JacC( 86, 89) = JacC( 86, 89) - dw( 83, 89)
      JacC( 86, 86) = JacC( 86, 86) - dw( 83, 86)
      JacC( 89, 89) = JacC( 89, 89) - dw( 83, 89)
      JacC( 89, 86) = JacC( 89, 86) - dw( 83, 86)
      JacC( 93, 89) = JacC( 93, 89) + dw( 83, 89)
      JacC( 93, 86) = JacC( 93, 86) + dw( 83, 86)
      JacC( 79, 89) = JacC( 79, 89) + dw( 84, 89)
      JacC( 79, 87) = JacC( 79, 87) + dw( 84, 87)
      JacC( 87, 89) = JacC( 87, 89) - dw( 84, 89)
      JacC( 87, 87) = JacC( 87, 87) - dw( 84, 87)
      JacC( 89, 89) = JacC( 89, 89) - dw( 84, 89)
      JacC( 89, 87) = JacC( 89, 87) - dw( 84, 87)
      JacC( 93, 89) = JacC( 93, 89) + dw( 84, 89)
      JacC( 93, 87) = JacC( 93, 87) + dw( 84, 87)
      JacC( 77, 89) = JacC( 77, 89) + dw( 85, 89)
      JacC( 84, 89) = JacC( 84, 89) + dw( 85, 89)
      JacC( 89, 89) = JacC( 89, 89) - dw( 85, 89)
      JacC( 96, 89) = JacC( 96, 89) + dw( 85, 89)
      JacC( 84, 93) = JacC( 84, 93) + dw( 86, 93)
      JacC( 84, 92) = JacC( 84, 92) + dw( 86, 92)
      JacC( 92, 93) = JacC( 92, 93) - dw( 86, 93)
      JacC( 92, 92) = JacC( 92, 92) - dw( 86, 92)
      JacC( 93, 93) = JacC( 93, 93) - dw( 86, 93)
      JacC( 93, 92) = JacC( 93, 92) - dw( 86, 92)
      JacC( 94, 93) = JacC( 94, 93) + dw( 86, 93)
      JacC( 94, 92) = JacC( 94, 92) + dw( 86, 92)
      JacC( 31, 93) = JacC( 31, 93) + dw( 87, 93)
      JacC( 31, 94) = JacC( 31, 94) + dw( 87, 94)
      JacC( 93, 93) = JacC( 93, 93) - dw( 87, 93)
      JacC( 93, 94) = JacC( 93, 94) - dw( 87, 94)
      JacC( 94, 93) = JacC( 94, 93) - dw( 87, 93)
      JacC( 94, 94) = JacC( 94, 94) - dw( 87, 94)
      JacC( 31, 31) = JacC( 31, 31) - dw( 88, 31)
      JacC( 93, 31) = JacC( 93, 31) + dw( 88, 31)
      JacC( 94, 31) = JacC( 94, 31) + dw( 88, 31)
      JacC( 31, 31) = JacC( 31, 31) - dw( 89, 31)
      JacC( 93, 31) = JacC( 93, 31) + dw( 89, 31)
      JacC( 94, 31) = JacC( 94, 31) + dw( 89, 31)
      JacC( 62, 93) = JacC( 62, 93)+ 0.8000000000000000D+00*dw( 90, 93)
      JacC( 62, 96) = JacC( 62, 96)+ 0.8000000000000000D+00*dw( 90, 96)
      JacC( 76, 93) = JacC( 76, 93)+ 0.2000000000000000D+00*dw( 90, 93)
      JacC( 76, 96) = JacC( 76, 96)+ 0.2000000000000000D+00*dw( 90, 96)
      JacC( 91, 93) = JacC( 91, 93)+ 0.2000000000000000D+00*dw( 90, 93)
      JacC( 91, 96) = JacC( 91, 96)+ 0.2000000000000000D+00*dw( 90, 96)
      JacC( 93, 93) = JacC( 93, 93) - dw( 90, 93)
      JacC( 93, 96) = JacC( 93, 96) - dw( 90, 96)
      JacC( 96, 93) = JacC( 96, 93) - dw( 90, 93)
      JacC( 96, 96) = JacC( 96, 96) - dw( 90, 96)
      JacC( 76, 93) = JacC( 76, 93)+ 0.1000000000000000D+00*dw( 91, 93)
      JacC( 76, 84) = JacC( 76, 84)+ 0.1000000000000000D+00*dw( 91, 84)
      JacC( 84, 93) = JacC( 84, 93)- 0.9999999999999998D-01*dw( 91, 93)
      JacC( 84, 84) = JacC( 84, 84)- 0.9999999999999998D-01*dw( 91, 84)
      JacC( 85, 93) = JacC( 85, 93) + dw( 91, 93)
      JacC( 85, 84) = JacC( 85, 84) + dw( 91, 84)
      JacC( 93, 93) = JacC( 93, 93) - dw( 91, 93)
      JacC( 93, 84) = JacC( 93, 84) - dw( 91, 84)
      JacC( 96, 93) = JacC( 96, 93)+ 0.9000000000000000D+00*dw( 91, 93)
      JacC( 96, 84) = JacC( 96, 84)+ 0.9000000000000000D+00*dw( 91, 84)
      JacC( 76, 93) = JacC( 76, 93)+ 0.1000000000000000D+00*dw( 92, 93)
      JacC( 76, 95) = JacC( 76, 95)+ 0.1000000000000000D+00*dw( 92, 95)
      JacC( 84, 93) = JacC( 84, 93)+ 0.9000000000000000D+00*dw( 92, 93)
      JacC( 84, 95) = JacC( 84, 95)+ 0.9000000000000000D+00*dw( 92, 95)
      JacC( 93, 93) = JacC( 93, 93) - dw( 92, 93)
      JacC( 93, 95) = JacC( 93, 95) - dw( 92, 95)
      JacC( 95, 93) = JacC( 95, 93) - dw( 92, 93)
      JacC( 95, 95) = JacC( 95, 95) - dw( 92, 95)
      JacC( 84, 93) = JacC( 84, 93)+ 0.2000000000000000D+01*dw( 93, 93)
      JacC( 84, 93) = JacC( 84, 93)+ 0.2000000000000000D+01*dw( 93, 93)
      JacC( 93, 93) = JacC( 93, 93)- 0.2000000000000000D+01*dw( 93, 93)
      JacC( 93, 93) = JacC( 93, 93)- 0.2000000000000000D+01*dw( 93, 93)
      JacC( 62, 62) = JacC( 62, 62) - dw( 94, 62)
      JacC( 62, 86) = JacC( 62, 86) - dw( 94, 86)
      JacC( 86, 62) = JacC( 86, 62) - dw( 94, 62)
      JacC( 86, 86) = JacC( 86, 86) - dw( 94, 86)
      JacC( 93, 62) = JacC( 93, 62) + dw( 94, 62)
      JacC( 93, 86) = JacC( 93, 86) + dw( 94, 86)
      JacC( 62, 62) = JacC( 62, 62) - dw( 95, 62)
      JacC( 84, 62) = JacC( 84, 62) + dw( 95, 62)
      JacC( 86, 62) = JacC( 86, 62) + dw( 95, 62)
      JacC( 76, 76) = JacC( 76, 76) - dw( 96, 76)
      JacC( 76, 86) = JacC( 76, 86) - dw( 96, 86)
      JacC( 84, 76) = JacC( 84, 76) + dw( 96, 76)
      JacC( 84, 86) = JacC( 84, 86) + dw( 96, 86)
      JacC( 86, 76) = JacC( 86, 76) - dw( 96, 76)
      JacC( 86, 86) = JacC( 86, 86) - dw( 96, 86)
      JacC( 75, 75) = JacC( 75, 75) - dw( 97, 75)
      JacC( 75, 88) = JacC( 75, 88) - dw( 97, 88)
      JacC( 86, 75) = JacC( 86, 75) + dw( 97, 75)
      JacC( 86, 88) = JacC( 86, 88) + dw( 97, 88)
      JacC( 88, 75) = JacC( 88, 75) - dw( 97, 75)
      JacC( 88, 88) = JacC( 88, 88) - dw( 97, 88)
      JacC( 90, 75) = JacC( 90, 75) + dw( 97, 75)
      JacC( 90, 88) = JacC( 90, 88) + dw( 97, 88)
      JacC( 75, 75) = JacC( 75, 75) - dw( 98, 75)
      JacC( 75, 86) = JacC( 75, 86) - dw( 98, 86)
      JacC( 86, 75) = JacC( 86, 75) - dw( 98, 75)
      JacC( 86, 86) = JacC( 86, 86) - dw( 98, 86)
      JacC( 90, 75) = JacC( 90, 75) + dw( 98, 75)
      JacC( 90, 86) = JacC( 90, 86) + dw( 98, 86)
      JacC( 75, 75) = JacC( 75, 75) - dw( 99, 75)
      JacC( 75, 87) = JacC( 75, 87) - dw( 99, 87)
      JacC( 79, 75) = JacC( 79, 75) + dw( 99, 75)
      JacC( 79, 87) = JacC( 79, 87) + dw( 99, 87)
      JacC( 87, 75) = JacC( 87, 75) - dw( 99, 75)
      JacC( 87, 87) = JacC( 87, 87) - dw( 99, 87)
      JacC( 90, 75) = JacC( 90, 75) + dw( 99, 75)
      JacC( 90, 87) = JacC( 90, 87) + dw( 99, 87)
      JacC( 75, 75) = JacC( 75, 75) - dw(100, 75)
      JacC( 77, 75) = JacC( 77, 75) + dw(100, 75)
      JacC( 84, 75) = JacC( 84, 75) + dw(100, 75)
      JacC( 96, 75) = JacC( 96, 75) + dw(100, 75)
      JacC( 89, 90) = JacC( 89, 90) + dw(101, 90)
      JacC( 89, 92) = JacC( 89, 92) + dw(101, 92)
      JacC( 90, 90) = JacC( 90, 90) - dw(101, 90)
      JacC( 90, 92) = JacC( 90, 92) - dw(101, 92)
      JacC( 92, 90) = JacC( 92, 90) - dw(101, 90)
      JacC( 92, 92) = JacC( 92, 92) - dw(101, 92)
      JacC( 94, 90) = JacC( 94, 90) + dw(101, 90)
      JacC( 94, 92) = JacC( 94, 92) + dw(101, 92)
      JacC( 95, 90) = JacC( 95, 90) + dw(101, 90)
      JacC( 95, 92) = JacC( 95, 92) + dw(101, 92)
      JacC( 96, 90) = JacC( 96, 90) + dw(101, 90)
      JacC( 96, 92) = JacC( 96, 92) + dw(101, 92)
      JacC( 38, 90) = JacC( 38, 90) + dw(102, 90)
      JacC( 38, 94) = JacC( 38, 94) + dw(102, 94)
      JacC( 90, 90) = JacC( 90, 90) - dw(102, 90)
      JacC( 90, 94) = JacC( 90, 94) - dw(102, 94)
      JacC( 94, 90) = JacC( 94, 90) - dw(102, 90)
      JacC( 94, 94) = JacC( 94, 94) - dw(102, 94)
      JacC( 38, 38) = JacC( 38, 38) - dw(103, 38)
      JacC( 90, 38) = JacC( 90, 38) + dw(103, 38)
      JacC( 94, 38) = JacC( 94, 38) + dw(103, 38)
      JacC( 38, 38) = JacC( 38, 38) - dw(104, 38)
      JacC( 90, 38) = JacC( 90, 38) + dw(104, 38)
      JacC( 94, 38) = JacC( 94, 38) + dw(104, 38)
      JacC( 38, 38) = JacC( 38, 38) - dw(105, 38)
      JacC( 38, 86) = JacC( 38, 86) - dw(105, 86)
      JacC( 86, 38) = JacC( 86, 38) - dw(105, 38)
      JacC( 86, 86) = JacC( 86, 86) - dw(105, 86)
      JacC( 89, 38) = JacC( 89, 38) + dw(105, 38)
      JacC( 89, 86) = JacC( 89, 86) + dw(105, 86)
      JacC( 94, 38) = JacC( 94, 38) + dw(105, 38)
      JacC( 94, 86) = JacC( 94, 86) + dw(105, 86)
      JacC( 62, 90) = JacC( 62, 90)+ 0.8000000000000000D+00*dw(106, 90)
      JacC( 62, 96) = JacC( 62, 96)+ 0.8000000000000000D+00*dw(106, 96)
      JacC( 76, 90) = JacC( 76, 90)+ 0.2000000000000000D+00*dw(106, 90)
      JacC( 76, 96) = JacC( 76, 96)+ 0.2000000000000000D+00*dw(106, 96)
      JacC( 90, 90) = JacC( 90, 90) - dw(106, 90)
      JacC( 90, 96) = JacC( 90, 96) - dw(106, 96)
      JacC( 91, 90) = JacC( 91, 90)+ 0.2000000000000000D+00*dw(106, 90)
      JacC( 91, 96) = JacC( 91, 96)+ 0.2000000000000000D+00*dw(106, 96)
      JacC( 96, 90) = JacC( 96, 90) - dw(106, 90)
      JacC( 96, 96) = JacC( 96, 96) - dw(106, 96)
      JacC( 76, 93) = JacC( 76, 93)+ 0.1000000000000000D+00*dw(107, 93)
      JacC( 76, 84) = JacC( 76, 84)+ 0.1000000000000000D+00*dw(107, 84)
      JacC( 84, 93) = JacC( 84, 93) - dw(107, 93)
      JacC( 84, 84) = JacC( 84, 84) - dw(107, 84)
      JacC( 85, 93) = JacC( 85, 93)+ 0.1000000000000000D+00*dw(107, 93)
      JacC( 85, 84) = JacC( 85, 84)+ 0.1000000000000000D+00*dw(107, 84)
      JacC( 89, 93) = JacC( 89, 93)+ 0.9000000000000000D+00*dw(107, 93)
      JacC( 89, 84) = JacC( 89, 84)+ 0.9000000000000000D+00*dw(107, 84)
      JacC( 93, 93) = JacC( 93, 93) - dw(107, 93)
      JacC( 93, 84) = JacC( 93, 84) - dw(107, 84)
      JacC( 95, 93) = JacC( 95, 93)+ 0.9000000000000000D+00*dw(107, 93)
      JacC( 95, 84) = JacC( 95, 84)+ 0.9000000000000000D+00*dw(107, 84)
      JacC( 96, 93) = JacC( 96, 93) + dw(107, 93)
      JacC( 96, 84) = JacC( 96, 84) + dw(107, 84)
      JacC( 76, 93) = JacC( 76, 93)+ 0.1000000000000000D+00*dw(108, 93)
      JacC( 76, 95) = JacC( 76, 95)+ 0.1000000000000000D+00*dw(108, 95)
      JacC( 89, 93) = JacC( 89, 93)+ 0.9000000000000000D+00*dw(108, 93)
      JacC( 89, 95) = JacC( 89, 95)+ 0.9000000000000000D+00*dw(108, 95)
      JacC( 93, 93) = JacC( 93, 93) - dw(108, 93)
      JacC( 93, 95) = JacC( 93, 95) - dw(108, 95)
      JacC( 95, 93) = JacC( 95, 93) - dw(108, 93)
      JacC( 95, 95) = JacC( 95, 95) - dw(108, 95)
      JacC( 89, 90) = JacC( 89, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 89, 90) = JacC( 89, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 90, 90) = JacC( 90, 90)- 0.2000000000000000D+01*dw(109, 90)
      JacC( 90, 90) = JacC( 90, 90)- 0.2000000000000000D+01*dw(109, 90)
      JacC( 95, 90) = JacC( 95, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 95, 90) = JacC( 95, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 96, 90) = JacC( 96, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 96, 90) = JacC( 96, 90)+ 0.2000000000000000D+01*dw(109, 90)
      JacC( 84, 90) = JacC( 84, 90) + dw(110, 90)
      JacC( 84, 93) = JacC( 84, 93) + dw(110, 93)
      JacC( 89, 90) = JacC( 89, 90) + dw(110, 90)
      JacC( 89, 93) = JacC( 89, 93) + dw(110, 93)
      JacC( 90, 90) = JacC( 90, 90) - dw(110, 90)
      JacC( 90, 93) = JacC( 90, 93) - dw(110, 93)
      JacC( 93, 90) = JacC( 93, 90) - dw(110, 90)
      JacC( 93, 93) = JacC( 93, 93) - dw(110, 93)
      JacC( 95, 90) = JacC( 95, 90) + dw(110, 90)
      JacC( 95, 93) = JacC( 95, 93) + dw(110, 93)
      JacC( 96, 90) = JacC( 96, 90) + dw(110, 90)
      JacC( 96, 93) = JacC( 96, 93) + dw(110, 93)
      JacC( 39, 74) = JacC( 39, 74)+ 0.7600000000000000D+00*dw(111, 74)
      JacC( 39, 86) = JacC( 39, 86)+ 0.7600000000000000D+00*dw(111, 86)
      JacC( 74, 74) = JacC( 74, 74)- 0.8900000000000000D+00*dw(111, 74)
      JacC( 74, 86) = JacC( 74, 86)- 0.8900000000000000D+00*dw(111, 86)
      JacC( 75, 74) = JacC( 75, 74)+ 0.5000000000000000D-01*dw(111, 74)
      JacC( 75, 86) = JacC( 75, 86)+ 0.5000000000000000D-01*dw(111, 86)
      JacC( 83, 74) = JacC( 83, 74)+ 0.1300000000000000D+00*dw(111, 74)
      JacC( 83, 86) = JacC( 83, 86)+ 0.1300000000000000D+00*dw(111, 86)
      JacC( 86, 74) = JacC( 86, 74) - dw(111, 74)
      JacC( 86, 86) = JacC( 86, 86) - dw(111, 86)
      JacC( 89, 74) = JacC( 89, 74)+ 0.6000000000000000D-01*dw(111, 74)
      JacC( 89, 86) = JacC( 89, 86)+ 0.6000000000000000D-01*dw(111, 86)
      JacC( 95, 74) = JacC( 95, 74)+ 0.8700000000000000D+00*dw(111, 74)
      JacC( 95, 86) = JacC( 95, 86)+ 0.8700000000000000D+00*dw(111, 86)
      JacC( 96, 74) = JacC( 96, 74)+ 0.1100000000000000D+00*dw(111, 74)
      JacC( 96, 86) = JacC( 96, 86)+ 0.1100000000000000D+00*dw(111, 86)
      JacC( 39, 39) = JacC( 39, 39)- 0.9800000000000000D+00*dw(112, 39)
      JacC( 74, 39) = JacC( 74, 39)+ 0.2100000000000000D+01*dw(112, 39)
      JacC( 75, 39) = JacC( 75, 39)+ 0.5000000000000000D+00*dw(112, 39)
      JacC( 83, 39) = JacC( 83, 39)+ 0.4000000000000000D-01*dw(112, 39)
      JacC( 89, 39) = JacC( 89, 39)+ 0.6000000000000000D+00*dw(112, 39)
      JacC( 95, 39) = JacC( 95, 39)+ 0.9600000000000000D+00*dw(112, 39)
      JacC( 96, 39) = JacC( 96, 39)+ 0.9399999999999999D+00*dw(112, 39)
      JacC( 39, 39) = JacC( 39, 39) - dw(113, 39)
      JacC( 96, 39) = JacC( 96, 39) + dw(113, 39)
      JacC( 39, 39) = JacC( 39, 39) - dw(114, 39)
      JacC( 39, 94) = JacC( 39, 94) - dw(114, 94)
      JacC( 73, 39) = JacC( 73, 39) + dw(114, 39)
      JacC( 73, 94) = JacC( 73, 94) + dw(114, 94)
      JacC( 94, 39) = JacC( 94, 39) - dw(114, 39)
      JacC( 94, 94) = JacC( 94, 94) - dw(114, 94)
      JacC( 58, 88) = JacC( 58, 88) - dw(115, 88)
      JacC( 58, 58) = JacC( 58, 58) - dw(115, 58)
      JacC( 74, 88) = JacC( 74, 88)+ 0.2000000000000000D+00*dw(115, 88)
      JacC( 74, 58) = JacC( 74, 58)+ 0.2000000000000000D+00*dw(115, 58)
      JacC( 75, 88) = JacC( 75, 88)+ 0.3000000000000000D+00*dw(115, 88)
      JacC( 75, 58) = JacC( 75, 58)+ 0.3000000000000000D+00*dw(115, 58)
      JacC( 77, 88) = JacC( 77, 88)+ 0.2000000000000000D+00*dw(115, 88)
      JacC( 77, 58) = JacC( 77, 58)+ 0.2000000000000000D+00*dw(115, 58)
      JacC( 83, 88) = JacC( 83, 88)+ 0.1000000000000000D-01*dw(115, 88)
      JacC( 83, 58) = JacC( 83, 58)+ 0.1000000000000000D-01*dw(115, 58)
      JacC( 85, 88) = JacC( 85, 88)+ 0.2000000000000000D+00*dw(115, 88)
      JacC( 85, 58) = JacC( 85, 58)+ 0.2000000000000000D+00*dw(115, 58)
      JacC( 86, 88) = JacC( 86, 88)+ 0.1000000000000000D+00*dw(115, 88)
      JacC( 86, 58) = JacC( 86, 58)+ 0.1000000000000000D+00*dw(115, 58)
      JacC( 88, 88) = JacC( 88, 88) - dw(115, 88)
      JacC( 88, 58) = JacC( 88, 58) - dw(115, 58)
      JacC( 89, 88) = JacC( 89, 88)+ 0.2000000000000000D+00*dw(115, 88)
      JacC( 89, 58) = JacC( 89, 58)+ 0.2000000000000000D+00*dw(115, 58)
      JacC( 95, 88) = JacC( 95, 88)+ 0.2000000000000000D+00*dw(115, 88)
      JacC( 95, 58) = JacC( 95, 58)+ 0.2000000000000000D+00*dw(115, 58)
      JacC( 96, 88) = JacC( 96, 88)+ 0.3000000000000000D+00*dw(115, 88)
      JacC( 96, 58) = JacC( 96, 58)+ 0.3000000000000000D+00*dw(115, 58)
      JacC( 58, 86) = JacC( 58, 86) - dw(116, 86)
      JacC( 58, 58) = JacC( 58, 58) - dw(116, 58)
      JacC( 74, 86) = JacC( 74, 86)+ 0.7000000000000000D+00*dw(116, 86)
      JacC( 74, 58) = JacC( 74, 58)+ 0.7000000000000000D+00*dw(116, 58)
      JacC( 75, 86) = JacC( 75, 86)+ 0.6200000000000000D+00*dw(116, 86)
      JacC( 75, 58) = JacC( 75, 58)+ 0.6200000000000000D+00*dw(116, 58)
      JacC( 85, 86) = JacC( 85, 86)+ 0.8000000000000000D+00*dw(116, 86)
      JacC( 85, 58) = JacC( 85, 58)+ 0.8000000000000000D+00*dw(116, 58)
      JacC( 86, 86) = JacC( 86, 86) - dw(116, 86)
      JacC( 86, 58) = JacC( 86, 58) - dw(116, 58)
      JacC( 89, 86) = JacC( 89, 86)+ 0.3300000000000000D+00*dw(116, 86)
      JacC( 89, 58) = JacC( 89, 58)+ 0.3300000000000000D+00*dw(116, 58)
      JacC( 95, 86) = JacC( 95, 86)+ 0.8000000000000000D+00*dw(116, 86)
      JacC( 95, 58) = JacC( 95, 58)+ 0.8000000000000000D+00*dw(116, 58)
      JacC( 96, 86) = JacC( 96, 86)+ 0.9500000000000000D+00*dw(116, 86)
      JacC( 96, 58) = JacC( 96, 58)+ 0.9500000000000000D+00*dw(116, 58)
      JacC( 58, 91) = JacC( 58, 91) - dw(117, 91)
      JacC( 58, 58) = JacC( 58, 58) - dw(117, 58)
      JacC( 74, 91) = JacC( 74, 91) + dw(117, 91)
      JacC( 74, 58) = JacC( 74, 58) + dw(117, 58)
      JacC( 75, 91) = JacC( 75, 91)+ 0.3200000000000000D+00*dw(117, 91)
      JacC( 75, 58) = JacC( 75, 58)+ 0.3200000000000000D+00*dw(117, 58)
      JacC( 77, 91) = JacC( 77, 91)+ 0.3300000000000000D+00*dw(117, 91)
      JacC( 77, 58) = JacC( 77, 58)+ 0.3300000000000000D+00*dw(117, 58)
      JacC( 85, 91) = JacC( 85, 91)+ 0.7400000000000000D+00*dw(117, 91)
      JacC( 85, 58) = JacC( 85, 58)+ 0.7400000000000000D+00*dw(117, 58)
      JacC( 86, 91) = JacC( 86, 91)+ 0.1000000000000000D+00*dw(117, 91)
      JacC( 86, 58) = JacC( 86, 58)+ 0.1000000000000000D+00*dw(117, 58)
      JacC( 89, 91) = JacC( 89, 91)+ 0.1800000000000000D+00*dw(117, 91)
      JacC( 89, 58) = JacC( 89, 58)+ 0.1800000000000000D+00*dw(117, 58)
      JacC( 91, 91) = JacC( 91, 91) - dw(117, 91)
      JacC( 91, 58) = JacC( 91, 58) - dw(117, 58)
      JacC( 95, 91) = JacC( 95, 91)+ 0.2200000000000000D+00*dw(117, 91)
      JacC( 95, 58) = JacC( 95, 58)+ 0.2200000000000000D+00*dw(117, 58)
      JacC( 96, 91) = JacC( 96, 91)+ 0.4400000000000000D+00*dw(117, 91)
      JacC( 96, 58) = JacC( 96, 58)+ 0.4400000000000000D+00*dw(117, 58)
      JacC( 58, 87) = JacC( 58, 87) - dw(118, 87)
      JacC( 58, 58) = JacC( 58, 58) - dw(118, 58)
      JacC( 74, 87) = JacC( 74, 87) + dw(118, 87)
      JacC( 74, 58) = JacC( 74, 58) + dw(118, 58)
      JacC( 75, 87) = JacC( 75, 87)+ 0.5600000000000001D+00*dw(118, 87)
      JacC( 75, 58) = JacC( 75, 58)+ 0.5600000000000001D+00*dw(118, 58)
      JacC( 83, 87) = JacC( 83, 87)+ 0.9000000000000000D-01*dw(118, 87)
      JacC( 83, 58) = JacC( 83, 58)+ 0.9000000000000000D-01*dw(118, 58)
      JacC( 85, 87) = JacC( 85, 87) + dw(118, 87)
      JacC( 85, 58) = JacC( 85, 58) + dw(118, 58)
      JacC( 87, 87) = JacC( 87, 87) - dw(118, 87)
      JacC( 87, 58) = JacC( 87, 58) - dw(118, 58)
      JacC( 89, 87) = JacC( 89, 87)+ 0.3500000000000000D+00*dw(118, 87)
      JacC( 89, 58) = JacC( 89, 58)+ 0.3500000000000000D+00*dw(118, 58)
      JacC( 94, 87) = JacC( 94, 87) + dw(118, 87)
      JacC( 94, 58) = JacC( 94, 58) + dw(118, 58)
      JacC( 95, 87) = JacC( 95, 87)+ 0.9100000000000000D+00*dw(118, 87)
      JacC( 95, 58) = JacC( 95, 58)+ 0.9100000000000000D+00*dw(118, 58)
      JacC( 55, 88) = JacC( 55, 88) - dw(119, 88)
      JacC( 55, 55) = JacC( 55, 55) - dw(119, 55)
      JacC( 77, 88) = JacC( 77, 88) + dw(119, 88)
      JacC( 77, 55) = JacC( 77, 55) + dw(119, 55)
      JacC( 85, 88) = JacC( 85, 88) + dw(119, 88)
      JacC( 85, 55) = JacC( 85, 55) + dw(119, 55)
      JacC( 86, 88) = JacC( 86, 88)+ 0.3000000000000000D+00*dw(119, 88)
      JacC( 86, 55) = JacC( 86, 55)+ 0.3000000000000000D+00*dw(119, 55)
      JacC( 88, 88) = JacC( 88, 88) - dw(119, 88)
      JacC( 88, 55) = JacC( 88, 55) - dw(119, 55)
      JacC( 95, 88) = JacC( 95, 88)+ 0.7000000000000000D+00*dw(119, 88)
      JacC( 95, 55) = JacC( 95, 55)+ 0.7000000000000000D+00*dw(119, 55)
      JacC( 96, 88) = JacC( 96, 88)+ 0.1700000000000000D+01*dw(119, 88)
      JacC( 96, 55) = JacC( 96, 55)+ 0.1700000000000000D+01*dw(119, 55)
      JacC( 55, 86) = JacC( 55, 86) - dw(120, 86)
      JacC( 55, 55) = JacC( 55, 55) - dw(120, 55)
      JacC( 75, 86) = JacC( 75, 86)+ 0.2200000000000000D+00*dw(120, 86)
      JacC( 75, 55) = JacC( 75, 55)+ 0.2200000000000000D+00*dw(120, 55)
      JacC( 85, 86) = JacC( 85, 86)+ 0.1560000000000000D+01*dw(120, 86)
      JacC( 85, 55) = JacC( 85, 55)+ 0.1560000000000000D+01*dw(120, 55)
      JacC( 86, 86) = JacC( 86, 86) - dw(120, 86)
      JacC( 86, 55) = JacC( 86, 55) - dw(120, 55)
      JacC( 95, 86) = JacC( 95, 86) + dw(120, 86)
      JacC( 95, 55) = JacC( 95, 55) + dw(120, 55)
      JacC( 96, 86) = JacC( 96, 86) + dw(120, 86)
      JacC( 96, 55) = JacC( 96, 55) + dw(120, 55)
      JacC( 55, 91) = JacC( 55, 91) - dw(121, 91)
      JacC( 55, 55) = JacC( 55, 55) - dw(121, 55)
      JacC( 56, 91) = JacC( 56, 91)+ 0.3700000000000000D+00*dw(121, 91)
      JacC( 56, 55) = JacC( 56, 55)+ 0.3700000000000000D+00*dw(121, 55)
      JacC( 77, 91) = JacC( 77, 91)+ 0.6300000000000000D+00*dw(121, 91)
      JacC( 77, 55) = JacC( 77, 55)+ 0.6300000000000000D+00*dw(121, 55)
      JacC( 85, 91) = JacC( 85, 91) + dw(121, 91)
      JacC( 85, 55) = JacC( 85, 55) + dw(121, 55)
      JacC( 86, 91) = JacC( 86, 91)+ 0.1300000000000000D+00*dw(121, 91)
      JacC( 86, 55) = JacC( 86, 55)+ 0.1300000000000000D+00*dw(121, 55)
      JacC( 91, 91) = JacC( 91, 91) - dw(121, 91)
      JacC( 91, 55) = JacC( 91, 55) - dw(121, 55)
      JacC( 96, 91) = JacC( 96, 91)+ 0.1300000000000000D+00*dw(121, 91)
      JacC( 96, 55) = JacC( 96, 55)+ 0.1300000000000000D+00*dw(121, 55)
      JacC( 55, 87) = JacC( 55, 87) - dw(122, 87)
      JacC( 55, 55) = JacC( 55, 55) - dw(122, 55)
      JacC( 85, 87) = JacC( 85, 87)+ 0.2000000000000000D+01*dw(122, 87)
      JacC( 85, 55) = JacC( 85, 55)+ 0.2000000000000000D+01*dw(122, 55)
      JacC( 87, 87) = JacC( 87, 87) - dw(122, 87)
      JacC( 87, 55) = JacC( 87, 55) - dw(122, 55)
      JacC( 94, 87) = JacC( 94, 87) + dw(122, 87)
      JacC( 94, 55) = JacC( 94, 55) + dw(122, 55)
      JacC( 95, 87) = JacC( 95, 87) + dw(122, 87)
      JacC( 95, 55) = JacC( 95, 55) + dw(122, 55)
      JacC( 59, 59) = JacC( 59, 59) - dw(123, 59)
      JacC( 59, 88) = JacC( 59, 88) - dw(123, 88)
      JacC( 74, 59) = JacC( 74, 59)+ 0.1000000000000000D+00*dw(123, 59)
      JacC( 74, 88) = JacC( 74, 88)+ 0.1000000000000000D+00*dw(123, 88)
      JacC( 75, 59) = JacC( 75, 59)+ 0.6600000000000000D+00*dw(123, 59)
      JacC( 75, 88) = JacC( 75, 88)+ 0.6600000000000000D+00*dw(123, 88)
      JacC( 77, 59) = JacC( 77, 59)+ 0.1000000000000000D+00*dw(123, 59)
      JacC( 77, 88) = JacC( 77, 88)+ 0.1000000000000000D+00*dw(123, 88)
      JacC( 88, 59) = JacC( 88, 59) - dw(123, 59)
      JacC( 88, 88) = JacC( 88, 88) - dw(123, 88)
      JacC( 89, 59) = JacC( 89, 59)+ 0.1240000000000000D+01*dw(123, 59)
      JacC( 89, 88) = JacC( 89, 88)+ 0.1240000000000000D+01*dw(123, 88)
      JacC( 95, 59) = JacC( 95, 59)+ 0.1000000000000000D+00*dw(123, 59)
      JacC( 95, 88) = JacC( 95, 88)+ 0.1000000000000000D+00*dw(123, 88)
      JacC( 96, 59) = JacC( 96, 59)+ 0.1000000000000000D+00*dw(123, 59)
      JacC( 96, 88) = JacC( 96, 88)+ 0.1000000000000000D+00*dw(123, 88)
      JacC( 59, 59) = JacC( 59, 59) - dw(124, 59)
      JacC( 59, 86) = JacC( 59, 86) - dw(124, 86)
      JacC( 75, 59) = JacC( 75, 59)+ 0.7000000000000000D+00*dw(124, 59)
      JacC( 75, 86) = JacC( 75, 86)+ 0.7000000000000000D+00*dw(124, 86)
      JacC( 86, 59) = JacC( 86, 59) - dw(124, 59)
      JacC( 86, 86) = JacC( 86, 86) - dw(124, 86)
      JacC( 89, 59) = JacC( 89, 59)+ 0.1300000000000000D+01*dw(124, 59)
      JacC( 89, 86) = JacC( 89, 86)+ 0.1300000000000000D+01*dw(124, 86)
      JacC( 95, 59) = JacC( 95, 59) + dw(124, 59)
      JacC( 95, 86) = JacC( 95, 86) + dw(124, 86)
      JacC( 96, 59) = JacC( 96, 59) + dw(124, 59)
      JacC( 96, 86) = JacC( 96, 86) + dw(124, 86)
      JacC( 59, 59) = JacC( 59, 59) - dw(125, 59)
      JacC( 59, 91) = JacC( 59, 91) - dw(125, 91)
      JacC( 75, 59) = JacC( 75, 59)+ 0.3500000000000000D+00*dw(125, 59)
      JacC( 75, 91) = JacC( 75, 91)+ 0.3500000000000000D+00*dw(125, 91)
      JacC( 77, 59) = JacC( 77, 59)+ 0.2500000000000000D+00*dw(125, 59)
      JacC( 77, 91) = JacC( 77, 91)+ 0.2500000000000000D+00*dw(125, 91)
      JacC( 85, 59) = JacC( 85, 59)+ 0.2500000000000000D+00*dw(125, 59)
      JacC( 85, 91) = JacC( 85, 91)+ 0.2500000000000000D+00*dw(125, 91)
      JacC( 86, 59) = JacC( 86, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 86, 91) = JacC( 86, 91)+ 0.5000000000000000D+00*dw(125, 91)
      JacC( 88, 59) = JacC( 88, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 88, 91) = JacC( 88, 91)+ 0.5000000000000000D+00*dw(125, 91)
      JacC( 89, 59) = JacC( 89, 59)+ 0.6500000000000000D+00*dw(125, 59)
      JacC( 89, 91) = JacC( 89, 91)+ 0.6500000000000000D+00*dw(125, 91)
      JacC( 91, 59) = JacC( 91, 59) - dw(125, 59)
      JacC( 91, 91) = JacC( 91, 91) - dw(125, 91)
      JacC( 96, 59) = JacC( 96, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 96, 91) = JacC( 96, 91)+ 0.5000000000000000D+00*dw(125, 91)
      JacC( 59, 59) = JacC( 59, 59) - dw(126, 59)
      JacC( 59, 87) = JacC( 59, 87) - dw(126, 87)
      JacC( 75, 59) = JacC( 75, 59)+ 0.6400000000000000D+00*dw(126, 59)
      JacC( 75, 87) = JacC( 75, 87)+ 0.6400000000000000D+00*dw(126, 87)
      JacC( 87, 59) = JacC( 87, 59) - dw(126, 59)
      JacC( 87, 87) = JacC( 87, 87) - dw(126, 87)
      JacC( 89, 59) = JacC( 89, 59)+ 0.1180000000000000D+01*dw(126, 59)
      JacC( 89, 87) = JacC( 89, 87)+ 0.1180000000000000D+01*dw(126, 87)
      JacC( 94, 59) = JacC( 94, 59) + dw(126, 59)
      JacC( 94, 87) = JacC( 94, 87) + dw(126, 87)
      JacC( 96, 59) = JacC( 96, 59) + dw(126, 59)
      JacC( 96, 87) = JacC( 96, 87) + dw(126, 87)
      JacC(  8,  8) = JacC(  8,  8) - dw(127,  8)
      JacC(  8, 86) = JacC(  8, 86) - dw(127, 86)
      JacC( 24,  8) = JacC( 24,  8)+ 0.5600000000000001D+00*dw(127,  8)
      JacC( 24, 86) = JacC( 24, 86)+ 0.5600000000000001D+00*dw(127, 86)
      JacC( 63,  8) = JacC( 63,  8)+ 0.3600000000000000D+00*dw(127,  8)
      JacC( 63, 86) = JacC( 63, 86)+ 0.3600000000000000D+00*dw(127, 86)
      JacC( 82,  8) = JacC( 82,  8)+ 0.2500000000000000D+00*dw(127,  8)
      JacC( 82, 86) = JacC( 82, 86)+ 0.2500000000000000D+00*dw(127, 86)
      JacC( 86,  8) = JacC( 86,  8) - dw(127,  8)
      JacC( 86, 86) = JacC( 86, 86) - dw(127, 86)
      JacC( 95,  8) = JacC( 95,  8)+ 0.8000000000000000D-01*dw(127,  8)
      JacC( 95, 86) = JacC( 95, 86)+ 0.8000000000000000D-01*dw(127, 86)
      JacC( 96,  8) = JacC( 96,  8)+ 0.4400000000000000D+00*dw(127,  8)
      JacC( 96, 86) = JacC( 96, 86)+ 0.4400000000000000D+00*dw(127, 86)
      JacC( 24, 24) = JacC( 24, 24) - dw(128, 24)
      JacC( 24, 92) = JacC( 24, 92) - dw(128, 92)
      JacC( 44, 24) = JacC( 44, 24)+ 0.9000000000000000D+00*dw(128, 24)
      JacC( 44, 92) = JacC( 44, 92)+ 0.9000000000000000D+00*dw(128, 92)
      JacC( 73, 24) = JacC( 73, 24)+ 0.1000000000000000D+00*dw(128, 24)
      JacC( 73, 92) = JacC( 73, 92)+ 0.1000000000000000D+00*dw(128, 92)
      JacC( 92, 24) = JacC( 92, 24) - dw(128, 24)
      JacC( 92, 92) = JacC( 92, 92) - dw(128, 92)
      JacC( 94, 24) = JacC( 94, 24)+ 0.9000000000000000D+00*dw(128, 24)
      JacC( 94, 92) = JacC( 94, 92)+ 0.9000000000000000D+00*dw(128, 92)
      JacC( 96, 24) = JacC( 96, 24)+ 0.9000000000000000D+00*dw(128, 24)
      JacC( 96, 92) = JacC( 96, 92)+ 0.9000000000000000D+00*dw(128, 92)
      JacC( 24, 24) = JacC( 24, 24) - dw(129, 24)
      JacC( 63, 24) = JacC( 63, 24) + dw(129, 24)
      JacC( 96, 24) = JacC( 96, 24) + dw(129, 24)
      JacC( 44, 86) = JacC( 44, 86)+ 0.3000000000000000D+00*dw(130, 86)
      JacC( 44, 63) = JacC( 44, 63)+ 0.3000000000000000D+00*dw(130, 63)
      JacC( 63, 86) = JacC( 63, 86) - dw(130, 86)
      JacC( 63, 63) = JacC( 63, 63) - dw(130, 63)
      JacC( 64, 86) = JacC( 64, 86)+ 0.4000000000000000D+00*dw(130, 86)
      JacC( 64, 63) = JacC( 64, 63)+ 0.4000000000000000D+00*dw(130, 63)
      JacC( 86, 86) = JacC( 86, 86) - dw(130, 86)
      JacC( 86, 63) = JacC( 86, 63) - dw(130, 63)
      JacC( 95, 86) = JacC( 95, 86)+ 0.6000000000000000D+00*dw(130, 86)
      JacC( 95, 63) = JacC( 95, 63)+ 0.6000000000000000D+00*dw(130, 63)
      JacC( 96, 86) = JacC( 96, 86)+ 0.6000000000000000D+00*dw(130, 86)
      JacC( 96, 63) = JacC( 96, 63)+ 0.6000000000000000D+00*dw(130, 63)
      JacC( 63, 63) = JacC( 63, 63) - dw(131, 63)
      JacC( 63, 87) = JacC( 63, 87) - dw(131, 87)
      JacC( 64, 63) = JacC( 64, 63) + dw(131, 63)
      JacC( 64, 87) = JacC( 64, 87) + dw(131, 87)
      JacC( 79, 63) = JacC( 79, 63) + dw(131, 63)
      JacC( 79, 87) = JacC( 79, 87) + dw(131, 87)
      JacC( 87, 63) = JacC( 87, 63) - dw(131, 63)
      JacC( 87, 87) = JacC( 87, 87) - dw(131, 87)
      JacC( 64, 64) = JacC( 64, 64) - dw(132, 64)
      JacC( 64, 94) = JacC( 64, 94) - dw(132, 94)
      JacC( 73, 64) = JacC( 73, 64) + dw(132, 64)
      JacC( 73, 94) = JacC( 73, 94) + dw(132, 94)
      JacC( 94, 64) = JacC( 94, 64) - dw(132, 64)
      JacC( 94, 94) = JacC( 94, 94) - dw(132, 94)
      JacC( 63, 64) = JacC( 63, 64) + dw(133, 64)
      JacC( 63, 96) = JacC( 63, 96) + dw(133, 96)
      JacC( 64, 64) = JacC( 64, 64) - dw(133, 64)
      JacC( 64, 96) = JacC( 64, 96) - dw(133, 96)
      JacC( 96, 64) = JacC( 96, 64) - dw(133, 64)
      JacC( 96, 96) = JacC( 96, 96) - dw(133, 96)
      JacC( 44, 44) = JacC( 44, 44) - dw(134, 44)
      JacC( 77, 44) = JacC( 77, 44) + dw(134, 44)
      JacC( 93, 44) = JacC( 93, 44) + dw(134, 44)
      JacC( 96, 44) = JacC( 96, 44) + dw(134, 44)
      JacC( 44, 44) = JacC( 44, 44) - dw(135, 44)
      JacC( 44, 86) = JacC( 44, 86) - dw(135, 86)
      JacC( 77, 44) = JacC( 77, 44)+ 0.2000000000000000D+01*dw(135, 44)
      JacC( 77, 86) = JacC( 77, 86)+ 0.2000000000000000D+01*dw(135, 86)
      JacC( 85, 44) = JacC( 85, 44) + dw(135, 44)
      JacC( 85, 86) = JacC( 85, 86) + dw(135, 86)
      JacC( 86, 44) = JacC( 86, 44) - dw(135, 44)
      JacC( 86, 86) = JacC( 86, 86) - dw(135, 86)
      JacC( 93, 44) = JacC( 93, 44) + dw(135, 44)
      JacC( 93, 86) = JacC( 93, 86) + dw(135, 86)
      JacC( 95, 44) = JacC( 95, 44) + dw(135, 44)
      JacC( 95, 86) = JacC( 95, 86) + dw(135, 86)
      JacC( 96, 44) = JacC( 96, 44)+ 0.2000000000000000D+01*dw(135, 44)
      JacC( 96, 86) = JacC( 96, 86)+ 0.2000000000000000D+01*dw(135, 86)
      JacC( 44, 44) = JacC( 44, 44) - dw(136, 44)
      JacC( 44, 91) = JacC( 44, 91) - dw(136, 91)
      JacC( 45, 44) = JacC( 45, 44)+ 0.2000000000000000D+00*dw(136, 44)
      JacC( 45, 91) = JacC( 45, 91)+ 0.2000000000000000D+00*dw(136, 91)
      JacC( 75, 44) = JacC( 75, 44)+ 0.3000000000000000D-01*dw(136, 44)
      JacC( 75, 91) = JacC( 75, 91)+ 0.3000000000000000D-01*dw(136, 91)
      JacC( 77, 44) = JacC( 77, 44)+ 0.6899999999999999D+00*dw(136, 44)
      JacC( 77, 91) = JacC( 77, 91)+ 0.6899999999999999D+00*dw(136, 91)
      JacC( 85, 44) = JacC( 85, 44)+ 0.7000000000000000D+00*dw(136, 44)
      JacC( 85, 91) = JacC( 85, 91)+ 0.7000000000000000D+00*dw(136, 91)
      JacC( 86, 44) = JacC( 86, 44)+ 0.8000000000000000D-01*dw(136, 44)
      JacC( 86, 91) = JacC( 86, 91)+ 0.8000000000000000D-01*dw(136, 91)
      JacC( 91, 44) = JacC( 91, 44) - dw(136, 44)
      JacC( 91, 91) = JacC( 91, 91) - dw(136, 91)
      JacC( 93, 44) = JacC( 93, 44)+ 0.6200000000000000D+00*dw(136, 44)
      JacC( 93, 91) = JacC( 93, 91)+ 0.6200000000000000D+00*dw(136, 91)
      JacC( 95, 44) = JacC( 95, 44)+ 0.3000000000000000D-01*dw(136, 44)
      JacC( 95, 91) = JacC( 95, 91)+ 0.3000000000000000D-01*dw(136, 91)
      JacC( 96, 44) = JacC( 96, 44)+ 0.7600000000000000D+00*dw(136, 44)
      JacC( 96, 91) = JacC( 96, 91)+ 0.7600000000000000D+00*dw(136, 91)
      JacC(  9, 86) = JacC(  9, 86) - dw(137, 86)
      JacC(  9,  9) = JacC(  9,  9) - dw(137,  9)
      JacC( 24, 86) = JacC( 24, 86)+ 0.3000000000000000D+00*dw(137, 86)
      JacC( 24,  9) = JacC( 24,  9)+ 0.3000000000000000D+00*dw(137,  9)
      JacC( 45, 86) = JacC( 45, 86)+ 0.8000000000000000D+00*dw(137, 86)
      JacC( 45,  9) = JacC( 45,  9)+ 0.8000000000000000D+00*dw(137,  9)
      JacC( 63, 86) = JacC( 63, 86)+ 0.2000000000000000D-01*dw(137, 86)
      JacC( 63,  9) = JacC( 63,  9)+ 0.2000000000000000D-01*dw(137,  9)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1100000000000000D+01*dw(137, 86)
      JacC( 74,  9) = JacC( 74,  9)+ 0.1100000000000000D+01*dw(137,  9)
      JacC( 78, 86) = JacC( 78, 86)+ 0.2740000000000000D+00*dw(137, 86)
      JacC( 78,  9) = JacC( 78,  9)+ 0.2740000000000000D+00*dw(137,  9)
      JacC( 86, 86) = JacC( 86, 86) - dw(137, 86)
      JacC( 86,  9) = JacC( 86,  9) - dw(137,  9)
      JacC( 95, 86) = JacC( 95, 86)+ 0.5000000000000000D+00*dw(137, 86)
      JacC( 95,  9) = JacC( 95,  9)+ 0.5000000000000000D+00*dw(137,  9)
      JacC( 96, 86) = JacC( 96, 86)+ 0.7000000000000000D+00*dw(137, 86)
      JacC( 96,  9) = JacC( 96,  9)+ 0.7000000000000000D+00*dw(137,  9)
      JacC( 45, 86) = JacC( 45, 86) - dw(138, 86)
      JacC( 45, 45) = JacC( 45, 45) - dw(138, 45)
      JacC( 86, 86) = JacC( 86, 86) - dw(138, 86)
      JacC( 86, 45) = JacC( 86, 45) - dw(138, 45)
      JacC( 93, 86) = JacC( 93, 86) + dw(138, 86)
      JacC( 93, 45) = JacC( 93, 45) + dw(138, 45)
      JacC( 95, 86) = JacC( 95, 86) + dw(138, 86)
      JacC( 95, 45) = JacC( 95, 45) + dw(138, 45)
      JacC( 45, 45) = JacC( 45, 45) - dw(139, 45)
      JacC( 77, 45) = JacC( 77, 45) + dw(139, 45)
      JacC( 93, 45) = JacC( 93, 45) + dw(139, 45)
      JacC( 96, 45) = JacC( 96, 45) + dw(139, 45)
      JacC( 71, 88) = JacC( 71, 88) - dw(140, 88)
      JacC( 71, 71) = JacC( 71, 71) - dw(140, 71)
      JacC( 72, 88) = JacC( 72, 88)+ 0.7500000000000000D+00*dw(140, 88)
      JacC( 72, 71) = JacC( 72, 71)+ 0.7500000000000000D+00*dw(140, 71)
      JacC( 74, 88) = JacC( 74, 88)+ 0.2500000000000000D+00*dw(140, 88)
      JacC( 74, 71) = JacC( 74, 71)+ 0.2500000000000000D+00*dw(140, 71)
      JacC( 85, 88) = JacC( 85, 88)+ 0.5000000000000000D+00*dw(140, 88)
      JacC( 85, 71) = JacC( 85, 71)+ 0.5000000000000000D+00*dw(140, 71)
      JacC( 88, 88) = JacC( 88, 88) - dw(140, 88)
      JacC( 88, 71) = JacC( 88, 71) - dw(140, 71)
      JacC( 90, 88) = JacC( 90, 88)+ 0.2500000000000000D+00*dw(140, 88)
      JacC( 90, 71) = JacC( 90, 71)+ 0.2500000000000000D+00*dw(140, 71)
      JacC( 95, 88) = JacC( 95, 88)+ 0.2500000000000000D+00*dw(140, 88)
      JacC( 95, 71) = JacC( 95, 71)+ 0.2500000000000000D+00*dw(140, 71)
      JacC( 96, 88) = JacC( 96, 88)+ 0.2500000000000000D+00*dw(140, 88)
      JacC( 96, 71) = JacC( 96, 71)+ 0.2500000000000000D+00*dw(140, 71)
      JacC( 71, 86) = JacC( 71, 86) - dw(141, 86)
      JacC( 71, 71) = JacC( 71, 71) - dw(141, 71)
      JacC( 72, 86) = JacC( 72, 86)+ 0.9120000000000000D+00*dw(141, 86)
      JacC( 72, 71) = JacC( 72, 71)+ 0.9120000000000000D+00*dw(141, 71)
      JacC( 80, 86) = JacC( 80, 86) + dw(141, 86)
      JacC( 80, 71) = JacC( 80, 71) + dw(141, 71)
      JacC( 83, 86) = JacC( 83, 86)+ 0.8799999999999999D-01*dw(141, 86)
      JacC( 83, 71) = JacC( 83, 71)+ 0.8799999999999999D-01*dw(141, 71)
      JacC( 85, 86) = JacC( 85, 86)+ 0.6290000000000000D+00*dw(141, 86)
      JacC( 85, 71) = JacC( 85, 71)+ 0.6290000000000000D+00*dw(141, 71)
      JacC( 86, 86) = JacC( 86, 86) - dw(141, 86)
      JacC( 86, 71) = JacC( 86, 71) - dw(141, 71)
      JacC( 95, 86) = JacC( 95, 86)+ 0.9910000000000000D+00*dw(141, 86)
      JacC( 95, 71) = JacC( 95, 71)+ 0.9910000000000000D+00*dw(141, 71)
      JacC( 96, 86) = JacC( 96, 86)+ 0.9120000000000000D+00*dw(141, 86)
      JacC( 96, 71) = JacC( 96, 71)+ 0.9120000000000000D+00*dw(141, 71)
      JacC( 71, 91) = JacC( 71, 91) - dw(142, 91)
      JacC( 71, 71) = JacC( 71, 71) - dw(142, 71)
      JacC( 72, 91) = JacC( 72, 91)+ 0.6500000000000000D+00*dw(142, 91)
      JacC( 72, 71) = JacC( 72, 71)+ 0.6500000000000000D+00*dw(142, 71)
      JacC( 74, 91) = JacC( 74, 91)+ 0.3500000000000000D+00*dw(142, 91)
      JacC( 74, 71) = JacC( 74, 71)+ 0.3500000000000000D+00*dw(142, 71)
      JacC( 75, 91) = JacC( 75, 91)+ 0.1500000000000000D+00*dw(142, 91)
      JacC( 75, 71) = JacC( 75, 71)+ 0.1500000000000000D+00*dw(142, 71)
      JacC( 77, 91) = JacC( 77, 91)+ 0.6600000000000000D-01*dw(142, 91)
      JacC( 77, 71) = JacC( 77, 71)+ 0.6600000000000000D-01*dw(142, 71)
      JacC( 85, 91) = JacC( 85, 91)+ 0.6000000000000000D+00*dw(142, 91)
      JacC( 85, 71) = JacC( 85, 71)+ 0.6000000000000000D+00*dw(142, 71)
      JacC( 86, 91) = JacC( 86, 91)+ 0.2660000000000000D+00*dw(142, 91)
      JacC( 86, 71) = JacC( 86, 71)+ 0.2660000000000000D+00*dw(142, 71)
      JacC( 90, 91) = JacC( 90, 91)+ 0.2000000000000000D+00*dw(142, 91)
      JacC( 90, 71) = JacC( 90, 71)+ 0.2000000000000000D+00*dw(142, 71)
      JacC( 91, 91) = JacC( 91, 91) - dw(142, 91)
      JacC( 91, 71) = JacC( 91, 71) - dw(142, 71)
      JacC( 95, 91) = JacC( 95, 91)+ 0.2000000000000000D+00*dw(142, 91)
      JacC( 95, 71) = JacC( 95, 71)+ 0.2000000000000000D+00*dw(142, 71)
      JacC( 96, 91) = JacC( 96, 91)+ 0.6600000000000000D-01*dw(142, 91)
      JacC( 96, 71) = JacC( 96, 71)+ 0.6600000000000000D-01*dw(142, 71)
      JacC( 70, 87) = JacC( 70, 87) + dw(143, 87)
      JacC( 70, 71) = JacC( 70, 71) + dw(143, 71)
      JacC( 71, 87) = JacC( 71, 87) - dw(143, 87)
      JacC( 71, 71) = JacC( 71, 71) - dw(143, 71)
      JacC( 72, 87) = JacC( 72, 87)+ 0.2000000000000000D+00*dw(143, 87)
      JacC( 72, 71) = JacC( 72, 71)+ 0.2000000000000000D+00*dw(143, 71)
      JacC( 73, 87) = JacC( 73, 87)+ 0.8000000000000000D+00*dw(143, 87)
      JacC( 73, 71) = JacC( 73, 71)+ 0.8000000000000000D+00*dw(143, 71)
      JacC( 74, 87) = JacC( 74, 87)+ 0.2400000000000000D+01*dw(143, 87)
      JacC( 74, 71) = JacC( 74, 71)+ 0.2400000000000000D+01*dw(143, 71)
      JacC( 75, 87) = JacC( 75, 87)+ 0.8000000000000000D+00*dw(143, 87)
      JacC( 75, 71) = JacC( 75, 71)+ 0.8000000000000000D+00*dw(143, 71)
      JacC( 87, 87) = JacC( 87, 87) - dw(143, 87)
      JacC( 87, 71) = JacC( 87, 71) - dw(143, 71)
      JacC( 94, 87) = JacC( 94, 87)+ 0.2000000000000000D+00*dw(143, 87)
      JacC( 94, 71) = JacC( 94, 71)+ 0.2000000000000000D+00*dw(143, 71)
      JacC( 95, 87) = JacC( 95, 87) + dw(143, 87)
      JacC( 95, 71) = JacC( 95, 71) + dw(143, 71)
      JacC( 96, 87) = JacC( 96, 87)+ 0.8000000000000000D+00*dw(143, 87)
      JacC( 96, 71) = JacC( 96, 71)+ 0.8000000000000000D+00*dw(143, 71)
      JacC( 45, 86) = JacC( 45, 86)+ 0.1680000000000000D+00*dw(144, 86)
      JacC( 45, 72) = JacC( 45, 72)+ 0.1680000000000000D+00*dw(144, 72)
      JacC( 72, 86) = JacC( 72, 86) - dw(144, 86)
      JacC( 72, 72) = JacC( 72, 72) - dw(144, 72)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1565000000000000D+01*dw(144, 86)
      JacC( 74, 72) = JacC( 74, 72)+ 0.1565000000000000D+01*dw(144, 72)
      JacC( 75, 86) = JacC( 75, 86)+ 0.1200000000000000D+00*dw(144, 86)
      JacC( 75, 72) = JacC( 75, 72)+ 0.1200000000000000D+00*dw(144, 72)
      JacC( 77, 86) = JacC( 77, 86)+ 0.3340000000000000D+00*dw(144, 86)
      JacC( 77, 72) = JacC( 77, 72)+ 0.3340000000000000D+00*dw(144, 72)
      JacC( 85, 86) = JacC( 85, 86)+ 0.1670000000000000D+00*dw(144, 86)
      JacC( 85, 72) = JacC( 85, 72)+ 0.1670000000000000D+00*dw(144, 72)
      JacC( 86, 86) = JacC( 86, 86) - dw(144, 86)
      JacC( 86, 72) = JacC( 86, 72) - dw(144, 72)
      JacC( 89, 86) = JacC( 89, 86)+ 0.2520000000000000D+00*dw(144, 86)
      JacC( 89, 72) = JacC( 89, 72)+ 0.2520000000000000D+00*dw(144, 72)
      JacC( 90, 86) = JacC( 90, 86)+ 0.2500000000000000D+00*dw(144, 86)
      JacC( 90, 72) = JacC( 90, 72)+ 0.2500000000000000D+00*dw(144, 72)
      JacC( 93, 86) = JacC( 93, 86)+ 0.2100000000000000D+00*dw(144, 86)
      JacC( 93, 72) = JacC( 93, 72)+ 0.2100000000000000D+00*dw(144, 72)
      JacC( 95, 86) = JacC( 95, 86)+ 0.7130000000000000D+00*dw(144, 86)
      JacC( 95, 72) = JacC( 95, 72)+ 0.7130000000000000D+00*dw(144, 72)
      JacC( 96, 86) = JacC( 96, 86)+ 0.5030000000000000D+00*dw(144, 86)
      JacC( 96, 72) = JacC( 96, 72)+ 0.5030000000000000D+00*dw(144, 72)
      JacC( 45, 91) = JacC( 45, 91)+ 0.8500000000000000D+00*dw(145, 91)
      JacC( 45, 72) = JacC( 45, 72)+ 0.8500000000000000D+00*dw(145, 72)
      JacC( 72, 91) = JacC( 72, 91) - dw(145, 91)
      JacC( 72, 72) = JacC( 72, 72) - dw(145, 72)
      JacC( 74, 91) = JacC( 74, 91)+ 0.3600000000000000D+00*dw(145, 91)
      JacC( 74, 72) = JacC( 74, 72)+ 0.3600000000000000D+00*dw(145, 72)
      JacC( 77, 91) = JacC( 77, 91)+ 0.2250000000000000D+00*dw(145, 91)
      JacC( 77, 72) = JacC( 77, 72)+ 0.2250000000000000D+00*dw(145, 72)
      JacC( 85, 91) = JacC( 85, 91)+ 0.1500000000000000D+00*dw(145, 91)
      JacC( 85, 72) = JacC( 85, 72)+ 0.1500000000000000D+00*dw(145, 72)
      JacC( 86, 91) = JacC( 86, 91)+ 0.2680000000000000D+00*dw(145, 91)
      JacC( 86, 72) = JacC( 86, 72)+ 0.2680000000000000D+00*dw(145, 72)
      JacC( 89, 91) = JacC( 89, 91)+ 0.2000000000000000D-01*dw(145, 91)
      JacC( 89, 72) = JacC( 89, 72)+ 0.2000000000000000D-01*dw(145, 72)
      JacC( 91, 91) = JacC( 91, 91) - dw(145, 91)
      JacC( 91, 72) = JacC( 91, 72) - dw(145, 72)
      JacC( 93, 91) = JacC( 93, 91)+ 0.1140000000000000D+00*dw(145, 91)
      JacC( 93, 72) = JacC( 93, 72)+ 0.1140000000000000D+00*dw(145, 72)
      JacC( 95, 91) = JacC( 95, 91)+ 0.6400000000000000D-01*dw(145, 91)
      JacC( 95, 72) = JacC( 95, 72)+ 0.6400000000000000D-01*dw(145, 72)
      JacC( 96, 91) = JacC( 96, 91)+ 0.1540000000000000D+00*dw(145, 91)
      JacC( 96, 72) = JacC( 96, 72)+ 0.1540000000000000D+00*dw(145, 72)
      JacC( 72, 87) = JacC( 72, 87) - dw(146, 87)
      JacC( 72, 72) = JacC( 72, 72) - dw(146, 72)
      JacC( 73, 87) = JacC( 73, 87)+ 0.8500000000000000D+00*dw(146, 87)
      JacC( 73, 72) = JacC( 73, 72)+ 0.8500000000000000D+00*dw(146, 72)
      JacC( 74, 87) = JacC( 74, 87)+ 0.1282000000000000D+01*dw(146, 87)
      JacC( 74, 72) = JacC( 74, 72)+ 0.1282000000000000D+01*dw(146, 72)
      JacC( 75, 87) = JacC( 75, 87)+ 0.3570000000000000D+00*dw(146, 87)
      JacC( 75, 72) = JacC( 75, 72)+ 0.3570000000000000D+00*dw(146, 72)
      JacC( 77, 87) = JacC( 77, 87)+ 0.6430000000000000D+00*dw(146, 87)
      JacC( 77, 72) = JacC( 77, 72)+ 0.6430000000000000D+00*dw(146, 72)
      JacC( 79, 87) = JacC( 79, 87)+ 0.1500000000000000D+00*dw(146, 87)
      JacC( 79, 72) = JacC( 79, 72)+ 0.1500000000000000D+00*dw(146, 72)
      JacC( 85, 87) = JacC( 85, 87)+ 0.2820000000000000D+00*dw(146, 87)
      JacC( 85, 72) = JacC( 85, 72)+ 0.2820000000000000D+00*dw(146, 72)
      JacC( 87, 87) = JacC( 87, 87) - dw(146, 87)
      JacC( 87, 72) = JacC( 87, 72) - dw(146, 72)
      JacC( 90, 87) = JacC( 90, 87)+ 0.7500000000000000D-01*dw(146, 87)
      JacC( 90, 72) = JacC( 90, 72)+ 0.7500000000000000D-01*dw(146, 72)
      JacC( 95, 87) = JacC( 95, 87)+ 0.7500000000000000D-01*dw(146, 87)
      JacC( 95, 72) = JacC( 95, 72)+ 0.7500000000000000D-01*dw(146, 72)
      JacC( 96, 87) = JacC( 96, 87)+ 0.9250000000000000D+00*dw(146, 87)
      JacC( 96, 72) = JacC( 96, 72)+ 0.9250000000000000D+00*dw(146, 72)
      JacC( 72, 72) = JacC( 72, 72) - dw(147, 72)
      JacC( 74, 72) = JacC( 74, 72)+ 0.8320000000000000D+00*dw(147, 72)
      JacC( 77, 72) = JacC( 77, 72)+ 0.3330000000000000D+00*dw(147, 72)
      JacC( 85, 72) = JacC( 85, 72)+ 0.9000000000000000D+00*dw(147, 72)
      JacC( 89, 72) = JacC( 89, 72)+ 0.6700000000000000D-01*dw(147, 72)
      JacC( 93, 72) = JacC( 93, 72)+ 0.9670000000000000D+00*dw(147, 72)
      JacC( 95, 72) = JacC( 95, 72)+ 0.7000000000000000D+00*dw(147, 72)
      JacC( 96, 72) = JacC( 96, 72)+ 0.1033000000000000D+01*dw(147, 72)
      JacC( 10, 10) = JacC( 10, 10) - dw(148, 10)
      JacC( 10, 86) = JacC( 10, 86) - dw(148, 86)
      JacC( 11, 10) = JacC( 11, 10) + dw(148, 10)
      JacC( 11, 86) = JacC( 11, 86) + dw(148, 86)
      JacC( 86, 10) = JacC( 86, 10) - dw(148, 10)
      JacC( 86, 86) = JacC( 86, 86) - dw(148, 86)
      JacC( 96, 10) = JacC( 96, 10) + dw(148, 10)
      JacC( 96, 86) = JacC( 96, 86) + dw(148, 86)
      JacC(  5, 86) = JacC(  5, 86) - dw(149, 86)
      JacC(  5,  5) = JacC(  5,  5) - dw(149,  5)
      JacC( 75, 86) = JacC( 75, 86)+ 0.5000000000000000D-01*dw(149, 86)
      JacC( 75,  5) = JacC( 75,  5)+ 0.5000000000000000D-01*dw(149,  5)
      JacC( 85, 86) = JacC( 85, 86)+ 0.1000000000000000D+00*dw(149, 86)
      JacC( 85,  5) = JacC( 85,  5)+ 0.1000000000000000D+00*dw(149,  5)
      JacC( 86, 86) = JacC( 86, 86) - dw(149, 86)
      JacC( 86,  5) = JacC( 86,  5) - dw(149,  5)
      JacC( 89, 86) = JacC( 89, 86)+ 0.9000000000000000D+00*dw(149, 86)
      JacC( 89,  5) = JacC( 89,  5)+ 0.9000000000000000D+00*dw(149,  5)
      JacC( 95, 86) = JacC( 95, 86)+ 0.1000000000000000D+00*dw(149, 86)
      JacC( 95,  5) = JacC( 95,  5)+ 0.1000000000000000D+00*dw(149,  5)
      JacC( 96, 86) = JacC( 96, 86) + dw(149, 86)
      JacC( 96,  5) = JacC( 96,  5) + dw(149,  5)
      JacC(  7, 86) = JacC(  7, 86) - dw(150, 86)
      JacC(  7,  7) = JacC(  7,  7) - dw(150,  7)
      JacC( 83, 86) = JacC( 83, 86)+ 0.8999999999999999D-02*dw(150, 86)
      JacC( 83,  7) = JacC( 83,  7)+ 0.8999999999999999D-02*dw(150,  7)
      JacC( 86, 86) = JacC( 86, 86) - dw(150, 86)
      JacC( 86,  7) = JacC( 86,  7) - dw(150,  7)
      JacC( 89, 86) = JacC( 89, 86)+ 0.9910000000000000D+00*dw(150, 86)
      JacC( 89,  7) = JacC( 89,  7)+ 0.9910000000000000D+00*dw(150,  7)
      JacC( 95, 86) = JacC( 95, 86)+ 0.9910000000000000D+00*dw(150, 86)
      JacC( 95,  7) = JacC( 95,  7)+ 0.9910000000000000D+00*dw(150,  7)
      JacC( 96, 86) = JacC( 96, 86) + dw(150, 86)
      JacC( 96,  7) = JacC( 96,  7) + dw(150,  7)
      JacC( 71, 94) = JacC( 71, 94) - dw(151, 94)
      JacC( 71, 71) = JacC( 71, 71) - dw(151, 71)
      JacC( 72, 94) = JacC( 72, 94)+ 0.2000000000000000D+00*dw(151, 94)
      JacC( 72, 71) = JacC( 72, 71)+ 0.2000000000000000D+00*dw(151, 71)
      JacC( 73, 94) = JacC( 73, 94)+ 0.8000000000000000D+00*dw(151, 94)
      JacC( 73, 71) = JacC( 73, 71)+ 0.8000000000000000D+00*dw(151, 71)
      JacC( 74, 94) = JacC( 74, 94)+ 0.2400000000000000D+01*dw(151, 94)
      JacC( 74, 71) = JacC( 74, 71)+ 0.2400000000000000D+01*dw(151, 71)
      JacC( 75, 94) = JacC( 75, 94)+ 0.8000000000000000D+00*dw(151, 94)
      JacC( 75, 71) = JacC( 75, 71)+ 0.8000000000000000D+00*dw(151, 71)
      JacC( 92, 94) = JacC( 92, 94)+ 0.2000000000000000D+00*dw(151, 94)
      JacC( 92, 71) = JacC( 92, 71)+ 0.2000000000000000D+00*dw(151, 71)
      JacC( 94, 94) = JacC( 94, 94) - dw(151, 94)
      JacC( 94, 71) = JacC( 94, 71) - dw(151, 71)
      JacC( 95, 94) = JacC( 95, 94) + dw(151, 94)
      JacC( 95, 71) = JacC( 95, 71) + dw(151, 71)
      JacC( 96, 94) = JacC( 96, 94)+ 0.8000000000000000D+00*dw(151, 94)
      JacC( 96, 71) = JacC( 96, 71)+ 0.8000000000000000D+00*dw(151, 71)
      JacC( 40, 96) = JacC( 40, 96)+ 0.5000000000000000D+00*dw(152, 96)
      JacC( 96, 96) = JacC( 96, 96) - dw(152, 96)
      JacC( 41, 94) = JacC( 41, 94)+ 0.5000000000000000D+00*dw(153, 94)
      JacC( 79, 94) = JacC( 79, 94)+ 0.5000000000000000D+00*dw(153, 94)
      JacC( 94, 94) = JacC( 94, 94) - dw(153, 94)
      JacC( 79, 87) = JacC( 79, 87) + dw(154, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(154, 87)
      JacC( 25, 25) = JacC( 25, 25) - dw(155, 25)
      JacC( 79, 25) = JacC( 79, 25)+ 0.2000000000000000D+01*dw(155, 25)
      JacC( 46, 46) = JacC( 46, 46) - dw(156, 46)
      JacC( 46, 86) = JacC( 46, 86) - dw(156, 86)
      JacC( 50, 46) = JacC( 50, 46)+ 0.1700000000000000D+00*dw(156, 46)
      JacC( 50, 86) = JacC( 50, 86)+ 0.1700000000000000D+00*dw(156, 86)
      JacC( 51, 46) = JacC( 51, 46)+ 0.1000000000000000D+00*dw(156, 46)
      JacC( 51, 86) = JacC( 51, 86)+ 0.1000000000000000D+00*dw(156, 86)
      JacC( 53, 46) = JacC( 53, 46) + dw(156, 46)
      JacC( 53, 86) = JacC( 53, 86) + dw(156, 86)
      JacC( 54, 46) = JacC( 54, 46)+ 0.3000000000000000D+00*dw(156, 46)
      JacC( 54, 86) = JacC( 54, 86)+ 0.3000000000000000D+00*dw(156, 86)
      JacC( 74, 46) = JacC( 74, 46)+ 0.1660000000000000D+01*dw(156, 46)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1660000000000000D+01*dw(156, 86)
      JacC( 75, 46) = JacC( 75, 46)+ 0.4700000000000000D+00*dw(156, 46)
      JacC( 75, 86) = JacC( 75, 86)+ 0.4700000000000000D+00*dw(156, 86)
      JacC( 83, 46) = JacC( 83, 46)+ 0.2500000000000000D+00*dw(156, 46)
      JacC( 83, 86) = JacC( 83, 86)+ 0.2500000000000000D+00*dw(156, 86)
      JacC( 85, 46) = JacC( 85, 46)+ 0.2800000000000000D+00*dw(156, 46)
      JacC( 85, 86) = JacC( 85, 86)+ 0.2800000000000000D+00*dw(156, 86)
      JacC( 86, 46) = JacC( 86, 46) - dw(156, 46)
      JacC( 86, 86) = JacC( 86, 86) - dw(156, 86)
      JacC( 95, 46) = JacC( 95, 46)+ 0.1250000000000000D+01*dw(156, 46)
      JacC( 95, 86) = JacC( 95, 86)+ 0.1250000000000000D+01*dw(156, 86)
      JacC( 96, 46) = JacC( 96, 46)+ 0.7500000000000000D+00*dw(156, 46)
      JacC( 96, 86) = JacC( 96, 86)+ 0.7500000000000000D+00*dw(156, 86)
      JacC( 46, 46) = JacC( 46, 46) - dw(157, 46)
      JacC( 46, 91) = JacC( 46, 91) - dw(157, 91)
      JacC( 48, 46) = JacC( 48, 46)+ 0.9000000000000000D+00*dw(157, 46)
      JacC( 48, 91) = JacC( 48, 91)+ 0.9000000000000000D+00*dw(157, 91)
      JacC( 50, 46) = JacC( 50, 46)+ 0.1600000000000000D+00*dw(157, 46)
      JacC( 50, 91) = JacC( 50, 91)+ 0.1600000000000000D+00*dw(157, 91)
      JacC( 51, 46) = JacC( 51, 46)+ 0.5000000000000000D-01*dw(157, 46)
      JacC( 51, 91) = JacC( 51, 91)+ 0.5000000000000000D-01*dw(157, 91)
      JacC( 52, 46) = JacC( 52, 46)+ 0.2000000000000000D-03*dw(157, 46)
      JacC( 52, 91) = JacC( 52, 91)+ 0.2000000000000000D-03*dw(157, 91)
      JacC( 54, 46) = JacC( 54, 46)+ 0.1800000000000000D+00*dw(157, 46)
      JacC( 54, 91) = JacC( 54, 91)+ 0.1800000000000000D+00*dw(157, 91)
      JacC( 74, 46) = JacC( 74, 46)+ 0.7000000000000000D+01*dw(157, 46)
      JacC( 74, 91) = JacC( 74, 91)+ 0.7000000000000000D+01*dw(157, 91)
      JacC( 75, 46) = JacC( 75, 46)+ 0.2100000000000000D+00*dw(157, 46)
      JacC( 75, 91) = JacC( 75, 91)+ 0.2100000000000000D+00*dw(157, 91)
      JacC( 77, 46) = JacC( 77, 46)+ 0.1000000000000000D-02*dw(157, 46)
      JacC( 77, 91) = JacC( 77, 91)+ 0.1000000000000000D-02*dw(157, 91)
      JacC( 83, 46) = JacC( 83, 46)+ 0.1800000000000000D+00*dw(157, 46)
      JacC( 83, 91) = JacC( 83, 91)+ 0.1800000000000000D+00*dw(157, 91)
      JacC( 85, 46) = JacC( 85, 46)+ 0.2400000000000000D+00*dw(157, 46)
      JacC( 85, 91) = JacC( 85, 91)+ 0.2400000000000000D+00*dw(157, 91)
      JacC( 86, 46) = JacC( 86, 46)+ 0.5700000000000000D+00*dw(157, 46)
      JacC( 86, 91) = JacC( 86, 91)+ 0.5700000000000000D+00*dw(157, 91)
      JacC( 90, 46) = JacC( 90, 46)+ 0.3900000000000000D+00*dw(157, 46)
      JacC( 90, 91) = JacC( 90, 91)+ 0.3900000000000000D+00*dw(157, 91)
      JacC( 91, 46) = JacC( 91, 46) - dw(157, 46)
      JacC( 91, 91) = JacC( 91, 91) - dw(157, 91)
      JacC( 95, 46) = JacC( 95, 46)+ 0.7600000000000000D+00*dw(157, 46)
      JacC( 95, 91) = JacC( 95, 91)+ 0.7600000000000000D+00*dw(157, 91)
      JacC( 96, 46) = JacC( 96, 46)+ 0.7000000000000001D-01*dw(157, 46)
      JacC( 96, 91) = JacC( 96, 91)+ 0.7000000000000001D-01*dw(157, 91)
      JacC( 46, 46) = JacC( 46, 46) - dw(158, 46)
      JacC( 46, 87) = JacC( 46, 87) - dw(158, 87)
      JacC( 47, 46) = JacC( 47, 46)+ 0.1000000000000000D+00*dw(158, 46)
      JacC( 47, 87) = JacC( 47, 87)+ 0.1000000000000000D+00*dw(158, 87)
      JacC( 54, 46) = JacC( 54, 46)+ 0.7000000000000000D+00*dw(158, 46)
      JacC( 54, 87) = JacC( 54, 87)+ 0.7000000000000000D+00*dw(158, 87)
      JacC( 67, 46) = JacC( 67, 46) + dw(158, 46)
      JacC( 67, 87) = JacC( 67, 87) + dw(158, 87)
      JacC( 73, 46) = JacC( 73, 46)+ 0.5300000000000000D+00*dw(158, 46)
      JacC( 73, 87) = JacC( 73, 87)+ 0.5300000000000000D+00*dw(158, 87)
      JacC( 75, 46) = JacC( 75, 46)+ 0.4700000000000000D+00*dw(158, 46)
      JacC( 75, 87) = JacC( 75, 87)+ 0.4700000000000000D+00*dw(158, 87)
      JacC( 83, 46) = JacC( 83, 46)+ 0.2500000000000000D+00*dw(158, 46)
      JacC( 83, 87) = JacC( 83, 87)+ 0.2500000000000000D+00*dw(158, 87)
      JacC( 87, 46) = JacC( 87, 46) - dw(158, 46)
      JacC( 87, 87) = JacC( 87, 87) - dw(158, 87)
      JacC( 94, 46) = JacC( 94, 46)+ 0.4700000000000000D+00*dw(158, 46)
      JacC( 94, 87) = JacC( 94, 87)+ 0.4700000000000000D+00*dw(158, 87)
      JacC( 95, 46) = JacC( 95, 46)+ 0.1030000000000000D+01*dw(158, 46)
      JacC( 95, 87) = JacC( 95, 87)+ 0.1030000000000000D+01*dw(158, 87)
      JacC( 96, 46) = JacC( 96, 46)+ 0.2800000000000000D+00*dw(158, 46)
      JacC( 96, 87) = JacC( 96, 87)+ 0.2800000000000000D+00*dw(158, 87)
      JacC( 49, 49) = JacC( 49, 49) - dw(159, 49)
      JacC( 49, 86) = JacC( 49, 86) - dw(159, 86)
      JacC( 50, 49) = JacC( 50, 49)+ 0.2000000000000000D+00*dw(159, 49)
      JacC( 50, 86) = JacC( 50, 86)+ 0.2000000000000000D+00*dw(159, 86)
      JacC( 51, 49) = JacC( 51, 49)+ 0.3500000000000000D-02*dw(159, 49)
      JacC( 51, 86) = JacC( 51, 86)+ 0.3500000000000000D-02*dw(159, 86)
      JacC( 53, 49) = JacC( 53, 49) + dw(159, 49)
      JacC( 53, 86) = JacC( 53, 86) + dw(159, 86)
      JacC( 54, 49) = JacC( 54, 49)+ 0.3500000000000000D+00*dw(159, 49)
      JacC( 54, 86) = JacC( 54, 86)+ 0.3500000000000000D+00*dw(159, 86)
      JacC( 74, 49) = JacC( 74, 49)+ 0.1660000000000000D+01*dw(159, 49)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1660000000000000D+01*dw(159, 86)
      JacC( 75, 49) = JacC( 75, 49)+ 0.4700000000000000D+00*dw(159, 49)
      JacC( 75, 86) = JacC( 75, 86)+ 0.4700000000000000D+00*dw(159, 86)
      JacC( 83, 49) = JacC( 83, 49)+ 0.2500000000000000D+00*dw(159, 49)
      JacC( 83, 86) = JacC( 83, 86)+ 0.2500000000000000D+00*dw(159, 86)
      JacC( 85, 49) = JacC( 85, 49)+ 0.2800000000000000D+00*dw(159, 49)
      JacC( 85, 86) = JacC( 85, 86)+ 0.2800000000000000D+00*dw(159, 86)
      JacC( 86, 49) = JacC( 86, 49) - dw(159, 49)
      JacC( 86, 86) = JacC( 86, 86) - dw(159, 86)
      JacC( 95, 49) = JacC( 95, 49)+ 0.1250000000000000D+01*dw(159, 49)
      JacC( 95, 86) = JacC( 95, 86)+ 0.1250000000000000D+01*dw(159, 86)
      JacC( 96, 49) = JacC( 96, 49)+ 0.7500000000000000D+00*dw(159, 49)
      JacC( 96, 86) = JacC( 96, 86)+ 0.7500000000000000D+00*dw(159, 86)
      JacC( 48, 49) = JacC( 48, 49)+ 0.9000000000000000D+00*dw(160, 49)
      JacC( 48, 91) = JacC( 48, 91)+ 0.9000000000000000D+00*dw(160, 91)
      JacC( 49, 49) = JacC( 49, 49) - dw(160, 49)
      JacC( 49, 91) = JacC( 49, 91) - dw(160, 91)
      JacC( 50, 49) = JacC( 50, 49)+ 0.1000000000000000D+00*dw(160, 49)
      JacC( 50, 91) = JacC( 50, 91)+ 0.1000000000000000D+00*dw(160, 91)
      JacC( 52, 49) = JacC( 52, 49)+ 0.2000000000000000D-03*dw(160, 49)
      JacC( 52, 91) = JacC( 52, 91)+ 0.2000000000000000D-03*dw(160, 91)
      JacC( 54, 49) = JacC( 54, 49)+ 0.9000000000000000D-01*dw(160, 49)
      JacC( 54, 91) = JacC( 54, 91)+ 0.9000000000000000D-01*dw(160, 91)
      JacC( 74, 49) = JacC( 74, 49)+ 0.7000000000000000D+01*dw(160, 49)
      JacC( 74, 91) = JacC( 74, 91)+ 0.7000000000000000D+01*dw(160, 91)
      JacC( 75, 49) = JacC( 75, 49)+ 0.2100000000000000D+00*dw(160, 49)
      JacC( 75, 91) = JacC( 75, 91)+ 0.2100000000000000D+00*dw(160, 91)
      JacC( 77, 49) = JacC( 77, 49)+ 0.1000000000000000D-02*dw(160, 49)
      JacC( 77, 91) = JacC( 77, 91)+ 0.1000000000000000D-02*dw(160, 91)
      JacC( 83, 49) = JacC( 83, 49)+ 0.1800000000000000D+00*dw(160, 49)
      JacC( 83, 91) = JacC( 83, 91)+ 0.1800000000000000D+00*dw(160, 91)
      JacC( 85, 49) = JacC( 85, 49)+ 0.2400000000000000D+00*dw(160, 49)
      JacC( 85, 91) = JacC( 85, 91)+ 0.2400000000000000D+00*dw(160, 91)
      JacC( 86, 49) = JacC( 86, 49)+ 0.5700000000000000D+00*dw(160, 49)
      JacC( 86, 91) = JacC( 86, 91)+ 0.5700000000000000D+00*dw(160, 91)
      JacC( 90, 49) = JacC( 90, 49)+ 0.3900000000000000D+00*dw(160, 49)
      JacC( 90, 91) = JacC( 90, 91)+ 0.3900000000000000D+00*dw(160, 91)
      JacC( 91, 49) = JacC( 91, 49) - dw(160, 49)
      JacC( 91, 91) = JacC( 91, 91) - dw(160, 91)
      JacC( 95, 49) = JacC( 95, 49)+ 0.7600000000000000D+00*dw(160, 49)
      JacC( 95, 91) = JacC( 95, 91)+ 0.7600000000000000D+00*dw(160, 91)
      JacC( 96, 49) = JacC( 96, 49)+ 0.7000000000000001D-01*dw(160, 49)
      JacC( 96, 91) = JacC( 96, 91)+ 0.7000000000000001D-01*dw(160, 91)
      JacC( 47, 49) = JacC( 47, 49)+ 0.2700000000000000D+00*dw(161, 49)
      JacC( 47, 87) = JacC( 47, 87)+ 0.2700000000000000D+00*dw(161, 87)
      JacC( 49, 49) = JacC( 49, 49) - dw(161, 49)
      JacC( 49, 87) = JacC( 49, 87) - dw(161, 87)
      JacC( 54, 49) = JacC( 54, 49)+ 0.6899999999999999D+00*dw(161, 49)
      JacC( 54, 87) = JacC( 54, 87)+ 0.6899999999999999D+00*dw(161, 87)
      JacC( 67, 49) = JacC( 67, 49) + dw(161, 49)
      JacC( 67, 87) = JacC( 67, 87) + dw(161, 87)
      JacC( 73, 49) = JacC( 73, 49)+ 0.5300000000000000D+00*dw(161, 49)
      JacC( 73, 87) = JacC( 73, 87)+ 0.5300000000000000D+00*dw(161, 87)
      JacC( 75, 49) = JacC( 75, 49)+ 0.4700000000000000D+00*dw(161, 49)
      JacC( 75, 87) = JacC( 75, 87)+ 0.4700000000000000D+00*dw(161, 87)
      JacC( 83, 49) = JacC( 83, 49)+ 0.2500000000000000D+00*dw(161, 49)
      JacC( 83, 87) = JacC( 83, 87)+ 0.2500000000000000D+00*dw(161, 87)
      JacC( 87, 49) = JacC( 87, 49) - dw(161, 49)
      JacC( 87, 87) = JacC( 87, 87) - dw(161, 87)
      JacC( 94, 49) = JacC( 94, 49)+ 0.4700000000000000D+00*dw(161, 49)
      JacC( 94, 87) = JacC( 94, 87)+ 0.4700000000000000D+00*dw(161, 87)
      JacC( 95, 49) = JacC( 95, 49)+ 0.1030000000000000D+01*dw(161, 49)
      JacC( 95, 87) = JacC( 95, 87)+ 0.1030000000000000D+01*dw(161, 87)
      JacC( 96, 49) = JacC( 96, 49)+ 0.2800000000000000D+00*dw(161, 49)
      JacC( 96, 87) = JacC( 96, 87)+ 0.2800000000000000D+00*dw(161, 87)
      JacC( 69, 82) = JacC( 69, 82)+ 0.7800000000000000D+00*dw(162, 82)
      JacC( 69, 96) = JacC( 69, 96)+ 0.7800000000000000D+00*dw(162, 96)
      JacC( 82, 82) = JacC( 82, 82) - dw(162, 82)
      JacC( 82, 96) = JacC( 82, 96) - dw(162, 96)
      JacC( 69, 82) = JacC( 69, 82)+ 0.7800000000000000D+00*dw(163, 82)
      JacC( 69, 84) = JacC( 69, 84)+ 0.7800000000000000D+00*dw(163, 84)
      JacC( 82, 82) = JacC( 82, 82) - dw(163, 82)
      JacC( 82, 84) = JacC( 82, 84) - dw(163, 84)
      JacC( 69, 82) = JacC( 69, 82)+ 0.7800000000000000D+00*dw(164, 82)
      JacC( 69, 93) = JacC( 69, 93)+ 0.7800000000000000D+00*dw(164, 93)
      JacC( 82, 82) = JacC( 82, 82) - dw(164, 82)
      JacC( 82, 93) = JacC( 82, 93) - dw(164, 93)
      JacC( 65, 82) = JacC( 65, 82)+ 0.9700000000000000D-01*dw(165, 82)
      JacC( 65, 92) = JacC( 65, 92)+ 0.9700000000000000D-01*dw(165, 92)
      JacC( 66, 82) = JacC( 66, 82)+ 0.7480000000000000D+00*dw(165, 82)
      JacC( 66, 92) = JacC( 66, 92)+ 0.7480000000000000D+00*dw(165, 92)
      JacC( 82, 82) = JacC( 82, 82) - dw(165, 82)
      JacC( 82, 92) = JacC( 82, 92) - dw(165, 92)
      JacC( 65, 82) = JacC( 65, 82)+ 0.9700000000000000D-01*dw(166, 82)
      JacC( 65, 87) = JacC( 65, 87)+ 0.9700000000000000D-01*dw(166, 87)
      JacC( 66, 82) = JacC( 66, 82)+ 0.7480000000000000D+00*dw(166, 82)
      JacC( 66, 87) = JacC( 66, 87)+ 0.7480000000000000D+00*dw(166, 87)
      JacC( 82, 82) = JacC( 82, 82) - dw(166, 82)
      JacC( 82, 87) = JacC( 82, 87) - dw(166, 87)
      JacC( 69, 78) = JacC( 69, 78)+ 0.7100000000000000D+00*dw(167, 78)
      JacC( 69, 96) = JacC( 69, 96)+ 0.7100000000000000D+00*dw(167, 96)
      JacC( 78, 78) = JacC( 78, 78) - dw(167, 78)
      JacC( 78, 96) = JacC( 78, 96) - dw(167, 96)
      JacC( 69, 78) = JacC( 69, 78)+ 0.7100000000000000D+00*dw(168, 78)
      JacC( 69, 84) = JacC( 69, 84)+ 0.7100000000000000D+00*dw(168, 84)
      JacC( 78, 78) = JacC( 78, 78) - dw(168, 78)
      JacC( 78, 84) = JacC( 78, 84) - dw(168, 84)
      JacC( 69, 78) = JacC( 69, 78)+ 0.7100000000000000D+00*dw(169, 78)
      JacC( 69, 93) = JacC( 69, 93)+ 0.7100000000000000D+00*dw(169, 93)
      JacC( 78, 78) = JacC( 78, 78) - dw(169, 78)
      JacC( 78, 93) = JacC( 78, 93) - dw(169, 93)
      JacC( 65, 78) = JacC( 65, 78)+ 0.6300000000000000D-01*dw(170, 78)
      JacC( 65, 92) = JacC( 65, 92)+ 0.6300000000000000D-01*dw(170, 92)
      JacC( 66, 78) = JacC( 66, 78)+ 0.4240000000000000D+00*dw(170, 78)
      JacC( 66, 92) = JacC( 66, 92)+ 0.4240000000000000D+00*dw(170, 92)
      JacC( 78, 78) = JacC( 78, 78) - dw(170, 78)
      JacC( 78, 92) = JacC( 78, 92) - dw(170, 92)
      JacC( 65, 78) = JacC( 65, 78)+ 0.6300000000000000D-01*dw(171, 78)
      JacC( 65, 87) = JacC( 65, 87)+ 0.6300000000000000D-01*dw(171, 87)
      JacC( 66, 78) = JacC( 66, 78)+ 0.4240000000000000D+00*dw(171, 78)
      JacC( 66, 87) = JacC( 66, 87)+ 0.4240000000000000D+00*dw(171, 87)
      JacC( 78, 78) = JacC( 78, 78) - dw(171, 78)
      JacC( 78, 87) = JacC( 78, 87) - dw(171, 87)
      JacC( 28, 80) = JacC( 28, 80)+ 0.2818000000000000D+00*dw(172, 80)
      JacC( 28, 96) = JacC( 28, 96)+ 0.2818000000000000D+00*dw(172, 96)
      JacC( 29, 80) = JacC( 29, 80)+ 0.2970000000000000D-01*dw(172, 80)
      JacC( 29, 96) = JacC( 29, 96)+ 0.2970000000000000D-01*dw(172, 96)
      JacC( 80, 80) = JacC( 80, 80) - dw(172, 80)
      JacC( 80, 96) = JacC( 80, 96) - dw(172, 96)
      JacC( 37, 80) = JacC( 37, 80)+ 0.2560000000000000D-01*dw(173, 80)
      JacC( 37, 84) = JacC( 37, 84)+ 0.2560000000000000D-01*dw(173, 84)
      JacC( 80, 80) = JacC( 80, 80) - dw(173, 80)
      JacC( 80, 84) = JacC( 80, 84) - dw(173, 84)
      JacC( 81, 80) = JacC( 81, 80)+ 0.2190000000000000D+00*dw(173, 80)
      JacC( 81, 84) = JacC( 81, 84)+ 0.2190000000000000D+00*dw(173, 84)
      JacC( 37, 80) = JacC( 37, 80)+ 0.2560000000000000D-01*dw(174, 80)
      JacC( 37, 93) = JacC( 37, 93)+ 0.2560000000000000D-01*dw(174, 93)
      JacC( 80, 80) = JacC( 80, 80) - dw(174, 80)
      JacC( 80, 93) = JacC( 80, 93) - dw(174, 93)
      JacC( 81, 80) = JacC( 81, 80)+ 0.2190000000000000D+00*dw(174, 80)
      JacC( 81, 93) = JacC( 81, 93)+ 0.2190000000000000D+00*dw(174, 93)
      JacC( 80, 80) = JacC( 80, 80) - dw(175, 80)
      JacC( 80, 87) = JacC( 80, 87) - dw(175, 87)
      JacC( 81, 80) = JacC( 81, 80)+ 0.4380000000000000D+00*dw(175, 80)
      JacC( 81, 87) = JacC( 81, 87)+ 0.4380000000000000D+00*dw(175, 87)
      JacC( 70, 80) = JacC( 70, 80)+ 0.4600000000000000D-01*dw(176, 80)
      JacC( 70, 92) = JacC( 70, 92)+ 0.4600000000000000D-01*dw(176, 92)
      JacC( 80, 80) = JacC( 80, 80) - dw(176, 80)
      JacC( 80, 92) = JacC( 80, 92) - dw(176, 92)
      JacC( 81, 80) = JacC( 81, 80)+ 0.4180000000000000D+00*dw(176, 80)
      JacC( 81, 92) = JacC( 81, 92)+ 0.4180000000000000D+00*dw(176, 92)
      JacC( 70, 70) = JacC( 70, 70) - dw(177, 70)
      JacC( 70, 86) = JacC( 70, 86) - dw(177, 86)
      JacC( 30, 70) = JacC( 30, 70)+ 0.7385000000000000D-01*dw(178, 70)
      JacC( 30, 87) = JacC( 30, 87)+ 0.7385000000000000D-01*dw(178, 87)
      JacC( 70, 70) = JacC( 70, 70) - dw(178, 70)
      JacC( 70, 87) = JacC( 70, 87) - dw(178, 87)
      JacC( 81, 81) = JacC( 81, 81) - dw(179, 81)
      JacC( 81, 92) = JacC( 81, 92) - dw(179, 92)
      JacC( 81, 81) = JacC( 81, 81) - dw(180, 81)
      JacC( 81, 96) = JacC( 81, 96) - dw(180, 96)
      JacC( 81, 81) = JacC( 81, 81) - dw(181, 81)
      JacC( 81, 84) = JacC( 81, 84) - dw(181, 84)
      JacC( 57, 81) = JacC( 57, 81) + dw(182, 81)
      JacC( 57, 94) = JacC( 57, 94) + dw(182, 94)
      JacC( 81, 81) = JacC( 81, 81) - dw(182, 81)
      JacC( 81, 94) = JacC( 81, 94) - dw(182, 94)
      JacC( 57, 57) = JacC( 57, 57) - dw(183, 57)
      JacC( 81, 57) = JacC( 81, 57) + dw(183, 57)
      JacC( 26, 57) = JacC( 26, 57)+ 0.6741000000000000D-01*dw(184, 57)
      JacC( 26, 86) = JacC( 26, 86)+ 0.6741000000000000D-01*dw(184, 86)
      JacC( 27, 57) = JacC( 27, 57)+ 0.4706000000000000D-01*dw(184, 57)
      JacC( 27, 86) = JacC( 27, 86)+ 0.4706000000000000D-01*dw(184, 86)
      JacC( 57, 57) = JacC( 57, 57) - dw(184, 57)
      JacC( 57, 86) = JacC( 57, 86) - dw(184, 86)
      JacC( 57, 57) = JacC( 57, 57) - dw(185, 57)
      JacC( 57, 87) = JacC( 57, 87) - dw(185, 87)
      JacC( 81, 57) = JacC( 81, 57) + dw(185, 57)
      JacC( 81, 87) = JacC( 81, 87) + dw(185, 87)
      JacC( 28, 28) = JacC( 28, 28) - dw(186, 28)
      JacC( 12, 12) = JacC( 12, 12) - dw(187, 12)
      JacC( 12, 86) = JacC( 12, 86) - dw(187, 86)
      JacC( 13, 12) = JacC( 13, 12)+ 0.7400000000000000D+00*dw(187, 12)
      JacC( 13, 86) = JacC( 13, 86)+ 0.7400000000000000D+00*dw(187, 86)
      JacC( 14, 12) = JacC( 14, 12)+ 0.2600000000000000D+00*dw(187, 12)
      JacC( 14, 86) = JacC( 14, 86)+ 0.2600000000000000D+00*dw(187, 86)
      JacC( 53, 12) = JacC( 53, 12) + dw(187, 12)
      JacC( 53, 86) = JacC( 53, 86) + dw(187, 86)
      JacC( 74, 12) = JacC( 74, 12)+ 0.1660000000000000D+01*dw(187, 12)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1660000000000000D+01*dw(187, 86)
      JacC( 75, 12) = JacC( 75, 12)+ 0.4700000000000000D+00*dw(187, 12)
      JacC( 75, 86) = JacC( 75, 86)+ 0.4700000000000000D+00*dw(187, 86)
      JacC( 83, 12) = JacC( 83, 12)+ 0.2500000000000000D+00*dw(187, 12)
      JacC( 83, 86) = JacC( 83, 86)+ 0.2500000000000000D+00*dw(187, 86)
      JacC( 85, 12) = JacC( 85, 12)+ 0.2800000000000000D+00*dw(187, 12)
      JacC( 85, 86) = JacC( 85, 86)+ 0.2800000000000000D+00*dw(187, 86)
      JacC( 86, 12) = JacC( 86, 12) - dw(187, 12)
      JacC( 86, 86) = JacC( 86, 86) - dw(187, 86)
      JacC( 95, 12) = JacC( 95, 12)+ 0.1250000000000000D+01*dw(187, 12)
      JacC( 95, 86) = JacC( 95, 86)+ 0.1250000000000000D+01*dw(187, 86)
      JacC( 96, 12) = JacC( 96, 12)+ 0.7500000000000000D+00*dw(187, 12)
      JacC( 96, 86) = JacC( 96, 86)+ 0.7500000000000000D+00*dw(187, 86)
      JacC( 50, 60) = JacC( 50, 60)+ 0.8000000000000000D-01*dw(188, 60)
      JacC( 50, 86) = JacC( 50, 86)+ 0.8000000000000000D-01*dw(188, 86)
      JacC( 51, 60) = JacC( 51, 60)+ 0.6000000000000000D-01*dw(188, 60)
      JacC( 51, 86) = JacC( 51, 86)+ 0.6000000000000000D-01*dw(188, 86)
      JacC( 53, 60) = JacC( 53, 60) + dw(188, 60)
      JacC( 53, 86) = JacC( 53, 86) + dw(188, 86)
      JacC( 54, 60) = JacC( 54, 60)+ 0.7000000000000001D-01*dw(188, 60)
      JacC( 54, 86) = JacC( 54, 86)+ 0.7000000000000001D-01*dw(188, 86)
      JacC( 60, 60) = JacC( 60, 60) - dw(188, 60)
      JacC( 60, 86) = JacC( 60, 86) - dw(188, 86)
      JacC( 74, 60) = JacC( 74, 60)+ 0.1660000000000000D+01*dw(188, 60)
      JacC( 74, 86) = JacC( 74, 86)+ 0.1660000000000000D+01*dw(188, 86)
      JacC( 75, 60) = JacC( 75, 60)+ 0.4700000000000000D+00*dw(188, 60)
      JacC( 75, 86) = JacC( 75, 86)+ 0.4700000000000000D+00*dw(188, 86)
      JacC( 83, 60) = JacC( 83, 60)+ 0.2500000000000000D+00*dw(188, 60)
      JacC( 83, 86) = JacC( 83, 86)+ 0.2500000000000000D+00*dw(188, 86)
      JacC( 85, 60) = JacC( 85, 60)+ 0.2800000000000000D+00*dw(188, 60)
      JacC( 85, 86) = JacC( 85, 86)+ 0.2800000000000000D+00*dw(188, 86)
      JacC( 86, 60) = JacC( 86, 60) - dw(188, 60)
      JacC( 86, 86) = JacC( 86, 86) - dw(188, 86)
      JacC( 95, 60) = JacC( 95, 60)+ 0.1250000000000000D+01*dw(188, 60)
      JacC( 95, 86) = JacC( 95, 86)+ 0.1250000000000000D+01*dw(188, 86)
      JacC( 96, 60) = JacC( 96, 60)+ 0.7500000000000000D+00*dw(188, 60)
      JacC( 96, 86) = JacC( 96, 86)+ 0.7500000000000000D+00*dw(188, 86)
      JacC( 47, 60) = JacC( 47, 60)+ 0.6300000000000000D+00*dw(189, 60)
      JacC( 47, 87) = JacC( 47, 87)+ 0.6300000000000000D+00*dw(189, 87)
      JacC( 54, 60) = JacC( 54, 60)+ 0.2000000000000000D-01*dw(189, 60)
      JacC( 54, 87) = JacC( 54, 87)+ 0.2000000000000000D-01*dw(189, 87)
      JacC( 60, 60) = JacC( 60, 60) - dw(189, 60)
      JacC( 60, 87) = JacC( 60, 87) - dw(189, 87)
      JacC( 67, 60) = JacC( 67, 60) + dw(189, 60)
      JacC( 67, 87) = JacC( 67, 87) + dw(189, 87)
      JacC( 73, 60) = JacC( 73, 60)+ 0.5300000000000000D+00*dw(189, 60)
      JacC( 73, 87) = JacC( 73, 87)+ 0.5300000000000000D+00*dw(189, 87)
      JacC( 75, 60) = JacC( 75, 60)+ 0.4700000000000000D+00*dw(189, 60)
      JacC( 75, 87) = JacC( 75, 87)+ 0.4700000000000000D+00*dw(189, 87)
      JacC( 83, 60) = JacC( 83, 60)+ 0.2500000000000000D+00*dw(189, 60)
      JacC( 83, 87) = JacC( 83, 87)+ 0.2500000000000000D+00*dw(189, 87)
      JacC( 87, 60) = JacC( 87, 60) - dw(189, 60)
      JacC( 87, 87) = JacC( 87, 87) - dw(189, 87)
      JacC( 94, 60) = JacC( 94, 60)+ 0.4700000000000000D+00*dw(189, 60)
      JacC( 94, 87) = JacC( 94, 87)+ 0.4700000000000000D+00*dw(189, 87)
      JacC( 95, 60) = JacC( 95, 60)+ 0.1030000000000000D+01*dw(189, 60)
      JacC( 95, 87) = JacC( 95, 87)+ 0.1030000000000000D+01*dw(189, 87)
      JacC( 96, 60) = JacC( 96, 60)+ 0.2800000000000000D+00*dw(189, 60)
      JacC( 96, 87) = JacC( 96, 87)+ 0.2800000000000000D+00*dw(189, 87)
      JacC( 50, 60) = JacC( 50, 60)+ 0.1300000000000000D+00*dw(190, 60)
      JacC( 50, 91) = JacC( 50, 91)+ 0.1300000000000000D+00*dw(190, 91)
      JacC( 51, 60) = JacC( 51, 60)+ 0.4000000000000000D-01*dw(190, 60)
      JacC( 51, 91) = JacC( 51, 91)+ 0.4000000000000000D-01*dw(190, 91)
      JacC( 54, 60) = JacC( 54, 60)+ 0.9000000000000000D-01*dw(190, 60)
      JacC( 54, 91) = JacC( 54, 91)+ 0.9000000000000000D-01*dw(190, 91)
      JacC( 60, 60) = JacC( 60, 60) - dw(190, 60)
      JacC( 60, 91) = JacC( 60, 91) - dw(190, 91)
      JacC( 74, 60) = JacC( 74, 60)+ 0.7000000000000000D+01*dw(190, 60)
      JacC( 74, 91) = JacC( 74, 91)+ 0.7000000000000000D+01*dw(190, 91)
      JacC( 75, 60) = JacC( 75, 60)+ 0.2100000000000000D+00*dw(190, 60)
      JacC( 75, 91) = JacC( 75, 91)+ 0.2100000000000000D+00*dw(190, 91)
      JacC( 77, 60) = JacC( 77, 60)+ 0.1000000000000000D-02*dw(190, 60)
      JacC( 77, 91) = JacC( 77, 91)+ 0.1000000000000000D-02*dw(190, 91)
      JacC( 83, 60) = JacC( 83, 60)+ 0.1800000000000000D+00*dw(190, 60)
      JacC( 83, 91) = JacC( 83, 91)+ 0.1800000000000000D+00*dw(190, 91)
      JacC( 85, 60) = JacC( 85, 60)+ 0.2400000000000000D+00*dw(190, 60)
      JacC( 85, 91) = JacC( 85, 91)+ 0.2400000000000000D+00*dw(190, 91)
      JacC( 86, 60) = JacC( 86, 60)+ 0.5700000000000000D+00*dw(190, 60)
      JacC( 86, 91) = JacC( 86, 91)+ 0.5700000000000000D+00*dw(190, 91)
      JacC( 90, 60) = JacC( 90, 60)+ 0.3900000000000000D+00*dw(190, 60)
      JacC( 90, 91) = JacC( 90, 91)+ 0.3900000000000000D+00*dw(190, 91)
      JacC( 91, 60) = JacC( 91, 60) - dw(190, 60)
      JacC( 91, 91) = JacC( 91, 91) - dw(190, 91)
      JacC( 95, 60) = JacC( 95, 60)+ 0.7600000000000000D+00*dw(190, 60)
      JacC( 95, 91) = JacC( 95, 91)+ 0.7600000000000000D+00*dw(190, 91)
      JacC( 96, 60) = JacC( 96, 60)+ 0.7000000000000001D-01*dw(190, 60)
      JacC( 96, 91) = JacC( 96, 91)+ 0.7000000000000001D-01*dw(190, 91)
      JacC( 15, 15) = JacC( 15, 15) - dw(191, 15)
      JacC( 15, 86) = JacC( 15, 86) - dw(191, 86)
      JacC( 18, 15) = JacC( 18, 15) + dw(191, 15)
      JacC( 18, 86) = JacC( 18, 86) + dw(191, 86)
      JacC( 16, 16) = JacC( 16, 16) - dw(192, 16)
      JacC( 16, 86) = JacC( 16, 86) - dw(192, 86)
      JacC( 19, 16) = JacC( 19, 16) + dw(192, 16)
      JacC( 19, 86) = JacC( 19, 86) + dw(192, 86)
      JacC( 17, 17) = JacC( 17, 17) - dw(193, 17)
      JacC( 17, 86) = JacC( 17, 86) - dw(193, 86)
      JacC( 20, 17) = JacC( 20, 17) + dw(193, 17)
      JacC( 20, 86) = JacC( 20, 86) + dw(193, 86)
      JacC( 46, 46) = JacC( 46, 46) - dw(194, 46)
      JacC( 46, 88) = JacC( 46, 88) - dw(194, 88)
      JacC( 74, 46) = JacC( 74, 46)+ 0.5120000000000000D+01*dw(194, 46)
      JacC( 74, 88) = JacC( 74, 88)+ 0.5120000000000000D+01*dw(194, 88)
      JacC( 75, 46) = JacC( 75, 46)+ 0.1500000000000000D+00*dw(194, 46)
      JacC( 75, 88) = JacC( 75, 88)+ 0.1500000000000000D+00*dw(194, 88)
      JacC( 88, 46) = JacC( 88, 46) - dw(194, 46)
      JacC( 88, 88) = JacC( 88, 88) - dw(194, 88)
      JacC( 49, 49) = JacC( 49, 49) - dw(195, 49)
      JacC( 49, 88) = JacC( 49, 88) - dw(195, 88)
      JacC( 74, 49) = JacC( 74, 49)+ 0.5120000000000000D+01*dw(195, 49)
      JacC( 74, 88) = JacC( 74, 88)+ 0.5120000000000000D+01*dw(195, 88)
      JacC( 75, 49) = JacC( 75, 49)+ 0.1500000000000000D+00*dw(195, 49)
      JacC( 75, 88) = JacC( 75, 88)+ 0.1500000000000000D+00*dw(195, 88)
      JacC( 88, 49) = JacC( 88, 49) - dw(195, 49)
      JacC( 88, 88) = JacC( 88, 88) - dw(195, 88)
      JacC( 60, 60) = JacC( 60, 60) - dw(196, 60)
      JacC( 60, 88) = JacC( 60, 88) - dw(196, 88)
      JacC( 74, 60) = JacC( 74, 60)+ 0.5120000000000000D+01*dw(196, 60)
      JacC( 74, 88) = JacC( 74, 88)+ 0.5120000000000000D+01*dw(196, 88)
      JacC( 75, 60) = JacC( 75, 60)+ 0.1500000000000000D+00*dw(196, 60)
      JacC( 75, 88) = JacC( 75, 88)+ 0.1500000000000000D+00*dw(196, 88)
      JacC( 88, 60) = JacC( 88, 60) - dw(196, 60)
      JacC( 88, 88) = JacC( 88, 88) - dw(196, 88)
      JacC( 21, 48) = JacC( 21, 48) + dw(197, 48)
      JacC( 48, 48) = JacC( 48, 48) - dw(197, 48)
      JacC( 21, 21) = JacC( 21, 21) - dw(198, 21)
      JacC( 22, 21) = JacC( 22, 21) + dw(198, 21)
      JacC( 22, 22) = JacC( 22, 22) - dw(199, 22)
      JacC( 32, 22) = JacC( 32, 22) + dw(199, 22)
      JacC( 32, 32) = JacC( 32, 32) - dw(200, 32)
      JacC( 48, 52) = JacC( 48, 52) - dw(201, 52)
      JacC( 48, 48) = JacC( 48, 48) - dw(201, 48)
      JacC( 52, 52) = JacC( 52, 52) - dw(201, 52)
      JacC( 52, 48) = JacC( 52, 48) - dw(201, 48)
      JacC( 52, 52) = JacC( 52, 52) - dw(202, 52)
      JacC( 52, 96) = JacC( 52, 96) - dw(202, 96)
      JacC( 52, 52) = JacC( 52, 52)- 0.5000000000000004D-02*dw(203, 52)
      JacC( 52, 92) = JacC( 52, 92)- 0.5000000000000004D-02*dw(203, 92)
      JacC( 32, 32) = JacC( 32, 32) - dw(204, 32)
      JacC( 32, 52) = JacC( 32, 52) - dw(204, 52)
      JacC( 33, 32) = JacC( 33, 32)+ 0.3480000000000000D+01*dw(204, 32)
      JacC( 33, 52) = JacC( 33, 52)+ 0.3480000000000000D+01*dw(204, 52)
      JacC( 34, 32) = JacC( 34, 32)+ 0.5160000000000000D+01*dw(204, 32)
      JacC( 34, 52) = JacC( 34, 52)+ 0.5160000000000000D+01*dw(204, 52)
      JacC( 52, 32) = JacC( 52, 32) - dw(204, 32)
      JacC( 52, 52) = JacC( 52, 52) - dw(204, 52)
      JacC( 32, 32) = JacC( 32, 32) - dw(205, 32)
      JacC( 32, 96) = JacC( 32, 96) - dw(205, 96)
      JacC( 33, 32) = JacC( 33, 32)+ 0.2640000000000000D+01*dw(205, 32)
      JacC( 33, 96) = JacC( 33, 96)+ 0.2640000000000000D+01*dw(205, 96)
      JacC( 34, 32) = JacC( 34, 32)+ 0.6000000000000000D+01*dw(205, 32)
      JacC( 34, 96) = JacC( 34, 96)+ 0.6000000000000000D+01*dw(205, 96)
      JacC( 35, 50) = JacC( 35, 50)+ 0.6100000000000000D-02*dw(206, 50)
      JacC( 35, 86) = JacC( 35, 86)+ 0.6100000000000000D-02*dw(206, 86)
      JacC( 50, 50) = JacC( 50, 50) - dw(206, 50)
      JacC( 50, 86) = JacC( 50, 86) - dw(206, 86)
      JacC( 53, 53) = JacC( 53, 53) - dw(207, 53)
      JacC( 53, 92) = JacC( 53, 92) - dw(207, 92)
      JacC( 68, 53) = JacC( 68, 53)+ 0.2010000000000000D+00*dw(207, 53)
      JacC( 68, 92) = JacC( 68, 92)+ 0.2010000000000000D+00*dw(207, 92)
      JacC( 67, 67) = JacC( 67, 67) - dw(208, 67)
      JacC( 67, 92) = JacC( 67, 92) - dw(208, 92)
      JacC( 68, 67) = JacC( 68, 67)+ 0.6879999999999999D+00*dw(208, 67)
      JacC( 68, 92) = JacC( 68, 92)+ 0.6879999999999999D+00*dw(208, 92)
      JacC( 67, 67) = JacC( 67, 67) - dw(209, 67)
      JacC( 67, 96) = JacC( 67, 96) - dw(209, 96)
      JacC( 68, 67) = JacC( 68, 67) + dw(209, 67)
      JacC( 68, 96) = JacC( 68, 96) + dw(209, 96)
      JacC( 67, 67) = JacC( 67, 67) - dw(210, 67)
      JacC( 67, 87) = JacC( 67, 87) - dw(210, 87)
      JacC( 68, 67) = JacC( 68, 67)+ 0.4220000000000000D+00*dw(210, 67)
      JacC( 68, 87) = JacC( 68, 87)+ 0.4220000000000000D+00*dw(210, 87)
      JacC( 67, 67) = JacC( 67, 67) - dw(211, 67)
      JacC( 67, 95) = JacC( 67, 95) - dw(211, 95)
      JacC( 68, 67) = JacC( 68, 67)+ 0.7110000000000000D+00*dw(211, 67)
      JacC( 68, 95) = JacC( 68, 95)+ 0.7110000000000000D+00*dw(211, 95)
      JacC( 67, 12) = JacC( 67, 12) + dw(212, 12)
      JacC( 67, 87) = JacC( 67, 87) + dw(212, 87)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
