C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      temp = M(8, 4) * x(4)
      x(8) = ( x(8) - temp ) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      temp = M(10, 9) * x(9)
      x(10) = ( x(10) - temp ) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      temp = M(13, 12) * x(12)
      x(13) = ( x(13) - temp ) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      temp = M(18, 6) * x(6)
      x(18) = ( x(18) - temp ) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      temp = M(27, 26) * x(26)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(28, 26) * x(26)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 5) * x(5)
      x(29) = ( x(29) - temp ) / M(29, 29)

      x(30) = x(30) / M(30, 30)

      x(31) = x(31) / M(31, 31)

      temp = M(32, 18) * x(18)
      temp = temp + M(32, 29) * x(29)
      temp = temp + M(32, 31) * x(31)
      x(32) = ( x(32) - temp ) / M(32, 32)

      x(33) = x(33) / M(33, 33)

      x(34) = x(34) / M(34, 34)

      x(35) = x(35) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      temp = M(37, 18) * x(18)
      temp = temp + M(37, 29) * x(29)
      temp = temp + M(37, 31) * x(31)
      temp = temp + M(37, 36) * x(36)
      x(37) = ( x(37) - temp ) / M(37, 37)

      x(38) = x(38) / M(38, 38)

      temp = M(39, 29) * x(29)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 37) * x(37)
      temp = temp + M(41, 39) * x(39)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 37) * x(37)
      temp = temp + M(42, 39) * x(39)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 19) * x(19)
      temp = temp + M(43, 24) * x(24)
      temp = temp + M(43, 26) * x(26)
      temp = temp + M(43, 33) * x(33)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 18) * x(18)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 4) * x(4)
      x(45) = ( x(45) - temp ) / M(45, 45)

      x(46) = x(46) / M(46, 46)

      temp = M(47, 46) * x(46)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 11) * x(11)
      temp = temp + M(48, 19) * x(19)
      temp = temp + M(48, 25) * x(25)
      temp = temp + M(48, 26) * x(26)
      temp = temp + M(48, 33) * x(33)
      temp = temp + M(48, 46) * x(46)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 31) * x(31)
      temp = temp + M(49, 37) * x(37)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 7) * x(7)
      temp = temp + M(50, 19) * x(19)
      temp = temp + M(50, 33) * x(33)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 19) * x(19)
      temp = temp + M(51, 33) * x(33)
      temp = temp + M(51, 50) * x(50)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 19) * x(19)
      temp = temp + M(52, 26) * x(26)
      temp = temp + M(52, 33) * x(33)
      temp = temp + M(52, 50) * x(50)
      temp = temp + M(52, 51) * x(51)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 52) * x(52)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 24) * x(24)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 26) * x(26)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 51) * x(51)
      temp = temp + M(56, 55) * x(55)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 19) * x(19)
      temp = temp + M(57, 24) * x(24)
      temp = temp + M(57, 25) * x(25)
      temp = temp + M(57, 26) * x(26)
      temp = temp + M(57, 33) * x(33)
      temp = temp + M(57, 50) * x(50)
      temp = temp + M(57, 52) * x(52)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 19) * x(19)
      temp = temp + M(58, 24) * x(24)
      temp = temp + M(58, 25) * x(25)
      temp = temp + M(58, 26) * x(26)
      temp = temp + M(58, 33) * x(33)
      temp = temp + M(58, 50) * x(50)
      temp = temp + M(58, 52) * x(52)
      temp = temp + M(58, 56) * x(56)
      temp = temp + M(58, 57) * x(57)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 56) * x(56)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 19) * x(19)
      temp = temp + M(60, 26) * x(26)
      temp = temp + M(60, 33) * x(33)
      temp = temp + M(60, 50) * x(50)
      temp = temp + M(60, 51) * x(51)
      temp = temp + M(60, 55) * x(55)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 3) * x(3)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 33) * x(33)
      temp = temp + M(62, 39) * x(39)
      temp = temp + M(62, 44) * x(44)
      temp = temp + M(62, 50) * x(50)
      temp = temp + M(62, 60) * x(60)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 18) * x(18)
      temp = temp + M(63, 19) * x(19)
      temp = temp + M(63, 24) * x(24)
      temp = temp + M(63, 25) * x(25)
      temp = temp + M(63, 26) * x(26)
      temp = temp + M(63, 29) * x(29)
      temp = temp + M(63, 31) * x(31)
      temp = temp + M(63, 33) * x(33)
      temp = temp + M(63, 37) * x(37)
      temp = temp + M(63, 46) * x(46)
      temp = temp + M(63, 50) * x(50)
      temp = temp + M(63, 52) * x(52)
      temp = temp + M(63, 56) * x(56)
      temp = temp + M(63, 60) * x(60)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 11) * x(11)
      temp = temp + M(64, 19) * x(19)
      temp = temp + M(64, 24) * x(24)
      temp = temp + M(64, 25) * x(25)
      temp = temp + M(64, 26) * x(26)
      temp = temp + M(64, 33) * x(33)
      temp = temp + M(64, 46) * x(46)
      temp = temp + M(64, 50) * x(50)
      temp = temp + M(64, 52) * x(52)
      temp = temp + M(64, 56) * x(56)
      temp = temp + M(64, 60) * x(60)
      temp = temp + M(64, 62) * x(62)
      temp = temp + M(64, 63) * x(63)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 11) * x(11)
      temp = temp + M(65, 39) * x(39)
      temp = temp + M(65, 44) * x(44)
      temp = temp + M(65, 49) * x(49)
      temp = temp + M(65, 62) * x(62)
      temp = temp + M(65, 63) * x(63)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 4) * x(4)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 25) * x(25)
      temp = temp + M(67, 63) * x(63)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 46) * x(46)
      temp = temp + M(68, 60) * x(60)
      temp = temp + M(68, 62) * x(62)
      temp = temp + M(68, 63) * x(63)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(69, 39) * x(39)
      temp = temp + M(69, 44) * x(44)
      temp = temp + M(69, 49) * x(49)
      temp = temp + M(69, 51) * x(51)
      temp = temp + M(69, 53) * x(53)
      temp = temp + M(69, 54) * x(54)
      temp = temp + M(69, 55) * x(55)
      temp = temp + M(69, 59) * x(59)
      temp = temp + M(69, 60) * x(60)
      temp = temp + M(69, 61) * x(61)
      temp = temp + M(69, 63) * x(63)
      temp = temp + M(69, 66) * x(66)
      temp = temp + M(69, 67) * x(67)
      temp = temp + M(69, 68) * x(68)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(70, 26) * x(26)
      temp = temp + M(70, 51) * x(51)
      temp = temp + M(70, 52) * x(52)
      temp = temp + M(70, 53) * x(53)
      temp = temp + M(70, 56) * x(56)
      temp = temp + M(70, 57) * x(57)
      temp = temp + M(70, 58) * x(58)
      temp = temp + M(70, 59) * x(59)
      temp = temp + M(70, 60) * x(60)
      temp = temp + M(70, 61) * x(61)
      temp = temp + M(70, 62) * x(62)
      temp = temp + M(70, 63) * x(63)
      temp = temp + M(70, 66) * x(66)
      temp = temp + M(70, 67) * x(67)
      temp = temp + M(70, 68) * x(68)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(71, 11) * x(11)
      temp = temp + M(71, 69) * x(69)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(72, 39) * x(39)
      temp = temp + M(72, 44) * x(44)
      temp = temp + M(72, 45) * x(45)
      temp = temp + M(72, 46) * x(46)
      temp = temp + M(72, 49) * x(49)
      temp = temp + M(72, 60) * x(60)
      temp = temp + M(72, 62) * x(62)
      temp = temp + M(72, 63) * x(63)
      temp = temp + M(72, 68) * x(68)
      temp = temp + M(72, 71) * x(71)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(73, 17) * x(17)
      temp = temp + M(73, 37) * x(37)
      temp = temp + M(73, 60) * x(60)
      temp = temp + M(73, 62) * x(62)
      temp = temp + M(73, 63) * x(63)
      temp = temp + M(73, 65) * x(65)
      temp = temp + M(73, 68) * x(68)
      temp = temp + M(73, 71) * x(71)
      temp = temp + M(73, 72) * x(72)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(74, 36) * x(36)
      temp = temp + M(74, 37) * x(37)
      temp = temp + M(74, 39) * x(39)
      temp = temp + M(74, 44) * x(44)
      temp = temp + M(74, 46) * x(46)
      temp = temp + M(74, 51) * x(51)
      temp = temp + M(74, 54) * x(54)
      temp = temp + M(74, 55) * x(55)
      temp = temp + M(74, 57) * x(57)
      temp = temp + M(74, 58) * x(58)
      temp = temp + M(74, 60) * x(60)
      temp = temp + M(74, 61) * x(61)
      temp = temp + M(74, 63) * x(63)
      temp = temp + M(74, 66) * x(66)
      temp = temp + M(74, 68) * x(68)
      temp = temp + M(74, 71) * x(71)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(75, 3) * x(3)
      temp = temp + M(75, 16) * x(16)
      temp = temp + M(75, 24) * x(24)
      temp = temp + M(75, 52) * x(52)
      temp = temp + M(75, 53) * x(53)
      temp = temp + M(75, 54) * x(54)
      temp = temp + M(75, 56) * x(56)
      temp = temp + M(75, 57) * x(57)
      temp = temp + M(75, 58) * x(58)
      temp = temp + M(75, 59) * x(59)
      temp = temp + M(75, 60) * x(60)
      temp = temp + M(75, 61) * x(61)
      temp = temp + M(75, 62) * x(62)
      temp = temp + M(75, 63) * x(63)
      temp = temp + M(75, 66) * x(66)
      temp = temp + M(75, 68) * x(68)
      temp = temp + M(75, 69) * x(69)
      temp = temp + M(75, 71) * x(71)
      temp = temp + M(75, 74) * x(74)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(76, 19) * x(19)
      temp = temp + M(76, 24) * x(24)
      temp = temp + M(76, 26) * x(26)
      temp = temp + M(76, 33) * x(33)
      temp = temp + M(76, 50) * x(50)
      temp = temp + M(76, 52) * x(52)
      temp = temp + M(76, 56) * x(56)
      temp = temp + M(76, 60) * x(60)
      temp = temp + M(76, 63) * x(63)
      temp = temp + M(76, 68) * x(68)
      temp = temp + M(76, 75) * x(75)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(77, 4) * x(4)
      temp = temp + M(77, 11) * x(11)
      temp = temp + M(77, 16) * x(16)
      temp = temp + M(77, 24) * x(24)
      temp = temp + M(77, 50) * x(50)
      temp = temp + M(77, 52) * x(52)
      temp = temp + M(77, 53) * x(53)
      temp = temp + M(77, 54) * x(54)
      temp = temp + M(77, 56) * x(56)
      temp = temp + M(77, 57) * x(57)
      temp = temp + M(77, 58) * x(58)
      temp = temp + M(77, 59) * x(59)
      temp = temp + M(77, 60) * x(60)
      temp = temp + M(77, 61) * x(61)
      temp = temp + M(77, 62) * x(62)
      temp = temp + M(77, 63) * x(63)
      temp = temp + M(77, 66) * x(66)
      temp = temp + M(77, 67) * x(67)
      temp = temp + M(77, 68) * x(68)
      temp = temp + M(77, 69) * x(69)
      temp = temp + M(77, 71) * x(71)
      temp = temp + M(77, 74) * x(74)
      temp = temp + M(77, 76) * x(76)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(78, 3) * x(3)
      temp = temp + M(78, 4) * x(4)
      temp = temp + M(78, 5) * x(5)
      temp = temp + M(78, 6) * x(6)
      temp = temp + M(78, 7) * x(7)
      temp = temp + M(78, 9) * x(9)
      temp = temp + M(78, 11) * x(11)
      temp = temp + M(78, 12) * x(12)
      temp = temp + M(78, 16) * x(16)
      temp = temp + M(78, 18) * x(18)
      temp = temp + M(78, 19) * x(19)
      temp = temp + M(78, 22) * x(22)
      temp = temp + M(78, 23) * x(23)
      temp = temp + M(78, 24) * x(24)
      temp = temp + M(78, 25) * x(25)
      temp = temp + M(78, 26) * x(26)
      temp = temp + M(78, 29) * x(29)
      temp = temp + M(78, 30) * x(30)
      temp = temp + M(78, 31) * x(31)
      temp = temp + M(78, 32) * x(32)
      temp = temp + M(78, 33) * x(33)
      temp = temp + M(78, 34) * x(34)
      temp = temp + M(78, 35) * x(35)
      temp = temp + M(78, 37) * x(37)
      temp = temp + M(78, 43) * x(43)
      temp = temp + M(78, 45) * x(45)
      temp = temp + M(78, 46) * x(46)
      temp = temp + M(78, 47) * x(47)
      temp = temp + M(78, 50) * x(50)
      temp = temp + M(78, 52) * x(52)
      temp = temp + M(78, 56) * x(56)
      temp = temp + M(78, 60) * x(60)
      temp = temp + M(78, 62) * x(62)
      temp = temp + M(78, 63) * x(63)
      temp = temp + M(78, 64) * x(64)
      temp = temp + M(78, 65) * x(65)
      temp = temp + M(78, 68) * x(68)
      temp = temp + M(78, 69) * x(69)
      temp = temp + M(78, 71) * x(71)
      temp = temp + M(78, 72) * x(72)
      temp = temp + M(78, 73) * x(73)
      temp = temp + M(78, 74) * x(74)
      temp = temp + M(78, 75) * x(75)
      temp = temp + M(78, 76) * x(76)
      temp = temp + M(78, 77) * x(77)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(79, 24) * x(24)
      temp = temp + M(79, 26) * x(26)
      temp = temp + M(79, 30) * x(30)
      temp = temp + M(79, 52) * x(52)
      temp = temp + M(79, 56) * x(56)
      temp = temp + M(79, 60) * x(60)
      temp = temp + M(79, 61) * x(61)
      temp = temp + M(79, 63) * x(63)
      temp = temp + M(79, 66) * x(66)
      temp = temp + M(79, 68) * x(68)
      temp = temp + M(79, 71) * x(71)
      temp = temp + M(79, 74) * x(74)
      temp = temp + M(79, 75) * x(75)
      temp = temp + M(79, 76) * x(76)
      temp = temp + M(79, 78) * x(78)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(80, 11) * x(11)
      temp = temp + M(80, 19) * x(19)
      temp = temp + M(80, 23) * x(23)
      temp = temp + M(80, 25) * x(25)
      temp = temp + M(80, 26) * x(26)
      temp = temp + M(80, 33) * x(33)
      temp = temp + M(80, 35) * x(35)
      temp = temp + M(80, 39) * x(39)
      temp = temp + M(80, 44) * x(44)
      temp = temp + M(80, 45) * x(45)
      temp = temp + M(80, 46) * x(46)
      temp = temp + M(80, 47) * x(47)
      temp = temp + M(80, 49) * x(49)
      temp = temp + M(80, 50) * x(50)
      temp = temp + M(80, 51) * x(51)
      temp = temp + M(80, 52) * x(52)
      temp = temp + M(80, 53) * x(53)
      temp = temp + M(80, 54) * x(54)
      temp = temp + M(80, 55) * x(55)
      temp = temp + M(80, 56) * x(56)
      temp = temp + M(80, 57) * x(57)
      temp = temp + M(80, 58) * x(58)
      temp = temp + M(80, 59) * x(59)
      temp = temp + M(80, 60) * x(60)
      temp = temp + M(80, 61) * x(61)
      temp = temp + M(80, 62) * x(62)
      temp = temp + M(80, 63) * x(63)
      temp = temp + M(80, 65) * x(65)
      temp = temp + M(80, 66) * x(66)
      temp = temp + M(80, 67) * x(67)
      temp = temp + M(80, 68) * x(68)
      temp = temp + M(80, 71) * x(71)
      temp = temp + M(80, 74) * x(74)
      temp = temp + M(80, 76) * x(76)
      temp = temp + M(80, 78) * x(78)
      temp = temp + M(80, 79) * x(79)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(81, 5) * x(5)
      temp = temp + M(81, 6) * x(6)
      temp = temp + M(81, 19) * x(19)
      temp = temp + M(81, 33) * x(33)
      temp = temp + M(81, 35) * x(35)
      temp = temp + M(81, 37) * x(37)
      temp = temp + M(81, 46) * x(46)
      temp = temp + M(81, 47) * x(47)
      temp = temp + M(81, 50) * x(50)
      temp = temp + M(81, 60) * x(60)
      temp = temp + M(81, 61) * x(61)
      temp = temp + M(81, 62) * x(62)
      temp = temp + M(81, 63) * x(63)
      temp = temp + M(81, 66) * x(66)
      temp = temp + M(81, 68) * x(68)
      temp = temp + M(81, 69) * x(69)
      temp = temp + M(81, 71) * x(71)
      temp = temp + M(81, 74) * x(74)
      temp = temp + M(81, 76) * x(76)
      temp = temp + M(81, 78) * x(78)
      temp = temp + M(81, 79) * x(79)
      temp = temp + M(81, 80) * x(80)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(82, 19) * x(19)
      temp = temp + M(82, 23) * x(23)
      temp = temp + M(82, 33) * x(33)
      temp = temp + M(82, 34) * x(34)
      temp = temp + M(82, 35) * x(35)
      temp = temp + M(82, 39) * x(39)
      temp = temp + M(82, 44) * x(44)
      temp = temp + M(82, 49) * x(49)
      temp = temp + M(82, 50) * x(50)
      temp = temp + M(82, 51) * x(51)
      temp = temp + M(82, 52) * x(52)
      temp = temp + M(82, 53) * x(53)
      temp = temp + M(82, 54) * x(54)
      temp = temp + M(82, 55) * x(55)
      temp = temp + M(82, 56) * x(56)
      temp = temp + M(82, 57) * x(57)
      temp = temp + M(82, 58) * x(58)
      temp = temp + M(82, 59) * x(59)
      temp = temp + M(82, 60) * x(60)
      temp = temp + M(82, 61) * x(61)
      temp = temp + M(82, 62) * x(62)
      temp = temp + M(82, 63) * x(63)
      temp = temp + M(82, 66) * x(66)
      temp = temp + M(82, 67) * x(67)
      temp = temp + M(82, 68) * x(68)
      temp = temp + M(82, 71) * x(71)
      temp = temp + M(82, 74) * x(74)
      temp = temp + M(82, 76) * x(76)
      temp = temp + M(82, 77) * x(77)
      temp = temp + M(82, 78) * x(78)
      temp = temp + M(82, 79) * x(79)
      temp = temp + M(82, 80) * x(80)
      temp = temp + M(82, 81) * x(81)
      x(82) = ( x(82) - temp ) / M(82, 82)

      temp = M(83, 19) * x(19)
      temp = temp + M(83, 33) * x(33)
      temp = temp + M(83, 35) * x(35)
      temp = temp + M(83, 39) * x(39)
      temp = temp + M(83, 44) * x(44)
      temp = temp + M(83, 45) * x(45)
      temp = temp + M(83, 46) * x(46)
      temp = temp + M(83, 47) * x(47)
      temp = temp + M(83, 49) * x(49)
      temp = temp + M(83, 50) * x(50)
      temp = temp + M(83, 51) * x(51)
      temp = temp + M(83, 53) * x(53)
      temp = temp + M(83, 54) * x(54)
      temp = temp + M(83, 55) * x(55)
      temp = temp + M(83, 57) * x(57)
      temp = temp + M(83, 58) * x(58)
      temp = temp + M(83, 59) * x(59)
      temp = temp + M(83, 60) * x(60)
      temp = temp + M(83, 61) * x(61)
      temp = temp + M(83, 62) * x(62)
      temp = temp + M(83, 63) * x(63)
      temp = temp + M(83, 66) * x(66)
      temp = temp + M(83, 67) * x(67)
      temp = temp + M(83, 68) * x(68)
      temp = temp + M(83, 71) * x(71)
      temp = temp + M(83, 72) * x(72)
      temp = temp + M(83, 74) * x(74)
      temp = temp + M(83, 75) * x(75)
      temp = temp + M(83, 76) * x(76)
      temp = temp + M(83, 77) * x(77)
      temp = temp + M(83, 78) * x(78)
      temp = temp + M(83, 79) * x(79)
      temp = temp + M(83, 80) * x(80)
      temp = temp + M(83, 81) * x(81)
      temp = temp + M(83, 82) * x(82)
      x(83) = ( x(83) - temp ) / M(83, 83)

      temp = M(84, 32) * x(32)
      temp = temp + M(84, 37) * x(37)
      temp = temp + M(84, 39) * x(39)
      temp = temp + M(84, 44) * x(44)
      temp = temp + M(84, 49) * x(49)
      temp = temp + M(84, 50) * x(50)
      temp = temp + M(84, 51) * x(51)
      temp = temp + M(84, 53) * x(53)
      temp = temp + M(84, 54) * x(54)
      temp = temp + M(84, 55) * x(55)
      temp = temp + M(84, 57) * x(57)
      temp = temp + M(84, 58) * x(58)
      temp = temp + M(84, 59) * x(59)
      temp = temp + M(84, 60) * x(60)
      temp = temp + M(84, 61) * x(61)
      temp = temp + M(84, 63) * x(63)
      temp = temp + M(84, 66) * x(66)
      temp = temp + M(84, 67) * x(67)
      temp = temp + M(84, 68) * x(68)
      temp = temp + M(84, 71) * x(71)
      temp = temp + M(84, 74) * x(74)
      temp = temp + M(84, 76) * x(76)
      temp = temp + M(84, 78) * x(78)
      temp = temp + M(84, 79) * x(79)
      temp = temp + M(84, 80) * x(80)
      temp = temp + M(84, 81) * x(81)
      temp = temp + M(84, 82) * x(82)
      temp = temp + M(84, 83) * x(83)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(85, 17) * x(17)
      temp = temp + M(85, 19) * x(19)
      temp = temp + M(85, 22) * x(22)
      temp = temp + M(85, 24) * x(24)
      temp = temp + M(85, 25) * x(25)
      temp = temp + M(85, 26) * x(26)
      temp = temp + M(85, 33) * x(33)
      temp = temp + M(85, 37) * x(37)
      temp = temp + M(85, 39) * x(39)
      temp = temp + M(85, 44) * x(44)
      temp = temp + M(85, 46) * x(46)
      temp = temp + M(85, 47) * x(47)
      temp = temp + M(85, 49) * x(49)
      temp = temp + M(85, 50) * x(50)
      temp = temp + M(85, 51) * x(51)
      temp = temp + M(85, 52) * x(52)
      temp = temp + M(85, 53) * x(53)
      temp = temp + M(85, 54) * x(54)
      temp = temp + M(85, 55) * x(55)
      temp = temp + M(85, 56) * x(56)
      temp = temp + M(85, 57) * x(57)
      temp = temp + M(85, 58) * x(58)
      temp = temp + M(85, 59) * x(59)
      temp = temp + M(85, 60) * x(60)
      temp = temp + M(85, 61) * x(61)
      temp = temp + M(85, 62) * x(62)
      temp = temp + M(85, 63) * x(63)
      temp = temp + M(85, 65) * x(65)
      temp = temp + M(85, 66) * x(66)
      temp = temp + M(85, 67) * x(67)
      temp = temp + M(85, 68) * x(68)
      temp = temp + M(85, 71) * x(71)
      temp = temp + M(85, 72) * x(72)
      temp = temp + M(85, 73) * x(73)
      temp = temp + M(85, 74) * x(74)
      temp = temp + M(85, 76) * x(76)
      temp = temp + M(85, 77) * x(77)
      temp = temp + M(85, 78) * x(78)
      temp = temp + M(85, 79) * x(79)
      temp = temp + M(85, 80) * x(80)
      temp = temp + M(85, 81) * x(81)
      temp = temp + M(85, 82) * x(82)
      temp = temp + M(85, 83) * x(83)
      temp = temp + M(85, 84) * x(84)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(86, 3) * x(3)
      temp = temp + M(86, 4) * x(4)
      temp = temp + M(86, 5) * x(5)
      temp = temp + M(86, 6) * x(6)
      temp = temp + M(86, 9) * x(9)
      temp = temp + M(86, 11) * x(11)
      temp = temp + M(86, 16) * x(16)
      temp = temp + M(86, 18) * x(18)
      temp = temp + M(86, 19) * x(19)
      temp = temp + M(86, 22) * x(22)
      temp = temp + M(86, 23) * x(23)
      temp = temp + M(86, 24) * x(24)
      temp = temp + M(86, 25) * x(25)
      temp = temp + M(86, 26) * x(26)
      temp = temp + M(86, 29) * x(29)
      temp = temp + M(86, 31) * x(31)
      temp = temp + M(86, 33) * x(33)
      temp = temp + M(86, 35) * x(35)
      temp = temp + M(86, 36) * x(36)
      temp = temp + M(86, 37) * x(37)
      temp = temp + M(86, 39) * x(39)
      temp = temp + M(86, 43) * x(43)
      temp = temp + M(86, 44) * x(44)
      temp = temp + M(86, 45) * x(45)
      temp = temp + M(86, 46) * x(46)
      temp = temp + M(86, 49) * x(49)
      temp = temp + M(86, 50) * x(50)
      temp = temp + M(86, 51) * x(51)
      temp = temp + M(86, 52) * x(52)
      temp = temp + M(86, 53) * x(53)
      temp = temp + M(86, 54) * x(54)
      temp = temp + M(86, 55) * x(55)
      temp = temp + M(86, 56) * x(56)
      temp = temp + M(86, 57) * x(57)
      temp = temp + M(86, 58) * x(58)
      temp = temp + M(86, 59) * x(59)
      temp = temp + M(86, 60) * x(60)
      temp = temp + M(86, 61) * x(61)
      temp = temp + M(86, 62) * x(62)
      temp = temp + M(86, 63) * x(63)
      temp = temp + M(86, 64) * x(64)
      temp = temp + M(86, 65) * x(65)
      temp = temp + M(86, 66) * x(66)
      temp = temp + M(86, 67) * x(67)
      temp = temp + M(86, 68) * x(68)
      temp = temp + M(86, 69) * x(69)
      temp = temp + M(86, 71) * x(71)
      temp = temp + M(86, 72) * x(72)
      temp = temp + M(86, 74) * x(74)
      temp = temp + M(86, 76) * x(76)
      temp = temp + M(86, 77) * x(77)
      temp = temp + M(86, 78) * x(78)
      temp = temp + M(86, 79) * x(79)
      temp = temp + M(86, 80) * x(80)
      temp = temp + M(86, 81) * x(81)
      temp = temp + M(86, 82) * x(82)
      temp = temp + M(86, 83) * x(83)
      temp = temp + M(86, 84) * x(84)
      temp = temp + M(86, 85) * x(85)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(87, 17) * x(17)
      temp = temp + M(87, 18) * x(18)
      temp = temp + M(87, 22) * x(22)
      temp = temp + M(87, 29) * x(29)
      temp = temp + M(87, 31) * x(31)
      temp = temp + M(87, 32) * x(32)
      temp = temp + M(87, 36) * x(36)
      temp = temp + M(87, 37) * x(37)
      temp = temp + M(87, 39) * x(39)
      temp = temp + M(87, 44) * x(44)
      temp = temp + M(87, 46) * x(46)
      temp = temp + M(87, 47) * x(47)
      temp = temp + M(87, 49) * x(49)
      temp = temp + M(87, 50) * x(50)
      temp = temp + M(87, 51) * x(51)
      temp = temp + M(87, 53) * x(53)
      temp = temp + M(87, 54) * x(54)
      temp = temp + M(87, 55) * x(55)
      temp = temp + M(87, 57) * x(57)
      temp = temp + M(87, 58) * x(58)
      temp = temp + M(87, 59) * x(59)
      temp = temp + M(87, 60) * x(60)
      temp = temp + M(87, 61) * x(61)
      temp = temp + M(87, 62) * x(62)
      temp = temp + M(87, 63) * x(63)
      temp = temp + M(87, 66) * x(66)
      temp = temp + M(87, 67) * x(67)
      temp = temp + M(87, 68) * x(68)
      temp = temp + M(87, 71) * x(71)
      temp = temp + M(87, 73) * x(73)
      temp = temp + M(87, 74) * x(74)
      temp = temp + M(87, 76) * x(76)
      temp = temp + M(87, 77) * x(77)
      temp = temp + M(87, 78) * x(78)
      temp = temp + M(87, 79) * x(79)
      temp = temp + M(87, 80) * x(80)
      temp = temp + M(87, 81) * x(81)
      temp = temp + M(87, 82) * x(82)
      temp = temp + M(87, 83) * x(83)
      temp = temp + M(87, 84) * x(84)
      temp = temp + M(87, 85) * x(85)
      temp = temp + M(87, 86) * x(86)
      x(87) = ( x(87) - temp ) / M(87, 87)


C     Backward substitution.

      temp = M(86, 87) * x(87)
      x(86) = x(86) - temp

      temp = M(85, 86) * x(86)
      temp = temp + M(85, 87) * x(87)
      x(85) = x(85) - temp

      temp = M(84, 85) * x(85)
      temp = temp + M(84, 86) * x(86)
      temp = temp + M(84, 87) * x(87)
      x(84) = x(84) - temp

      temp = M(83, 84) * x(84)
      temp = temp + M(83, 85) * x(85)
      temp = temp + M(83, 86) * x(86)
      temp = temp + M(83, 87) * x(87)
      x(83) = x(83) - temp

      temp = M(82, 83) * x(83)
      temp = temp + M(82, 84) * x(84)
      temp = temp + M(82, 85) * x(85)
      temp = temp + M(82, 86) * x(86)
      temp = temp + M(82, 87) * x(87)
      x(82) = x(82) - temp

      temp = M(81, 82) * x(82)
      temp = temp + M(81, 83) * x(83)
      temp = temp + M(81, 84) * x(84)
      temp = temp + M(81, 85) * x(85)
      temp = temp + M(81, 86) * x(86)
      temp = temp + M(81, 87) * x(87)
      x(81) = x(81) - temp

      temp = M(80, 81) * x(81)
      temp = temp + M(80, 82) * x(82)
      temp = temp + M(80, 83) * x(83)
      temp = temp + M(80, 84) * x(84)
      temp = temp + M(80, 85) * x(85)
      temp = temp + M(80, 86) * x(86)
      temp = temp + M(80, 87) * x(87)
      x(80) = x(80) - temp

      temp = M(79, 80) * x(80)
      temp = temp + M(79, 81) * x(81)
      temp = temp + M(79, 82) * x(82)
      temp = temp + M(79, 83) * x(83)
      temp = temp + M(79, 84) * x(84)
      temp = temp + M(79, 85) * x(85)
      temp = temp + M(79, 86) * x(86)
      temp = temp + M(79, 87) * x(87)
      x(79) = x(79) - temp

      temp = M(78, 79) * x(79)
      temp = temp + M(78, 80) * x(80)
      temp = temp + M(78, 81) * x(81)
      temp = temp + M(78, 82) * x(82)
      temp = temp + M(78, 83) * x(83)
      temp = temp + M(78, 84) * x(84)
      temp = temp + M(78, 85) * x(85)
      temp = temp + M(78, 86) * x(86)
      temp = temp + M(78, 87) * x(87)
      x(78) = x(78) - temp

      temp = M(77, 78) * x(78)
      temp = temp + M(77, 79) * x(79)
      temp = temp + M(77, 81) * x(81)
      temp = temp + M(77, 82) * x(82)
      temp = temp + M(77, 83) * x(83)
      temp = temp + M(77, 84) * x(84)
      temp = temp + M(77, 85) * x(85)
      temp = temp + M(77, 86) * x(86)
      temp = temp + M(77, 87) * x(87)
      x(77) = x(77) - temp

      temp = M(76, 78) * x(78)
      temp = temp + M(76, 79) * x(79)
      temp = temp + M(76, 81) * x(81)
      temp = temp + M(76, 82) * x(82)
      temp = temp + M(76, 83) * x(83)
      temp = temp + M(76, 84) * x(84)
      temp = temp + M(76, 85) * x(85)
      temp = temp + M(76, 86) * x(86)
      temp = temp + M(76, 87) * x(87)
      x(76) = x(76) - temp

      temp = M(75, 76) * x(76)
      temp = temp + M(75, 78) * x(78)
      temp = temp + M(75, 79) * x(79)
      temp = temp + M(75, 81) * x(81)
      temp = temp + M(75, 82) * x(82)
      temp = temp + M(75, 83) * x(83)
      temp = temp + M(75, 84) * x(84)
      temp = temp + M(75, 85) * x(85)
      temp = temp + M(75, 86) * x(86)
      temp = temp + M(75, 87) * x(87)
      x(75) = x(75) - temp

      temp = M(74, 76) * x(76)
      temp = temp + M(74, 78) * x(78)
      temp = temp + M(74, 79) * x(79)
      temp = temp + M(74, 81) * x(81)
      temp = temp + M(74, 82) * x(82)
      temp = temp + M(74, 83) * x(83)
      temp = temp + M(74, 84) * x(84)
      temp = temp + M(74, 85) * x(85)
      temp = temp + M(74, 86) * x(86)
      temp = temp + M(74, 87) * x(87)
      x(74) = x(74) - temp

      temp = M(73, 74) * x(74)
      temp = temp + M(73, 76) * x(76)
      temp = temp + M(73, 77) * x(77)
      temp = temp + M(73, 78) * x(78)
      temp = temp + M(73, 79) * x(79)
      temp = temp + M(73, 80) * x(80)
      temp = temp + M(73, 81) * x(81)
      temp = temp + M(73, 82) * x(82)
      temp = temp + M(73, 83) * x(83)
      temp = temp + M(73, 84) * x(84)
      temp = temp + M(73, 85) * x(85)
      temp = temp + M(73, 86) * x(86)
      temp = temp + M(73, 87) * x(87)
      x(73) = x(73) - temp

      temp = M(72, 74) * x(74)
      temp = temp + M(72, 76) * x(76)
      temp = temp + M(72, 78) * x(78)
      temp = temp + M(72, 79) * x(79)
      temp = temp + M(72, 81) * x(81)
      temp = temp + M(72, 82) * x(82)
      temp = temp + M(72, 83) * x(83)
      temp = temp + M(72, 84) * x(84)
      temp = temp + M(72, 85) * x(85)
      temp = temp + M(72, 86) * x(86)
      temp = temp + M(72, 87) * x(87)
      x(72) = x(72) - temp

      temp = M(71, 74) * x(74)
      temp = temp + M(71, 76) * x(76)
      temp = temp + M(71, 78) * x(78)
      temp = temp + M(71, 79) * x(79)
      temp = temp + M(71, 81) * x(81)
      temp = temp + M(71, 82) * x(82)
      temp = temp + M(71, 83) * x(83)
      temp = temp + M(71, 84) * x(84)
      temp = temp + M(71, 85) * x(85)
      temp = temp + M(71, 86) * x(86)
      temp = temp + M(71, 87) * x(87)
      x(71) = x(71) - temp

      temp = M(70, 71) * x(71)
      temp = temp + M(70, 76) * x(76)
      temp = temp + M(70, 78) * x(78)
      temp = temp + M(70, 79) * x(79)
      temp = temp + M(70, 82) * x(82)
      temp = temp + M(70, 83) * x(83)
      temp = temp + M(70, 84) * x(84)
      temp = temp + M(70, 85) * x(85)
      temp = temp + M(70, 86) * x(86)
      temp = temp + M(70, 87) * x(87)
      x(70) = x(70) - temp

      temp = M(69, 71) * x(71)
      temp = temp + M(69, 76) * x(76)
      temp = temp + M(69, 78) * x(78)
      temp = temp + M(69, 79) * x(79)
      temp = temp + M(69, 81) * x(81)
      temp = temp + M(69, 82) * x(82)
      temp = temp + M(69, 83) * x(83)
      temp = temp + M(69, 84) * x(84)
      temp = temp + M(69, 85) * x(85)
      temp = temp + M(69, 86) * x(86)
      temp = temp + M(69, 87) * x(87)
      x(69) = x(69) - temp

      temp = M(68, 78) * x(78)
      temp = temp + M(68, 82) * x(82)
      temp = temp + M(68, 83) * x(83)
      temp = temp + M(68, 84) * x(84)
      temp = temp + M(68, 85) * x(85)
      temp = temp + M(68, 86) * x(86)
      temp = temp + M(68, 87) * x(87)
      x(68) = x(68) - temp

      temp = M(67, 68) * x(68)
      temp = temp + M(67, 78) * x(78)
      temp = temp + M(67, 82) * x(82)
      temp = temp + M(67, 83) * x(83)
      temp = temp + M(67, 84) * x(84)
      temp = temp + M(67, 85) * x(85)
      temp = temp + M(67, 86) * x(86)
      temp = temp + M(67, 87) * x(87)
      x(67) = x(67) - temp

      temp = M(66, 78) * x(78)
      temp = temp + M(66, 82) * x(82)
      temp = temp + M(66, 83) * x(83)
      temp = temp + M(66, 84) * x(84)
      temp = temp + M(66, 85) * x(85)
      temp = temp + M(66, 86) * x(86)
      x(66) = x(66) - temp

      temp = M(65, 68) * x(68)
      temp = temp + M(65, 71) * x(71)
      temp = temp + M(65, 78) * x(78)
      temp = temp + M(65, 82) * x(82)
      temp = temp + M(65, 83) * x(83)
      temp = temp + M(65, 84) * x(84)
      temp = temp + M(65, 85) * x(85)
      temp = temp + M(65, 86) * x(86)
      temp = temp + M(65, 87) * x(87)
      x(65) = x(65) - temp

      temp = M(64, 65) * x(65)
      temp = temp + M(64, 68) * x(68)
      temp = temp + M(64, 72) * x(72)
      temp = temp + M(64, 77) * x(77)
      temp = temp + M(64, 78) * x(78)
      temp = temp + M(64, 80) * x(80)
      temp = temp + M(64, 82) * x(82)
      temp = temp + M(64, 83) * x(83)
      temp = temp + M(64, 84) * x(84)
      temp = temp + M(64, 85) * x(85)
      temp = temp + M(64, 86) * x(86)
      temp = temp + M(64, 87) * x(87)
      x(64) = x(64) - temp

      temp = M(63, 68) * x(68)
      temp = temp + M(63, 78) * x(78)
      temp = temp + M(63, 82) * x(82)
      temp = temp + M(63, 83) * x(83)
      temp = temp + M(63, 84) * x(84)
      temp = temp + M(63, 85) * x(85)
      temp = temp + M(63, 86) * x(86)
      temp = temp + M(63, 87) * x(87)
      x(63) = x(63) - temp

      temp = M(62, 63) * x(63)
      temp = temp + M(62, 78) * x(78)
      temp = temp + M(62, 82) * x(82)
      temp = temp + M(62, 83) * x(83)
      temp = temp + M(62, 84) * x(84)
      temp = temp + M(62, 85) * x(85)
      temp = temp + M(62, 86) * x(86)
      temp = temp + M(62, 87) * x(87)
      x(62) = x(62) - temp

      temp = M(61, 78) * x(78)
      temp = temp + M(61, 82) * x(82)
      temp = temp + M(61, 83) * x(83)
      temp = temp + M(61, 84) * x(84)
      temp = temp + M(61, 85) * x(85)
      temp = temp + M(61, 86) * x(86)
      x(61) = x(61) - temp

      temp = M(60, 63) * x(63)
      temp = temp + M(60, 78) * x(78)
      temp = temp + M(60, 82) * x(82)
      temp = temp + M(60, 83) * x(83)
      temp = temp + M(60, 84) * x(84)
      temp = temp + M(60, 85) * x(85)
      temp = temp + M(60, 86) * x(86)
      temp = temp + M(60, 87) * x(87)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 63) * x(63)
      temp = temp + M(59, 78) * x(78)
      temp = temp + M(59, 82) * x(82)
      temp = temp + M(59, 83) * x(83)
      temp = temp + M(59, 84) * x(84)
      temp = temp + M(59, 85) * x(85)
      temp = temp + M(59, 86) * x(86)
      temp = temp + M(59, 87) * x(87)
      x(59) = x(59) - temp

      temp = M(58, 60) * x(60)
      temp = temp + M(58, 63) * x(63)
      temp = temp + M(58, 78) * x(78)
      temp = temp + M(58, 82) * x(82)
      temp = temp + M(58, 83) * x(83)
      temp = temp + M(58, 84) * x(84)
      temp = temp + M(58, 85) * x(85)
      temp = temp + M(58, 86) * x(86)
      temp = temp + M(58, 87) * x(87)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 60) * x(60)
      temp = temp + M(57, 63) * x(63)
      temp = temp + M(57, 78) * x(78)
      temp = temp + M(57, 82) * x(82)
      temp = temp + M(57, 83) * x(83)
      temp = temp + M(57, 84) * x(84)
      temp = temp + M(57, 85) * x(85)
      temp = temp + M(57, 86) * x(86)
      temp = temp + M(57, 87) * x(87)
      x(57) = x(57) - temp

      temp = M(56, 60) * x(60)
      temp = temp + M(56, 63) * x(63)
      temp = temp + M(56, 78) * x(78)
      temp = temp + M(56, 82) * x(82)
      temp = temp + M(56, 83) * x(83)
      temp = temp + M(56, 84) * x(84)
      temp = temp + M(56, 85) * x(85)
      temp = temp + M(56, 86) * x(86)
      temp = temp + M(56, 87) * x(87)
      x(56) = x(56) - temp

      temp = M(55, 63) * x(63)
      temp = temp + M(55, 78) * x(78)
      temp = temp + M(55, 82) * x(82)
      temp = temp + M(55, 83) * x(83)
      temp = temp + M(55, 84) * x(84)
      temp = temp + M(55, 85) * x(85)
      temp = temp + M(55, 86) * x(86)
      x(55) = x(55) - temp

      temp = M(54, 63) * x(63)
      temp = temp + M(54, 78) * x(78)
      temp = temp + M(54, 82) * x(82)
      temp = temp + M(54, 83) * x(83)
      temp = temp + M(54, 84) * x(84)
      temp = temp + M(54, 85) * x(85)
      temp = temp + M(54, 86) * x(86)
      x(54) = x(54) - temp

      temp = M(53, 60) * x(60)
      temp = temp + M(53, 63) * x(63)
      temp = temp + M(53, 78) * x(78)
      temp = temp + M(53, 82) * x(82)
      temp = temp + M(53, 83) * x(83)
      temp = temp + M(53, 84) * x(84)
      temp = temp + M(53, 85) * x(85)
      temp = temp + M(53, 86) * x(86)
      temp = temp + M(53, 87) * x(87)
      x(53) = x(53) - temp

      temp = M(52, 60) * x(60)
      temp = temp + M(52, 63) * x(63)
      temp = temp + M(52, 78) * x(78)
      temp = temp + M(52, 82) * x(82)
      temp = temp + M(52, 83) * x(83)
      temp = temp + M(52, 84) * x(84)
      temp = temp + M(52, 85) * x(85)
      temp = temp + M(52, 86) * x(86)
      temp = temp + M(52, 87) * x(87)
      x(52) = x(52) - temp

      temp = M(51, 60) * x(60)
      temp = temp + M(51, 63) * x(63)
      temp = temp + M(51, 78) * x(78)
      temp = temp + M(51, 82) * x(82)
      temp = temp + M(51, 83) * x(83)
      temp = temp + M(51, 84) * x(84)
      temp = temp + M(51, 85) * x(85)
      temp = temp + M(51, 86) * x(86)
      temp = temp + M(51, 87) * x(87)
      x(51) = x(51) - temp

      temp = M(50, 60) * x(60)
      temp = temp + M(50, 63) * x(63)
      temp = temp + M(50, 78) * x(78)
      temp = temp + M(50, 84) * x(84)
      temp = temp + M(50, 85) * x(85)
      temp = temp + M(50, 87) * x(87)
      x(50) = x(50) - temp

      temp = M(49, 63) * x(63)
      temp = temp + M(49, 78) * x(78)
      temp = temp + M(49, 82) * x(82)
      temp = temp + M(49, 83) * x(83)
      temp = temp + M(49, 84) * x(84)
      temp = temp + M(49, 85) * x(85)
      temp = temp + M(49, 86) * x(86)
      temp = temp + M(49, 87) * x(87)
      x(49) = x(49) - temp

      temp = M(48, 50) * x(50)
      temp = temp + M(48, 52) * x(52)
      temp = temp + M(48, 60) * x(60)
      temp = temp + M(48, 62) * x(62)
      temp = temp + M(48, 63) * x(63)
      temp = temp + M(48, 68) * x(68)
      temp = temp + M(48, 78) * x(78)
      temp = temp + M(48, 85) * x(85)
      temp = temp + M(48, 87) * x(87)
      x(48) = x(48) - temp

      temp = M(47, 63) * x(63)
      temp = temp + M(47, 68) * x(68)
      temp = temp + M(47, 78) * x(78)
      temp = temp + M(47, 83) * x(83)
      temp = temp + M(47, 85) * x(85)
      temp = temp + M(47, 87) * x(87)
      x(47) = x(47) - temp

      temp = M(46, 63) * x(63)
      temp = temp + M(46, 68) * x(68)
      temp = temp + M(46, 78) * x(78)
      temp = temp + M(46, 85) * x(85)
      temp = temp + M(46, 87) * x(87)
      x(46) = x(46) - temp

      temp = M(45, 46) * x(46)
      temp = temp + M(45, 60) * x(60)
      temp = temp + M(45, 76) * x(76)
      temp = temp + M(45, 78) * x(78)
      temp = temp + M(45, 82) * x(82)
      x(45) = x(45) - temp

      temp = M(44, 63) * x(63)
      temp = temp + M(44, 78) * x(78)
      temp = temp + M(44, 82) * x(82)
      temp = temp + M(44, 83) * x(83)
      temp = temp + M(44, 84) * x(84)
      temp = temp + M(44, 85) * x(85)
      temp = temp + M(44, 86) * x(86)
      temp = temp + M(44, 87) * x(87)
      x(44) = x(44) - temp

      temp = M(43, 50) * x(50)
      temp = temp + M(43, 52) * x(52)
      temp = temp + M(43, 56) * x(56)
      temp = temp + M(43, 63) * x(63)
      temp = temp + M(43, 78) * x(78)
      temp = temp + M(43, 85) * x(85)
      temp = temp + M(43, 86) * x(86)
      x(43) = x(43) - temp

      temp = M(42, 44) * x(44)
      temp = temp + M(42, 63) * x(63)
      temp = temp + M(42, 78) * x(78)
      temp = temp + M(42, 82) * x(82)
      temp = temp + M(42, 83) * x(83)
      temp = temp + M(42, 84) * x(84)
      temp = temp + M(42, 85) * x(85)
      temp = temp + M(42, 86) * x(86)
      temp = temp + M(42, 87) * x(87)
      x(42) = x(42) - temp

      temp = M(41, 44) * x(44)
      temp = temp + M(41, 63) * x(63)
      temp = temp + M(41, 78) * x(78)
      temp = temp + M(41, 82) * x(82)
      temp = temp + M(41, 83) * x(83)
      temp = temp + M(41, 84) * x(84)
      temp = temp + M(41, 85) * x(85)
      temp = temp + M(41, 86) * x(86)
      temp = temp + M(41, 87) * x(87)
      x(41) = x(41) - temp

      temp = M(40, 44) * x(44)
      temp = temp + M(40, 63) * x(63)
      temp = temp + M(40, 78) * x(78)
      temp = temp + M(40, 82) * x(82)
      temp = temp + M(40, 83) * x(83)
      temp = temp + M(40, 84) * x(84)
      temp = temp + M(40, 85) * x(85)
      temp = temp + M(40, 86) * x(86)
      temp = temp + M(40, 87) * x(87)
      x(40) = x(40) - temp

      temp = M(39, 63) * x(63)
      temp = temp + M(39, 78) * x(78)
      temp = temp + M(39, 82) * x(82)
      temp = temp + M(39, 83) * x(83)
      temp = temp + M(39, 84) * x(84)
      temp = temp + M(39, 85) * x(85)
      temp = temp + M(39, 86) * x(86)
      temp = temp + M(39, 87) * x(87)
      x(39) = x(39) - temp

      temp = M(38, 52) * x(52)
      temp = temp + M(38, 56) * x(56)
      temp = temp + M(38, 63) * x(63)
      temp = temp + M(38, 78) * x(78)
      temp = temp + M(38, 85) * x(85)
      x(38) = x(38) - temp

      temp = M(37, 63) * x(63)
      temp = temp + M(37, 78) * x(78)
      temp = temp + M(37, 85) * x(85)
      temp = temp + M(37, 86) * x(86)
      temp = temp + M(37, 87) * x(87)
      x(37) = x(37) - temp

      temp = M(36, 37) * x(37)
      temp = temp + M(36, 78) * x(78)
      temp = temp + M(36, 85) * x(85)
      temp = temp + M(36, 86) * x(86)
      temp = temp + M(36, 87) * x(87)
      x(36) = x(36) - temp

      temp = M(35, 62) * x(62)
      temp = temp + M(35, 63) * x(63)
      temp = temp + M(35, 78) * x(78)
      temp = temp + M(35, 83) * x(83)
      temp = temp + M(35, 86) * x(86)
      x(35) = x(35) - temp

      temp = M(34, 52) * x(52)
      temp = temp + M(34, 56) * x(56)
      temp = temp + M(34, 63) * x(63)
      temp = temp + M(34, 78) * x(78)
      x(34) = x(34) - temp

      temp = M(33, 50) * x(50)
      temp = temp + M(33, 63) * x(63)
      temp = temp + M(33, 78) * x(78)
      temp = temp + M(33, 85) * x(85)
      x(33) = x(33) - temp

      temp = M(32, 37) * x(37)
      temp = temp + M(32, 63) * x(63)
      temp = temp + M(32, 78) * x(78)
      temp = temp + M(32, 84) * x(84)
      temp = temp + M(32, 87) * x(87)
      x(32) = x(32) - temp

      temp = M(31, 37) * x(37)
      temp = temp + M(31, 63) * x(63)
      temp = temp + M(31, 78) * x(78)
      temp = temp + M(31, 87) * x(87)
      x(31) = x(31) - temp

      temp = M(30, 52) * x(52)
      temp = temp + M(30, 56) * x(56)
      temp = temp + M(30, 63) * x(63)
      temp = temp + M(30, 78) * x(78)
      x(30) = x(30) - temp

      temp = M(29, 63) * x(63)
      temp = temp + M(29, 78) * x(78)
      temp = temp + M(29, 87) * x(87)
      x(29) = x(29) - temp

      temp = M(28, 63) * x(63)
      temp = temp + M(28, 78) * x(78)
      temp = temp + M(28, 85) * x(85)
      x(28) = x(28) - temp

      temp = M(27, 63) * x(63)
      temp = temp + M(27, 78) * x(78)
      temp = temp + M(27, 85) * x(85)
      x(27) = x(27) - temp

      temp = M(26, 63) * x(63)
      temp = temp + M(26, 78) * x(78)
      temp = temp + M(26, 85) * x(85)
      x(26) = x(26) - temp

      temp = M(25, 63) * x(63)
      temp = temp + M(25, 78) * x(78)
      temp = temp + M(25, 85) * x(85)
      x(25) = x(25) - temp

      temp = M(24, 63) * x(63)
      temp = temp + M(24, 78) * x(78)
      temp = temp + M(24, 85) * x(85)
      x(24) = x(24) - temp

      temp = M(23, 78) * x(78)
      temp = temp + M(23, 82) * x(82)
      temp = temp + M(23, 86) * x(86)
      x(23) = x(23) - temp

      temp = M(22, 78) * x(78)
      temp = temp + M(22, 86) * x(86)
      temp = temp + M(22, 87) * x(87)
      x(22) = x(22) - temp

      temp = M(21, 24) * x(24)
      temp = temp + M(21, 63) * x(63)
      temp = temp + M(21, 78) * x(78)
      x(21) = x(21) - temp

      temp = M(20, 24) * x(24)
      temp = temp + M(20, 63) * x(63)
      temp = temp + M(20, 78) * x(78)
      x(20) = x(20) - temp

      temp = M(19, 63) * x(63)
      temp = temp + M(19, 78) * x(78)
      temp = temp + M(19, 85) * x(85)
      x(19) = x(19) - temp

      temp = M(18, 63) * x(63)
      temp = temp + M(18, 78) * x(78)
      temp = temp + M(18, 87) * x(87)
      x(18) = x(18) - temp

      temp = M(17, 85) * x(85)
      temp = temp + M(17, 87) * x(87)
      x(17) = x(17) - temp

      temp = M(16, 62) * x(62)
      temp = temp + M(16, 78) * x(78)
      x(16) = x(16) - temp

      temp = M(15, 33) * x(33)
      temp = temp + M(15, 78) * x(78)
      x(15) = x(15) - temp

      temp = M(14, 33) * x(33)
      temp = temp + M(14, 78) * x(78)
      x(14) = x(14) - temp

      temp = M(13, 78) * x(78)
      x(13) = x(13) - temp

      temp = M(12, 78) * x(78)
      x(12) = x(12) - temp

      temp = M(11, 78) * x(78)
      x(11) = x(11) - temp

      temp = M(10, 78) * x(78)
      x(10) = x(10) - temp

      temp = M(9, 78) * x(78)
      x(9) = x(9) - temp

      temp = M(8, 78) * x(78)
      x(8) = x(8) - temp

      temp = M(7, 63) * x(63)
      x(7) = x(7) - temp

      temp = M(6, 78) * x(78)
      x(6) = x(6) - temp

      temp = M(5, 78) * x(78)
      x(5) = x(5) - temp

      temp = M(4, 78) * x(78)
      x(4) = x(4) - temp

      temp = M(3, 78) * x(78)
      x(3) = x(3) - temp


      END
