C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve_tr (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M^t * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      temp = M(23, 35) * x(23)
      temp = temp + M(24, 35) * x(24)
      x(35) = x(35) - temp

      temp = M(21, 49) * x(21)
      x(49) = x(49) - temp

      temp = M(56, 58) * x(56)
      x(58) = x(58) - temp

      temp = M(40, 62) * x(40)
      x(62) = x(62) - temp

      temp = M(62, 64) * x(62)
      temp = temp + M(63, 64) * x(63)
      x(64) = x(64) - temp

      temp = M(61, 65) * x(61)
      temp = temp + M(62, 65) * x(62)
      temp = temp + M(63, 65) * x(63)
      temp = temp + M(64, 65) * x(64)
      x(65) = x(65) - temp

      temp = M(64, 66) * x(64)
      x(66) = x(66) - temp

      temp = M(54, 67) * x(54)
      temp = temp + M(55, 67) * x(55)
      x(67) = x(67) - temp

      temp = M(33, 73) * x(33)
      x(73) = x(73) - temp

      temp = M(43, 80) * x(43)
      temp = temp + M(44, 80) * x(44)
      temp = temp + M(52, 80) * x(52)
      temp = temp + M(53, 80) * x(53)
      x(80) = x(80) - temp

      temp = M(81, 82) * x(81)
      x(82) = x(82) - temp

      temp = M(34, 83) * x(34)
      temp = temp + M(49, 83) * x(49)
      x(83) = x(83) - temp

      temp = M(41, 92) * x(41)
      temp = temp + M(70, 92) * x(70)
      temp = temp + M(76, 92) * x(76)
      temp = temp + M(78, 92) * x(78)
      temp = temp + M(79, 92) * x(79)
      x(92) = x(92) - temp

      temp = M(78, 93) * x(78)
      temp = temp + M(79, 93) * x(79)
      temp = temp + M(86, 93) * x(86)
      x(93) = x(93) - temp

      temp = M(86, 96) * x(86)
      x(96) = x(96) - temp

      temp = M(3, 97) * x(3)
      temp = temp + M(25, 97) * x(25)
      temp = temp + M(26, 97) * x(26)
      temp = temp + M(27, 97) * x(27)
      temp = temp + M(29, 97) * x(29)
      temp = temp + M(31, 97) * x(31)
      temp = temp + M(32, 97) * x(32)
      temp = temp + M(35, 97) * x(35)
      temp = temp + M(36, 97) * x(36)
      temp = temp + M(37, 97) * x(37)
      temp = temp + M(38, 97) * x(38)
      temp = temp + M(42, 97) * x(42)
      temp = temp + M(43, 97) * x(43)
      temp = temp + M(44, 97) * x(44)
      temp = temp + M(49, 97) * x(49)
      temp = temp + M(51, 97) * x(51)
      temp = temp + M(52, 97) * x(52)
      temp = temp + M(53, 97) * x(53)
      temp = temp + M(72, 97) * x(72)
      temp = temp + M(73, 97) * x(73)
      temp = temp + M(74, 97) * x(74)
      temp = temp + M(77, 97) * x(77)
      temp = temp + M(78, 97) * x(78)
      temp = temp + M(79, 97) * x(79)
      temp = temp + M(80, 97) * x(80)
      temp = temp + M(81, 97) * x(81)
      temp = temp + M(82, 97) * x(82)
      temp = temp + M(83, 97) * x(83)
      temp = temp + M(84, 97) * x(84)
      temp = temp + M(85, 97) * x(85)
      temp = temp + M(86, 97) * x(86)
      temp = temp + M(87, 97) * x(87)
      temp = temp + M(88, 97) * x(88)
      temp = temp + M(89, 97) * x(89)
      temp = temp + M(93, 97) * x(93)
      temp = temp + M(94, 97) * x(94)
      temp = temp + M(95, 97) * x(95)
      temp = temp + M(96, 97) * x(96)
      x(97) = x(97) - temp

      temp = M(74, 98) * x(74)
      temp = temp + M(86, 98) * x(86)
      temp = temp + M(97, 98) * x(97)
      x(98) = x(98) - temp

      temp = M(97, 100) * x(97)
      temp = temp + M(98, 100) * x(98)
      temp = temp + M(99, 100) * x(99)
      x(100) = x(100) - temp

      temp = M(94, 101) * x(94)
      temp = temp + M(95, 101) * x(95)
      x(101) = x(101) - temp

      temp = M(75, 104) * x(75)
      x(104) = x(104) - temp

      temp = M(90, 105) * x(90)
      temp = temp + M(91, 105) * x(91)
      temp = temp + M(103, 105) * x(103)
      x(105) = x(105) - temp

      temp = M(90, 106) * x(90)
      temp = temp + M(91, 106) * x(91)
      temp = temp + M(103, 106) * x(103)
      x(106) = x(106) - temp

      temp = M(90, 107) * x(90)
      temp = temp + M(91, 107) * x(91)
      temp = temp + M(103, 107) * x(103)
      x(107) = x(107) - temp

      temp = M(39, 109) * x(39)
      temp = temp + M(50, 109) * x(50)
      temp = temp + M(89, 109) * x(89)
      temp = temp + M(94, 109) * x(94)
      temp = temp + M(95, 109) * x(95)
      temp = temp + M(102, 109) * x(102)
      x(109) = x(109) - temp

      temp = M(108, 112) * x(108)
      temp = temp + M(111, 112) * x(111)
      x(112) = x(112) - temp

      temp = M(76, 114) * x(76)
      temp = temp + M(94, 114) * x(94)
      temp = temp + M(95, 114) * x(95)
      temp = temp + M(102, 114) * x(102)
      temp = temp + M(108, 114) * x(108)
      temp = temp + M(110, 114) * x(110)
      temp = temp + M(111, 114) * x(111)
      temp = temp + M(113, 114) * x(113)
      x(114) = x(114) - temp

      temp = M(112, 115) * x(112)
      temp = temp + M(113, 115) * x(113)
      x(115) = x(115) - temp

      temp = M(114, 116) * x(114)
      temp = temp + M(115, 116) * x(115)
      x(116) = x(116) - temp

      temp = M(78, 117) * x(78)
      temp = temp + M(79, 117) * x(79)
      temp = temp + M(94, 117) * x(94)
      temp = temp + M(95, 117) * x(95)
      temp = temp + M(102, 117) * x(102)
      temp = temp + M(108, 117) * x(108)
      temp = temp + M(111, 117) * x(111)
      temp = temp + M(113, 117) * x(113)
      temp = temp + M(115, 117) * x(115)
      temp = temp + M(116, 117) * x(116)
      x(117) = x(117) - temp

      temp = M(116, 118) * x(116)
      temp = temp + M(117, 118) * x(117)
      x(118) = x(118) - temp

      temp = M(111, 119) * x(111)
      temp = temp + M(113, 119) * x(113)
      x(119) = x(119) - temp

      temp = M(47, 120) * x(47)
      temp = temp + M(74, 120) * x(74)
      temp = temp + M(115, 120) * x(115)
      x(120) = x(120) - temp

      temp = M(30, 121) * x(30)
      temp = temp + M(95, 121) * x(95)
      temp = temp + M(102, 121) * x(102)
      temp = temp + M(111, 121) * x(111)
      temp = temp + M(113, 121) * x(113)
      temp = temp + M(115, 121) * x(115)
      x(121) = x(121) - temp

      temp = M(30, 122) * x(30)
      temp = temp + M(33, 122) * x(33)
      temp = temp + M(45, 122) * x(45)
      temp = temp + M(54, 122) * x(54)
      temp = temp + M(55, 122) * x(55)
      temp = temp + M(56, 122) * x(56)
      temp = temp + M(57, 122) * x(57)
      temp = temp + M(58, 122) * x(58)
      temp = temp + M(59, 122) * x(59)
      temp = temp + M(60, 122) * x(60)
      temp = temp + M(61, 122) * x(61)
      temp = temp + M(62, 122) * x(62)
      temp = temp + M(63, 122) * x(63)
      temp = temp + M(64, 122) * x(64)
      temp = temp + M(65, 122) * x(65)
      temp = temp + M(66, 122) * x(66)
      temp = temp + M(67, 122) * x(67)
      temp = temp + M(68, 122) * x(68)
      temp = temp + M(69, 122) * x(69)
      temp = temp + M(70, 122) * x(70)
      temp = temp + M(71, 122) * x(71)
      temp = temp + M(72, 122) * x(72)
      temp = temp + M(73, 122) * x(73)
      temp = temp + M(75, 122) * x(75)
      temp = temp + M(76, 122) * x(76)
      temp = temp + M(77, 122) * x(77)
      temp = temp + M(78, 122) * x(78)
      temp = temp + M(79, 122) * x(79)
      temp = temp + M(80, 122) * x(80)
      temp = temp + M(81, 122) * x(81)
      temp = temp + M(82, 122) * x(82)
      temp = temp + M(83, 122) * x(83)
      temp = temp + M(84, 122) * x(84)
      temp = temp + M(85, 122) * x(85)
      temp = temp + M(86, 122) * x(86)
      temp = temp + M(87, 122) * x(87)
      temp = temp + M(88, 122) * x(88)
      temp = temp + M(89, 122) * x(89)
      temp = temp + M(90, 122) * x(90)
      temp = temp + M(91, 122) * x(91)
      temp = temp + M(92, 122) * x(92)
      temp = temp + M(93, 122) * x(93)
      temp = temp + M(94, 122) * x(94)
      temp = temp + M(95, 122) * x(95)
      temp = temp + M(96, 122) * x(96)
      temp = temp + M(97, 122) * x(97)
      temp = temp + M(98, 122) * x(98)
      temp = temp + M(99, 122) * x(99)
      temp = temp + M(100, 122) * x(100)
      temp = temp + M(101, 122) * x(101)
      temp = temp + M(102, 122) * x(102)
      temp = temp + M(103, 122) * x(103)
      temp = temp + M(104, 122) * x(104)
      temp = temp + M(105, 122) * x(105)
      temp = temp + M(106, 122) * x(106)
      temp = temp + M(107, 122) * x(107)
      temp = temp + M(108, 122) * x(108)
      temp = temp + M(109, 122) * x(109)
      temp = temp + M(110, 122) * x(110)
      temp = temp + M(111, 122) * x(111)
      temp = temp + M(112, 122) * x(112)
      temp = temp + M(113, 122) * x(113)
      temp = temp + M(114, 122) * x(114)
      temp = temp + M(115, 122) * x(115)
      temp = temp + M(116, 122) * x(116)
      temp = temp + M(117, 122) * x(117)
      temp = temp + M(118, 122) * x(118)
      temp = temp + M(119, 122) * x(119)
      temp = temp + M(120, 122) * x(120)
      temp = temp + M(121, 122) * x(121)
      x(122) = x(122) - temp

      temp = M(20, 123) * x(20)
      temp = temp + M(28, 123) * x(28)
      temp = temp + M(46, 123) * x(46)
      temp = temp + M(47, 123) * x(47)
      temp = temp + M(48, 123) * x(48)
      temp = temp + M(50, 123) * x(50)
      temp = temp + M(51, 123) * x(51)
      temp = temp + M(55, 123) * x(55)
      temp = temp + M(64, 123) * x(64)
      temp = temp + M(89, 123) * x(89)
      temp = temp + M(90, 123) * x(90)
      temp = temp + M(91, 123) * x(91)
      temp = temp + M(97, 123) * x(97)
      temp = temp + M(98, 123) * x(98)
      temp = temp + M(99, 123) * x(99)
      temp = temp + M(100, 123) * x(100)
      temp = temp + M(101, 123) * x(101)
      temp = temp + M(102, 123) * x(102)
      temp = temp + M(104, 123) * x(104)
      temp = temp + M(108, 123) * x(108)
      temp = temp + M(109, 123) * x(109)
      temp = temp + M(110, 123) * x(110)
      temp = temp + M(111, 123) * x(111)
      temp = temp + M(113, 123) * x(113)
      temp = temp + M(114, 123) * x(114)
      temp = temp + M(115, 123) * x(115)
      temp = temp + M(116, 123) * x(116)
      temp = temp + M(118, 123) * x(118)
      temp = temp + M(119, 123) * x(119)
      temp = temp + M(120, 123) * x(120)
      temp = temp + M(121, 123) * x(121)
      temp = temp + M(122, 123) * x(122)
      x(123) = x(123) - temp

      temp = M(46, 124) * x(46)
      temp = temp + M(54, 124) * x(54)
      temp = temp + M(55, 124) * x(55)
      temp = temp + M(56, 124) * x(56)
      temp = temp + M(57, 124) * x(57)
      temp = temp + M(58, 124) * x(58)
      temp = temp + M(59, 124) * x(59)
      temp = temp + M(60, 124) * x(60)
      temp = temp + M(61, 124) * x(61)
      temp = temp + M(62, 124) * x(62)
      temp = temp + M(63, 124) * x(63)
      temp = temp + M(64, 124) * x(64)
      temp = temp + M(65, 124) * x(65)
      temp = temp + M(66, 124) * x(66)
      temp = temp + M(67, 124) * x(67)
      temp = temp + M(68, 124) * x(68)
      temp = temp + M(69, 124) * x(69)
      temp = temp + M(70, 124) * x(70)
      temp = temp + M(71, 124) * x(71)
      temp = temp + M(72, 124) * x(72)
      temp = temp + M(73, 124) * x(73)
      temp = temp + M(74, 124) * x(74)
      temp = temp + M(75, 124) * x(75)
      temp = temp + M(76, 124) * x(76)
      temp = temp + M(77, 124) * x(77)
      temp = temp + M(78, 124) * x(78)
      temp = temp + M(79, 124) * x(79)
      temp = temp + M(80, 124) * x(80)
      temp = temp + M(81, 124) * x(81)
      temp = temp + M(82, 124) * x(82)
      temp = temp + M(83, 124) * x(83)
      temp = temp + M(84, 124) * x(84)
      temp = temp + M(85, 124) * x(85)
      temp = temp + M(86, 124) * x(86)
      temp = temp + M(87, 124) * x(87)
      temp = temp + M(88, 124) * x(88)
      temp = temp + M(89, 124) * x(89)
      temp = temp + M(90, 124) * x(90)
      temp = temp + M(91, 124) * x(91)
      temp = temp + M(92, 124) * x(92)
      temp = temp + M(93, 124) * x(93)
      temp = temp + M(94, 124) * x(94)
      temp = temp + M(95, 124) * x(95)
      temp = temp + M(96, 124) * x(96)
      temp = temp + M(97, 124) * x(97)
      temp = temp + M(98, 124) * x(98)
      temp = temp + M(99, 124) * x(99)
      temp = temp + M(100, 124) * x(100)
      temp = temp + M(101, 124) * x(101)
      temp = temp + M(102, 124) * x(102)
      temp = temp + M(103, 124) * x(103)
      temp = temp + M(104, 124) * x(104)
      temp = temp + M(105, 124) * x(105)
      temp = temp + M(106, 124) * x(106)
      temp = temp + M(107, 124) * x(107)
      temp = temp + M(108, 124) * x(108)
      temp = temp + M(109, 124) * x(109)
      temp = temp + M(110, 124) * x(110)
      temp = temp + M(111, 124) * x(111)
      temp = temp + M(112, 124) * x(112)
      temp = temp + M(113, 124) * x(113)
      temp = temp + M(114, 124) * x(114)
      temp = temp + M(115, 124) * x(115)
      temp = temp + M(116, 124) * x(116)
      temp = temp + M(117, 124) * x(117)
      temp = temp + M(118, 124) * x(118)
      temp = temp + M(119, 124) * x(119)
      temp = temp + M(120, 124) * x(120)
      temp = temp + M(121, 124) * x(121)
      temp = temp + M(122, 124) * x(122)
      temp = temp + M(123, 124) * x(123)
      x(124) = x(124) - temp

      temp = M(28, 125) * x(28)
      temp = temp + M(41, 125) * x(41)
      temp = temp + M(49, 125) * x(49)
      temp = temp + M(51, 125) * x(51)
      temp = temp + M(54, 125) * x(54)
      temp = temp + M(55, 125) * x(55)
      temp = temp + M(56, 125) * x(56)
      temp = temp + M(57, 125) * x(57)
      temp = temp + M(58, 125) * x(58)
      temp = temp + M(59, 125) * x(59)
      temp = temp + M(60, 125) * x(60)
      temp = temp + M(61, 125) * x(61)
      temp = temp + M(62, 125) * x(62)
      temp = temp + M(63, 125) * x(63)
      temp = temp + M(64, 125) * x(64)
      temp = temp + M(65, 125) * x(65)
      temp = temp + M(66, 125) * x(66)
      temp = temp + M(67, 125) * x(67)
      temp = temp + M(68, 125) * x(68)
      temp = temp + M(69, 125) * x(69)
      temp = temp + M(70, 125) * x(70)
      temp = temp + M(71, 125) * x(71)
      temp = temp + M(72, 125) * x(72)
      temp = temp + M(73, 125) * x(73)
      temp = temp + M(75, 125) * x(75)
      temp = temp + M(76, 125) * x(76)
      temp = temp + M(77, 125) * x(77)
      temp = temp + M(78, 125) * x(78)
      temp = temp + M(79, 125) * x(79)
      temp = temp + M(80, 125) * x(80)
      temp = temp + M(81, 125) * x(81)
      temp = temp + M(82, 125) * x(82)
      temp = temp + M(83, 125) * x(83)
      temp = temp + M(84, 125) * x(84)
      temp = temp + M(85, 125) * x(85)
      temp = temp + M(86, 125) * x(86)
      temp = temp + M(87, 125) * x(87)
      temp = temp + M(88, 125) * x(88)
      temp = temp + M(89, 125) * x(89)
      temp = temp + M(90, 125) * x(90)
      temp = temp + M(91, 125) * x(91)
      temp = temp + M(92, 125) * x(92)
      temp = temp + M(93, 125) * x(93)
      temp = temp + M(94, 125) * x(94)
      temp = temp + M(95, 125) * x(95)
      temp = temp + M(96, 125) * x(96)
      temp = temp + M(97, 125) * x(97)
      temp = temp + M(98, 125) * x(98)
      temp = temp + M(99, 125) * x(99)
      temp = temp + M(100, 125) * x(100)
      temp = temp + M(101, 125) * x(101)
      temp = temp + M(102, 125) * x(102)
      temp = temp + M(104, 125) * x(104)
      temp = temp + M(105, 125) * x(105)
      temp = temp + M(106, 125) * x(106)
      temp = temp + M(107, 125) * x(107)
      temp = temp + M(108, 125) * x(108)
      temp = temp + M(109, 125) * x(109)
      temp = temp + M(110, 125) * x(110)
      temp = temp + M(111, 125) * x(111)
      temp = temp + M(112, 125) * x(112)
      temp = temp + M(113, 125) * x(113)
      temp = temp + M(114, 125) * x(114)
      temp = temp + M(115, 125) * x(115)
      temp = temp + M(116, 125) * x(116)
      temp = temp + M(117, 125) * x(117)
      temp = temp + M(118, 125) * x(118)
      temp = temp + M(119, 125) * x(119)
      temp = temp + M(120, 125) * x(120)
      temp = temp + M(121, 125) * x(121)
      temp = temp + M(122, 125) * x(122)
      temp = temp + M(123, 125) * x(123)
      temp = temp + M(124, 125) * x(124)
      x(125) = x(125) - temp

      temp = M(116, 126) * x(116)
      temp = temp + M(117, 126) * x(117)
      temp = temp + M(118, 126) * x(118)
      temp = temp + M(119, 126) * x(119)
      temp = temp + M(120, 126) * x(120)
      temp = temp + M(121, 126) * x(121)
      temp = temp + M(122, 126) * x(122)
      temp = temp + M(123, 126) * x(123)
      temp = temp + M(124, 126) * x(124)
      temp = temp + M(125, 126) * x(125)
      x(126) = x(126) - temp

      temp = M(122, 127) * x(122)
      temp = temp + M(123, 127) * x(123)
      temp = temp + M(124, 127) * x(124)
      temp = temp + M(125, 127) * x(125)
      temp = temp + M(126, 127) * x(126)
      x(127) = x(127) - temp

      temp = M(111, 128) * x(111)
      temp = temp + M(113, 128) * x(113)
      temp = temp + M(123, 128) * x(123)
      temp = temp + M(124, 128) * x(124)
      temp = temp + M(125, 128) * x(125)
      temp = temp + M(126, 128) * x(126)
      temp = temp + M(127, 128) * x(127)
      x(128) = x(128) - temp

      temp = M(20, 129) * x(20)
      temp = temp + M(22, 129) * x(22)
      temp = temp + M(25, 129) * x(25)
      temp = temp + M(26, 129) * x(26)
      temp = temp + M(27, 129) * x(27)
      temp = temp + M(29, 129) * x(29)
      temp = temp + M(31, 129) * x(31)
      temp = temp + M(32, 129) * x(32)
      temp = temp + M(35, 129) * x(35)
      temp = temp + M(36, 129) * x(36)
      temp = temp + M(37, 129) * x(37)
      temp = temp + M(38, 129) * x(38)
      temp = temp + M(40, 129) * x(40)
      temp = temp + M(42, 129) * x(42)
      temp = temp + M(43, 129) * x(43)
      temp = temp + M(44, 129) * x(44)
      temp = temp + M(49, 129) * x(49)
      temp = temp + M(50, 129) * x(50)
      temp = temp + M(51, 129) * x(51)
      temp = temp + M(52, 129) * x(52)
      temp = temp + M(53, 129) * x(53)
      temp = temp + M(54, 129) * x(54)
      temp = temp + M(55, 129) * x(55)
      temp = temp + M(56, 129) * x(56)
      temp = temp + M(57, 129) * x(57)
      temp = temp + M(58, 129) * x(58)
      temp = temp + M(59, 129) * x(59)
      temp = temp + M(60, 129) * x(60)
      temp = temp + M(61, 129) * x(61)
      temp = temp + M(62, 129) * x(62)
      temp = temp + M(63, 129) * x(63)
      temp = temp + M(64, 129) * x(64)
      temp = temp + M(65, 129) * x(65)
      temp = temp + M(66, 129) * x(66)
      temp = temp + M(67, 129) * x(67)
      temp = temp + M(68, 129) * x(68)
      temp = temp + M(69, 129) * x(69)
      temp = temp + M(70, 129) * x(70)
      temp = temp + M(71, 129) * x(71)
      temp = temp + M(72, 129) * x(72)
      temp = temp + M(73, 129) * x(73)
      temp = temp + M(75, 129) * x(75)
      temp = temp + M(76, 129) * x(76)
      temp = temp + M(77, 129) * x(77)
      temp = temp + M(78, 129) * x(78)
      temp = temp + M(79, 129) * x(79)
      temp = temp + M(80, 129) * x(80)
      temp = temp + M(81, 129) * x(81)
      temp = temp + M(82, 129) * x(82)
      temp = temp + M(83, 129) * x(83)
      temp = temp + M(84, 129) * x(84)
      temp = temp + M(85, 129) * x(85)
      temp = temp + M(86, 129) * x(86)
      temp = temp + M(87, 129) * x(87)
      temp = temp + M(88, 129) * x(88)
      temp = temp + M(89, 129) * x(89)
      temp = temp + M(90, 129) * x(90)
      temp = temp + M(91, 129) * x(91)
      temp = temp + M(92, 129) * x(92)
      temp = temp + M(93, 129) * x(93)
      temp = temp + M(94, 129) * x(94)
      temp = temp + M(95, 129) * x(95)
      temp = temp + M(96, 129) * x(96)
      temp = temp + M(97, 129) * x(97)
      temp = temp + M(98, 129) * x(98)
      temp = temp + M(99, 129) * x(99)
      temp = temp + M(100, 129) * x(100)
      temp = temp + M(101, 129) * x(101)
      temp = temp + M(102, 129) * x(102)
      temp = temp + M(104, 129) * x(104)
      temp = temp + M(105, 129) * x(105)
      temp = temp + M(106, 129) * x(106)
      temp = temp + M(107, 129) * x(107)
      temp = temp + M(108, 129) * x(108)
      temp = temp + M(109, 129) * x(109)
      temp = temp + M(110, 129) * x(110)
      temp = temp + M(111, 129) * x(111)
      temp = temp + M(112, 129) * x(112)
      temp = temp + M(113, 129) * x(113)
      temp = temp + M(114, 129) * x(114)
      temp = temp + M(115, 129) * x(115)
      temp = temp + M(116, 129) * x(116)
      temp = temp + M(117, 129) * x(117)
      temp = temp + M(118, 129) * x(118)
      temp = temp + M(119, 129) * x(119)
      temp = temp + M(120, 129) * x(120)
      temp = temp + M(121, 129) * x(121)
      temp = temp + M(122, 129) * x(122)
      temp = temp + M(123, 129) * x(123)
      temp = temp + M(124, 129) * x(124)
      temp = temp + M(125, 129) * x(125)
      temp = temp + M(126, 129) * x(126)
      temp = temp + M(127, 129) * x(127)
      temp = temp + M(128, 129) * x(128)
      x(129) = x(129) - temp

      temp = M(34, 130) * x(34)
      temp = temp + M(39, 130) * x(39)
      temp = temp + M(45, 130) * x(45)
      temp = temp + M(48, 130) * x(48)
      temp = temp + M(53, 130) * x(53)
      temp = temp + M(58, 130) * x(58)
      temp = temp + M(60, 130) * x(60)
      temp = temp + M(61, 130) * x(61)
      temp = temp + M(62, 130) * x(62)
      temp = temp + M(63, 130) * x(63)
      temp = temp + M(64, 130) * x(64)
      temp = temp + M(65, 130) * x(65)
      temp = temp + M(68, 130) * x(68)
      temp = temp + M(69, 130) * x(69)
      temp = temp + M(70, 130) * x(70)
      temp = temp + M(71, 130) * x(71)
      temp = temp + M(72, 130) * x(72)
      temp = temp + M(73, 130) * x(73)
      temp = temp + M(74, 130) * x(74)
      temp = temp + M(76, 130) * x(76)
      temp = temp + M(77, 130) * x(77)
      temp = temp + M(78, 130) * x(78)
      temp = temp + M(79, 130) * x(79)
      temp = temp + M(80, 130) * x(80)
      temp = temp + M(81, 130) * x(81)
      temp = temp + M(82, 130) * x(82)
      temp = temp + M(83, 130) * x(83)
      temp = temp + M(84, 130) * x(84)
      temp = temp + M(85, 130) * x(85)
      temp = temp + M(86, 130) * x(86)
      temp = temp + M(87, 130) * x(87)
      temp = temp + M(88, 130) * x(88)
      temp = temp + M(89, 130) * x(89)
      temp = temp + M(90, 130) * x(90)
      temp = temp + M(91, 130) * x(91)
      temp = temp + M(92, 130) * x(92)
      temp = temp + M(93, 130) * x(93)
      temp = temp + M(94, 130) * x(94)
      temp = temp + M(95, 130) * x(95)
      temp = temp + M(96, 130) * x(96)
      temp = temp + M(97, 130) * x(97)
      temp = temp + M(98, 130) * x(98)
      temp = temp + M(99, 130) * x(99)
      temp = temp + M(100, 130) * x(100)
      temp = temp + M(101, 130) * x(101)
      temp = temp + M(102, 130) * x(102)
      temp = temp + M(103, 130) * x(103)
      temp = temp + M(104, 130) * x(104)
      temp = temp + M(105, 130) * x(105)
      temp = temp + M(106, 130) * x(106)
      temp = temp + M(107, 130) * x(107)
      temp = temp + M(108, 130) * x(108)
      temp = temp + M(109, 130) * x(109)
      temp = temp + M(110, 130) * x(110)
      temp = temp + M(111, 130) * x(111)
      temp = temp + M(112, 130) * x(112)
      temp = temp + M(113, 130) * x(113)
      temp = temp + M(114, 130) * x(114)
      temp = temp + M(115, 130) * x(115)
      temp = temp + M(116, 130) * x(116)
      temp = temp + M(117, 130) * x(117)
      temp = temp + M(118, 130) * x(118)
      temp = temp + M(119, 130) * x(119)
      temp = temp + M(120, 130) * x(120)
      temp = temp + M(121, 130) * x(121)
      temp = temp + M(122, 130) * x(122)
      temp = temp + M(123, 130) * x(123)
      temp = temp + M(124, 130) * x(124)
      temp = temp + M(125, 130) * x(125)
      temp = temp + M(126, 130) * x(126)
      temp = temp + M(127, 130) * x(127)
      temp = temp + M(128, 130) * x(128)
      temp = temp + M(129, 130) * x(129)
      x(130) = x(130) - temp

      temp = M(4, 131) * x(4)
      temp = temp + M(5, 131) * x(5)
      temp = temp + M(6, 131) * x(6)
      temp = temp + M(7, 131) * x(7)
      temp = temp + M(8, 131) * x(8)
      temp = temp + M(9, 131) * x(9)
      temp = temp + M(10, 131) * x(10)
      temp = temp + M(11, 131) * x(11)
      temp = temp + M(12, 131) * x(12)
      temp = temp + M(13, 131) * x(13)
      temp = temp + M(14, 131) * x(14)
      temp = temp + M(15, 131) * x(15)
      temp = temp + M(16, 131) * x(16)
      temp = temp + M(17, 131) * x(17)
      temp = temp + M(18, 131) * x(18)
      temp = temp + M(19, 131) * x(19)
      temp = temp + M(21, 131) * x(21)
      temp = temp + M(22, 131) * x(22)
      temp = temp + M(23, 131) * x(23)
      temp = temp + M(24, 131) * x(24)
      temp = temp + M(25, 131) * x(25)
      temp = temp + M(26, 131) * x(26)
      temp = temp + M(27, 131) * x(27)
      temp = temp + M(28, 131) * x(28)
      temp = temp + M(29, 131) * x(29)
      temp = temp + M(30, 131) * x(30)
      temp = temp + M(31, 131) * x(31)
      temp = temp + M(32, 131) * x(32)
      temp = temp + M(33, 131) * x(33)
      temp = temp + M(34, 131) * x(34)
      temp = temp + M(35, 131) * x(35)
      temp = temp + M(36, 131) * x(36)
      temp = temp + M(37, 131) * x(37)
      temp = temp + M(38, 131) * x(38)
      temp = temp + M(39, 131) * x(39)
      temp = temp + M(40, 131) * x(40)
      temp = temp + M(41, 131) * x(41)
      temp = temp + M(42, 131) * x(42)
      temp = temp + M(43, 131) * x(43)
      temp = temp + M(44, 131) * x(44)
      temp = temp + M(45, 131) * x(45)
      temp = temp + M(46, 131) * x(46)
      temp = temp + M(47, 131) * x(47)
      temp = temp + M(48, 131) * x(48)
      temp = temp + M(49, 131) * x(49)
      temp = temp + M(50, 131) * x(50)
      temp = temp + M(51, 131) * x(51)
      temp = temp + M(52, 131) * x(52)
      temp = temp + M(53, 131) * x(53)
      temp = temp + M(56, 131) * x(56)
      temp = temp + M(57, 131) * x(57)
      temp = temp + M(58, 131) * x(58)
      temp = temp + M(59, 131) * x(59)
      temp = temp + M(60, 131) * x(60)
      temp = temp + M(61, 131) * x(61)
      temp = temp + M(62, 131) * x(62)
      temp = temp + M(63, 131) * x(63)
      temp = temp + M(64, 131) * x(64)
      temp = temp + M(65, 131) * x(65)
      temp = temp + M(66, 131) * x(66)
      temp = temp + M(67, 131) * x(67)
      temp = temp + M(68, 131) * x(68)
      temp = temp + M(69, 131) * x(69)
      temp = temp + M(70, 131) * x(70)
      temp = temp + M(71, 131) * x(71)
      temp = temp + M(72, 131) * x(72)
      temp = temp + M(73, 131) * x(73)
      temp = temp + M(74, 131) * x(74)
      temp = temp + M(75, 131) * x(75)
      temp = temp + M(76, 131) * x(76)
      temp = temp + M(77, 131) * x(77)
      temp = temp + M(78, 131) * x(78)
      temp = temp + M(79, 131) * x(79)
      temp = temp + M(80, 131) * x(80)
      temp = temp + M(81, 131) * x(81)
      temp = temp + M(82, 131) * x(82)
      temp = temp + M(83, 131) * x(83)
      temp = temp + M(84, 131) * x(84)
      temp = temp + M(85, 131) * x(85)
      temp = temp + M(86, 131) * x(86)
      temp = temp + M(87, 131) * x(87)
      temp = temp + M(88, 131) * x(88)
      temp = temp + M(89, 131) * x(89)
      temp = temp + M(90, 131) * x(90)
      temp = temp + M(91, 131) * x(91)
      temp = temp + M(92, 131) * x(92)
      temp = temp + M(93, 131) * x(93)
      temp = temp + M(94, 131) * x(94)
      temp = temp + M(95, 131) * x(95)
      temp = temp + M(96, 131) * x(96)
      temp = temp + M(97, 131) * x(97)
      temp = temp + M(98, 131) * x(98)
      temp = temp + M(99, 131) * x(99)
      temp = temp + M(100, 131) * x(100)
      temp = temp + M(101, 131) * x(101)
      temp = temp + M(102, 131) * x(102)
      temp = temp + M(104, 131) * x(104)
      temp = temp + M(105, 131) * x(105)
      temp = temp + M(106, 131) * x(106)
      temp = temp + M(107, 131) * x(107)
      temp = temp + M(108, 131) * x(108)
      temp = temp + M(109, 131) * x(109)
      temp = temp + M(110, 131) * x(110)
      temp = temp + M(111, 131) * x(111)
      temp = temp + M(112, 131) * x(112)
      temp = temp + M(113, 131) * x(113)
      temp = temp + M(114, 131) * x(114)
      temp = temp + M(115, 131) * x(115)
      temp = temp + M(116, 131) * x(116)
      temp = temp + M(117, 131) * x(117)
      temp = temp + M(118, 131) * x(118)
      temp = temp + M(119, 131) * x(119)
      temp = temp + M(120, 131) * x(120)
      temp = temp + M(121, 131) * x(121)
      temp = temp + M(122, 131) * x(122)
      temp = temp + M(123, 131) * x(123)
      temp = temp + M(124, 131) * x(124)
      temp = temp + M(125, 131) * x(125)
      temp = temp + M(126, 131) * x(126)
      temp = temp + M(127, 131) * x(127)
      temp = temp + M(128, 131) * x(128)
      temp = temp + M(129, 131) * x(129)
      temp = temp + M(130, 131) * x(130)
      x(131) = x(131) - temp


C     Backward substitution.

      x(131) = x(131) / M(131, 131)

      temp = M(131, 130) * x(131)
      x(130) = ( x(130) - temp ) / M(130, 130)

      temp = M(130, 129) * x(130)
      temp = temp + M(131, 129) * x(131)
      x(129) = ( x(129) - temp ) / M(129, 129)

      temp = M(129, 128) * x(129)
      temp = temp + M(130, 128) * x(130)
      temp = temp + M(131, 128) * x(131)
      x(128) = ( x(128) - temp ) / M(128, 128)

      temp = M(128, 127) * x(128)
      temp = temp + M(129, 127) * x(129)
      temp = temp + M(130, 127) * x(130)
      temp = temp + M(131, 127) * x(131)
      x(127) = ( x(127) - temp ) / M(127, 127)

      temp = M(127, 126) * x(127)
      temp = temp + M(128, 126) * x(128)
      temp = temp + M(129, 126) * x(129)
      temp = temp + M(130, 126) * x(130)
      temp = temp + M(131, 126) * x(131)
      x(126) = ( x(126) - temp ) / M(126, 126)

      temp = M(126, 125) * x(126)
      temp = temp + M(127, 125) * x(127)
      temp = temp + M(128, 125) * x(128)
      temp = temp + M(129, 125) * x(129)
      temp = temp + M(130, 125) * x(130)
      temp = temp + M(131, 125) * x(131)
      x(125) = ( x(125) - temp ) / M(125, 125)

      temp = M(125, 124) * x(125)
      temp = temp + M(126, 124) * x(126)
      temp = temp + M(127, 124) * x(127)
      temp = temp + M(128, 124) * x(128)
      temp = temp + M(129, 124) * x(129)
      temp = temp + M(130, 124) * x(130)
      temp = temp + M(131, 124) * x(131)
      x(124) = ( x(124) - temp ) / M(124, 124)

      temp = M(124, 123) * x(124)
      temp = temp + M(125, 123) * x(125)
      temp = temp + M(126, 123) * x(126)
      temp = temp + M(127, 123) * x(127)
      temp = temp + M(128, 123) * x(128)
      temp = temp + M(129, 123) * x(129)
      temp = temp + M(130, 123) * x(130)
      temp = temp + M(131, 123) * x(131)
      x(123) = ( x(123) - temp ) / M(123, 123)

      temp = M(123, 122) * x(123)
      temp = temp + M(124, 122) * x(124)
      temp = temp + M(125, 122) * x(125)
      temp = temp + M(126, 122) * x(126)
      temp = temp + M(127, 122) * x(127)
      temp = temp + M(128, 122) * x(128)
      temp = temp + M(129, 122) * x(129)
      temp = temp + M(130, 122) * x(130)
      temp = temp + M(131, 122) * x(131)
      x(122) = ( x(122) - temp ) / M(122, 122)

      temp = M(122, 121) * x(122)
      temp = temp + M(123, 121) * x(123)
      temp = temp + M(124, 121) * x(124)
      temp = temp + M(125, 121) * x(125)
      temp = temp + M(126, 121) * x(126)
      temp = temp + M(128, 121) * x(128)
      temp = temp + M(129, 121) * x(129)
      temp = temp + M(130, 121) * x(130)
      temp = temp + M(131, 121) * x(131)
      x(121) = ( x(121) - temp ) / M(121, 121)

      temp = M(121, 120) * x(121)
      temp = temp + M(122, 120) * x(122)
      temp = temp + M(123, 120) * x(123)
      temp = temp + M(124, 120) * x(124)
      temp = temp + M(125, 120) * x(125)
      temp = temp + M(126, 120) * x(126)
      temp = temp + M(127, 120) * x(127)
      temp = temp + M(128, 120) * x(128)
      temp = temp + M(129, 120) * x(129)
      temp = temp + M(130, 120) * x(130)
      temp = temp + M(131, 120) * x(131)
      x(120) = ( x(120) - temp ) / M(120, 120)

      temp = M(120, 119) * x(120)
      temp = temp + M(121, 119) * x(121)
      temp = temp + M(123, 119) * x(123)
      temp = temp + M(129, 119) * x(129)
      temp = temp + M(130, 119) * x(130)
      temp = temp + M(131, 119) * x(131)
      x(119) = ( x(119) - temp ) / M(119, 119)

      temp = M(119, 118) * x(119)
      temp = temp + M(121, 118) * x(121)
      temp = temp + M(122, 118) * x(122)
      temp = temp + M(123, 118) * x(123)
      temp = temp + M(124, 118) * x(124)
      temp = temp + M(125, 118) * x(125)
      temp = temp + M(126, 118) * x(126)
      temp = temp + M(127, 118) * x(127)
      temp = temp + M(128, 118) * x(128)
      temp = temp + M(129, 118) * x(129)
      temp = temp + M(130, 118) * x(130)
      temp = temp + M(131, 118) * x(131)
      x(118) = ( x(118) - temp ) / M(118, 118)

      temp = M(118, 117) * x(118)
      temp = temp + M(119, 117) * x(119)
      temp = temp + M(121, 117) * x(121)
      temp = temp + M(122, 117) * x(122)
      temp = temp + M(123, 117) * x(123)
      temp = temp + M(124, 117) * x(124)
      temp = temp + M(125, 117) * x(125)
      temp = temp + M(126, 117) * x(126)
      temp = temp + M(127, 117) * x(127)
      temp = temp + M(128, 117) * x(128)
      temp = temp + M(129, 117) * x(129)
      temp = temp + M(130, 117) * x(130)
      temp = temp + M(131, 117) * x(131)
      x(117) = ( x(117) - temp ) / M(117, 117)

      temp = M(119, 116) * x(119)
      temp = temp + M(121, 116) * x(121)
      temp = temp + M(122, 116) * x(122)
      temp = temp + M(123, 116) * x(123)
      temp = temp + M(124, 116) * x(124)
      temp = temp + M(125, 116) * x(125)
      temp = temp + M(126, 116) * x(126)
      temp = temp + M(127, 116) * x(127)
      temp = temp + M(128, 116) * x(128)
      temp = temp + M(129, 116) * x(129)
      temp = temp + M(130, 116) * x(130)
      temp = temp + M(131, 116) * x(131)
      x(116) = ( x(116) - temp ) / M(116, 116)

      temp = M(122, 115) * x(122)
      temp = temp + M(123, 115) * x(123)
      temp = temp + M(124, 115) * x(124)
      temp = temp + M(125, 115) * x(125)
      temp = temp + M(126, 115) * x(126)
      temp = temp + M(128, 115) * x(128)
      temp = temp + M(129, 115) * x(129)
      temp = temp + M(130, 115) * x(130)
      temp = temp + M(131, 115) * x(131)
      x(115) = ( x(115) - temp ) / M(115, 115)

      temp = M(115, 114) * x(115)
      temp = temp + M(119, 114) * x(119)
      temp = temp + M(122, 114) * x(122)
      temp = temp + M(123, 114) * x(123)
      temp = temp + M(124, 114) * x(124)
      temp = temp + M(125, 114) * x(125)
      temp = temp + M(126, 114) * x(126)
      temp = temp + M(127, 114) * x(127)
      temp = temp + M(128, 114) * x(128)
      temp = temp + M(129, 114) * x(129)
      temp = temp + M(130, 114) * x(130)
      temp = temp + M(131, 114) * x(131)
      x(114) = ( x(114) - temp ) / M(114, 114)

      temp = M(130, 113) * x(130)
      temp = temp + M(131, 113) * x(131)
      x(113) = ( x(113) - temp ) / M(113, 113)

      temp = M(113, 112) * x(113)
      temp = temp + M(122, 112) * x(122)
      temp = temp + M(123, 112) * x(123)
      temp = temp + M(124, 112) * x(124)
      temp = temp + M(125, 112) * x(125)
      temp = temp + M(126, 112) * x(126)
      temp = temp + M(128, 112) * x(128)
      temp = temp + M(129, 112) * x(129)
      temp = temp + M(130, 112) * x(130)
      temp = temp + M(131, 112) * x(131)
      x(112) = ( x(112) - temp ) / M(112, 112)

      temp = M(123, 111) * x(123)
      temp = temp + M(129, 111) * x(129)
      temp = temp + M(131, 111) * x(131)
      x(111) = ( x(111) - temp ) / M(111, 111)

      temp = M(111, 110) * x(111)
      temp = temp + M(113, 110) * x(113)
      temp = temp + M(124, 110) * x(124)
      temp = temp + M(129, 110) * x(129)
      temp = temp + M(130, 110) * x(130)
      temp = temp + M(131, 110) * x(131)
      x(110) = ( x(110) - temp ) / M(110, 110)

      temp = M(110, 109) * x(110)
      temp = temp + M(111, 109) * x(111)
      temp = temp + M(113, 109) * x(113)
      temp = temp + M(115, 109) * x(115)
      temp = temp + M(119, 109) * x(119)
      temp = temp + M(122, 109) * x(122)
      temp = temp + M(123, 109) * x(123)
      temp = temp + M(124, 109) * x(124)
      temp = temp + M(125, 109) * x(125)
      temp = temp + M(128, 109) * x(128)
      temp = temp + M(129, 109) * x(129)
      temp = temp + M(130, 109) * x(130)
      temp = temp + M(131, 109) * x(131)
      x(109) = ( x(109) - temp ) / M(109, 109)

      temp = M(111, 108) * x(111)
      temp = temp + M(113, 108) * x(113)
      temp = temp + M(128, 108) * x(128)
      temp = temp + M(129, 108) * x(129)
      temp = temp + M(130, 108) * x(130)
      temp = temp + M(131, 108) * x(131)
      x(108) = ( x(108) - temp ) / M(108, 108)

      x(107) = x(107) / M(107, 107)

      x(106) = x(106) / M(106, 106)

      x(105) = x(105) / M(105, 105)

      temp = M(108, 104) * x(108)
      temp = temp + M(110, 104) * x(110)
      temp = temp + M(122, 104) * x(122)
      temp = temp + M(123, 104) * x(123)
      temp = temp + M(124, 104) * x(124)
      temp = temp + M(125, 104) * x(125)
      temp = temp + M(126, 104) * x(126)
      temp = temp + M(128, 104) * x(128)
      temp = temp + M(129, 104) * x(129)
      temp = temp + M(130, 104) * x(130)
      temp = temp + M(131, 104) * x(131)
      x(104) = ( x(104) - temp ) / M(104, 104)

      x(103) = x(103) / M(103, 103)

      temp = M(128, 102) * x(128)
      temp = temp + M(130, 102) * x(130)
      temp = temp + M(131, 102) * x(131)
      x(102) = ( x(102) - temp ) / M(102, 102)

      temp = M(102, 101) * x(102)
      temp = temp + M(111, 101) * x(111)
      temp = temp + M(113, 101) * x(113)
      temp = temp + M(115, 101) * x(115)
      temp = temp + M(116, 101) * x(116)
      temp = temp + M(119, 101) * x(119)
      temp = temp + M(122, 101) * x(122)
      temp = temp + M(123, 101) * x(123)
      temp = temp + M(124, 101) * x(124)
      temp = temp + M(125, 101) * x(125)
      temp = temp + M(126, 101) * x(126)
      temp = temp + M(128, 101) * x(128)
      temp = temp + M(129, 101) * x(129)
      temp = temp + M(130, 101) * x(130)
      temp = temp + M(131, 101) * x(131)
      x(101) = ( x(101) - temp ) / M(101, 101)

      temp = M(101, 100) * x(101)
      temp = temp + M(102, 100) * x(102)
      temp = temp + M(108, 100) * x(108)
      temp = temp + M(109, 100) * x(109)
      temp = temp + M(110, 100) * x(110)
      temp = temp + M(111, 100) * x(111)
      temp = temp + M(113, 100) * x(113)
      temp = temp + M(114, 100) * x(114)
      temp = temp + M(115, 100) * x(115)
      temp = temp + M(116, 100) * x(116)
      temp = temp + M(118, 100) * x(118)
      temp = temp + M(119, 100) * x(119)
      temp = temp + M(121, 100) * x(121)
      temp = temp + M(122, 100) * x(122)
      temp = temp + M(123, 100) * x(123)
      temp = temp + M(124, 100) * x(124)
      temp = temp + M(125, 100) * x(125)
      temp = temp + M(126, 100) * x(126)
      temp = temp + M(127, 100) * x(127)
      temp = temp + M(128, 100) * x(128)
      temp = temp + M(129, 100) * x(129)
      temp = temp + M(130, 100) * x(130)
      temp = temp + M(131, 100) * x(131)
      x(100) = ( x(100) - temp ) / M(100, 100)

      temp = M(100, 99) * x(100)
      temp = temp + M(122, 99) * x(122)
      temp = temp + M(123, 99) * x(123)
      temp = temp + M(124, 99) * x(124)
      temp = temp + M(125, 99) * x(125)
      temp = temp + M(126, 99) * x(126)
      temp = temp + M(128, 99) * x(128)
      temp = temp + M(129, 99) * x(129)
      temp = temp + M(130, 99) * x(130)
      x(99) = ( x(99) - temp ) / M(99, 99)

      temp = M(99, 98) * x(99)
      temp = temp + M(100, 98) * x(100)
      temp = temp + M(101, 98) * x(101)
      temp = temp + M(102, 98) * x(102)
      temp = temp + M(108, 98) * x(108)
      temp = temp + M(109, 98) * x(109)
      temp = temp + M(110, 98) * x(110)
      temp = temp + M(111, 98) * x(111)
      temp = temp + M(113, 98) * x(113)
      temp = temp + M(114, 98) * x(114)
      temp = temp + M(115, 98) * x(115)
      temp = temp + M(116, 98) * x(116)
      temp = temp + M(118, 98) * x(118)
      temp = temp + M(119, 98) * x(119)
      temp = temp + M(121, 98) * x(121)
      temp = temp + M(122, 98) * x(122)
      temp = temp + M(123, 98) * x(123)
      temp = temp + M(124, 98) * x(124)
      temp = temp + M(125, 98) * x(125)
      temp = temp + M(126, 98) * x(126)
      temp = temp + M(127, 98) * x(127)
      temp = temp + M(128, 98) * x(128)
      temp = temp + M(129, 98) * x(129)
      temp = temp + M(130, 98) * x(130)
      temp = temp + M(131, 98) * x(131)
      x(98) = ( x(98) - temp ) / M(98, 98)

      temp = M(98, 97) * x(98)
      temp = temp + M(99, 97) * x(99)
      temp = temp + M(100, 97) * x(100)
      temp = temp + M(101, 97) * x(101)
      temp = temp + M(102, 97) * x(102)
      temp = temp + M(108, 97) * x(108)
      temp = temp + M(109, 97) * x(109)
      temp = temp + M(110, 97) * x(110)
      temp = temp + M(111, 97) * x(111)
      temp = temp + M(113, 97) * x(113)
      temp = temp + M(114, 97) * x(114)
      temp = temp + M(115, 97) * x(115)
      temp = temp + M(116, 97) * x(116)
      temp = temp + M(118, 97) * x(118)
      temp = temp + M(119, 97) * x(119)
      temp = temp + M(121, 97) * x(121)
      temp = temp + M(122, 97) * x(122)
      temp = temp + M(123, 97) * x(123)
      temp = temp + M(124, 97) * x(124)
      temp = temp + M(125, 97) * x(125)
      temp = temp + M(126, 97) * x(126)
      temp = temp + M(127, 97) * x(127)
      temp = temp + M(128, 97) * x(128)
      temp = temp + M(129, 97) * x(129)
      temp = temp + M(130, 97) * x(130)
      temp = temp + M(131, 97) * x(131)
      x(97) = ( x(97) - temp ) / M(97, 97)

      temp = M(97, 96) * x(97)
      temp = temp + M(109, 96) * x(109)
      temp = temp + M(110, 96) * x(110)
      temp = temp + M(111, 96) * x(111)
      temp = temp + M(113, 96) * x(113)
      temp = temp + M(118, 96) * x(118)
      temp = temp + M(124, 96) * x(124)
      temp = temp + M(127, 96) * x(127)
      temp = temp + M(128, 96) * x(128)
      temp = temp + M(129, 96) * x(129)
      temp = temp + M(130, 96) * x(130)
      temp = temp + M(131, 96) * x(131)
      x(96) = ( x(96) - temp ) / M(96, 96)

      temp = M(111, 95) * x(111)
      temp = temp + M(113, 95) * x(113)
      temp = temp + M(122, 95) * x(122)
      temp = temp + M(124, 95) * x(124)
      temp = temp + M(129, 95) * x(129)
      temp = temp + M(130, 95) * x(130)
      temp = temp + M(131, 95) * x(131)
      x(95) = ( x(95) - temp ) / M(95, 95)

      temp = M(95, 94) * x(95)
      temp = temp + M(119, 94) * x(119)
      temp = temp + M(130, 94) * x(130)
      temp = temp + M(131, 94) * x(131)
      x(94) = ( x(94) - temp ) / M(94, 94)

      temp = M(94, 93) * x(94)
      temp = temp + M(102, 93) * x(102)
      temp = temp + M(115, 93) * x(115)
      temp = temp + M(116, 93) * x(116)
      temp = temp + M(118, 93) * x(118)
      temp = temp + M(119, 93) * x(119)
      temp = temp + M(122, 93) * x(122)
      temp = temp + M(123, 93) * x(123)
      temp = temp + M(124, 93) * x(124)
      temp = temp + M(125, 93) * x(125)
      temp = temp + M(126, 93) * x(126)
      temp = temp + M(128, 93) * x(128)
      temp = temp + M(129, 93) * x(129)
      temp = temp + M(130, 93) * x(130)
      temp = temp + M(131, 93) * x(131)
      x(93) = ( x(93) - temp ) / M(93, 93)

      temp = M(94, 92) * x(94)
      temp = temp + M(102, 92) * x(102)
      temp = temp + M(108, 92) * x(108)
      temp = temp + M(110, 92) * x(110)
      temp = temp + M(113, 92) * x(113)
      temp = temp + M(115, 92) * x(115)
      temp = temp + M(116, 92) * x(116)
      temp = temp + M(118, 92) * x(118)
      temp = temp + M(119, 92) * x(119)
      temp = temp + M(121, 92) * x(121)
      temp = temp + M(122, 92) * x(122)
      temp = temp + M(123, 92) * x(123)
      temp = temp + M(124, 92) * x(124)
      temp = temp + M(125, 92) * x(125)
      temp = temp + M(126, 92) * x(126)
      temp = temp + M(127, 92) * x(127)
      temp = temp + M(128, 92) * x(128)
      temp = temp + M(129, 92) * x(129)
      temp = temp + M(130, 92) * x(130)
      temp = temp + M(131, 92) * x(131)
      x(92) = ( x(92) - temp ) / M(92, 92)

      x(91) = x(91) / M(91, 91)

      x(90) = x(90) / M(90, 90)

      temp = M(110, 89) * x(110)
      temp = temp + M(130, 89) * x(130)
      temp = temp + M(131, 89) * x(131)
      x(89) = ( x(89) - temp ) / M(89, 89)

      temp = M(94, 88) * x(94)
      temp = temp + M(102, 88) * x(102)
      temp = temp + M(110, 88) * x(110)
      temp = temp + M(115, 88) * x(115)
      temp = temp + M(119, 88) * x(119)
      temp = temp + M(122, 88) * x(122)
      temp = temp + M(123, 88) * x(123)
      temp = temp + M(124, 88) * x(124)
      temp = temp + M(125, 88) * x(125)
      temp = temp + M(126, 88) * x(126)
      temp = temp + M(127, 88) * x(127)
      temp = temp + M(128, 88) * x(128)
      temp = temp + M(129, 88) * x(129)
      temp = temp + M(130, 88) * x(130)
      x(88) = ( x(88) - temp ) / M(88, 88)

      temp = M(94, 87) * x(94)
      temp = temp + M(102, 87) * x(102)
      temp = temp + M(108, 87) * x(108)
      temp = temp + M(110, 87) * x(110)
      temp = temp + M(113, 87) * x(113)
      temp = temp + M(115, 87) * x(115)
      temp = temp + M(116, 87) * x(116)
      temp = temp + M(119, 87) * x(119)
      temp = temp + M(122, 87) * x(122)
      temp = temp + M(123, 87) * x(123)
      temp = temp + M(124, 87) * x(124)
      temp = temp + M(125, 87) * x(125)
      temp = temp + M(126, 87) * x(126)
      temp = temp + M(128, 87) * x(128)
      temp = temp + M(129, 87) * x(129)
      temp = temp + M(130, 87) * x(130)
      x(87) = ( x(87) - temp ) / M(87, 87)

      temp = M(130, 86) * x(130)
      temp = temp + M(131, 86) * x(131)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(86, 85) * x(86)
      temp = temp + M(87, 85) * x(87)
      temp = temp + M(97, 85) * x(97)
      temp = temp + M(108, 85) * x(108)
      temp = temp + M(110, 85) * x(110)
      temp = temp + M(113, 85) * x(113)
      temp = temp + M(116, 85) * x(116)
      temp = temp + M(118, 85) * x(118)
      temp = temp + M(119, 85) * x(119)
      temp = temp + M(122, 85) * x(122)
      temp = temp + M(124, 85) * x(124)
      temp = temp + M(127, 85) * x(127)
      temp = temp + M(128, 85) * x(128)
      temp = temp + M(129, 85) * x(129)
      temp = temp + M(130, 85) * x(130)
      temp = temp + M(131, 85) * x(131)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(85, 84) * x(85)
      temp = temp + M(86, 84) * x(86)
      temp = temp + M(88, 84) * x(88)
      temp = temp + M(97, 84) * x(97)
      temp = temp + M(109, 84) * x(109)
      temp = temp + M(110, 84) * x(110)
      temp = temp + M(113, 84) * x(113)
      temp = temp + M(122, 84) * x(122)
      temp = temp + M(124, 84) * x(124)
      temp = temp + M(127, 84) * x(127)
      temp = temp + M(128, 84) * x(128)
      temp = temp + M(130, 84) * x(130)
      temp = temp + M(131, 84) * x(131)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(84, 83) * x(84)
      temp = temp + M(89, 83) * x(89)
      temp = temp + M(94, 83) * x(94)
      temp = temp + M(96, 83) * x(96)
      temp = temp + M(102, 83) * x(102)
      temp = temp + M(113, 83) * x(113)
      temp = temp + M(115, 83) * x(115)
      temp = temp + M(122, 83) * x(122)
      temp = temp + M(123, 83) * x(123)
      temp = temp + M(124, 83) * x(124)
      temp = temp + M(125, 83) * x(125)
      temp = temp + M(128, 83) * x(128)
      temp = temp + M(129, 83) * x(129)
      temp = temp + M(130, 83) * x(130)
      temp = temp + M(131, 83) * x(131)
      x(83) = ( x(83) - temp ) / M(83, 83)

      temp = M(94, 82) * x(94)
      temp = temp + M(102, 82) * x(102)
      temp = temp + M(115, 82) * x(115)
      temp = temp + M(116, 82) * x(116)
      temp = temp + M(118, 82) * x(118)
      temp = temp + M(119, 82) * x(119)
      temp = temp + M(122, 82) * x(122)
      temp = temp + M(123, 82) * x(123)
      temp = temp + M(124, 82) * x(124)
      temp = temp + M(125, 82) * x(125)
      temp = temp + M(128, 82) * x(128)
      temp = temp + M(129, 82) * x(129)
      temp = temp + M(130, 82) * x(130)
      x(82) = ( x(82) - temp ) / M(82, 82)

      temp = M(82, 81) * x(82)
      temp = temp + M(94, 81) * x(94)
      temp = temp + M(102, 81) * x(102)
      temp = temp + M(115, 81) * x(115)
      temp = temp + M(116, 81) * x(116)
      temp = temp + M(118, 81) * x(118)
      temp = temp + M(119, 81) * x(119)
      temp = temp + M(122, 81) * x(122)
      temp = temp + M(123, 81) * x(123)
      temp = temp + M(124, 81) * x(124)
      temp = temp + M(125, 81) * x(125)
      temp = temp + M(128, 81) * x(128)
      temp = temp + M(129, 81) * x(129)
      temp = temp + M(130, 81) * x(130)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(81, 80) * x(81)
      temp = temp + M(82, 80) * x(82)
      temp = temp + M(97, 80) * x(97)
      temp = temp + M(101, 80) * x(101)
      temp = temp + M(113, 80) * x(113)
      temp = temp + M(114, 80) * x(114)
      temp = temp + M(115, 80) * x(115)
      temp = temp + M(116, 80) * x(116)
      temp = temp + M(119, 80) * x(119)
      temp = temp + M(121, 80) * x(121)
      temp = temp + M(122, 80) * x(122)
      temp = temp + M(128, 80) * x(128)
      temp = temp + M(129, 80) * x(129)
      temp = temp + M(130, 80) * x(130)
      temp = temp + M(131, 80) * x(131)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(94, 79) * x(94)
      temp = temp + M(102, 79) * x(102)
      temp = temp + M(115, 79) * x(115)
      temp = temp + M(122, 79) * x(122)
      temp = temp + M(123, 79) * x(123)
      temp = temp + M(124, 79) * x(124)
      temp = temp + M(125, 79) * x(125)
      temp = temp + M(126, 79) * x(126)
      temp = temp + M(128, 79) * x(128)
      temp = temp + M(129, 79) * x(129)
      temp = temp + M(130, 79) * x(130)
      temp = temp + M(131, 79) * x(131)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(79, 78) * x(79)
      temp = temp + M(122, 78) * x(122)
      temp = temp + M(124, 78) * x(124)
      temp = temp + M(131, 78) * x(131)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(78, 77) * x(78)
      temp = temp + M(80, 77) * x(80)
      temp = temp + M(94, 77) * x(94)
      temp = temp + M(96, 77) * x(96)
      temp = temp + M(102, 77) * x(102)
      temp = temp + M(115, 77) * x(115)
      temp = temp + M(116, 77) * x(116)
      temp = temp + M(118, 77) * x(118)
      temp = temp + M(122, 77) * x(122)
      temp = temp + M(123, 77) * x(123)
      temp = temp + M(124, 77) * x(124)
      temp = temp + M(125, 77) * x(125)
      temp = temp + M(126, 77) * x(126)
      temp = temp + M(128, 77) * x(128)
      temp = temp + M(129, 77) * x(129)
      temp = temp + M(130, 77) * x(130)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(108, 76) * x(108)
      temp = temp + M(110, 76) * x(110)
      temp = temp + M(113, 76) * x(113)
      temp = temp + M(119, 76) * x(119)
      temp = temp + M(124, 76) * x(124)
      temp = temp + M(127, 76) * x(127)
      temp = temp + M(130, 76) * x(130)
      temp = temp + M(131, 76) * x(131)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(110, 75) * x(110)
      temp = temp + M(124, 75) * x(124)
      temp = temp + M(128, 75) * x(128)
      temp = temp + M(130, 75) * x(130)
      temp = temp + M(131, 75) * x(131)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(122, 74) * x(122)
      temp = temp + M(124, 74) * x(124)
      temp = temp + M(127, 74) * x(127)
      temp = temp + M(128, 74) * x(128)
      temp = temp + M(131, 74) * x(131)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(102, 73) * x(102)
      temp = temp + M(115, 73) * x(115)
      temp = temp + M(119, 73) * x(119)
      temp = temp + M(122, 73) * x(122)
      temp = temp + M(123, 73) * x(123)
      temp = temp + M(124, 73) * x(124)
      temp = temp + M(125, 73) * x(125)
      temp = temp + M(126, 73) * x(126)
      temp = temp + M(128, 73) * x(128)
      temp = temp + M(129, 73) * x(129)
      temp = temp + M(130, 73) * x(130)
      temp = temp + M(131, 73) * x(131)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(94, 72) * x(94)
      temp = temp + M(102, 72) * x(102)
      temp = temp + M(115, 72) * x(115)
      temp = temp + M(116, 72) * x(116)
      temp = temp + M(119, 72) * x(119)
      temp = temp + M(122, 72) * x(122)
      temp = temp + M(123, 72) * x(123)
      temp = temp + M(124, 72) * x(124)
      temp = temp + M(125, 72) * x(125)
      temp = temp + M(126, 72) * x(126)
      temp = temp + M(128, 72) * x(128)
      temp = temp + M(129, 72) * x(129)
      temp = temp + M(130, 72) * x(130)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(80, 71) * x(80)
      temp = temp + M(85, 71) * x(85)
      temp = temp + M(108, 71) * x(108)
      temp = temp + M(118, 71) * x(118)
      temp = temp + M(122, 71) * x(122)
      temp = temp + M(123, 71) * x(123)
      temp = temp + M(124, 71) * x(124)
      temp = temp + M(125, 71) * x(125)
      temp = temp + M(126, 71) * x(126)
      temp = temp + M(128, 71) * x(128)
      temp = temp + M(129, 71) * x(129)
      temp = temp + M(130, 71) * x(130)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(76, 70) * x(76)
      temp = temp + M(94, 70) * x(94)
      temp = temp + M(102, 70) * x(102)
      temp = temp + M(115, 70) * x(115)
      temp = temp + M(122, 70) * x(122)
      temp = temp + M(123, 70) * x(123)
      temp = temp + M(124, 70) * x(124)
      temp = temp + M(125, 70) * x(125)
      temp = temp + M(126, 70) * x(126)
      temp = temp + M(128, 70) * x(128)
      temp = temp + M(129, 70) * x(129)
      temp = temp + M(130, 70) * x(130)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(94, 69) * x(94)
      temp = temp + M(102, 69) * x(102)
      temp = temp + M(115, 69) * x(115)
      temp = temp + M(116, 69) * x(116)
      temp = temp + M(118, 69) * x(118)
      temp = temp + M(119, 69) * x(119)
      temp = temp + M(121, 69) * x(121)
      temp = temp + M(122, 69) * x(122)
      temp = temp + M(123, 69) * x(123)
      temp = temp + M(124, 69) * x(124)
      temp = temp + M(125, 69) * x(125)
      temp = temp + M(126, 69) * x(126)
      temp = temp + M(127, 69) * x(127)
      temp = temp + M(128, 69) * x(128)
      temp = temp + M(129, 69) * x(129)
      temp = temp + M(130, 69) * x(130)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(108, 68) * x(108)
      temp = temp + M(110, 68) * x(110)
      temp = temp + M(113, 68) * x(113)
      temp = temp + M(119, 68) * x(119)
      temp = temp + M(124, 68) * x(124)
      temp = temp + M(127, 68) * x(127)
      temp = temp + M(130, 68) * x(130)
      temp = temp + M(131, 68) * x(131)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(118, 67) * x(118)
      temp = temp + M(122, 67) * x(122)
      temp = temp + M(123, 67) * x(123)
      temp = temp + M(124, 67) * x(124)
      temp = temp + M(125, 67) * x(125)
      temp = temp + M(128, 67) * x(128)
      temp = temp + M(129, 67) * x(129)
      temp = temp + M(130, 67) * x(130)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(67, 66) * x(67)
      temp = temp + M(90, 66) * x(90)
      temp = temp + M(91, 66) * x(91)
      temp = temp + M(100, 66) * x(100)
      temp = temp + M(104, 66) * x(104)
      temp = temp + M(108, 66) * x(108)
      temp = temp + M(111, 66) * x(111)
      temp = temp + M(113, 66) * x(113)
      temp = temp + M(118, 66) * x(118)
      temp = temp + M(122, 66) * x(122)
      temp = temp + M(123, 66) * x(123)
      temp = temp + M(124, 66) * x(124)
      temp = temp + M(125, 66) * x(125)
      temp = temp + M(126, 66) * x(126)
      temp = temp + M(128, 66) * x(128)
      temp = temp + M(129, 66) * x(129)
      temp = temp + M(130, 66) * x(130)
      temp = temp + M(131, 66) * x(131)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(68, 65) * x(68)
      temp = temp + M(76, 65) * x(76)
      temp = temp + M(90, 65) * x(90)
      temp = temp + M(91, 65) * x(91)
      temp = temp + M(98, 65) * x(98)
      temp = temp + M(100, 65) * x(100)
      temp = temp + M(104, 65) * x(104)
      temp = temp + M(108, 65) * x(108)
      temp = temp + M(110, 65) * x(110)
      temp = temp + M(111, 65) * x(111)
      temp = temp + M(118, 65) * x(118)
      temp = temp + M(122, 65) * x(122)
      temp = temp + M(123, 65) * x(123)
      temp = temp + M(124, 65) * x(124)
      temp = temp + M(125, 65) * x(125)
      temp = temp + M(126, 65) * x(126)
      temp = temp + M(128, 65) * x(128)
      temp = temp + M(129, 65) * x(129)
      temp = temp + M(130, 65) * x(130)
      temp = temp + M(131, 65) * x(131)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(90, 64) * x(90)
      temp = temp + M(91, 64) * x(91)
      temp = temp + M(100, 64) * x(100)
      temp = temp + M(104, 64) * x(104)
      temp = temp + M(108, 64) * x(108)
      temp = temp + M(111, 64) * x(111)
      temp = temp + M(118, 64) * x(118)
      temp = temp + M(122, 64) * x(122)
      temp = temp + M(123, 64) * x(123)
      temp = temp + M(124, 64) * x(124)
      temp = temp + M(125, 64) * x(125)
      temp = temp + M(126, 64) * x(126)
      temp = temp + M(128, 64) * x(128)
      temp = temp + M(129, 64) * x(129)
      temp = temp + M(130, 64) * x(130)
      temp = temp + M(131, 64) * x(131)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(108, 63) * x(108)
      temp = temp + M(118, 63) * x(118)
      temp = temp + M(122, 63) * x(122)
      temp = temp + M(123, 63) * x(123)
      temp = temp + M(124, 63) * x(124)
      temp = temp + M(125, 63) * x(125)
      temp = temp + M(126, 63) * x(126)
      temp = temp + M(128, 63) * x(128)
      temp = temp + M(129, 63) * x(129)
      temp = temp + M(130, 63) * x(130)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(63, 62) * x(63)
      temp = temp + M(64, 62) * x(64)
      temp = temp + M(90, 62) * x(90)
      temp = temp + M(91, 62) * x(91)
      temp = temp + M(100, 62) * x(100)
      temp = temp + M(104, 62) * x(104)
      temp = temp + M(111, 62) * x(111)
      temp = temp + M(129, 62) * x(129)
      temp = temp + M(130, 62) * x(130)
      temp = temp + M(131, 62) * x(131)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(76, 61) * x(76)
      temp = temp + M(98, 61) * x(98)
      temp = temp + M(110, 61) * x(110)
      temp = temp + M(118, 61) * x(118)
      temp = temp + M(122, 61) * x(122)
      temp = temp + M(123, 61) * x(123)
      temp = temp + M(124, 61) * x(124)
      temp = temp + M(125, 61) * x(125)
      temp = temp + M(128, 61) * x(128)
      temp = temp + M(129, 61) * x(129)
      temp = temp + M(130, 61) * x(130)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(61, 60) * x(61)
      temp = temp + M(62, 60) * x(62)
      temp = temp + M(68, 60) * x(68)
      temp = temp + M(118, 60) * x(118)
      temp = temp + M(122, 60) * x(122)
      temp = temp + M(123, 60) * x(123)
      temp = temp + M(124, 60) * x(124)
      temp = temp + M(125, 60) * x(125)
      temp = temp + M(126, 60) * x(126)
      temp = temp + M(128, 60) * x(128)
      temp = temp + M(129, 60) * x(129)
      temp = temp + M(130, 60) * x(130)
      temp = temp + M(131, 60) * x(131)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(66, 59) * x(66)
      temp = temp + M(122, 59) * x(122)
      temp = temp + M(123, 59) * x(123)
      temp = temp + M(124, 59) * x(124)
      temp = temp + M(125, 59) * x(125)
      temp = temp + M(128, 59) * x(128)
      temp = temp + M(129, 59) * x(129)
      temp = temp + M(130, 59) * x(130)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(62, 58) * x(62)
      temp = temp + M(68, 58) * x(68)
      temp = temp + M(76, 58) * x(76)
      temp = temp + M(108, 58) * x(108)
      temp = temp + M(110, 58) * x(110)
      temp = temp + M(118, 58) * x(118)
      temp = temp + M(122, 58) * x(122)
      temp = temp + M(123, 58) * x(123)
      temp = temp + M(124, 58) * x(124)
      temp = temp + M(125, 58) * x(125)
      temp = temp + M(126, 58) * x(126)
      temp = temp + M(128, 58) * x(128)
      temp = temp + M(129, 58) * x(129)
      temp = temp + M(130, 58) * x(130)
      temp = temp + M(131, 58) * x(131)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(66, 57) * x(66)
      temp = temp + M(122, 57) * x(122)
      temp = temp + M(123, 57) * x(123)
      temp = temp + M(124, 57) * x(124)
      temp = temp + M(125, 57) * x(125)
      temp = temp + M(128, 57) * x(128)
      temp = temp + M(129, 57) * x(129)
      temp = temp + M(130, 57) * x(130)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(76, 56) * x(76)
      temp = temp + M(110, 56) * x(110)
      temp = temp + M(118, 56) * x(118)
      temp = temp + M(122, 56) * x(122)
      temp = temp + M(123, 56) * x(123)
      temp = temp + M(124, 56) * x(124)
      temp = temp + M(125, 56) * x(125)
      temp = temp + M(128, 56) * x(128)
      temp = temp + M(129, 56) * x(129)
      temp = temp + M(130, 56) * x(130)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(118, 55) * x(118)
      temp = temp + M(123, 55) * x(123)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(55, 54) * x(55)
      temp = temp + M(122, 54) * x(122)
      temp = temp + M(123, 54) * x(123)
      temp = temp + M(124, 54) * x(124)
      temp = temp + M(125, 54) * x(125)
      temp = temp + M(128, 54) * x(128)
      temp = temp + M(129, 54) * x(129)
      temp = temp + M(130, 54) * x(130)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(130, 53) * x(130)
      temp = temp + M(131, 53) * x(131)
      x(53) = ( x(53) - temp ) / M(53, 53)

      x(52) = x(52) / M(52, 52)

      temp = M(97, 51) * x(97)
      temp = temp + M(123, 51) * x(123)
      temp = temp + M(125, 51) * x(125)
      temp = temp + M(129, 51) * x(129)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(89, 50) * x(89)
      temp = temp + M(109, 50) * x(109)
      temp = temp + M(123, 50) * x(123)
      temp = temp + M(129, 50) * x(129)
      temp = temp + M(131, 50) * x(131)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(89, 49) * x(89)
      temp = temp + M(113, 49) * x(113)
      temp = temp + M(123, 49) * x(123)
      temp = temp + M(128, 49) * x(128)
      temp = temp + M(131, 49) * x(131)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(123, 48) * x(123)
      temp = temp + M(129, 48) * x(129)
      temp = temp + M(130, 48) * x(130)
      temp = temp + M(131, 48) * x(131)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(120, 47) * x(120)
      temp = temp + M(123, 47) * x(123)
      temp = temp + M(127, 47) * x(127)
      temp = temp + M(128, 47) * x(128)
      temp = temp + M(129, 47) * x(129)
      temp = temp + M(131, 47) * x(131)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(122, 46) * x(122)
      temp = temp + M(123, 46) * x(123)
      temp = temp + M(124, 46) * x(124)
      temp = temp + M(127, 46) * x(127)
      temp = temp + M(128, 46) * x(128)
      temp = temp + M(129, 46) * x(129)
      temp = temp + M(131, 46) * x(131)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(122, 45) * x(122)
      temp = temp + M(128, 45) * x(128)
      temp = temp + M(130, 45) * x(130)
      temp = temp + M(131, 45) * x(131)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(121, 44) * x(121)
      temp = temp + M(131, 44) * x(131)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(122, 43) * x(122)
      temp = temp + M(131, 43) * x(131)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(43, 42) * x(43)
      temp = temp + M(44, 42) * x(44)
      temp = temp + M(52, 42) * x(52)
      temp = temp + M(53, 42) * x(53)
      temp = temp + M(72, 42) * x(72)
      temp = temp + M(81, 42) * x(81)
      temp = temp + M(82, 42) * x(82)
      temp = temp + M(86, 42) * x(86)
      temp = temp + M(97, 42) * x(97)
      temp = temp + M(113, 42) * x(113)
      temp = temp + M(114, 42) * x(114)
      temp = temp + M(115, 42) * x(115)
      temp = temp + M(116, 42) * x(116)
      temp = temp + M(119, 42) * x(119)
      temp = temp + M(121, 42) * x(121)
      temp = temp + M(122, 42) * x(122)
      temp = temp + M(128, 42) * x(128)
      temp = temp + M(129, 42) * x(129)
      temp = temp + M(130, 42) * x(130)
      temp = temp + M(131, 42) * x(131)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(70, 41) * x(70)
      temp = temp + M(121, 41) * x(121)
      temp = temp + M(122, 41) * x(122)
      temp = temp + M(124, 41) * x(124)
      temp = temp + M(131, 41) * x(131)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(100, 40) * x(100)
      temp = temp + M(111, 40) * x(111)
      temp = temp + M(129, 40) * x(129)
      temp = temp + M(131, 40) * x(131)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(109, 39) * x(109)
      temp = temp + M(131, 39) * x(131)
      x(39) = ( x(39) - temp ) / M(39, 39)

      x(38) = x(38) / M(38, 38)

      x(37) = x(37) / M(37, 37)

      temp = M(37, 36) * x(37)
      temp = temp + M(38, 36) * x(38)
      temp = temp + M(42, 36) * x(42)
      temp = temp + M(53, 36) * x(53)
      temp = temp + M(77, 36) * x(77)
      temp = temp + M(81, 36) * x(81)
      temp = temp + M(82, 36) * x(82)
      temp = temp + M(86, 36) * x(86)
      temp = temp + M(96, 36) * x(96)
      temp = temp + M(97, 36) * x(97)
      temp = temp + M(113, 36) * x(113)
      temp = temp + M(114, 36) * x(114)
      temp = temp + M(115, 36) * x(115)
      temp = temp + M(121, 36) * x(121)
      temp = temp + M(128, 36) * x(128)
      temp = temp + M(129, 36) * x(129)
      temp = temp + M(130, 36) * x(130)
      temp = temp + M(131, 36) * x(131)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(49, 35) * x(49)
      temp = temp + M(53, 35) * x(53)
      temp = temp + M(83, 35) * x(83)
      temp = temp + M(84, 35) * x(84)
      temp = temp + M(86, 35) * x(86)
      temp = temp + M(96, 35) * x(96)
      temp = temp + M(97, 35) * x(97)
      temp = temp + M(109, 35) * x(109)
      temp = temp + M(113, 35) * x(113)
      temp = temp + M(122, 35) * x(122)
      temp = temp + M(124, 35) * x(124)
      temp = temp + M(128, 35) * x(128)
      temp = temp + M(129, 35) * x(129)
      temp = temp + M(130, 35) * x(130)
      temp = temp + M(131, 35) * x(131)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(96, 34) * x(96)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(119, 33) * x(119)
      temp = temp + M(130, 33) * x(130)
      temp = temp + M(131, 33) * x(131)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(73, 32) * x(73)
      temp = temp + M(81, 32) * x(81)
      temp = temp + M(82, 32) * x(82)
      temp = temp + M(86, 32) * x(86)
      temp = temp + M(97, 32) * x(97)
      temp = temp + M(113, 32) * x(113)
      temp = temp + M(128, 32) * x(128)
      temp = temp + M(129, 32) * x(129)
      temp = temp + M(130, 32) * x(130)
      temp = temp + M(131, 32) * x(131)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(97, 31) * x(97)
      temp = temp + M(108, 31) * x(108)
      temp = temp + M(111, 31) * x(111)
      temp = temp + M(113, 31) * x(113)
      temp = temp + M(119, 31) * x(119)
      temp = temp + M(123, 31) * x(123)
      temp = temp + M(127, 31) * x(127)
      temp = temp + M(129, 31) * x(129)
      temp = temp + M(130, 31) * x(130)
      temp = temp + M(131, 31) * x(131)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(95, 30) * x(95)
      temp = temp + M(130, 30) * x(130)
      temp = temp + M(131, 30) * x(131)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(42, 29) * x(42)
      temp = temp + M(51, 29) * x(51)
      temp = temp + M(53, 29) * x(53)
      temp = temp + M(81, 29) * x(81)
      temp = temp + M(82, 29) * x(82)
      temp = temp + M(86, 29) * x(86)
      temp = temp + M(96, 29) * x(96)
      temp = temp + M(97, 29) * x(97)
      temp = temp + M(101, 29) * x(101)
      temp = temp + M(113, 29) * x(113)
      temp = temp + M(114, 29) * x(114)
      temp = temp + M(122, 29) * x(122)
      temp = temp + M(124, 29) * x(124)
      temp = temp + M(127, 29) * x(127)
      temp = temp + M(128, 29) * x(128)
      temp = temp + M(129, 29) * x(129)
      temp = temp + M(130, 29) * x(130)
      temp = temp + M(131, 29) * x(131)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(123, 28) * x(123)
      temp = temp + M(125, 28) * x(125)
      temp = temp + M(131, 28) * x(131)
      x(28) = ( x(28) - temp ) / M(28, 28)

      x(27) = x(27) / M(27, 27)

      x(26) = x(26) / M(26, 26)

      temp = M(26, 25) * x(26)
      temp = temp + M(27, 25) * x(27)
      temp = temp + M(53, 25) * x(53)
      temp = temp + M(81, 25) * x(81)
      temp = temp + M(82, 25) * x(82)
      temp = temp + M(93, 25) * x(93)
      temp = temp + M(97, 25) * x(97)
      temp = temp + M(113, 25) * x(113)
      temp = temp + M(114, 25) * x(114)
      temp = temp + M(116, 25) * x(116)
      temp = temp + M(119, 25) * x(119)
      temp = temp + M(121, 25) * x(121)
      temp = temp + M(129, 25) * x(129)
      temp = temp + M(130, 25) * x(130)
      temp = temp + M(131, 25) * x(131)
      x(25) = ( x(25) - temp ) / M(25, 25)

      x(24) = x(24) / M(24, 24)

      x(23) = x(23) / M(23, 23)

      temp = M(40, 22) * x(40)
      temp = temp + M(63, 22) * x(63)
      temp = temp + M(64, 22) * x(64)
      temp = temp + M(90, 22) * x(90)
      temp = temp + M(91, 22) * x(91)
      temp = temp + M(104, 22) * x(104)
      temp = temp + M(111, 22) * x(111)
      temp = temp + M(129, 22) * x(129)
      temp = temp + M(130, 22) * x(130)
      temp = temp + M(131, 22) * x(131)
      x(22) = ( x(22) - temp ) / M(22, 22)

      temp = M(113, 21) * x(113)
      temp = temp + M(123, 21) * x(123)
      temp = temp + M(128, 21) * x(128)
      temp = temp + M(131, 21) * x(131)
      x(21) = ( x(21) - temp ) / M(21, 21)

      temp = M(111, 20) * x(111)
      temp = temp + M(123, 20) * x(123)
      temp = temp + M(129, 20) * x(129)
      x(20) = ( x(20) - temp ) / M(20, 20)

      x(19) = x(19) / M(19, 19)

      temp = M(19, 18) * x(19)
      temp = temp + M(131, 18) * x(131)
      x(18) = ( x(18) - temp ) / M(18, 18)

      x(17) = x(17) / M(17, 17)

      temp = M(31, 16) * x(31)
      temp = temp + M(61, 16) * x(61)
      temp = temp + M(62, 16) * x(62)
      temp = temp + M(65, 16) * x(65)
      temp = temp + M(68, 16) * x(68)
      temp = temp + M(130, 16) * x(130)
      temp = temp + M(131, 16) * x(131)
      x(16) = ( x(16) - temp ) / M(16, 16)

      temp = M(16, 15) * x(16)
      temp = temp + M(59, 15) * x(59)
      temp = temp + M(62, 15) * x(62)
      temp = temp + M(107, 15) * x(107)
      temp = temp + M(130, 15) * x(130)
      temp = temp + M(131, 15) * x(131)
      x(15) = ( x(15) - temp ) / M(15, 15)

      temp = M(31, 14) * x(31)
      temp = temp + M(60, 14) * x(60)
      temp = temp + M(61, 14) * x(61)
      temp = temp + M(62, 14) * x(62)
      temp = temp + M(68, 14) * x(68)
      temp = temp + M(130, 14) * x(130)
      temp = temp + M(131, 14) * x(131)
      x(14) = ( x(14) - temp ) / M(14, 14)

      temp = M(14, 13) * x(14)
      temp = temp + M(59, 13) * x(59)
      temp = temp + M(62, 13) * x(62)
      temp = temp + M(106, 13) * x(106)
      temp = temp + M(130, 13) * x(130)
      temp = temp + M(131, 13) * x(131)
      x(13) = ( x(13) - temp ) / M(13, 13)

      temp = M(31, 12) * x(31)
      temp = temp + M(56, 12) * x(56)
      temp = temp + M(58, 12) * x(58)
      temp = temp + M(62, 12) * x(62)
      temp = temp + M(68, 12) * x(68)
      temp = temp + M(130, 12) * x(130)
      temp = temp + M(131, 12) * x(131)
      x(12) = ( x(12) - temp ) / M(12, 12)

      temp = M(12, 11) * x(12)
      temp = temp + M(57, 11) * x(57)
      temp = temp + M(62, 11) * x(62)
      temp = temp + M(105, 11) * x(105)
      temp = temp + M(130, 11) * x(130)
      temp = temp + M(131, 11) * x(131)
      x(11) = ( x(11) - temp ) / M(11, 11)

      temp = M(17, 10) * x(17)
      temp = temp + M(69, 10) * x(69)
      temp = temp + M(75, 10) * x(75)
      temp = temp + M(119, 10) * x(119)
      temp = temp + M(130, 10) * x(130)
      temp = temp + M(131, 10) * x(131)
      x(10) = ( x(10) - temp ) / M(10, 10)

      temp = M(92, 9) * x(92)
      temp = temp + M(131, 9) * x(131)
      x(9) = ( x(9) - temp ) / M(9, 9)

      temp = M(117, 8) * x(117)
      temp = temp + M(131, 8) * x(131)
      x(8) = ( x(8) - temp ) / M(8, 8)

      temp = M(22, 7) * x(22)
      temp = temp + M(71, 7) * x(71)
      temp = temp + M(85, 7) * x(85)
      temp = temp + M(130, 7) * x(130)
      temp = temp + M(131, 7) * x(131)
      x(7) = ( x(7) - temp ) / M(7, 7)

      temp = M(86, 6) * x(86)
      temp = temp + M(108, 6) * x(108)
      temp = temp + M(113, 6) * x(113)
      temp = temp + M(130, 6) * x(130)
      temp = temp + M(131, 6) * x(131)
      x(6) = ( x(6) - temp ) / M(6, 6)

      x(5) = x(5) / M(5, 5)

      temp = M(5, 4) * x(5)
      temp = temp + M(130, 4) * x(130)
      temp = temp + M(131, 4) * x(131)
      x(4) = ( x(4) - temp ) / M(4, 4)

      temp = M(51, 3) * x(51)
      temp = temp + M(131, 3) * x(131)
      x(3) = ( x(3) - temp ) / M(3, 3)

      x(2) = x(2) / M(2, 2)

      x(1) = x(1) / M(1, 1)


      END
