C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 78) = M(3, 78) / M(3, 3)

C     Upper part.
      M(4, 78) = M(4, 78) / M(4, 4)

C     Upper part.
      M(5, 78) = M(5, 78) / M(5, 5)

C     Upper part.
      M(6, 78) = M(6, 78) / M(6, 6)

C     Upper part.
      M(7, 63) = M(7, 63) / M(7, 7)

C     Upper part.
      temp = M(8, 4) * M(4, 78)
      M(8, 78) = ( M(8, 78) - temp ) / M(8, 8)

C     Upper part.
      M(9, 78) = M(9, 78) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 78)
      M(10, 78) = ( M(10, 78) - temp ) / M(10, 10)

C     Upper part.
      M(11, 78) = M(11, 78) / M(11, 11)

C     Upper part.
      M(12, 78) = M(12, 78) / M(12, 12)

C     Upper part.
      temp = M(13, 12) * M(12, 78)
      M(13, 78) = ( M(13, 78) - temp ) / M(13, 13)

C     Upper part.
      M(14, 33) = M(14, 33) / M(14, 14)
C     Upper part.
      M(14, 78) = M(14, 78) / M(14, 14)

C     Upper part.
      M(15, 33) = M(15, 33) / M(15, 15)
C     Upper part.
      M(15, 78) = M(15, 78) / M(15, 15)

C     Upper part.
      M(16, 62) = M(16, 62) / M(16, 16)
C     Upper part.
      M(16, 78) = M(16, 78) / M(16, 16)

C     Upper part.
      M(17, 85) = M(17, 85) / M(17, 17)
C     Upper part.
      M(17, 87) = M(17, 87) / M(17, 17)

C     Upper part.
      M(18, 63) = M(18, 63) / M(18, 18)
C     Upper part.
      temp = M(18, 6) * M(6, 78)
      M(18, 78) = ( M(18, 78) - temp ) / M(18, 18)
C     Upper part.
      M(18, 87) = M(18, 87) / M(18, 18)

C     Upper part.
      M(19, 63) = M(19, 63) / M(19, 19)
C     Upper part.
      M(19, 78) = M(19, 78) / M(19, 19)
C     Upper part.
      M(19, 85) = M(19, 85) / M(19, 19)

C     Upper part.
      M(20, 24) = M(20, 24) / M(20, 20)
C     Upper part.
      M(20, 63) = M(20, 63) / M(20, 20)
C     Upper part.
      M(20, 78) = M(20, 78) / M(20, 20)

C     Upper part.
      M(21, 24) = M(21, 24) / M(21, 21)
C     Upper part.
      M(21, 63) = M(21, 63) / M(21, 21)
C     Upper part.
      M(21, 78) = M(21, 78) / M(21, 21)

C     Upper part.
      M(22, 78) = M(22, 78) / M(22, 22)
C     Upper part.
      M(22, 86) = M(22, 86) / M(22, 22)
C     Upper part.
      M(22, 87) = M(22, 87) / M(22, 22)

C     Upper part.
      M(23, 78) = M(23, 78) / M(23, 23)
C     Upper part.
      M(23, 82) = M(23, 82) / M(23, 23)
C     Upper part.
      M(23, 86) = M(23, 86) / M(23, 23)

C     Upper part.
      M(24, 63) = M(24, 63) / M(24, 24)
C     Upper part.
      M(24, 78) = M(24, 78) / M(24, 24)
C     Upper part.
      M(24, 85) = M(24, 85) / M(24, 24)

C     Upper part.
      M(25, 63) = M(25, 63) / M(25, 25)
C     Upper part.
      M(25, 78) = M(25, 78) / M(25, 25)
C     Upper part.
      M(25, 85) = M(25, 85) / M(25, 25)

C     Upper part.
      M(26, 63) = M(26, 63) / M(26, 26)
C     Upper part.
      M(26, 78) = M(26, 78) / M(26, 26)
C     Upper part.
      M(26, 85) = M(26, 85) / M(26, 26)

C     Upper part.
      temp = M(27, 26) * M(26, 63)
      M(27, 63) = ( M(27, 63) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 26) * M(26, 78)
      M(27, 78) = ( M(27, 78) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 26) * M(26, 85)
      M(27, 85) = ( M(27, 85) - temp ) / M(27, 27)

C     Upper part.
      temp = M(28, 26) * M(26, 63)
      M(28, 63) = ( M(28, 63) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 26) * M(26, 78)
      M(28, 78) = ( M(28, 78) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 26) * M(26, 85)
      M(28, 85) = ( M(28, 85) - temp ) / M(28, 28)

C     Upper part.
      M(29, 63) = M(29, 63) / M(29, 29)
C     Upper part.
      temp = M(29, 5) * M(5, 78)
      M(29, 78) = ( M(29, 78) - temp ) / M(29, 29)
C     Upper part.
      M(29, 87) = M(29, 87) / M(29, 29)

C     Upper part.
      M(30, 52) = M(30, 52) / M(30, 30)
C     Upper part.
      M(30, 56) = M(30, 56) / M(30, 30)
C     Upper part.
      M(30, 63) = M(30, 63) / M(30, 30)
C     Upper part.
      M(30, 78) = M(30, 78) / M(30, 30)

C     Upper part.
      M(31, 37) = M(31, 37) / M(31, 31)
C     Upper part.
      M(31, 63) = M(31, 63) / M(31, 31)
C     Upper part.
      M(31, 78) = M(31, 78) / M(31, 31)
C     Upper part.
      M(31, 87) = M(31, 87) / M(31, 31)

C     Upper part.
      temp = M(32, 31) * M(31, 37)
      M(32, 37) = ( M(32, 37) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 18) * M(18, 63)
      temp = temp + M(32, 29) * M(29, 63)
      temp = temp + M(32, 31) * M(31, 63)
      M(32, 63) = ( M(32, 63) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 18) * M(18, 78)
      temp = temp + M(32, 29) * M(29, 78)
      temp = temp + M(32, 31) * M(31, 78)
      M(32, 78) = ( M(32, 78) - temp ) / M(32, 32)
C     Upper part.
      M(32, 84) = M(32, 84) / M(32, 32)
C     Upper part.
      temp = M(32, 18) * M(18, 87)
      temp = temp + M(32, 29) * M(29, 87)
      temp = temp + M(32, 31) * M(31, 87)
      M(32, 87) = ( M(32, 87) - temp ) / M(32, 32)

C     Upper part.
      M(33, 50) = M(33, 50) / M(33, 33)
C     Upper part.
      M(33, 63) = M(33, 63) / M(33, 33)
C     Upper part.
      M(33, 78) = M(33, 78) / M(33, 33)
C     Upper part.
      M(33, 85) = M(33, 85) / M(33, 33)

C     Upper part.
      M(34, 52) = M(34, 52) / M(34, 34)
C     Upper part.
      M(34, 56) = M(34, 56) / M(34, 34)
C     Upper part.
      M(34, 63) = M(34, 63) / M(34, 34)
C     Upper part.
      M(34, 78) = M(34, 78) / M(34, 34)

C     Upper part.
      M(35, 62) = M(35, 62) / M(35, 35)
C     Upper part.
      M(35, 63) = M(35, 63) / M(35, 35)
C     Upper part.
      M(35, 78) = M(35, 78) / M(35, 35)
C     Upper part.
      M(35, 83) = M(35, 83) / M(35, 35)
C     Upper part.
      M(35, 86) = M(35, 86) / M(35, 35)

C     Upper part.
      M(36, 37) = M(36, 37) / M(36, 36)
C     Upper part.
      M(36, 78) = M(36, 78) / M(36, 36)
C     Upper part.
      M(36, 85) = M(36, 85) / M(36, 36)
C     Upper part.
      M(36, 86) = M(36, 86) / M(36, 36)
C     Upper part.
      M(36, 87) = M(36, 87) / M(36, 36)

C     Lower part.
      temp = M(37, 31) * M(31, 37)
      temp = temp + M(37, 36) * M(36, 37)
      M(37, 37) = M(37, 37) - temp
C     Lower part.
      temp = M(49, 31) * M(31, 37)
      M(49, 37) = M(49, 37) - temp
C     Lower part.
      temp = M(63, 31) * M(31, 37)
      M(63, 37) = M(63, 37) - temp
C     Lower part.
      temp = M(74, 36) * M(36, 37)
      M(74, 37) = M(74, 37) - temp
C     Lower part.
      temp = M(78, 31) * M(31, 37)
      temp = temp + M(78, 32) * M(32, 37)
      M(78, 37) = M(78, 37) - temp
C     Lower part.
      temp = M(84, 32) * M(32, 37)
      M(84, 37) = M(84, 37) - temp
C     Lower part.
      temp = M(86, 31) * M(31, 37)
      temp = temp + M(86, 36) * M(36, 37)
      M(86, 37) = M(86, 37) - temp
C     Lower part.
      temp = M(87, 31) * M(31, 37)
      temp = temp + M(87, 32) * M(32, 37)
      temp = temp + M(87, 36) * M(36, 37)
      M(87, 37) = M(87, 37) - temp
C     Upper part.
      temp = M(37, 18) * M(18, 63)
      temp = temp + M(37, 29) * M(29, 63)
      temp = temp + M(37, 31) * M(31, 63)
      M(37, 63) = ( M(37, 63) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 18) * M(18, 78)
      temp = temp + M(37, 29) * M(29, 78)
      temp = temp + M(37, 31) * M(31, 78)
      temp = temp + M(37, 36) * M(36, 78)
      M(37, 78) = ( M(37, 78) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 36) * M(36, 85)
      M(37, 85) = ( M(37, 85) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 36) * M(36, 86)
      M(37, 86) = ( M(37, 86) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 18) * M(18, 87)
      temp = temp + M(37, 29) * M(29, 87)
      temp = temp + M(37, 31) * M(31, 87)
      temp = temp + M(37, 36) * M(36, 87)
      M(37, 87) = ( M(37, 87) - temp ) / M(37, 37)

C     Upper part.
      M(38, 52) = M(38, 52) / M(38, 38)
C     Upper part.
      M(38, 56) = M(38, 56) / M(38, 38)
C     Upper part.
      M(38, 63) = M(38, 63) / M(38, 38)
C     Upper part.
      M(38, 78) = M(38, 78) / M(38, 38)
C     Upper part.
      M(38, 85) = M(38, 85) / M(38, 38)

C     Upper part.
      temp = M(39, 29) * M(29, 63)
      M(39, 63) = ( M(39, 63) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 29) * M(29, 78)
      M(39, 78) = ( M(39, 78) - temp ) / M(39, 39)
C     Upper part.
      M(39, 82) = M(39, 82) / M(39, 39)
C     Upper part.
      M(39, 83) = M(39, 83) / M(39, 39)
C     Upper part.
      M(39, 84) = M(39, 84) / M(39, 39)
C     Upper part.
      M(39, 85) = M(39, 85) / M(39, 39)
C     Upper part.
      M(39, 86) = M(39, 86) / M(39, 39)
C     Upper part.
      temp = M(39, 29) * M(29, 87)
      M(39, 87) = ( M(39, 87) - temp ) / M(39, 39)

C     Upper part.
      M(40, 44) = M(40, 44) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 63)
      M(40, 63) = ( M(40, 63) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 78)
      M(40, 78) = ( M(40, 78) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 82)
      M(40, 82) = ( M(40, 82) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 83)
      M(40, 83) = ( M(40, 83) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 84)
      M(40, 84) = ( M(40, 84) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 85)
      M(40, 85) = ( M(40, 85) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 86)
      M(40, 86) = ( M(40, 86) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 87)
      M(40, 87) = ( M(40, 87) - temp ) / M(40, 40)

C     Upper part.
      M(41, 44) = M(41, 44) / M(41, 41)
C     Upper part.
      temp = M(41, 37) * M(37, 63)
      temp = temp + M(41, 39) * M(39, 63)
      M(41, 63) = ( M(41, 63) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 37) * M(37, 78)
      temp = temp + M(41, 39) * M(39, 78)
      M(41, 78) = ( M(41, 78) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 39) * M(39, 82)
      M(41, 82) = ( M(41, 82) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 39) * M(39, 83)
      M(41, 83) = ( M(41, 83) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 39) * M(39, 84)
      M(41, 84) = ( M(41, 84) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 37) * M(37, 85)
      temp = temp + M(41, 39) * M(39, 85)
      M(41, 85) = ( M(41, 85) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 37) * M(37, 86)
      temp = temp + M(41, 39) * M(39, 86)
      M(41, 86) = ( M(41, 86) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 37) * M(37, 87)
      temp = temp + M(41, 39) * M(39, 87)
      M(41, 87) = ( M(41, 87) - temp ) / M(41, 41)

C     Upper part.
      M(42, 44) = M(42, 44) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 63)
      temp = temp + M(42, 39) * M(39, 63)
      M(42, 63) = ( M(42, 63) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 78)
      temp = temp + M(42, 39) * M(39, 78)
      M(42, 78) = ( M(42, 78) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 39) * M(39, 82)
      M(42, 82) = ( M(42, 82) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 39) * M(39, 83)
      M(42, 83) = ( M(42, 83) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 39) * M(39, 84)
      M(42, 84) = ( M(42, 84) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 85)
      temp = temp + M(42, 39) * M(39, 85)
      M(42, 85) = ( M(42, 85) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 86)
      temp = temp + M(42, 39) * M(39, 86)
      M(42, 86) = ( M(42, 86) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 87)
      temp = temp + M(42, 39) * M(39, 87)
      M(42, 87) = ( M(42, 87) - temp ) / M(42, 42)

C     Upper part.
      temp = M(43, 33) * M(33, 50)
      M(43, 50) = ( M(43, 50) - temp ) / M(43, 43)
C     Upper part.
      M(43, 52) = M(43, 52) / M(43, 43)
C     Upper part.
      M(43, 56) = M(43, 56) / M(43, 43)
C     Upper part.
      temp = M(43, 19) * M(19, 63)
      temp = temp + M(43, 24) * M(24, 63)
      temp = temp + M(43, 26) * M(26, 63)
      temp = temp + M(43, 33) * M(33, 63)
      M(43, 63) = ( M(43, 63) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 19) * M(19, 78)
      temp = temp + M(43, 24) * M(24, 78)
      temp = temp + M(43, 26) * M(26, 78)
      temp = temp + M(43, 33) * M(33, 78)
      M(43, 78) = ( M(43, 78) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 19) * M(19, 85)
      temp = temp + M(43, 24) * M(24, 85)
      temp = temp + M(43, 26) * M(26, 85)
      temp = temp + M(43, 33) * M(33, 85)
      M(43, 85) = ( M(43, 85) - temp ) / M(43, 43)
C     Upper part.
      M(43, 86) = M(43, 86) / M(43, 43)

C     Upper part.
      temp = M(44, 18) * M(18, 63)
      M(44, 63) = ( M(44, 63) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 18) * M(18, 78)
      M(44, 78) = ( M(44, 78) - temp ) / M(44, 44)
C     Upper part.
      M(44, 82) = M(44, 82) / M(44, 44)
C     Upper part.
      M(44, 83) = M(44, 83) / M(44, 44)
C     Upper part.
      M(44, 84) = M(44, 84) / M(44, 44)
C     Upper part.
      M(44, 85) = M(44, 85) / M(44, 44)
C     Upper part.
      M(44, 86) = M(44, 86) / M(44, 44)
C     Upper part.
      temp = M(44, 18) * M(18, 87)
      M(44, 87) = ( M(44, 87) - temp ) / M(44, 44)

C     Upper part.
      M(45, 46) = M(45, 46) / M(45, 45)
C     Upper part.
      M(45, 60) = M(45, 60) / M(45, 45)
C     Upper part.
      M(45, 76) = M(45, 76) / M(45, 45)
C     Upper part.
      temp = M(45, 4) * M(4, 78)
      M(45, 78) = ( M(45, 78) - temp ) / M(45, 45)
C     Upper part.
      M(45, 82) = M(45, 82) / M(45, 45)

C     Lower part.
      temp = M(72, 45) * M(45, 46)
      M(72, 46) = M(72, 46) - temp
C     Lower part.
      temp = M(78, 45) * M(45, 46)
      M(78, 46) = M(78, 46) - temp
C     Lower part.
      temp = M(80, 45) * M(45, 46)
      M(80, 46) = M(80, 46) - temp
C     Lower part.
      temp = M(83, 45) * M(45, 46)
      M(83, 46) = M(83, 46) - temp
C     Lower part.
      temp = M(86, 45) * M(45, 46)
      M(86, 46) = M(86, 46) - temp
C     Upper part.
      M(46, 63) = M(46, 63) / M(46, 46)
C     Upper part.
      M(46, 68) = M(46, 68) / M(46, 46)
C     Upper part.
      M(46, 78) = M(46, 78) / M(46, 46)
C     Upper part.
      M(46, 85) = M(46, 85) / M(46, 46)
C     Upper part.
      M(46, 87) = M(46, 87) / M(46, 46)

C     Upper part.
      temp = M(47, 46) * M(46, 63)
      M(47, 63) = ( M(47, 63) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 68)
      M(47, 68) = ( M(47, 68) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 78)
      M(47, 78) = ( M(47, 78) - temp ) / M(47, 47)
C     Upper part.
      M(47, 83) = M(47, 83) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 85)
      M(47, 85) = ( M(47, 85) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 87)
      M(47, 87) = ( M(47, 87) - temp ) / M(47, 47)

C     Upper part.
      temp = M(48, 33) * M(33, 50)
      M(48, 50) = ( M(48, 50) - temp ) / M(48, 48)
C     Upper part.
      M(48, 52) = M(48, 52) / M(48, 48)
C     Upper part.
      M(48, 60) = M(48, 60) / M(48, 48)
C     Upper part.
      M(48, 62) = M(48, 62) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 63)
      temp = temp + M(48, 25) * M(25, 63)
      temp = temp + M(48, 26) * M(26, 63)
      temp = temp + M(48, 33) * M(33, 63)
      temp = temp + M(48, 46) * M(46, 63)
      M(48, 63) = ( M(48, 63) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 68)
      M(48, 68) = ( M(48, 68) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 11) * M(11, 78)
      temp = temp + M(48, 19) * M(19, 78)
      temp = temp + M(48, 25) * M(25, 78)
      temp = temp + M(48, 26) * M(26, 78)
      temp = temp + M(48, 33) * M(33, 78)
      temp = temp + M(48, 46) * M(46, 78)
      M(48, 78) = ( M(48, 78) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 85)
      temp = temp + M(48, 25) * M(25, 85)
      temp = temp + M(48, 26) * M(26, 85)
      temp = temp + M(48, 33) * M(33, 85)
      temp = temp + M(48, 46) * M(46, 85)
      M(48, 85) = ( M(48, 85) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 46) * M(46, 87)
      M(48, 87) = ( M(48, 87) - temp ) / M(48, 48)

C     Upper part.
      temp = M(49, 31) * M(31, 63)
      temp = temp + M(49, 37) * M(37, 63)
      M(49, 63) = ( M(49, 63) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 31) * M(31, 78)
      temp = temp + M(49, 37) * M(37, 78)
      M(49, 78) = ( M(49, 78) - temp ) / M(49, 49)
C     Upper part.
      M(49, 82) = M(49, 82) / M(49, 49)
C     Upper part.
      M(49, 83) = M(49, 83) / M(49, 49)
C     Upper part.
      M(49, 84) = M(49, 84) / M(49, 49)
C     Upper part.
      temp = M(49, 37) * M(37, 85)
      M(49, 85) = ( M(49, 85) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 37) * M(37, 86)
      M(49, 86) = ( M(49, 86) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 31) * M(31, 87)
      temp = temp + M(49, 37) * M(37, 87)
      M(49, 87) = ( M(49, 87) - temp ) / M(49, 49)

C     Lower part.
      temp = M(50, 33) * M(33, 50)
      M(50, 50) = M(50, 50) - temp
C     Lower part.
      temp = M(51, 33) * M(33, 50)
      M(51, 50) = M(51, 50) - temp
C     Lower part.
      temp = M(52, 33) * M(33, 50)
      M(52, 50) = M(52, 50) - temp
C     Lower part.
      temp = M(57, 33) * M(33, 50)
      M(57, 50) = M(57, 50) - temp
C     Lower part.
      temp = M(58, 33) * M(33, 50)
      M(58, 50) = M(58, 50) - temp
C     Lower part.
      temp = M(60, 33) * M(33, 50)
      M(60, 50) = M(60, 50) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 50)
      M(62, 50) = M(62, 50) - temp
C     Lower part.
      temp = M(63, 33) * M(33, 50)
      M(63, 50) = M(63, 50) - temp
C     Lower part.
      temp = M(64, 33) * M(33, 50)
      M(64, 50) = M(64, 50) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 50)
      M(76, 50) = M(76, 50) - temp
C     Lower part.
      temp = M(78, 33) * M(33, 50)
      temp = temp + M(78, 43) * M(43, 50)
      M(78, 50) = M(78, 50) - temp
C     Lower part.
      temp = M(80, 33) * M(33, 50)
      M(80, 50) = M(80, 50) - temp
C     Lower part.
      temp = M(81, 33) * M(33, 50)
      M(81, 50) = M(81, 50) - temp
C     Lower part.
      temp = M(82, 33) * M(33, 50)
      M(82, 50) = M(82, 50) - temp
C     Lower part.
      temp = M(83, 33) * M(33, 50)
      M(83, 50) = M(83, 50) - temp
C     Lower part.
      temp = M(85, 33) * M(33, 50)
      M(85, 50) = M(85, 50) - temp
C     Lower part.
      temp = M(86, 33) * M(33, 50)
      temp = temp + M(86, 43) * M(43, 50)
      M(86, 50) = M(86, 50) - temp
C     Upper part.
      M(50, 60) = M(50, 60) / M(50, 50)
C     Upper part.
      temp = M(50, 7) * M(7, 63)
      temp = temp + M(50, 19) * M(19, 63)
      temp = temp + M(50, 33) * M(33, 63)
      M(50, 63) = ( M(50, 63) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 19) * M(19, 78)
      temp = temp + M(50, 33) * M(33, 78)
      M(50, 78) = ( M(50, 78) - temp ) / M(50, 50)
C     Upper part.
      M(50, 84) = M(50, 84) / M(50, 50)
C     Upper part.
      temp = M(50, 19) * M(19, 85)
      temp = temp + M(50, 33) * M(33, 85)
      M(50, 85) = ( M(50, 85) - temp ) / M(50, 50)
C     Upper part.
      M(50, 87) = M(50, 87) / M(50, 50)

C     Upper part.
      temp = M(51, 50) * M(50, 60)
      M(51, 60) = ( M(51, 60) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 19) * M(19, 63)
      temp = temp + M(51, 33) * M(33, 63)
      temp = temp + M(51, 50) * M(50, 63)
      M(51, 63) = ( M(51, 63) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 19) * M(19, 78)
      temp = temp + M(51, 33) * M(33, 78)
      temp = temp + M(51, 50) * M(50, 78)
      M(51, 78) = ( M(51, 78) - temp ) / M(51, 51)
C     Upper part.
      M(51, 82) = M(51, 82) / M(51, 51)
C     Upper part.
      M(51, 83) = M(51, 83) / M(51, 51)
C     Upper part.
      temp = M(51, 50) * M(50, 84)
      M(51, 84) = ( M(51, 84) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 19) * M(19, 85)
      temp = temp + M(51, 33) * M(33, 85)
      temp = temp + M(51, 50) * M(50, 85)
      M(51, 85) = ( M(51, 85) - temp ) / M(51, 51)
C     Upper part.
      M(51, 86) = M(51, 86) / M(51, 51)
C     Upper part.
      temp = M(51, 50) * M(50, 87)
      M(51, 87) = ( M(51, 87) - temp ) / M(51, 51)

C     Lower part.
      temp = M(78, 30) * M(30, 52)
      temp = temp + M(78, 34) * M(34, 52)
      temp = temp + M(78, 43) * M(43, 52)
      M(78, 52) = M(78, 52) - temp
C     Lower part.
      temp = M(79, 30) * M(30, 52)
      M(79, 52) = M(79, 52) - temp
C     Lower part.
      temp = M(82, 34) * M(34, 52)
      M(82, 52) = M(82, 52) - temp
C     Lower part.
      temp = M(86, 43) * M(43, 52)
      M(86, 52) = M(86, 52) - temp
C     Upper part.
      temp = M(52, 50) * M(50, 60)
      temp = temp + M(52, 51) * M(51, 60)
      M(52, 60) = ( M(52, 60) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 19) * M(19, 63)
      temp = temp + M(52, 26) * M(26, 63)
      temp = temp + M(52, 33) * M(33, 63)
      temp = temp + M(52, 50) * M(50, 63)
      temp = temp + M(52, 51) * M(51, 63)
      M(52, 63) = ( M(52, 63) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 19) * M(19, 78)
      temp = temp + M(52, 26) * M(26, 78)
      temp = temp + M(52, 33) * M(33, 78)
      temp = temp + M(52, 50) * M(50, 78)
      temp = temp + M(52, 51) * M(51, 78)
      M(52, 78) = ( M(52, 78) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 51) * M(51, 82)
      M(52, 82) = ( M(52, 82) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 51) * M(51, 83)
      M(52, 83) = ( M(52, 83) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 50) * M(50, 84)
      temp = temp + M(52, 51) * M(51, 84)
      M(52, 84) = ( M(52, 84) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 19) * M(19, 85)
      temp = temp + M(52, 26) * M(26, 85)
      temp = temp + M(52, 33) * M(33, 85)
      temp = temp + M(52, 50) * M(50, 85)
      temp = temp + M(52, 51) * M(51, 85)
      M(52, 85) = ( M(52, 85) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 51) * M(51, 86)
      M(52, 86) = ( M(52, 86) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 50) * M(50, 87)
      temp = temp + M(52, 51) * M(51, 87)
      M(52, 87) = ( M(52, 87) - temp ) / M(52, 52)

C     Upper part.
      temp = M(53, 52) * M(52, 60)
      M(53, 60) = ( M(53, 60) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 63)
      M(53, 63) = ( M(53, 63) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 78)
      M(53, 78) = ( M(53, 78) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 82)
      M(53, 82) = ( M(53, 82) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 83)
      M(53, 83) = ( M(53, 83) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 84)
      M(53, 84) = ( M(53, 84) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 85)
      M(53, 85) = ( M(53, 85) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 86)
      M(53, 86) = ( M(53, 86) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 52) * M(52, 87)
      M(53, 87) = ( M(53, 87) - temp ) / M(53, 53)

C     Upper part.
      temp = M(54, 24) * M(24, 63)
      M(54, 63) = ( M(54, 63) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 24) * M(24, 78)
      M(54, 78) = ( M(54, 78) - temp ) / M(54, 54)
C     Upper part.
      M(54, 82) = M(54, 82) / M(54, 54)
C     Upper part.
      M(54, 83) = M(54, 83) / M(54, 54)
C     Upper part.
      M(54, 84) = M(54, 84) / M(54, 54)
C     Upper part.
      temp = M(54, 24) * M(24, 85)
      M(54, 85) = ( M(54, 85) - temp ) / M(54, 54)
C     Upper part.
      M(54, 86) = M(54, 86) / M(54, 54)

C     Upper part.
      temp = M(55, 26) * M(26, 63)
      M(55, 63) = ( M(55, 63) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 26) * M(26, 78)
      M(55, 78) = ( M(55, 78) - temp ) / M(55, 55)
C     Upper part.
      M(55, 82) = M(55, 82) / M(55, 55)
C     Upper part.
      M(55, 83) = M(55, 83) / M(55, 55)
C     Upper part.
      M(55, 84) = M(55, 84) / M(55, 55)
C     Upper part.
      temp = M(55, 26) * M(26, 85)
      M(55, 85) = ( M(55, 85) - temp ) / M(55, 55)
C     Upper part.
      M(55, 86) = M(55, 86) / M(55, 55)

C     Lower part.
      temp = M(78, 30) * M(30, 56)
      temp = temp + M(78, 34) * M(34, 56)
      temp = temp + M(78, 43) * M(43, 56)
      M(78, 56) = M(78, 56) - temp
C     Lower part.
      temp = M(79, 30) * M(30, 56)
      M(79, 56) = M(79, 56) - temp
C     Lower part.
      temp = M(82, 34) * M(34, 56)
      M(82, 56) = M(82, 56) - temp
C     Lower part.
      temp = M(86, 43) * M(43, 56)
      M(86, 56) = M(86, 56) - temp
C     Upper part.
      temp = M(56, 51) * M(51, 60)
      M(56, 60) = ( M(56, 60) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 63)
      temp = temp + M(56, 55) * M(55, 63)
      M(56, 63) = ( M(56, 63) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 78)
      temp = temp + M(56, 55) * M(55, 78)
      M(56, 78) = ( M(56, 78) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 82)
      temp = temp + M(56, 55) * M(55, 82)
      M(56, 82) = ( M(56, 82) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 83)
      temp = temp + M(56, 55) * M(55, 83)
      M(56, 83) = ( M(56, 83) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 84)
      temp = temp + M(56, 55) * M(55, 84)
      M(56, 84) = ( M(56, 84) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 85)
      temp = temp + M(56, 55) * M(55, 85)
      M(56, 85) = ( M(56, 85) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 86)
      temp = temp + M(56, 55) * M(55, 86)
      M(56, 86) = ( M(56, 86) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 87)
      M(56, 87) = ( M(56, 87) - temp ) / M(56, 56)

C     Upper part.
      M(57, 58) = M(57, 58) / M(57, 57)
C     Upper part.
      temp = M(57, 50) * M(50, 60)
      temp = temp + M(57, 52) * M(52, 60)
      temp = temp + M(57, 56) * M(56, 60)
      M(57, 60) = ( M(57, 60) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 19) * M(19, 63)
      temp = temp + M(57, 24) * M(24, 63)
      temp = temp + M(57, 25) * M(25, 63)
      temp = temp + M(57, 26) * M(26, 63)
      temp = temp + M(57, 33) * M(33, 63)
      temp = temp + M(57, 50) * M(50, 63)
      temp = temp + M(57, 52) * M(52, 63)
      temp = temp + M(57, 56) * M(56, 63)
      M(57, 63) = ( M(57, 63) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 19) * M(19, 78)
      temp = temp + M(57, 24) * M(24, 78)
      temp = temp + M(57, 25) * M(25, 78)
      temp = temp + M(57, 26) * M(26, 78)
      temp = temp + M(57, 33) * M(33, 78)
      temp = temp + M(57, 50) * M(50, 78)
      temp = temp + M(57, 52) * M(52, 78)
      temp = temp + M(57, 56) * M(56, 78)
      M(57, 78) = ( M(57, 78) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 82)
      temp = temp + M(57, 56) * M(56, 82)
      M(57, 82) = ( M(57, 82) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 83)
      temp = temp + M(57, 56) * M(56, 83)
      M(57, 83) = ( M(57, 83) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 50) * M(50, 84)
      temp = temp + M(57, 52) * M(52, 84)
      temp = temp + M(57, 56) * M(56, 84)
      M(57, 84) = ( M(57, 84) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 19) * M(19, 85)
      temp = temp + M(57, 24) * M(24, 85)
      temp = temp + M(57, 25) * M(25, 85)
      temp = temp + M(57, 26) * M(26, 85)
      temp = temp + M(57, 33) * M(33, 85)
      temp = temp + M(57, 50) * M(50, 85)
      temp = temp + M(57, 52) * M(52, 85)
      temp = temp + M(57, 56) * M(56, 85)
      M(57, 85) = ( M(57, 85) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 86)
      temp = temp + M(57, 56) * M(56, 86)
      M(57, 86) = ( M(57, 86) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 50) * M(50, 87)
      temp = temp + M(57, 52) * M(52, 87)
      temp = temp + M(57, 56) * M(56, 87)
      M(57, 87) = ( M(57, 87) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(70, 57) * M(57, 58)
      M(70, 58) = M(70, 58) - temp
C     Lower part.
      temp = M(74, 57) * M(57, 58)
      M(74, 58) = M(74, 58) - temp
C     Lower part.
      temp = M(75, 57) * M(57, 58)
      M(75, 58) = M(75, 58) - temp
C     Lower part.
      temp = M(77, 57) * M(57, 58)
      M(77, 58) = M(77, 58) - temp
C     Lower part.
      temp = M(80, 57) * M(57, 58)
      M(80, 58) = M(80, 58) - temp
C     Lower part.
      temp = M(82, 57) * M(57, 58)
      M(82, 58) = M(82, 58) - temp
C     Lower part.
      temp = M(83, 57) * M(57, 58)
      M(83, 58) = M(83, 58) - temp
C     Lower part.
      temp = M(84, 57) * M(57, 58)
      M(84, 58) = M(84, 58) - temp
C     Lower part.
      temp = M(85, 57) * M(57, 58)
      M(85, 58) = M(85, 58) - temp
C     Lower part.
      temp = M(86, 57) * M(57, 58)
      M(86, 58) = M(86, 58) - temp
C     Lower part.
      temp = M(87, 57) * M(57, 58)
      M(87, 58) = M(87, 58) - temp
C     Upper part.
      temp = M(58, 50) * M(50, 60)
      temp = temp + M(58, 52) * M(52, 60)
      temp = temp + M(58, 56) * M(56, 60)
      temp = temp + M(58, 57) * M(57, 60)
      M(58, 60) = ( M(58, 60) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 63)
      temp = temp + M(58, 24) * M(24, 63)
      temp = temp + M(58, 25) * M(25, 63)
      temp = temp + M(58, 26) * M(26, 63)
      temp = temp + M(58, 33) * M(33, 63)
      temp = temp + M(58, 50) * M(50, 63)
      temp = temp + M(58, 52) * M(52, 63)
      temp = temp + M(58, 56) * M(56, 63)
      temp = temp + M(58, 57) * M(57, 63)
      M(58, 63) = ( M(58, 63) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 78)
      temp = temp + M(58, 24) * M(24, 78)
      temp = temp + M(58, 25) * M(25, 78)
      temp = temp + M(58, 26) * M(26, 78)
      temp = temp + M(58, 33) * M(33, 78)
      temp = temp + M(58, 50) * M(50, 78)
      temp = temp + M(58, 52) * M(52, 78)
      temp = temp + M(58, 56) * M(56, 78)
      temp = temp + M(58, 57) * M(57, 78)
      M(58, 78) = ( M(58, 78) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 82)
      temp = temp + M(58, 56) * M(56, 82)
      temp = temp + M(58, 57) * M(57, 82)
      M(58, 82) = ( M(58, 82) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 83)
      temp = temp + M(58, 56) * M(56, 83)
      temp = temp + M(58, 57) * M(57, 83)
      M(58, 83) = ( M(58, 83) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 50) * M(50, 84)
      temp = temp + M(58, 52) * M(52, 84)
      temp = temp + M(58, 56) * M(56, 84)
      temp = temp + M(58, 57) * M(57, 84)
      M(58, 84) = ( M(58, 84) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 85)
      temp = temp + M(58, 24) * M(24, 85)
      temp = temp + M(58, 25) * M(25, 85)
      temp = temp + M(58, 26) * M(26, 85)
      temp = temp + M(58, 33) * M(33, 85)
      temp = temp + M(58, 50) * M(50, 85)
      temp = temp + M(58, 52) * M(52, 85)
      temp = temp + M(58, 56) * M(56, 85)
      temp = temp + M(58, 57) * M(57, 85)
      M(58, 85) = ( M(58, 85) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 86)
      temp = temp + M(58, 56) * M(56, 86)
      temp = temp + M(58, 57) * M(57, 86)
      M(58, 86) = ( M(58, 86) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 50) * M(50, 87)
      temp = temp + M(58, 52) * M(52, 87)
      temp = temp + M(58, 56) * M(56, 87)
      temp = temp + M(58, 57) * M(57, 87)
      M(58, 87) = ( M(58, 87) - temp ) / M(58, 58)

C     Upper part.
      temp = M(59, 56) * M(56, 60)
      M(59, 60) = ( M(59, 60) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 63)
      M(59, 63) = ( M(59, 63) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 78)
      M(59, 78) = ( M(59, 78) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 82)
      M(59, 82) = ( M(59, 82) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 83)
      M(59, 83) = ( M(59, 83) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 84)
      M(59, 84) = ( M(59, 84) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 85)
      M(59, 85) = ( M(59, 85) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 86)
      M(59, 86) = ( M(59, 86) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 87)
      M(59, 87) = ( M(59, 87) - temp ) / M(59, 59)

C     Lower part.
      temp = M(60, 50) * M(50, 60)
      temp = temp + M(60, 51) * M(51, 60)
      M(60, 60) = M(60, 60) - temp
C     Lower part.
      temp = M(62, 50) * M(50, 60)
      M(62, 60) = M(62, 60) - temp
C     Lower part.
      temp = M(63, 50) * M(50, 60)
      temp = temp + M(63, 52) * M(52, 60)
      temp = temp + M(63, 56) * M(56, 60)
      M(63, 60) = M(63, 60) - temp
C     Lower part.
      temp = M(64, 50) * M(50, 60)
      temp = temp + M(64, 52) * M(52, 60)
      temp = temp + M(64, 56) * M(56, 60)
      M(64, 60) = M(64, 60) - temp
C     Lower part.
      temp = M(69, 51) * M(51, 60)
      temp = temp + M(69, 53) * M(53, 60)
      temp = temp + M(69, 59) * M(59, 60)
      M(69, 60) = M(69, 60) - temp
C     Lower part.
      temp = M(70, 51) * M(51, 60)
      temp = temp + M(70, 52) * M(52, 60)
      temp = temp + M(70, 53) * M(53, 60)
      temp = temp + M(70, 56) * M(56, 60)
      temp = temp + M(70, 57) * M(57, 60)
      temp = temp + M(70, 58) * M(58, 60)
      temp = temp + M(70, 59) * M(59, 60)
      M(70, 60) = M(70, 60) - temp
C     Lower part.
      temp = M(72, 45) * M(45, 60)
      M(72, 60) = M(72, 60) - temp
C     Lower part.
      temp = M(74, 51) * M(51, 60)
      temp = temp + M(74, 57) * M(57, 60)
      temp = temp + M(74, 58) * M(58, 60)
      M(74, 60) = M(74, 60) - temp
C     Lower part.
      temp = M(75, 52) * M(52, 60)
      temp = temp + M(75, 53) * M(53, 60)
      temp = temp + M(75, 56) * M(56, 60)
      temp = temp + M(75, 57) * M(57, 60)
      temp = temp + M(75, 58) * M(58, 60)
      temp = temp + M(75, 59) * M(59, 60)
      M(75, 60) = M(75, 60) - temp
C     Lower part.
      temp = M(76, 50) * M(50, 60)
      temp = temp + M(76, 52) * M(52, 60)
      temp = temp + M(76, 56) * M(56, 60)
      M(76, 60) = M(76, 60) - temp
C     Lower part.
      temp = M(77, 50) * M(50, 60)
      temp = temp + M(77, 52) * M(52, 60)
      temp = temp + M(77, 53) * M(53, 60)
      temp = temp + M(77, 56) * M(56, 60)
      temp = temp + M(77, 57) * M(57, 60)
      temp = temp + M(77, 58) * M(58, 60)
      temp = temp + M(77, 59) * M(59, 60)
      M(77, 60) = M(77, 60) - temp
C     Lower part.
      temp = M(78, 45) * M(45, 60)
      temp = temp + M(78, 50) * M(50, 60)
      temp = temp + M(78, 52) * M(52, 60)
      temp = temp + M(78, 56) * M(56, 60)
      M(78, 60) = M(78, 60) - temp
C     Lower part.
      temp = M(79, 52) * M(52, 60)
      temp = temp + M(79, 56) * M(56, 60)
      M(79, 60) = M(79, 60) - temp
C     Lower part.
      temp = M(80, 45) * M(45, 60)
      temp = temp + M(80, 50) * M(50, 60)
      temp = temp + M(80, 51) * M(51, 60)
      temp = temp + M(80, 52) * M(52, 60)
      temp = temp + M(80, 53) * M(53, 60)
      temp = temp + M(80, 56) * M(56, 60)
      temp = temp + M(80, 57) * M(57, 60)
      temp = temp + M(80, 58) * M(58, 60)
      temp = temp + M(80, 59) * M(59, 60)
      M(80, 60) = M(80, 60) - temp
C     Lower part.
      temp = M(81, 50) * M(50, 60)
      M(81, 60) = M(81, 60) - temp
C     Lower part.
      temp = M(82, 50) * M(50, 60)
      temp = temp + M(82, 51) * M(51, 60)
      temp = temp + M(82, 52) * M(52, 60)
      temp = temp + M(82, 53) * M(53, 60)
      temp = temp + M(82, 56) * M(56, 60)
      temp = temp + M(82, 57) * M(57, 60)
      temp = temp + M(82, 58) * M(58, 60)
      temp = temp + M(82, 59) * M(59, 60)
      M(82, 60) = M(82, 60) - temp
C     Lower part.
      temp = M(83, 45) * M(45, 60)
      temp = temp + M(83, 50) * M(50, 60)
      temp = temp + M(83, 51) * M(51, 60)
      temp = temp + M(83, 53) * M(53, 60)
      temp = temp + M(83, 57) * M(57, 60)
      temp = temp + M(83, 58) * M(58, 60)
      temp = temp + M(83, 59) * M(59, 60)
      M(83, 60) = M(83, 60) - temp
C     Lower part.
      temp = M(84, 50) * M(50, 60)
      temp = temp + M(84, 51) * M(51, 60)
      temp = temp + M(84, 53) * M(53, 60)
      temp = temp + M(84, 57) * M(57, 60)
      temp = temp + M(84, 58) * M(58, 60)
      temp = temp + M(84, 59) * M(59, 60)
      M(84, 60) = M(84, 60) - temp
C     Lower part.
      temp = M(85, 50) * M(50, 60)
      temp = temp + M(85, 51) * M(51, 60)
      temp = temp + M(85, 52) * M(52, 60)
      temp = temp + M(85, 53) * M(53, 60)
      temp = temp + M(85, 56) * M(56, 60)
      temp = temp + M(85, 57) * M(57, 60)
      temp = temp + M(85, 58) * M(58, 60)
      temp = temp + M(85, 59) * M(59, 60)
      M(85, 60) = M(85, 60) - temp
C     Lower part.
      temp = M(86, 45) * M(45, 60)
      temp = temp + M(86, 50) * M(50, 60)
      temp = temp + M(86, 51) * M(51, 60)
      temp = temp + M(86, 52) * M(52, 60)
      temp = temp + M(86, 53) * M(53, 60)
      temp = temp + M(86, 56) * M(56, 60)
      temp = temp + M(86, 57) * M(57, 60)
      temp = temp + M(86, 58) * M(58, 60)
      temp = temp + M(86, 59) * M(59, 60)
      M(86, 60) = M(86, 60) - temp
C     Lower part.
      temp = M(87, 50) * M(50, 60)
      temp = temp + M(87, 51) * M(51, 60)
      temp = temp + M(87, 53) * M(53, 60)
      temp = temp + M(87, 57) * M(57, 60)
      temp = temp + M(87, 58) * M(58, 60)
      temp = temp + M(87, 59) * M(59, 60)
      M(87, 60) = M(87, 60) - temp
C     Upper part.
      temp = M(60, 19) * M(19, 63)
      temp = temp + M(60, 26) * M(26, 63)
      temp = temp + M(60, 33) * M(33, 63)
      temp = temp + M(60, 50) * M(50, 63)
      temp = temp + M(60, 51) * M(51, 63)
      temp = temp + M(60, 55) * M(55, 63)
      M(60, 63) = ( M(60, 63) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 19) * M(19, 78)
      temp = temp + M(60, 26) * M(26, 78)
      temp = temp + M(60, 33) * M(33, 78)
      temp = temp + M(60, 50) * M(50, 78)
      temp = temp + M(60, 51) * M(51, 78)
      temp = temp + M(60, 55) * M(55, 78)
      M(60, 78) = ( M(60, 78) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 51) * M(51, 82)
      temp = temp + M(60, 55) * M(55, 82)
      M(60, 82) = ( M(60, 82) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 51) * M(51, 83)
      temp = temp + M(60, 55) * M(55, 83)
      M(60, 83) = ( M(60, 83) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 50) * M(50, 84)
      temp = temp + M(60, 51) * M(51, 84)
      temp = temp + M(60, 55) * M(55, 84)
      M(60, 84) = ( M(60, 84) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 19) * M(19, 85)
      temp = temp + M(60, 26) * M(26, 85)
      temp = temp + M(60, 33) * M(33, 85)
      temp = temp + M(60, 50) * M(50, 85)
      temp = temp + M(60, 51) * M(51, 85)
      temp = temp + M(60, 55) * M(55, 85)
      M(60, 85) = ( M(60, 85) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 51) * M(51, 86)
      temp = temp + M(60, 55) * M(55, 86)
      M(60, 86) = ( M(60, 86) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 50) * M(50, 87)
      temp = temp + M(60, 51) * M(51, 87)
      M(60, 87) = ( M(60, 87) - temp ) / M(60, 60)

C     Upper part.
      temp = M(61, 3) * M(3, 78)
      M(61, 78) = ( M(61, 78) - temp ) / M(61, 61)
C     Upper part.
      M(61, 82) = M(61, 82) / M(61, 61)
C     Upper part.
      M(61, 83) = M(61, 83) / M(61, 61)
C     Upper part.
      M(61, 84) = M(61, 84) / M(61, 61)
C     Upper part.
      M(61, 85) = M(61, 85) / M(61, 61)
C     Upper part.
      M(61, 86) = M(61, 86) / M(61, 61)

C     Lower part.
      temp = M(75, 16) * M(16, 62)
      M(75, 62) = M(75, 62) - temp
C     Lower part.
      temp = M(77, 16) * M(16, 62)
      M(77, 62) = M(77, 62) - temp
C     Lower part.
      temp = M(78, 16) * M(16, 62)
      temp = temp + M(78, 35) * M(35, 62)
      M(78, 62) = M(78, 62) - temp
C     Lower part.
      temp = M(80, 35) * M(35, 62)
      M(80, 62) = M(80, 62) - temp
C     Lower part.
      temp = M(81, 35) * M(35, 62)
      M(81, 62) = M(81, 62) - temp
C     Lower part.
      temp = M(82, 35) * M(35, 62)
      M(82, 62) = M(82, 62) - temp
C     Lower part.
      temp = M(83, 35) * M(35, 62)
      M(83, 62) = M(83, 62) - temp
C     Lower part.
      temp = M(86, 16) * M(16, 62)
      temp = temp + M(86, 35) * M(35, 62)
      M(86, 62) = M(86, 62) - temp
C     Upper part.
      temp = M(62, 33) * M(33, 63)
      temp = temp + M(62, 39) * M(39, 63)
      temp = temp + M(62, 44) * M(44, 63)
      temp = temp + M(62, 50) * M(50, 63)
      temp = temp + M(62, 60) * M(60, 63)
      M(62, 63) = ( M(62, 63) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 33) * M(33, 78)
      temp = temp + M(62, 39) * M(39, 78)
      temp = temp + M(62, 44) * M(44, 78)
      temp = temp + M(62, 50) * M(50, 78)
      temp = temp + M(62, 60) * M(60, 78)
      M(62, 78) = ( M(62, 78) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 82)
      temp = temp + M(62, 44) * M(44, 82)
      temp = temp + M(62, 60) * M(60, 82)
      M(62, 82) = ( M(62, 82) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 83)
      temp = temp + M(62, 44) * M(44, 83)
      temp = temp + M(62, 60) * M(60, 83)
      M(62, 83) = ( M(62, 83) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 84)
      temp = temp + M(62, 44) * M(44, 84)
      temp = temp + M(62, 50) * M(50, 84)
      temp = temp + M(62, 60) * M(60, 84)
      M(62, 84) = ( M(62, 84) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 33) * M(33, 85)
      temp = temp + M(62, 39) * M(39, 85)
      temp = temp + M(62, 44) * M(44, 85)
      temp = temp + M(62, 50) * M(50, 85)
      temp = temp + M(62, 60) * M(60, 85)
      M(62, 85) = ( M(62, 85) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 86)
      temp = temp + M(62, 44) * M(44, 86)
      temp = temp + M(62, 60) * M(60, 86)
      M(62, 86) = ( M(62, 86) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 87)
      temp = temp + M(62, 44) * M(44, 87)
      temp = temp + M(62, 50) * M(50, 87)
      temp = temp + M(62, 60) * M(60, 87)
      M(62, 87) = ( M(62, 87) - temp ) / M(62, 62)

C     Lower part.
      temp = M(63, 18) * M(18, 63)
      temp = temp + M(63, 19) * M(19, 63)
      temp = temp + M(63, 24) * M(24, 63)
      temp = temp + M(63, 25) * M(25, 63)
      temp = temp + M(63, 26) * M(26, 63)
      temp = temp + M(63, 29) * M(29, 63)
      temp = temp + M(63, 31) * M(31, 63)
      temp = temp + M(63, 33) * M(33, 63)
      temp = temp + M(63, 37) * M(37, 63)
      temp = temp + M(63, 46) * M(46, 63)
      temp = temp + M(63, 50) * M(50, 63)
      temp = temp + M(63, 52) * M(52, 63)
      temp = temp + M(63, 56) * M(56, 63)
      temp = temp + M(63, 60) * M(60, 63)
      temp = temp + M(63, 62) * M(62, 63)
      M(63, 63) = M(63, 63) - temp
C     Lower part.
      temp = M(64, 19) * M(19, 63)
      temp = temp + M(64, 24) * M(24, 63)
      temp = temp + M(64, 25) * M(25, 63)
      temp = temp + M(64, 26) * M(26, 63)
      temp = temp + M(64, 33) * M(33, 63)
      temp = temp + M(64, 46) * M(46, 63)
      temp = temp + M(64, 50) * M(50, 63)
      temp = temp + M(64, 52) * M(52, 63)
      temp = temp + M(64, 56) * M(56, 63)
      temp = temp + M(64, 60) * M(60, 63)
      temp = temp + M(64, 62) * M(62, 63)
      M(64, 63) = M(64, 63) - temp
C     Lower part.
      temp = M(65, 39) * M(39, 63)
      temp = temp + M(65, 44) * M(44, 63)
      temp = temp + M(65, 49) * M(49, 63)
      temp = temp + M(65, 62) * M(62, 63)
      M(65, 63) = M(65, 63) - temp
C     Lower part.
      temp = M(67, 25) * M(25, 63)
      M(67, 63) = M(67, 63) - temp
C     Lower part.
      temp = M(68, 46) * M(46, 63)
      temp = temp + M(68, 60) * M(60, 63)
      temp = temp + M(68, 62) * M(62, 63)
      M(68, 63) = M(68, 63) - temp
C     Lower part.
      temp = M(69, 39) * M(39, 63)
      temp = temp + M(69, 44) * M(44, 63)
      temp = temp + M(69, 49) * M(49, 63)
      temp = temp + M(69, 51) * M(51, 63)
      temp = temp + M(69, 53) * M(53, 63)
      temp = temp + M(69, 54) * M(54, 63)
      temp = temp + M(69, 55) * M(55, 63)
      temp = temp + M(69, 59) * M(59, 63)
      temp = temp + M(69, 60) * M(60, 63)
      M(69, 63) = M(69, 63) - temp
C     Lower part.
      temp = M(70, 26) * M(26, 63)
      temp = temp + M(70, 51) * M(51, 63)
      temp = temp + M(70, 52) * M(52, 63)
      temp = temp + M(70, 53) * M(53, 63)
      temp = temp + M(70, 56) * M(56, 63)
      temp = temp + M(70, 57) * M(57, 63)
      temp = temp + M(70, 58) * M(58, 63)
      temp = temp + M(70, 59) * M(59, 63)
      temp = temp + M(70, 60) * M(60, 63)
      temp = temp + M(70, 62) * M(62, 63)
      M(70, 63) = M(70, 63) - temp
C     Lower part.
      temp = M(72, 39) * M(39, 63)
      temp = temp + M(72, 44) * M(44, 63)
      temp = temp + M(72, 46) * M(46, 63)
      temp = temp + M(72, 49) * M(49, 63)
      temp = temp + M(72, 60) * M(60, 63)
      temp = temp + M(72, 62) * M(62, 63)
      M(72, 63) = M(72, 63) - temp
C     Lower part.
      temp = M(73, 37) * M(37, 63)
      temp = temp + M(73, 60) * M(60, 63)
      temp = temp + M(73, 62) * M(62, 63)
      M(73, 63) = M(73, 63) - temp
C     Lower part.
      temp = M(74, 37) * M(37, 63)
      temp = temp + M(74, 39) * M(39, 63)
      temp = temp + M(74, 44) * M(44, 63)
      temp = temp + M(74, 46) * M(46, 63)
      temp = temp + M(74, 51) * M(51, 63)
      temp = temp + M(74, 54) * M(54, 63)
      temp = temp + M(74, 55) * M(55, 63)
      temp = temp + M(74, 57) * M(57, 63)
      temp = temp + M(74, 58) * M(58, 63)
      temp = temp + M(74, 60) * M(60, 63)
      M(74, 63) = M(74, 63) - temp
C     Lower part.
      temp = M(75, 24) * M(24, 63)
      temp = temp + M(75, 52) * M(52, 63)
      temp = temp + M(75, 53) * M(53, 63)
      temp = temp + M(75, 54) * M(54, 63)
      temp = temp + M(75, 56) * M(56, 63)
      temp = temp + M(75, 57) * M(57, 63)
      temp = temp + M(75, 58) * M(58, 63)
      temp = temp + M(75, 59) * M(59, 63)
      temp = temp + M(75, 60) * M(60, 63)
      temp = temp + M(75, 62) * M(62, 63)
      M(75, 63) = M(75, 63) - temp
C     Lower part.
      temp = M(76, 19) * M(19, 63)
      temp = temp + M(76, 24) * M(24, 63)
      temp = temp + M(76, 26) * M(26, 63)
      temp = temp + M(76, 33) * M(33, 63)
      temp = temp + M(76, 50) * M(50, 63)
      temp = temp + M(76, 52) * M(52, 63)
      temp = temp + M(76, 56) * M(56, 63)
      temp = temp + M(76, 60) * M(60, 63)
      M(76, 63) = M(76, 63) - temp
C     Lower part.
      temp = M(77, 24) * M(24, 63)
      temp = temp + M(77, 50) * M(50, 63)
      temp = temp + M(77, 52) * M(52, 63)
      temp = temp + M(77, 53) * M(53, 63)
      temp = temp + M(77, 54) * M(54, 63)
      temp = temp + M(77, 56) * M(56, 63)
      temp = temp + M(77, 57) * M(57, 63)
      temp = temp + M(77, 58) * M(58, 63)
      temp = temp + M(77, 59) * M(59, 63)
      temp = temp + M(77, 60) * M(60, 63)
      temp = temp + M(77, 62) * M(62, 63)
      M(77, 63) = M(77, 63) - temp
C     Lower part.
      temp = M(78, 7) * M(7, 63)
      temp = temp + M(78, 18) * M(18, 63)
      temp = temp + M(78, 19) * M(19, 63)
      temp = temp + M(78, 24) * M(24, 63)
      temp = temp + M(78, 25) * M(25, 63)
      temp = temp + M(78, 26) * M(26, 63)
      temp = temp + M(78, 29) * M(29, 63)
      temp = temp + M(78, 30) * M(30, 63)
      temp = temp + M(78, 31) * M(31, 63)
      temp = temp + M(78, 32) * M(32, 63)
      temp = temp + M(78, 33) * M(33, 63)
      temp = temp + M(78, 34) * M(34, 63)
      temp = temp + M(78, 35) * M(35, 63)
      temp = temp + M(78, 37) * M(37, 63)
      temp = temp + M(78, 43) * M(43, 63)
      temp = temp + M(78, 46) * M(46, 63)
      temp = temp + M(78, 47) * M(47, 63)
      temp = temp + M(78, 50) * M(50, 63)
      temp = temp + M(78, 52) * M(52, 63)
      temp = temp + M(78, 56) * M(56, 63)
      temp = temp + M(78, 60) * M(60, 63)
      temp = temp + M(78, 62) * M(62, 63)
      M(78, 63) = M(78, 63) - temp
C     Lower part.
      temp = M(79, 24) * M(24, 63)
      temp = temp + M(79, 26) * M(26, 63)
      temp = temp + M(79, 30) * M(30, 63)
      temp = temp + M(79, 52) * M(52, 63)
      temp = temp + M(79, 56) * M(56, 63)
      temp = temp + M(79, 60) * M(60, 63)
      M(79, 63) = M(79, 63) - temp
C     Lower part.
      temp = M(80, 19) * M(19, 63)
      temp = temp + M(80, 25) * M(25, 63)
      temp = temp + M(80, 26) * M(26, 63)
      temp = temp + M(80, 33) * M(33, 63)
      temp = temp + M(80, 35) * M(35, 63)
      temp = temp + M(80, 39) * M(39, 63)
      temp = temp + M(80, 44) * M(44, 63)
      temp = temp + M(80, 46) * M(46, 63)
      temp = temp + M(80, 47) * M(47, 63)
      temp = temp + M(80, 49) * M(49, 63)
      temp = temp + M(80, 50) * M(50, 63)
      temp = temp + M(80, 51) * M(51, 63)
      temp = temp + M(80, 52) * M(52, 63)
      temp = temp + M(80, 53) * M(53, 63)
      temp = temp + M(80, 54) * M(54, 63)
      temp = temp + M(80, 55) * M(55, 63)
      temp = temp + M(80, 56) * M(56, 63)
      temp = temp + M(80, 57) * M(57, 63)
      temp = temp + M(80, 58) * M(58, 63)
      temp = temp + M(80, 59) * M(59, 63)
      temp = temp + M(80, 60) * M(60, 63)
      temp = temp + M(80, 62) * M(62, 63)
      M(80, 63) = M(80, 63) - temp
C     Lower part.
      temp = M(81, 19) * M(19, 63)
      temp = temp + M(81, 33) * M(33, 63)
      temp = temp + M(81, 35) * M(35, 63)
      temp = temp + M(81, 37) * M(37, 63)
      temp = temp + M(81, 46) * M(46, 63)
      temp = temp + M(81, 47) * M(47, 63)
      temp = temp + M(81, 50) * M(50, 63)
      temp = temp + M(81, 60) * M(60, 63)
      temp = temp + M(81, 62) * M(62, 63)
      M(81, 63) = M(81, 63) - temp
C     Lower part.
      temp = M(82, 19) * M(19, 63)
      temp = temp + M(82, 33) * M(33, 63)
      temp = temp + M(82, 34) * M(34, 63)
      temp = temp + M(82, 35) * M(35, 63)
      temp = temp + M(82, 39) * M(39, 63)
      temp = temp + M(82, 44) * M(44, 63)
      temp = temp + M(82, 49) * M(49, 63)
      temp = temp + M(82, 50) * M(50, 63)
      temp = temp + M(82, 51) * M(51, 63)
      temp = temp + M(82, 52) * M(52, 63)
      temp = temp + M(82, 53) * M(53, 63)
      temp = temp + M(82, 54) * M(54, 63)
      temp = temp + M(82, 55) * M(55, 63)
      temp = temp + M(82, 56) * M(56, 63)
      temp = temp + M(82, 57) * M(57, 63)
      temp = temp + M(82, 58) * M(58, 63)
      temp = temp + M(82, 59) * M(59, 63)
      temp = temp + M(82, 60) * M(60, 63)
      temp = temp + M(82, 62) * M(62, 63)
      M(82, 63) = M(82, 63) - temp
C     Lower part.
      temp = M(83, 19) * M(19, 63)
      temp = temp + M(83, 33) * M(33, 63)
      temp = temp + M(83, 35) * M(35, 63)
      temp = temp + M(83, 39) * M(39, 63)
      temp = temp + M(83, 44) * M(44, 63)
      temp = temp + M(83, 46) * M(46, 63)
      temp = temp + M(83, 47) * M(47, 63)
      temp = temp + M(83, 49) * M(49, 63)
      temp = temp + M(83, 50) * M(50, 63)
      temp = temp + M(83, 51) * M(51, 63)
      temp = temp + M(83, 53) * M(53, 63)
      temp = temp + M(83, 54) * M(54, 63)
      temp = temp + M(83, 55) * M(55, 63)
      temp = temp + M(83, 57) * M(57, 63)
      temp = temp + M(83, 58) * M(58, 63)
      temp = temp + M(83, 59) * M(59, 63)
      temp = temp + M(83, 60) * M(60, 63)
      temp = temp + M(83, 62) * M(62, 63)
      M(83, 63) = M(83, 63) - temp
C     Lower part.
      temp = M(84, 32) * M(32, 63)
      temp = temp + M(84, 37) * M(37, 63)
      temp = temp + M(84, 39) * M(39, 63)
      temp = temp + M(84, 44) * M(44, 63)
      temp = temp + M(84, 49) * M(49, 63)
      temp = temp + M(84, 50) * M(50, 63)
      temp = temp + M(84, 51) * M(51, 63)
      temp = temp + M(84, 53) * M(53, 63)
      temp = temp + M(84, 54) * M(54, 63)
      temp = temp + M(84, 55) * M(55, 63)
      temp = temp + M(84, 57) * M(57, 63)
      temp = temp + M(84, 58) * M(58, 63)
      temp = temp + M(84, 59) * M(59, 63)
      temp = temp + M(84, 60) * M(60, 63)
      M(84, 63) = M(84, 63) - temp
C     Lower part.
      temp = M(85, 19) * M(19, 63)
      temp = temp + M(85, 24) * M(24, 63)
      temp = temp + M(85, 25) * M(25, 63)
      temp = temp + M(85, 26) * M(26, 63)
      temp = temp + M(85, 33) * M(33, 63)
      temp = temp + M(85, 37) * M(37, 63)
      temp = temp + M(85, 39) * M(39, 63)
      temp = temp + M(85, 44) * M(44, 63)
      temp = temp + M(85, 46) * M(46, 63)
      temp = temp + M(85, 47) * M(47, 63)
      temp = temp + M(85, 49) * M(49, 63)
      temp = temp + M(85, 50) * M(50, 63)
      temp = temp + M(85, 51) * M(51, 63)
      temp = temp + M(85, 52) * M(52, 63)
      temp = temp + M(85, 53) * M(53, 63)
      temp = temp + M(85, 54) * M(54, 63)
      temp = temp + M(85, 55) * M(55, 63)
      temp = temp + M(85, 56) * M(56, 63)
      temp = temp + M(85, 57) * M(57, 63)
      temp = temp + M(85, 58) * M(58, 63)
      temp = temp + M(85, 59) * M(59, 63)
      temp = temp + M(85, 60) * M(60, 63)
      temp = temp + M(85, 62) * M(62, 63)
      M(85, 63) = M(85, 63) - temp
C     Lower part.
      temp = M(86, 18) * M(18, 63)
      temp = temp + M(86, 19) * M(19, 63)
      temp = temp + M(86, 24) * M(24, 63)
      temp = temp + M(86, 25) * M(25, 63)
      temp = temp + M(86, 26) * M(26, 63)
      temp = temp + M(86, 29) * M(29, 63)
      temp = temp + M(86, 31) * M(31, 63)
      temp = temp + M(86, 33) * M(33, 63)
      temp = temp + M(86, 35) * M(35, 63)
      temp = temp + M(86, 37) * M(37, 63)
      temp = temp + M(86, 39) * M(39, 63)
      temp = temp + M(86, 43) * M(43, 63)
      temp = temp + M(86, 44) * M(44, 63)
      temp = temp + M(86, 46) * M(46, 63)
      temp = temp + M(86, 49) * M(49, 63)
      temp = temp + M(86, 50) * M(50, 63)
      temp = temp + M(86, 51) * M(51, 63)
      temp = temp + M(86, 52) * M(52, 63)
      temp = temp + M(86, 53) * M(53, 63)
      temp = temp + M(86, 54) * M(54, 63)
      temp = temp + M(86, 55) * M(55, 63)
      temp = temp + M(86, 56) * M(56, 63)
      temp = temp + M(86, 57) * M(57, 63)
      temp = temp + M(86, 58) * M(58, 63)
      temp = temp + M(86, 59) * M(59, 63)
      temp = temp + M(86, 60) * M(60, 63)
      temp = temp + M(86, 62) * M(62, 63)
      M(86, 63) = M(86, 63) - temp
C     Lower part.
      temp = M(87, 18) * M(18, 63)
      temp = temp + M(87, 29) * M(29, 63)
      temp = temp + M(87, 31) * M(31, 63)
      temp = temp + M(87, 32) * M(32, 63)
      temp = temp + M(87, 37) * M(37, 63)
      temp = temp + M(87, 39) * M(39, 63)
      temp = temp + M(87, 44) * M(44, 63)
      temp = temp + M(87, 46) * M(46, 63)
      temp = temp + M(87, 47) * M(47, 63)
      temp = temp + M(87, 49) * M(49, 63)
      temp = temp + M(87, 50) * M(50, 63)
      temp = temp + M(87, 51) * M(51, 63)
      temp = temp + M(87, 53) * M(53, 63)
      temp = temp + M(87, 54) * M(54, 63)
      temp = temp + M(87, 55) * M(55, 63)
      temp = temp + M(87, 57) * M(57, 63)
      temp = temp + M(87, 58) * M(58, 63)
      temp = temp + M(87, 59) * M(59, 63)
      temp = temp + M(87, 60) * M(60, 63)
      temp = temp + M(87, 62) * M(62, 63)
      M(87, 63) = M(87, 63) - temp
C     Upper part.
      temp = M(63, 46) * M(46, 68)
      M(63, 68) = ( M(63, 68) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 18) * M(18, 78)
      temp = temp + M(63, 19) * M(19, 78)
      temp = temp + M(63, 24) * M(24, 78)
      temp = temp + M(63, 25) * M(25, 78)
      temp = temp + M(63, 26) * M(26, 78)
      temp = temp + M(63, 29) * M(29, 78)
      temp = temp + M(63, 31) * M(31, 78)
      temp = temp + M(63, 33) * M(33, 78)
      temp = temp + M(63, 37) * M(37, 78)
      temp = temp + M(63, 46) * M(46, 78)
      temp = temp + M(63, 50) * M(50, 78)
      temp = temp + M(63, 52) * M(52, 78)
      temp = temp + M(63, 56) * M(56, 78)
      temp = temp + M(63, 60) * M(60, 78)
      temp = temp + M(63, 62) * M(62, 78)
      M(63, 78) = ( M(63, 78) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 52) * M(52, 82)
      temp = temp + M(63, 56) * M(56, 82)
      temp = temp + M(63, 60) * M(60, 82)
      temp = temp + M(63, 62) * M(62, 82)
      M(63, 82) = ( M(63, 82) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 52) * M(52, 83)
      temp = temp + M(63, 56) * M(56, 83)
      temp = temp + M(63, 60) * M(60, 83)
      temp = temp + M(63, 62) * M(62, 83)
      M(63, 83) = ( M(63, 83) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 50) * M(50, 84)
      temp = temp + M(63, 52) * M(52, 84)
      temp = temp + M(63, 56) * M(56, 84)
      temp = temp + M(63, 60) * M(60, 84)
      temp = temp + M(63, 62) * M(62, 84)
      M(63, 84) = ( M(63, 84) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 19) * M(19, 85)
      temp = temp + M(63, 24) * M(24, 85)
      temp = temp + M(63, 25) * M(25, 85)
      temp = temp + M(63, 26) * M(26, 85)
      temp = temp + M(63, 33) * M(33, 85)
      temp = temp + M(63, 37) * M(37, 85)
      temp = temp + M(63, 46) * M(46, 85)
      temp = temp + M(63, 50) * M(50, 85)
      temp = temp + M(63, 52) * M(52, 85)
      temp = temp + M(63, 56) * M(56, 85)
      temp = temp + M(63, 60) * M(60, 85)
      temp = temp + M(63, 62) * M(62, 85)
      M(63, 85) = ( M(63, 85) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 37) * M(37, 86)
      temp = temp + M(63, 52) * M(52, 86)
      temp = temp + M(63, 56) * M(56, 86)
      temp = temp + M(63, 60) * M(60, 86)
      temp = temp + M(63, 62) * M(62, 86)
      M(63, 86) = ( M(63, 86) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 18) * M(18, 87)
      temp = temp + M(63, 29) * M(29, 87)
      temp = temp + M(63, 31) * M(31, 87)
      temp = temp + M(63, 37) * M(37, 87)
      temp = temp + M(63, 46) * M(46, 87)
      temp = temp + M(63, 50) * M(50, 87)
      temp = temp + M(63, 52) * M(52, 87)
      temp = temp + M(63, 56) * M(56, 87)
      temp = temp + M(63, 60) * M(60, 87)
      temp = temp + M(63, 62) * M(62, 87)
      M(63, 87) = ( M(63, 87) - temp ) / M(63, 63)

C     Upper part.
      M(64, 65) = M(64, 65) / M(64, 64)
C     Upper part.
      temp = M(64, 46) * M(46, 68)
      temp = temp + M(64, 63) * M(63, 68)
      M(64, 68) = ( M(64, 68) - temp ) / M(64, 64)
C     Upper part.
      M(64, 72) = M(64, 72) / M(64, 64)
C     Upper part.
      M(64, 77) = M(64, 77) / M(64, 64)
C     Upper part.
      temp = M(64, 11) * M(11, 78)
      temp = temp + M(64, 19) * M(19, 78)
      temp = temp + M(64, 24) * M(24, 78)
      temp = temp + M(64, 25) * M(25, 78)
      temp = temp + M(64, 26) * M(26, 78)
      temp = temp + M(64, 33) * M(33, 78)
      temp = temp + M(64, 46) * M(46, 78)
      temp = temp + M(64, 50) * M(50, 78)
      temp = temp + M(64, 52) * M(52, 78)
      temp = temp + M(64, 56) * M(56, 78)
      temp = temp + M(64, 60) * M(60, 78)
      temp = temp + M(64, 62) * M(62, 78)
      temp = temp + M(64, 63) * M(63, 78)
      M(64, 78) = ( M(64, 78) - temp ) / M(64, 64)
C     Upper part.
      M(64, 80) = M(64, 80) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 82)
      temp = temp + M(64, 56) * M(56, 82)
      temp = temp + M(64, 60) * M(60, 82)
      temp = temp + M(64, 62) * M(62, 82)
      temp = temp + M(64, 63) * M(63, 82)
      M(64, 82) = ( M(64, 82) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 83)
      temp = temp + M(64, 56) * M(56, 83)
      temp = temp + M(64, 60) * M(60, 83)
      temp = temp + M(64, 62) * M(62, 83)
      temp = temp + M(64, 63) * M(63, 83)
      M(64, 83) = ( M(64, 83) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 50) * M(50, 84)
      temp = temp + M(64, 52) * M(52, 84)
      temp = temp + M(64, 56) * M(56, 84)
      temp = temp + M(64, 60) * M(60, 84)
      temp = temp + M(64, 62) * M(62, 84)
      temp = temp + M(64, 63) * M(63, 84)
      M(64, 84) = ( M(64, 84) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 19) * M(19, 85)
      temp = temp + M(64, 24) * M(24, 85)
      temp = temp + M(64, 25) * M(25, 85)
      temp = temp + M(64, 26) * M(26, 85)
      temp = temp + M(64, 33) * M(33, 85)
      temp = temp + M(64, 46) * M(46, 85)
      temp = temp + M(64, 50) * M(50, 85)
      temp = temp + M(64, 52) * M(52, 85)
      temp = temp + M(64, 56) * M(56, 85)
      temp = temp + M(64, 60) * M(60, 85)
      temp = temp + M(64, 62) * M(62, 85)
      temp = temp + M(64, 63) * M(63, 85)
      M(64, 85) = ( M(64, 85) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 86)
      temp = temp + M(64, 56) * M(56, 86)
      temp = temp + M(64, 60) * M(60, 86)
      temp = temp + M(64, 62) * M(62, 86)
      temp = temp + M(64, 63) * M(63, 86)
      M(64, 86) = ( M(64, 86) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 46) * M(46, 87)
      temp = temp + M(64, 50) * M(50, 87)
      temp = temp + M(64, 52) * M(52, 87)
      temp = temp + M(64, 56) * M(56, 87)
      temp = temp + M(64, 60) * M(60, 87)
      temp = temp + M(64, 62) * M(62, 87)
      temp = temp + M(64, 63) * M(63, 87)
      M(64, 87) = ( M(64, 87) - temp ) / M(64, 64)

C     Lower part.
      temp = M(78, 64) * M(64, 65)
      M(78, 65) = M(78, 65) - temp
C     Lower part.
      temp = M(86, 64) * M(64, 65)
      M(86, 65) = M(86, 65) - temp
C     Upper part.
      temp = M(65, 63) * M(63, 68)
      M(65, 68) = ( M(65, 68) - temp ) / M(65, 65)
C     Upper part.
      M(65, 71) = M(65, 71) / M(65, 65)
C     Upper part.
      temp = M(65, 11) * M(11, 78)
      temp = temp + M(65, 39) * M(39, 78)
      temp = temp + M(65, 44) * M(44, 78)
      temp = temp + M(65, 49) * M(49, 78)
      temp = temp + M(65, 62) * M(62, 78)
      temp = temp + M(65, 63) * M(63, 78)
      M(65, 78) = ( M(65, 78) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 82)
      temp = temp + M(65, 44) * M(44, 82)
      temp = temp + M(65, 49) * M(49, 82)
      temp = temp + M(65, 62) * M(62, 82)
      temp = temp + M(65, 63) * M(63, 82)
      M(65, 82) = ( M(65, 82) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 83)
      temp = temp + M(65, 44) * M(44, 83)
      temp = temp + M(65, 49) * M(49, 83)
      temp = temp + M(65, 62) * M(62, 83)
      temp = temp + M(65, 63) * M(63, 83)
      M(65, 83) = ( M(65, 83) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 84)
      temp = temp + M(65, 44) * M(44, 84)
      temp = temp + M(65, 49) * M(49, 84)
      temp = temp + M(65, 62) * M(62, 84)
      temp = temp + M(65, 63) * M(63, 84)
      M(65, 84) = ( M(65, 84) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 85)
      temp = temp + M(65, 44) * M(44, 85)
      temp = temp + M(65, 49) * M(49, 85)
      temp = temp + M(65, 62) * M(62, 85)
      temp = temp + M(65, 63) * M(63, 85)
      M(65, 85) = ( M(65, 85) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 86)
      temp = temp + M(65, 44) * M(44, 86)
      temp = temp + M(65, 49) * M(49, 86)
      temp = temp + M(65, 62) * M(62, 86)
      temp = temp + M(65, 63) * M(63, 86)
      M(65, 86) = ( M(65, 86) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 39) * M(39, 87)
      temp = temp + M(65, 44) * M(44, 87)
      temp = temp + M(65, 49) * M(49, 87)
      temp = temp + M(65, 62) * M(62, 87)
      temp = temp + M(65, 63) * M(63, 87)
      M(65, 87) = ( M(65, 87) - temp ) / M(65, 65)

C     Upper part.
      temp = M(66, 4) * M(4, 78)
      M(66, 78) = ( M(66, 78) - temp ) / M(66, 66)
C     Upper part.
      M(66, 82) = M(66, 82) / M(66, 66)
C     Upper part.
      M(66, 83) = M(66, 83) / M(66, 66)
C     Upper part.
      M(66, 84) = M(66, 84) / M(66, 66)
C     Upper part.
      M(66, 85) = M(66, 85) / M(66, 66)
C     Upper part.
      M(66, 86) = M(66, 86) / M(66, 66)

C     Upper part.
      temp = M(67, 63) * M(63, 68)
      M(67, 68) = ( M(67, 68) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 25) * M(25, 78)
      temp = temp + M(67, 63) * M(63, 78)
      M(67, 78) = ( M(67, 78) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 63) * M(63, 82)
      M(67, 82) = ( M(67, 82) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 63) * M(63, 83)
      M(67, 83) = ( M(67, 83) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 63) * M(63, 84)
      M(67, 84) = ( M(67, 84) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 25) * M(25, 85)
      temp = temp + M(67, 63) * M(63, 85)
      M(67, 85) = ( M(67, 85) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 63) * M(63, 86)
      M(67, 86) = ( M(67, 86) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 63) * M(63, 87)
      M(67, 87) = ( M(67, 87) - temp ) / M(67, 67)

C     Lower part.
      temp = M(68, 46) * M(46, 68)
      temp = temp + M(68, 63) * M(63, 68)
      M(68, 68) = M(68, 68) - temp
C     Lower part.
      temp = M(69, 63) * M(63, 68)
      temp = temp + M(69, 67) * M(67, 68)
      M(69, 68) = M(69, 68) - temp
C     Lower part.
      temp = M(70, 63) * M(63, 68)
      temp = temp + M(70, 67) * M(67, 68)
      M(70, 68) = M(70, 68) - temp
C     Lower part.
      temp = M(72, 46) * M(46, 68)
      temp = temp + M(72, 63) * M(63, 68)
      M(72, 68) = M(72, 68) - temp
C     Lower part.
      temp = M(73, 63) * M(63, 68)
      temp = temp + M(73, 65) * M(65, 68)
      M(73, 68) = M(73, 68) - temp
C     Lower part.
      temp = M(74, 46) * M(46, 68)
      temp = temp + M(74, 63) * M(63, 68)
      M(74, 68) = M(74, 68) - temp
C     Lower part.
      temp = M(75, 63) * M(63, 68)
      M(75, 68) = M(75, 68) - temp
C     Lower part.
      temp = M(76, 63) * M(63, 68)
      M(76, 68) = M(76, 68) - temp
C     Lower part.
      temp = M(77, 63) * M(63, 68)
      temp = temp + M(77, 67) * M(67, 68)
      M(77, 68) = M(77, 68) - temp
C     Lower part.
      temp = M(78, 46) * M(46, 68)
      temp = temp + M(78, 47) * M(47, 68)
      temp = temp + M(78, 63) * M(63, 68)
      temp = temp + M(78, 64) * M(64, 68)
      temp = temp + M(78, 65) * M(65, 68)
      M(78, 68) = M(78, 68) - temp
C     Lower part.
      temp = M(79, 63) * M(63, 68)
      M(79, 68) = M(79, 68) - temp
C     Lower part.
      temp = M(80, 46) * M(46, 68)
      temp = temp + M(80, 47) * M(47, 68)
      temp = temp + M(80, 63) * M(63, 68)
      temp = temp + M(80, 65) * M(65, 68)
      temp = temp + M(80, 67) * M(67, 68)
      M(80, 68) = M(80, 68) - temp
C     Lower part.
      temp = M(81, 46) * M(46, 68)
      temp = temp + M(81, 47) * M(47, 68)
      temp = temp + M(81, 63) * M(63, 68)
      M(81, 68) = M(81, 68) - temp
C     Lower part.
      temp = M(82, 63) * M(63, 68)
      temp = temp + M(82, 67) * M(67, 68)
      M(82, 68) = M(82, 68) - temp
C     Lower part.
      temp = M(83, 46) * M(46, 68)
      temp = temp + M(83, 47) * M(47, 68)
      temp = temp + M(83, 63) * M(63, 68)
      temp = temp + M(83, 67) * M(67, 68)
      M(83, 68) = M(83, 68) - temp
C     Lower part.
      temp = M(84, 63) * M(63, 68)
      temp = temp + M(84, 67) * M(67, 68)
      M(84, 68) = M(84, 68) - temp
C     Lower part.
      temp = M(85, 46) * M(46, 68)
      temp = temp + M(85, 47) * M(47, 68)
      temp = temp + M(85, 63) * M(63, 68)
      temp = temp + M(85, 65) * M(65, 68)
      temp = temp + M(85, 67) * M(67, 68)
      M(85, 68) = M(85, 68) - temp
C     Lower part.
      temp = M(86, 46) * M(46, 68)
      temp = temp + M(86, 63) * M(63, 68)
      temp = temp + M(86, 64) * M(64, 68)
      temp = temp + M(86, 65) * M(65, 68)
      temp = temp + M(86, 67) * M(67, 68)
      M(86, 68) = M(86, 68) - temp
C     Lower part.
      temp = M(87, 46) * M(46, 68)
      temp = temp + M(87, 47) * M(47, 68)
      temp = temp + M(87, 63) * M(63, 68)
      temp = temp + M(87, 67) * M(67, 68)
      M(87, 68) = M(87, 68) - temp
C     Upper part.
      temp = M(68, 46) * M(46, 78)
      temp = temp + M(68, 60) * M(60, 78)
      temp = temp + M(68, 62) * M(62, 78)
      temp = temp + M(68, 63) * M(63, 78)
      M(68, 78) = ( M(68, 78) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 60) * M(60, 82)
      temp = temp + M(68, 62) * M(62, 82)
      temp = temp + M(68, 63) * M(63, 82)
      M(68, 82) = ( M(68, 82) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 60) * M(60, 83)
      temp = temp + M(68, 62) * M(62, 83)
      temp = temp + M(68, 63) * M(63, 83)
      M(68, 83) = ( M(68, 83) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 60) * M(60, 84)
      temp = temp + M(68, 62) * M(62, 84)
      temp = temp + M(68, 63) * M(63, 84)
      M(68, 84) = ( M(68, 84) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 46) * M(46, 85)
      temp = temp + M(68, 60) * M(60, 85)
      temp = temp + M(68, 62) * M(62, 85)
      temp = temp + M(68, 63) * M(63, 85)
      M(68, 85) = ( M(68, 85) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 60) * M(60, 86)
      temp = temp + M(68, 62) * M(62, 86)
      temp = temp + M(68, 63) * M(63, 86)
      M(68, 86) = ( M(68, 86) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 46) * M(46, 87)
      temp = temp + M(68, 60) * M(60, 87)
      temp = temp + M(68, 62) * M(62, 87)
      temp = temp + M(68, 63) * M(63, 87)
      M(68, 87) = ( M(68, 87) - temp ) / M(68, 68)

C     Upper part.
      M(69, 71) = M(69, 71) / M(69, 69)
C     Upper part.
      M(69, 76) = M(69, 76) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 78)
      temp = temp + M(69, 44) * M(44, 78)
      temp = temp + M(69, 49) * M(49, 78)
      temp = temp + M(69, 51) * M(51, 78)
      temp = temp + M(69, 53) * M(53, 78)
      temp = temp + M(69, 54) * M(54, 78)
      temp = temp + M(69, 55) * M(55, 78)
      temp = temp + M(69, 59) * M(59, 78)
      temp = temp + M(69, 60) * M(60, 78)
      temp = temp + M(69, 61) * M(61, 78)
      temp = temp + M(69, 63) * M(63, 78)
      temp = temp + M(69, 66) * M(66, 78)
      temp = temp + M(69, 67) * M(67, 78)
      temp = temp + M(69, 68) * M(68, 78)
      M(69, 78) = ( M(69, 78) - temp ) / M(69, 69)
C     Upper part.
      M(69, 79) = M(69, 79) / M(69, 69)
C     Upper part.
      M(69, 81) = M(69, 81) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 82)
      temp = temp + M(69, 44) * M(44, 82)
      temp = temp + M(69, 49) * M(49, 82)
      temp = temp + M(69, 51) * M(51, 82)
      temp = temp + M(69, 53) * M(53, 82)
      temp = temp + M(69, 54) * M(54, 82)
      temp = temp + M(69, 55) * M(55, 82)
      temp = temp + M(69, 59) * M(59, 82)
      temp = temp + M(69, 60) * M(60, 82)
      temp = temp + M(69, 61) * M(61, 82)
      temp = temp + M(69, 63) * M(63, 82)
      temp = temp + M(69, 66) * M(66, 82)
      temp = temp + M(69, 67) * M(67, 82)
      temp = temp + M(69, 68) * M(68, 82)
      M(69, 82) = ( M(69, 82) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 83)
      temp = temp + M(69, 44) * M(44, 83)
      temp = temp + M(69, 49) * M(49, 83)
      temp = temp + M(69, 51) * M(51, 83)
      temp = temp + M(69, 53) * M(53, 83)
      temp = temp + M(69, 54) * M(54, 83)
      temp = temp + M(69, 55) * M(55, 83)
      temp = temp + M(69, 59) * M(59, 83)
      temp = temp + M(69, 60) * M(60, 83)
      temp = temp + M(69, 61) * M(61, 83)
      temp = temp + M(69, 63) * M(63, 83)
      temp = temp + M(69, 66) * M(66, 83)
      temp = temp + M(69, 67) * M(67, 83)
      temp = temp + M(69, 68) * M(68, 83)
      M(69, 83) = ( M(69, 83) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 84)
      temp = temp + M(69, 44) * M(44, 84)
      temp = temp + M(69, 49) * M(49, 84)
      temp = temp + M(69, 51) * M(51, 84)
      temp = temp + M(69, 53) * M(53, 84)
      temp = temp + M(69, 54) * M(54, 84)
      temp = temp + M(69, 55) * M(55, 84)
      temp = temp + M(69, 59) * M(59, 84)
      temp = temp + M(69, 60) * M(60, 84)
      temp = temp + M(69, 61) * M(61, 84)
      temp = temp + M(69, 63) * M(63, 84)
      temp = temp + M(69, 66) * M(66, 84)
      temp = temp + M(69, 67) * M(67, 84)
      temp = temp + M(69, 68) * M(68, 84)
      M(69, 84) = ( M(69, 84) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 85)
      temp = temp + M(69, 44) * M(44, 85)
      temp = temp + M(69, 49) * M(49, 85)
      temp = temp + M(69, 51) * M(51, 85)
      temp = temp + M(69, 53) * M(53, 85)
      temp = temp + M(69, 54) * M(54, 85)
      temp = temp + M(69, 55) * M(55, 85)
      temp = temp + M(69, 59) * M(59, 85)
      temp = temp + M(69, 60) * M(60, 85)
      temp = temp + M(69, 61) * M(61, 85)
      temp = temp + M(69, 63) * M(63, 85)
      temp = temp + M(69, 66) * M(66, 85)
      temp = temp + M(69, 67) * M(67, 85)
      temp = temp + M(69, 68) * M(68, 85)
      M(69, 85) = ( M(69, 85) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 86)
      temp = temp + M(69, 44) * M(44, 86)
      temp = temp + M(69, 49) * M(49, 86)
      temp = temp + M(69, 51) * M(51, 86)
      temp = temp + M(69, 53) * M(53, 86)
      temp = temp + M(69, 54) * M(54, 86)
      temp = temp + M(69, 55) * M(55, 86)
      temp = temp + M(69, 59) * M(59, 86)
      temp = temp + M(69, 60) * M(60, 86)
      temp = temp + M(69, 61) * M(61, 86)
      temp = temp + M(69, 63) * M(63, 86)
      temp = temp + M(69, 66) * M(66, 86)
      temp = temp + M(69, 67) * M(67, 86)
      temp = temp + M(69, 68) * M(68, 86)
      M(69, 86) = ( M(69, 86) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 39) * M(39, 87)
      temp = temp + M(69, 44) * M(44, 87)
      temp = temp + M(69, 49) * M(49, 87)
      temp = temp + M(69, 51) * M(51, 87)
      temp = temp + M(69, 53) * M(53, 87)
      temp = temp + M(69, 59) * M(59, 87)
      temp = temp + M(69, 60) * M(60, 87)
      temp = temp + M(69, 63) * M(63, 87)
      temp = temp + M(69, 67) * M(67, 87)
      temp = temp + M(69, 68) * M(68, 87)
      M(69, 87) = ( M(69, 87) - temp ) / M(69, 69)

C     Upper part.
      M(70, 71) = M(70, 71) / M(70, 70)
C     Upper part.
      M(70, 76) = M(70, 76) / M(70, 70)
C     Upper part.
      temp = M(70, 26) * M(26, 78)
      temp = temp + M(70, 51) * M(51, 78)
      temp = temp + M(70, 52) * M(52, 78)
      temp = temp + M(70, 53) * M(53, 78)
      temp = temp + M(70, 56) * M(56, 78)
      temp = temp + M(70, 57) * M(57, 78)
      temp = temp + M(70, 58) * M(58, 78)
      temp = temp + M(70, 59) * M(59, 78)
      temp = temp + M(70, 60) * M(60, 78)
      temp = temp + M(70, 61) * M(61, 78)
      temp = temp + M(70, 62) * M(62, 78)
      temp = temp + M(70, 63) * M(63, 78)
      temp = temp + M(70, 66) * M(66, 78)
      temp = temp + M(70, 67) * M(67, 78)
      temp = temp + M(70, 68) * M(68, 78)
      M(70, 78) = ( M(70, 78) - temp ) / M(70, 70)
C     Upper part.
      M(70, 79) = M(70, 79) / M(70, 70)
C     Upper part.
      temp = M(70, 51) * M(51, 82)
      temp = temp + M(70, 52) * M(52, 82)
      temp = temp + M(70, 53) * M(53, 82)
      temp = temp + M(70, 56) * M(56, 82)
      temp = temp + M(70, 57) * M(57, 82)
      temp = temp + M(70, 58) * M(58, 82)
      temp = temp + M(70, 59) * M(59, 82)
      temp = temp + M(70, 60) * M(60, 82)
      temp = temp + M(70, 61) * M(61, 82)
      temp = temp + M(70, 62) * M(62, 82)
      temp = temp + M(70, 63) * M(63, 82)
      temp = temp + M(70, 66) * M(66, 82)
      temp = temp + M(70, 67) * M(67, 82)
      temp = temp + M(70, 68) * M(68, 82)
      M(70, 82) = ( M(70, 82) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 51) * M(51, 83)
      temp = temp + M(70, 52) * M(52, 83)
      temp = temp + M(70, 53) * M(53, 83)
      temp = temp + M(70, 56) * M(56, 83)
      temp = temp + M(70, 57) * M(57, 83)
      temp = temp + M(70, 58) * M(58, 83)
      temp = temp + M(70, 59) * M(59, 83)
      temp = temp + M(70, 60) * M(60, 83)
      temp = temp + M(70, 61) * M(61, 83)
      temp = temp + M(70, 62) * M(62, 83)
      temp = temp + M(70, 63) * M(63, 83)
      temp = temp + M(70, 66) * M(66, 83)
      temp = temp + M(70, 67) * M(67, 83)
      temp = temp + M(70, 68) * M(68, 83)
      M(70, 83) = ( M(70, 83) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 51) * M(51, 84)
      temp = temp + M(70, 52) * M(52, 84)
      temp = temp + M(70, 53) * M(53, 84)
      temp = temp + M(70, 56) * M(56, 84)
      temp = temp + M(70, 57) * M(57, 84)
      temp = temp + M(70, 58) * M(58, 84)
      temp = temp + M(70, 59) * M(59, 84)
      temp = temp + M(70, 60) * M(60, 84)
      temp = temp + M(70, 61) * M(61, 84)
      temp = temp + M(70, 62) * M(62, 84)
      temp = temp + M(70, 63) * M(63, 84)
      temp = temp + M(70, 66) * M(66, 84)
      temp = temp + M(70, 67) * M(67, 84)
      temp = temp + M(70, 68) * M(68, 84)
      M(70, 84) = ( M(70, 84) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 26) * M(26, 85)
      temp = temp + M(70, 51) * M(51, 85)
      temp = temp + M(70, 52) * M(52, 85)
      temp = temp + M(70, 53) * M(53, 85)
      temp = temp + M(70, 56) * M(56, 85)
      temp = temp + M(70, 57) * M(57, 85)
      temp = temp + M(70, 58) * M(58, 85)
      temp = temp + M(70, 59) * M(59, 85)
      temp = temp + M(70, 60) * M(60, 85)
      temp = temp + M(70, 61) * M(61, 85)
      temp = temp + M(70, 62) * M(62, 85)
      temp = temp + M(70, 63) * M(63, 85)
      temp = temp + M(70, 66) * M(66, 85)
      temp = temp + M(70, 67) * M(67, 85)
      temp = temp + M(70, 68) * M(68, 85)
      M(70, 85) = ( M(70, 85) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 51) * M(51, 86)
      temp = temp + M(70, 52) * M(52, 86)
      temp = temp + M(70, 53) * M(53, 86)
      temp = temp + M(70, 56) * M(56, 86)
      temp = temp + M(70, 57) * M(57, 86)
      temp = temp + M(70, 58) * M(58, 86)
      temp = temp + M(70, 59) * M(59, 86)
      temp = temp + M(70, 60) * M(60, 86)
      temp = temp + M(70, 61) * M(61, 86)
      temp = temp + M(70, 62) * M(62, 86)
      temp = temp + M(70, 63) * M(63, 86)
      temp = temp + M(70, 66) * M(66, 86)
      temp = temp + M(70, 67) * M(67, 86)
      temp = temp + M(70, 68) * M(68, 86)
      M(70, 86) = ( M(70, 86) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 51) * M(51, 87)
      temp = temp + M(70, 52) * M(52, 87)
      temp = temp + M(70, 53) * M(53, 87)
      temp = temp + M(70, 56) * M(56, 87)
      temp = temp + M(70, 57) * M(57, 87)
      temp = temp + M(70, 58) * M(58, 87)
      temp = temp + M(70, 59) * M(59, 87)
      temp = temp + M(70, 60) * M(60, 87)
      temp = temp + M(70, 62) * M(62, 87)
      temp = temp + M(70, 63) * M(63, 87)
      temp = temp + M(70, 67) * M(67, 87)
      temp = temp + M(70, 68) * M(68, 87)
      M(70, 87) = ( M(70, 87) - temp ) / M(70, 70)

C     Lower part.
      temp = M(71, 69) * M(69, 71)
      M(71, 71) = M(71, 71) - temp
C     Lower part.
      temp = M(73, 65) * M(65, 71)
      M(73, 71) = M(73, 71) - temp
C     Lower part.
      temp = M(75, 69) * M(69, 71)
      M(75, 71) = M(75, 71) - temp
C     Lower part.
      temp = M(77, 69) * M(69, 71)
      M(77, 71) = M(77, 71) - temp
C     Lower part.
      temp = M(78, 65) * M(65, 71)
      temp = temp + M(78, 69) * M(69, 71)
      M(78, 71) = M(78, 71) - temp
C     Lower part.
      temp = M(80, 65) * M(65, 71)
      M(80, 71) = M(80, 71) - temp
C     Lower part.
      temp = M(81, 69) * M(69, 71)
      M(81, 71) = M(81, 71) - temp
C     Lower part.
      temp = M(85, 65) * M(65, 71)
      M(85, 71) = M(85, 71) - temp
C     Lower part.
      temp = M(86, 65) * M(65, 71)
      temp = temp + M(86, 69) * M(69, 71)
      M(86, 71) = M(86, 71) - temp
C     Upper part.
      M(71, 74) = M(71, 74) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 76)
      M(71, 76) = ( M(71, 76) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 11) * M(11, 78)
      temp = temp + M(71, 69) * M(69, 78)
      M(71, 78) = ( M(71, 78) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 79)
      M(71, 79) = ( M(71, 79) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 81)
      M(71, 81) = ( M(71, 81) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 82)
      M(71, 82) = ( M(71, 82) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 83)
      M(71, 83) = ( M(71, 83) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 84)
      M(71, 84) = ( M(71, 84) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 85)
      M(71, 85) = ( M(71, 85) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 86)
      M(71, 86) = ( M(71, 86) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 87)
      M(71, 87) = ( M(71, 87) - temp ) / M(71, 71)

C     Lower part.
      temp = M(78, 64) * M(64, 72)
      M(78, 72) = M(78, 72) - temp
C     Lower part.
      temp = M(86, 64) * M(64, 72)
      M(86, 72) = M(86, 72) - temp
C     Upper part.
      temp = M(72, 71) * M(71, 74)
      M(72, 74) = ( M(72, 74) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 45) * M(45, 76)
      temp = temp + M(72, 71) * M(71, 76)
      M(72, 76) = ( M(72, 76) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 78)
      temp = temp + M(72, 44) * M(44, 78)
      temp = temp + M(72, 45) * M(45, 78)
      temp = temp + M(72, 46) * M(46, 78)
      temp = temp + M(72, 49) * M(49, 78)
      temp = temp + M(72, 60) * M(60, 78)
      temp = temp + M(72, 62) * M(62, 78)
      temp = temp + M(72, 63) * M(63, 78)
      temp = temp + M(72, 68) * M(68, 78)
      temp = temp + M(72, 71) * M(71, 78)
      M(72, 78) = ( M(72, 78) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 79)
      M(72, 79) = ( M(72, 79) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 71) * M(71, 81)
      M(72, 81) = ( M(72, 81) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 82)
      temp = temp + M(72, 44) * M(44, 82)
      temp = temp + M(72, 45) * M(45, 82)
      temp = temp + M(72, 49) * M(49, 82)
      temp = temp + M(72, 60) * M(60, 82)
      temp = temp + M(72, 62) * M(62, 82)
      temp = temp + M(72, 63) * M(63, 82)
      temp = temp + M(72, 68) * M(68, 82)
      temp = temp + M(72, 71) * M(71, 82)
      M(72, 82) = ( M(72, 82) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 83)
      temp = temp + M(72, 44) * M(44, 83)
      temp = temp + M(72, 49) * M(49, 83)
      temp = temp + M(72, 60) * M(60, 83)
      temp = temp + M(72, 62) * M(62, 83)
      temp = temp + M(72, 63) * M(63, 83)
      temp = temp + M(72, 68) * M(68, 83)
      temp = temp + M(72, 71) * M(71, 83)
      M(72, 83) = ( M(72, 83) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 84)
      temp = temp + M(72, 44) * M(44, 84)
      temp = temp + M(72, 49) * M(49, 84)
      temp = temp + M(72, 60) * M(60, 84)
      temp = temp + M(72, 62) * M(62, 84)
      temp = temp + M(72, 63) * M(63, 84)
      temp = temp + M(72, 68) * M(68, 84)
      temp = temp + M(72, 71) * M(71, 84)
      M(72, 84) = ( M(72, 84) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 85)
      temp = temp + M(72, 44) * M(44, 85)
      temp = temp + M(72, 46) * M(46, 85)
      temp = temp + M(72, 49) * M(49, 85)
      temp = temp + M(72, 60) * M(60, 85)
      temp = temp + M(72, 62) * M(62, 85)
      temp = temp + M(72, 63) * M(63, 85)
      temp = temp + M(72, 68) * M(68, 85)
      temp = temp + M(72, 71) * M(71, 85)
      M(72, 85) = ( M(72, 85) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 86)
      temp = temp + M(72, 44) * M(44, 86)
      temp = temp + M(72, 49) * M(49, 86)
      temp = temp + M(72, 60) * M(60, 86)
      temp = temp + M(72, 62) * M(62, 86)
      temp = temp + M(72, 63) * M(63, 86)
      temp = temp + M(72, 68) * M(68, 86)
      temp = temp + M(72, 71) * M(71, 86)
      M(72, 86) = ( M(72, 86) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 39) * M(39, 87)
      temp = temp + M(72, 44) * M(44, 87)
      temp = temp + M(72, 46) * M(46, 87)
      temp = temp + M(72, 49) * M(49, 87)
      temp = temp + M(72, 60) * M(60, 87)
      temp = temp + M(72, 62) * M(62, 87)
      temp = temp + M(72, 63) * M(63, 87)
      temp = temp + M(72, 68) * M(68, 87)
      temp = temp + M(72, 71) * M(71, 87)
      M(72, 87) = ( M(72, 87) - temp ) / M(72, 72)

C     Upper part.
      temp = M(73, 71) * M(71, 74)
      temp = temp + M(73, 72) * M(72, 74)
      M(73, 74) = ( M(73, 74) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 71) * M(71, 76)
      temp = temp + M(73, 72) * M(72, 76)
      M(73, 76) = ( M(73, 76) - temp ) / M(73, 73)
C     Upper part.
      M(73, 77) = M(73, 77) / M(73, 73)
C     Upper part.
      temp = M(73, 37) * M(37, 78)
      temp = temp + M(73, 60) * M(60, 78)
      temp = temp + M(73, 62) * M(62, 78)
      temp = temp + M(73, 63) * M(63, 78)
      temp = temp + M(73, 65) * M(65, 78)
      temp = temp + M(73, 68) * M(68, 78)
      temp = temp + M(73, 71) * M(71, 78)
      temp = temp + M(73, 72) * M(72, 78)
      M(73, 78) = ( M(73, 78) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 71) * M(71, 79)
      temp = temp + M(73, 72) * M(72, 79)
      M(73, 79) = ( M(73, 79) - temp ) / M(73, 73)
C     Upper part.
      M(73, 80) = M(73, 80) / M(73, 73)
C     Upper part.
      temp = M(73, 71) * M(71, 81)
      temp = temp + M(73, 72) * M(72, 81)
      M(73, 81) = ( M(73, 81) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 60) * M(60, 82)
      temp = temp + M(73, 62) * M(62, 82)
      temp = temp + M(73, 63) * M(63, 82)
      temp = temp + M(73, 65) * M(65, 82)
      temp = temp + M(73, 68) * M(68, 82)
      temp = temp + M(73, 71) * M(71, 82)
      temp = temp + M(73, 72) * M(72, 82)
      M(73, 82) = ( M(73, 82) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 60) * M(60, 83)
      temp = temp + M(73, 62) * M(62, 83)
      temp = temp + M(73, 63) * M(63, 83)
      temp = temp + M(73, 65) * M(65, 83)
      temp = temp + M(73, 68) * M(68, 83)
      temp = temp + M(73, 71) * M(71, 83)
      temp = temp + M(73, 72) * M(72, 83)
      M(73, 83) = ( M(73, 83) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 60) * M(60, 84)
      temp = temp + M(73, 62) * M(62, 84)
      temp = temp + M(73, 63) * M(63, 84)
      temp = temp + M(73, 65) * M(65, 84)
      temp = temp + M(73, 68) * M(68, 84)
      temp = temp + M(73, 71) * M(71, 84)
      temp = temp + M(73, 72) * M(72, 84)
      M(73, 84) = ( M(73, 84) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 17) * M(17, 85)
      temp = temp + M(73, 37) * M(37, 85)
      temp = temp + M(73, 60) * M(60, 85)
      temp = temp + M(73, 62) * M(62, 85)
      temp = temp + M(73, 63) * M(63, 85)
      temp = temp + M(73, 65) * M(65, 85)
      temp = temp + M(73, 68) * M(68, 85)
      temp = temp + M(73, 71) * M(71, 85)
      temp = temp + M(73, 72) * M(72, 85)
      M(73, 85) = ( M(73, 85) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 37) * M(37, 86)
      temp = temp + M(73, 60) * M(60, 86)
      temp = temp + M(73, 62) * M(62, 86)
      temp = temp + M(73, 63) * M(63, 86)
      temp = temp + M(73, 65) * M(65, 86)
      temp = temp + M(73, 68) * M(68, 86)
      temp = temp + M(73, 71) * M(71, 86)
      temp = temp + M(73, 72) * M(72, 86)
      M(73, 86) = ( M(73, 86) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 17) * M(17, 87)
      temp = temp + M(73, 37) * M(37, 87)
      temp = temp + M(73, 60) * M(60, 87)
      temp = temp + M(73, 62) * M(62, 87)
      temp = temp + M(73, 63) * M(63, 87)
      temp = temp + M(73, 65) * M(65, 87)
      temp = temp + M(73, 68) * M(68, 87)
      temp = temp + M(73, 71) * M(71, 87)
      temp = temp + M(73, 72) * M(72, 87)
      M(73, 87) = ( M(73, 87) - temp ) / M(73, 73)

C     Lower part.
      temp = M(74, 71) * M(71, 74)
      M(74, 74) = M(74, 74) - temp
C     Lower part.
      temp = M(75, 71) * M(71, 74)
      M(75, 74) = M(75, 74) - temp
C     Lower part.
      temp = M(77, 71) * M(71, 74)
      M(77, 74) = M(77, 74) - temp
C     Lower part.
      temp = M(78, 71) * M(71, 74)
      temp = temp + M(78, 72) * M(72, 74)
      temp = temp + M(78, 73) * M(73, 74)
      M(78, 74) = M(78, 74) - temp
C     Lower part.
      temp = M(79, 71) * M(71, 74)
      M(79, 74) = M(79, 74) - temp
C     Lower part.
      temp = M(80, 71) * M(71, 74)
      M(80, 74) = M(80, 74) - temp
C     Lower part.
      temp = M(81, 71) * M(71, 74)
      M(81, 74) = M(81, 74) - temp
C     Lower part.
      temp = M(82, 71) * M(71, 74)
      M(82, 74) = M(82, 74) - temp
C     Lower part.
      temp = M(83, 71) * M(71, 74)
      temp = temp + M(83, 72) * M(72, 74)
      M(83, 74) = M(83, 74) - temp
C     Lower part.
      temp = M(84, 71) * M(71, 74)
      M(84, 74) = M(84, 74) - temp
C     Lower part.
      temp = M(85, 71) * M(71, 74)
      temp = temp + M(85, 72) * M(72, 74)
      temp = temp + M(85, 73) * M(73, 74)
      M(85, 74) = M(85, 74) - temp
C     Lower part.
      temp = M(86, 71) * M(71, 74)
      temp = temp + M(86, 72) * M(72, 74)
      M(86, 74) = M(86, 74) - temp
C     Lower part.
      temp = M(87, 71) * M(71, 74)
      temp = temp + M(87, 73) * M(73, 74)
      M(87, 74) = M(87, 74) - temp
C     Upper part.
      temp = M(74, 71) * M(71, 76)
      M(74, 76) = ( M(74, 76) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 36) * M(36, 78)
      temp = temp + M(74, 37) * M(37, 78)
      temp = temp + M(74, 39) * M(39, 78)
      temp = temp + M(74, 44) * M(44, 78)
      temp = temp + M(74, 46) * M(46, 78)
      temp = temp + M(74, 51) * M(51, 78)
      temp = temp + M(74, 54) * M(54, 78)
      temp = temp + M(74, 55) * M(55, 78)
      temp = temp + M(74, 57) * M(57, 78)
      temp = temp + M(74, 58) * M(58, 78)
      temp = temp + M(74, 60) * M(60, 78)
      temp = temp + M(74, 61) * M(61, 78)
      temp = temp + M(74, 63) * M(63, 78)
      temp = temp + M(74, 66) * M(66, 78)
      temp = temp + M(74, 68) * M(68, 78)
      temp = temp + M(74, 71) * M(71, 78)
      M(74, 78) = ( M(74, 78) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 71) * M(71, 79)
      M(74, 79) = ( M(74, 79) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 71) * M(71, 81)
      M(74, 81) = ( M(74, 81) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 39) * M(39, 82)
      temp = temp + M(74, 44) * M(44, 82)
      temp = temp + M(74, 51) * M(51, 82)
      temp = temp + M(74, 54) * M(54, 82)
      temp = temp + M(74, 55) * M(55, 82)
      temp = temp + M(74, 57) * M(57, 82)
      temp = temp + M(74, 58) * M(58, 82)
      temp = temp + M(74, 60) * M(60, 82)
      temp = temp + M(74, 61) * M(61, 82)
      temp = temp + M(74, 63) * M(63, 82)
      temp = temp + M(74, 66) * M(66, 82)
      temp = temp + M(74, 68) * M(68, 82)
      temp = temp + M(74, 71) * M(71, 82)
      M(74, 82) = ( M(74, 82) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 39) * M(39, 83)
      temp = temp + M(74, 44) * M(44, 83)
      temp = temp + M(74, 51) * M(51, 83)
      temp = temp + M(74, 54) * M(54, 83)
      temp = temp + M(74, 55) * M(55, 83)
      temp = temp + M(74, 57) * M(57, 83)
      temp = temp + M(74, 58) * M(58, 83)
      temp = temp + M(74, 60) * M(60, 83)
      temp = temp + M(74, 61) * M(61, 83)
      temp = temp + M(74, 63) * M(63, 83)
      temp = temp + M(74, 66) * M(66, 83)
      temp = temp + M(74, 68) * M(68, 83)
      temp = temp + M(74, 71) * M(71, 83)
      M(74, 83) = ( M(74, 83) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 39) * M(39, 84)
      temp = temp + M(74, 44) * M(44, 84)
      temp = temp + M(74, 51) * M(51, 84)
      temp = temp + M(74, 54) * M(54, 84)
      temp = temp + M(74, 55) * M(55, 84)
      temp = temp + M(74, 57) * M(57, 84)
      temp = temp + M(74, 58) * M(58, 84)
      temp = temp + M(74, 60) * M(60, 84)
      temp = temp + M(74, 61) * M(61, 84)
      temp = temp + M(74, 63) * M(63, 84)
      temp = temp + M(74, 66) * M(66, 84)
      temp = temp + M(74, 68) * M(68, 84)
      temp = temp + M(74, 71) * M(71, 84)
      M(74, 84) = ( M(74, 84) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 36) * M(36, 85)
      temp = temp + M(74, 37) * M(37, 85)
      temp = temp + M(74, 39) * M(39, 85)
      temp = temp + M(74, 44) * M(44, 85)
      temp = temp + M(74, 46) * M(46, 85)
      temp = temp + M(74, 51) * M(51, 85)
      temp = temp + M(74, 54) * M(54, 85)
      temp = temp + M(74, 55) * M(55, 85)
      temp = temp + M(74, 57) * M(57, 85)
      temp = temp + M(74, 58) * M(58, 85)
      temp = temp + M(74, 60) * M(60, 85)
      temp = temp + M(74, 61) * M(61, 85)
      temp = temp + M(74, 63) * M(63, 85)
      temp = temp + M(74, 66) * M(66, 85)
      temp = temp + M(74, 68) * M(68, 85)
      temp = temp + M(74, 71) * M(71, 85)
      M(74, 85) = ( M(74, 85) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 36) * M(36, 86)
      temp = temp + M(74, 37) * M(37, 86)
      temp = temp + M(74, 39) * M(39, 86)
      temp = temp + M(74, 44) * M(44, 86)
      temp = temp + M(74, 51) * M(51, 86)
      temp = temp + M(74, 54) * M(54, 86)
      temp = temp + M(74, 55) * M(55, 86)
      temp = temp + M(74, 57) * M(57, 86)
      temp = temp + M(74, 58) * M(58, 86)
      temp = temp + M(74, 60) * M(60, 86)
      temp = temp + M(74, 61) * M(61, 86)
      temp = temp + M(74, 63) * M(63, 86)
      temp = temp + M(74, 66) * M(66, 86)
      temp = temp + M(74, 68) * M(68, 86)
      temp = temp + M(74, 71) * M(71, 86)
      M(74, 86) = ( M(74, 86) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 36) * M(36, 87)
      temp = temp + M(74, 37) * M(37, 87)
      temp = temp + M(74, 39) * M(39, 87)
      temp = temp + M(74, 44) * M(44, 87)
      temp = temp + M(74, 46) * M(46, 87)
      temp = temp + M(74, 51) * M(51, 87)
      temp = temp + M(74, 57) * M(57, 87)
      temp = temp + M(74, 58) * M(58, 87)
      temp = temp + M(74, 60) * M(60, 87)
      temp = temp + M(74, 63) * M(63, 87)
      temp = temp + M(74, 68) * M(68, 87)
      temp = temp + M(74, 71) * M(71, 87)
      M(74, 87) = ( M(74, 87) - temp ) / M(74, 74)

C     Upper part.
      temp = M(75, 69) * M(69, 76)
      temp = temp + M(75, 71) * M(71, 76)
      temp = temp + M(75, 74) * M(74, 76)
      M(75, 76) = ( M(75, 76) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 3) * M(3, 78)
      temp = temp + M(75, 16) * M(16, 78)
      temp = temp + M(75, 24) * M(24, 78)
      temp = temp + M(75, 52) * M(52, 78)
      temp = temp + M(75, 53) * M(53, 78)
      temp = temp + M(75, 54) * M(54, 78)
      temp = temp + M(75, 56) * M(56, 78)
      temp = temp + M(75, 57) * M(57, 78)
      temp = temp + M(75, 58) * M(58, 78)
      temp = temp + M(75, 59) * M(59, 78)
      temp = temp + M(75, 60) * M(60, 78)
      temp = temp + M(75, 61) * M(61, 78)
      temp = temp + M(75, 62) * M(62, 78)
      temp = temp + M(75, 63) * M(63, 78)
      temp = temp + M(75, 66) * M(66, 78)
      temp = temp + M(75, 68) * M(68, 78)
      temp = temp + M(75, 69) * M(69, 78)
      temp = temp + M(75, 71) * M(71, 78)
      temp = temp + M(75, 74) * M(74, 78)
      M(75, 78) = ( M(75, 78) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 69) * M(69, 79)
      temp = temp + M(75, 71) * M(71, 79)
      temp = temp + M(75, 74) * M(74, 79)
      M(75, 79) = ( M(75, 79) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 69) * M(69, 81)
      temp = temp + M(75, 71) * M(71, 81)
      temp = temp + M(75, 74) * M(74, 81)
      M(75, 81) = ( M(75, 81) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 52) * M(52, 82)
      temp = temp + M(75, 53) * M(53, 82)
      temp = temp + M(75, 54) * M(54, 82)
      temp = temp + M(75, 56) * M(56, 82)
      temp = temp + M(75, 57) * M(57, 82)
      temp = temp + M(75, 58) * M(58, 82)
      temp = temp + M(75, 59) * M(59, 82)
      temp = temp + M(75, 60) * M(60, 82)
      temp = temp + M(75, 61) * M(61, 82)
      temp = temp + M(75, 62) * M(62, 82)
      temp = temp + M(75, 63) * M(63, 82)
      temp = temp + M(75, 66) * M(66, 82)
      temp = temp + M(75, 68) * M(68, 82)
      temp = temp + M(75, 69) * M(69, 82)
      temp = temp + M(75, 71) * M(71, 82)
      temp = temp + M(75, 74) * M(74, 82)
      M(75, 82) = ( M(75, 82) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 52) * M(52, 83)
      temp = temp + M(75, 53) * M(53, 83)
      temp = temp + M(75, 54) * M(54, 83)
      temp = temp + M(75, 56) * M(56, 83)
      temp = temp + M(75, 57) * M(57, 83)
      temp = temp + M(75, 58) * M(58, 83)
      temp = temp + M(75, 59) * M(59, 83)
      temp = temp + M(75, 60) * M(60, 83)
      temp = temp + M(75, 61) * M(61, 83)
      temp = temp + M(75, 62) * M(62, 83)
      temp = temp + M(75, 63) * M(63, 83)
      temp = temp + M(75, 66) * M(66, 83)
      temp = temp + M(75, 68) * M(68, 83)
      temp = temp + M(75, 69) * M(69, 83)
      temp = temp + M(75, 71) * M(71, 83)
      temp = temp + M(75, 74) * M(74, 83)
      M(75, 83) = ( M(75, 83) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 52) * M(52, 84)
      temp = temp + M(75, 53) * M(53, 84)
      temp = temp + M(75, 54) * M(54, 84)
      temp = temp + M(75, 56) * M(56, 84)
      temp = temp + M(75, 57) * M(57, 84)
      temp = temp + M(75, 58) * M(58, 84)
      temp = temp + M(75, 59) * M(59, 84)
      temp = temp + M(75, 60) * M(60, 84)
      temp = temp + M(75, 61) * M(61, 84)
      temp = temp + M(75, 62) * M(62, 84)
      temp = temp + M(75, 63) * M(63, 84)
      temp = temp + M(75, 66) * M(66, 84)
      temp = temp + M(75, 68) * M(68, 84)
      temp = temp + M(75, 69) * M(69, 84)
      temp = temp + M(75, 71) * M(71, 84)
      temp = temp + M(75, 74) * M(74, 84)
      M(75, 84) = ( M(75, 84) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 24) * M(24, 85)
      temp = temp + M(75, 52) * M(52, 85)
      temp = temp + M(75, 53) * M(53, 85)
      temp = temp + M(75, 54) * M(54, 85)
      temp = temp + M(75, 56) * M(56, 85)
      temp = temp + M(75, 57) * M(57, 85)
      temp = temp + M(75, 58) * M(58, 85)
      temp = temp + M(75, 59) * M(59, 85)
      temp = temp + M(75, 60) * M(60, 85)
      temp = temp + M(75, 61) * M(61, 85)
      temp = temp + M(75, 62) * M(62, 85)
      temp = temp + M(75, 63) * M(63, 85)
      temp = temp + M(75, 66) * M(66, 85)
      temp = temp + M(75, 68) * M(68, 85)
      temp = temp + M(75, 69) * M(69, 85)
      temp = temp + M(75, 71) * M(71, 85)
      temp = temp + M(75, 74) * M(74, 85)
      M(75, 85) = ( M(75, 85) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 52) * M(52, 86)
      temp = temp + M(75, 53) * M(53, 86)
      temp = temp + M(75, 54) * M(54, 86)
      temp = temp + M(75, 56) * M(56, 86)
      temp = temp + M(75, 57) * M(57, 86)
      temp = temp + M(75, 58) * M(58, 86)
      temp = temp + M(75, 59) * M(59, 86)
      temp = temp + M(75, 60) * M(60, 86)
      temp = temp + M(75, 61) * M(61, 86)
      temp = temp + M(75, 62) * M(62, 86)
      temp = temp + M(75, 63) * M(63, 86)
      temp = temp + M(75, 66) * M(66, 86)
      temp = temp + M(75, 68) * M(68, 86)
      temp = temp + M(75, 69) * M(69, 86)
      temp = temp + M(75, 71) * M(71, 86)
      temp = temp + M(75, 74) * M(74, 86)
      M(75, 86) = ( M(75, 86) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 52) * M(52, 87)
      temp = temp + M(75, 53) * M(53, 87)
      temp = temp + M(75, 56) * M(56, 87)
      temp = temp + M(75, 57) * M(57, 87)
      temp = temp + M(75, 58) * M(58, 87)
      temp = temp + M(75, 59) * M(59, 87)
      temp = temp + M(75, 60) * M(60, 87)
      temp = temp + M(75, 62) * M(62, 87)
      temp = temp + M(75, 63) * M(63, 87)
      temp = temp + M(75, 68) * M(68, 87)
      temp = temp + M(75, 69) * M(69, 87)
      temp = temp + M(75, 71) * M(71, 87)
      temp = temp + M(75, 74) * M(74, 87)
      M(75, 87) = ( M(75, 87) - temp ) / M(75, 75)

C     Lower part.
      temp = M(76, 75) * M(75, 76)
      M(76, 76) = M(76, 76) - temp
C     Lower part.
      temp = M(77, 69) * M(69, 76)
      temp = temp + M(77, 71) * M(71, 76)
      temp = temp + M(77, 74) * M(74, 76)
      M(77, 76) = M(77, 76) - temp
C     Lower part.
      temp = M(78, 45) * M(45, 76)
      temp = temp + M(78, 69) * M(69, 76)
      temp = temp + M(78, 71) * M(71, 76)
      temp = temp + M(78, 72) * M(72, 76)
      temp = temp + M(78, 73) * M(73, 76)
      temp = temp + M(78, 74) * M(74, 76)
      temp = temp + M(78, 75) * M(75, 76)
      M(78, 76) = M(78, 76) - temp
C     Lower part.
      temp = M(79, 71) * M(71, 76)
      temp = temp + M(79, 74) * M(74, 76)
      temp = temp + M(79, 75) * M(75, 76)
      M(79, 76) = M(79, 76) - temp
C     Lower part.
      temp = M(80, 45) * M(45, 76)
      temp = temp + M(80, 71) * M(71, 76)
      temp = temp + M(80, 74) * M(74, 76)
      M(80, 76) = M(80, 76) - temp
C     Lower part.
      temp = M(81, 69) * M(69, 76)
      temp = temp + M(81, 71) * M(71, 76)
      temp = temp + M(81, 74) * M(74, 76)
      M(81, 76) = M(81, 76) - temp
C     Lower part.
      temp = M(82, 71) * M(71, 76)
      temp = temp + M(82, 74) * M(74, 76)
      M(82, 76) = M(82, 76) - temp
C     Lower part.
      temp = M(83, 45) * M(45, 76)
      temp = temp + M(83, 71) * M(71, 76)
      temp = temp + M(83, 72) * M(72, 76)
      temp = temp + M(83, 74) * M(74, 76)
      temp = temp + M(83, 75) * M(75, 76)
      M(83, 76) = M(83, 76) - temp
C     Lower part.
      temp = M(84, 71) * M(71, 76)
      temp = temp + M(84, 74) * M(74, 76)
      M(84, 76) = M(84, 76) - temp
C     Lower part.
      temp = M(85, 71) * M(71, 76)
      temp = temp + M(85, 72) * M(72, 76)
      temp = temp + M(85, 73) * M(73, 76)
      temp = temp + M(85, 74) * M(74, 76)
      M(85, 76) = M(85, 76) - temp
C     Lower part.
      temp = M(86, 45) * M(45, 76)
      temp = temp + M(86, 69) * M(69, 76)
      temp = temp + M(86, 71) * M(71, 76)
      temp = temp + M(86, 72) * M(72, 76)
      temp = temp + M(86, 74) * M(74, 76)
      M(86, 76) = M(86, 76) - temp
C     Lower part.
      temp = M(87, 71) * M(71, 76)
      temp = temp + M(87, 73) * M(73, 76)
      temp = temp + M(87, 74) * M(74, 76)
      M(87, 76) = M(87, 76) - temp
C     Upper part.
      temp = M(76, 19) * M(19, 78)
      temp = temp + M(76, 24) * M(24, 78)
      temp = temp + M(76, 26) * M(26, 78)
      temp = temp + M(76, 33) * M(33, 78)
      temp = temp + M(76, 50) * M(50, 78)
      temp = temp + M(76, 52) * M(52, 78)
      temp = temp + M(76, 56) * M(56, 78)
      temp = temp + M(76, 60) * M(60, 78)
      temp = temp + M(76, 63) * M(63, 78)
      temp = temp + M(76, 68) * M(68, 78)
      temp = temp + M(76, 75) * M(75, 78)
      M(76, 78) = ( M(76, 78) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 79)
      M(76, 79) = ( M(76, 79) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 81)
      M(76, 81) = ( M(76, 81) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 52) * M(52, 82)
      temp = temp + M(76, 56) * M(56, 82)
      temp = temp + M(76, 60) * M(60, 82)
      temp = temp + M(76, 63) * M(63, 82)
      temp = temp + M(76, 68) * M(68, 82)
      temp = temp + M(76, 75) * M(75, 82)
      M(76, 82) = ( M(76, 82) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 52) * M(52, 83)
      temp = temp + M(76, 56) * M(56, 83)
      temp = temp + M(76, 60) * M(60, 83)
      temp = temp + M(76, 63) * M(63, 83)
      temp = temp + M(76, 68) * M(68, 83)
      temp = temp + M(76, 75) * M(75, 83)
      M(76, 83) = ( M(76, 83) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 50) * M(50, 84)
      temp = temp + M(76, 52) * M(52, 84)
      temp = temp + M(76, 56) * M(56, 84)
      temp = temp + M(76, 60) * M(60, 84)
      temp = temp + M(76, 63) * M(63, 84)
      temp = temp + M(76, 68) * M(68, 84)
      temp = temp + M(76, 75) * M(75, 84)
      M(76, 84) = ( M(76, 84) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 19) * M(19, 85)
      temp = temp + M(76, 24) * M(24, 85)
      temp = temp + M(76, 26) * M(26, 85)
      temp = temp + M(76, 33) * M(33, 85)
      temp = temp + M(76, 50) * M(50, 85)
      temp = temp + M(76, 52) * M(52, 85)
      temp = temp + M(76, 56) * M(56, 85)
      temp = temp + M(76, 60) * M(60, 85)
      temp = temp + M(76, 63) * M(63, 85)
      temp = temp + M(76, 68) * M(68, 85)
      temp = temp + M(76, 75) * M(75, 85)
      M(76, 85) = ( M(76, 85) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 52) * M(52, 86)
      temp = temp + M(76, 56) * M(56, 86)
      temp = temp + M(76, 60) * M(60, 86)
      temp = temp + M(76, 63) * M(63, 86)
      temp = temp + M(76, 68) * M(68, 86)
      temp = temp + M(76, 75) * M(75, 86)
      M(76, 86) = ( M(76, 86) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 50) * M(50, 87)
      temp = temp + M(76, 52) * M(52, 87)
      temp = temp + M(76, 56) * M(56, 87)
      temp = temp + M(76, 60) * M(60, 87)
      temp = temp + M(76, 63) * M(63, 87)
      temp = temp + M(76, 68) * M(68, 87)
      temp = temp + M(76, 75) * M(75, 87)
      M(76, 87) = ( M(76, 87) - temp ) / M(76, 76)

C     Lower part.
      temp = M(78, 64) * M(64, 77)
      temp = temp + M(78, 73) * M(73, 77)
      M(78, 77) = M(78, 77) - temp
C     Lower part.
      temp = M(85, 73) * M(73, 77)
      M(85, 77) = M(85, 77) - temp
C     Lower part.
      temp = M(86, 64) * M(64, 77)
      M(86, 77) = M(86, 77) - temp
C     Lower part.
      temp = M(87, 73) * M(73, 77)
      M(87, 77) = M(87, 77) - temp
C     Upper part.
      temp = M(77, 4) * M(4, 78)
      temp = temp + M(77, 11) * M(11, 78)
      temp = temp + M(77, 16) * M(16, 78)
      temp = temp + M(77, 24) * M(24, 78)
      temp = temp + M(77, 50) * M(50, 78)
      temp = temp + M(77, 52) * M(52, 78)
      temp = temp + M(77, 53) * M(53, 78)
      temp = temp + M(77, 54) * M(54, 78)
      temp = temp + M(77, 56) * M(56, 78)
      temp = temp + M(77, 57) * M(57, 78)
      temp = temp + M(77, 58) * M(58, 78)
      temp = temp + M(77, 59) * M(59, 78)
      temp = temp + M(77, 60) * M(60, 78)
      temp = temp + M(77, 61) * M(61, 78)
      temp = temp + M(77, 62) * M(62, 78)
      temp = temp + M(77, 63) * M(63, 78)
      temp = temp + M(77, 66) * M(66, 78)
      temp = temp + M(77, 67) * M(67, 78)
      temp = temp + M(77, 68) * M(68, 78)
      temp = temp + M(77, 69) * M(69, 78)
      temp = temp + M(77, 71) * M(71, 78)
      temp = temp + M(77, 74) * M(74, 78)
      temp = temp + M(77, 76) * M(76, 78)
      M(77, 78) = ( M(77, 78) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 69) * M(69, 79)
      temp = temp + M(77, 71) * M(71, 79)
      temp = temp + M(77, 74) * M(74, 79)
      temp = temp + M(77, 76) * M(76, 79)
      M(77, 79) = ( M(77, 79) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 69) * M(69, 81)
      temp = temp + M(77, 71) * M(71, 81)
      temp = temp + M(77, 74) * M(74, 81)
      temp = temp + M(77, 76) * M(76, 81)
      M(77, 81) = ( M(77, 81) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 82)
      temp = temp + M(77, 53) * M(53, 82)
      temp = temp + M(77, 54) * M(54, 82)
      temp = temp + M(77, 56) * M(56, 82)
      temp = temp + M(77, 57) * M(57, 82)
      temp = temp + M(77, 58) * M(58, 82)
      temp = temp + M(77, 59) * M(59, 82)
      temp = temp + M(77, 60) * M(60, 82)
      temp = temp + M(77, 61) * M(61, 82)
      temp = temp + M(77, 62) * M(62, 82)
      temp = temp + M(77, 63) * M(63, 82)
      temp = temp + M(77, 66) * M(66, 82)
      temp = temp + M(77, 67) * M(67, 82)
      temp = temp + M(77, 68) * M(68, 82)
      temp = temp + M(77, 69) * M(69, 82)
      temp = temp + M(77, 71) * M(71, 82)
      temp = temp + M(77, 74) * M(74, 82)
      temp = temp + M(77, 76) * M(76, 82)
      M(77, 82) = ( M(77, 82) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 83)
      temp = temp + M(77, 53) * M(53, 83)
      temp = temp + M(77, 54) * M(54, 83)
      temp = temp + M(77, 56) * M(56, 83)
      temp = temp + M(77, 57) * M(57, 83)
      temp = temp + M(77, 58) * M(58, 83)
      temp = temp + M(77, 59) * M(59, 83)
      temp = temp + M(77, 60) * M(60, 83)
      temp = temp + M(77, 61) * M(61, 83)
      temp = temp + M(77, 62) * M(62, 83)
      temp = temp + M(77, 63) * M(63, 83)
      temp = temp + M(77, 66) * M(66, 83)
      temp = temp + M(77, 67) * M(67, 83)
      temp = temp + M(77, 68) * M(68, 83)
      temp = temp + M(77, 69) * M(69, 83)
      temp = temp + M(77, 71) * M(71, 83)
      temp = temp + M(77, 74) * M(74, 83)
      temp = temp + M(77, 76) * M(76, 83)
      M(77, 83) = ( M(77, 83) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 50) * M(50, 84)
      temp = temp + M(77, 52) * M(52, 84)
      temp = temp + M(77, 53) * M(53, 84)
      temp = temp + M(77, 54) * M(54, 84)
      temp = temp + M(77, 56) * M(56, 84)
      temp = temp + M(77, 57) * M(57, 84)
      temp = temp + M(77, 58) * M(58, 84)
      temp = temp + M(77, 59) * M(59, 84)
      temp = temp + M(77, 60) * M(60, 84)
      temp = temp + M(77, 61) * M(61, 84)
      temp = temp + M(77, 62) * M(62, 84)
      temp = temp + M(77, 63) * M(63, 84)
      temp = temp + M(77, 66) * M(66, 84)
      temp = temp + M(77, 67) * M(67, 84)
      temp = temp + M(77, 68) * M(68, 84)
      temp = temp + M(77, 69) * M(69, 84)
      temp = temp + M(77, 71) * M(71, 84)
      temp = temp + M(77, 74) * M(74, 84)
      temp = temp + M(77, 76) * M(76, 84)
      M(77, 84) = ( M(77, 84) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 24) * M(24, 85)
      temp = temp + M(77, 50) * M(50, 85)
      temp = temp + M(77, 52) * M(52, 85)
      temp = temp + M(77, 53) * M(53, 85)
      temp = temp + M(77, 54) * M(54, 85)
      temp = temp + M(77, 56) * M(56, 85)
      temp = temp + M(77, 57) * M(57, 85)
      temp = temp + M(77, 58) * M(58, 85)
      temp = temp + M(77, 59) * M(59, 85)
      temp = temp + M(77, 60) * M(60, 85)
      temp = temp + M(77, 61) * M(61, 85)
      temp = temp + M(77, 62) * M(62, 85)
      temp = temp + M(77, 63) * M(63, 85)
      temp = temp + M(77, 66) * M(66, 85)
      temp = temp + M(77, 67) * M(67, 85)
      temp = temp + M(77, 68) * M(68, 85)
      temp = temp + M(77, 69) * M(69, 85)
      temp = temp + M(77, 71) * M(71, 85)
      temp = temp + M(77, 74) * M(74, 85)
      temp = temp + M(77, 76) * M(76, 85)
      M(77, 85) = ( M(77, 85) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 86)
      temp = temp + M(77, 53) * M(53, 86)
      temp = temp + M(77, 54) * M(54, 86)
      temp = temp + M(77, 56) * M(56, 86)
      temp = temp + M(77, 57) * M(57, 86)
      temp = temp + M(77, 58) * M(58, 86)
      temp = temp + M(77, 59) * M(59, 86)
      temp = temp + M(77, 60) * M(60, 86)
      temp = temp + M(77, 61) * M(61, 86)
      temp = temp + M(77, 62) * M(62, 86)
      temp = temp + M(77, 63) * M(63, 86)
      temp = temp + M(77, 66) * M(66, 86)
      temp = temp + M(77, 67) * M(67, 86)
      temp = temp + M(77, 68) * M(68, 86)
      temp = temp + M(77, 69) * M(69, 86)
      temp = temp + M(77, 71) * M(71, 86)
      temp = temp + M(77, 74) * M(74, 86)
      temp = temp + M(77, 76) * M(76, 86)
      M(77, 86) = ( M(77, 86) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 50) * M(50, 87)
      temp = temp + M(77, 52) * M(52, 87)
      temp = temp + M(77, 53) * M(53, 87)
      temp = temp + M(77, 56) * M(56, 87)
      temp = temp + M(77, 57) * M(57, 87)
      temp = temp + M(77, 58) * M(58, 87)
      temp = temp + M(77, 59) * M(59, 87)
      temp = temp + M(77, 60) * M(60, 87)
      temp = temp + M(77, 62) * M(62, 87)
      temp = temp + M(77, 63) * M(63, 87)
      temp = temp + M(77, 67) * M(67, 87)
      temp = temp + M(77, 68) * M(68, 87)
      temp = temp + M(77, 69) * M(69, 87)
      temp = temp + M(77, 71) * M(71, 87)
      temp = temp + M(77, 74) * M(74, 87)
      temp = temp + M(77, 76) * M(76, 87)
      M(77, 87) = ( M(77, 87) - temp ) / M(77, 77)

C     Lower part.
      temp = M(78, 3) * M(3, 78)
      temp = temp + M(78, 4) * M(4, 78)
      temp = temp + M(78, 5) * M(5, 78)
      temp = temp + M(78, 6) * M(6, 78)
      temp = temp + M(78, 9) * M(9, 78)
      temp = temp + M(78, 11) * M(11, 78)
      temp = temp + M(78, 12) * M(12, 78)
      temp = temp + M(78, 16) * M(16, 78)
      temp = temp + M(78, 18) * M(18, 78)
      temp = temp + M(78, 19) * M(19, 78)
      temp = temp + M(78, 22) * M(22, 78)
      temp = temp + M(78, 23) * M(23, 78)
      temp = temp + M(78, 24) * M(24, 78)
      temp = temp + M(78, 25) * M(25, 78)
      temp = temp + M(78, 26) * M(26, 78)
      temp = temp + M(78, 29) * M(29, 78)
      temp = temp + M(78, 30) * M(30, 78)
      temp = temp + M(78, 31) * M(31, 78)
      temp = temp + M(78, 32) * M(32, 78)
      temp = temp + M(78, 33) * M(33, 78)
      temp = temp + M(78, 34) * M(34, 78)
      temp = temp + M(78, 35) * M(35, 78)
      temp = temp + M(78, 37) * M(37, 78)
      temp = temp + M(78, 43) * M(43, 78)
      temp = temp + M(78, 45) * M(45, 78)
      temp = temp + M(78, 46) * M(46, 78)
      temp = temp + M(78, 47) * M(47, 78)
      temp = temp + M(78, 50) * M(50, 78)
      temp = temp + M(78, 52) * M(52, 78)
      temp = temp + M(78, 56) * M(56, 78)
      temp = temp + M(78, 60) * M(60, 78)
      temp = temp + M(78, 62) * M(62, 78)
      temp = temp + M(78, 63) * M(63, 78)
      temp = temp + M(78, 64) * M(64, 78)
      temp = temp + M(78, 65) * M(65, 78)
      temp = temp + M(78, 68) * M(68, 78)
      temp = temp + M(78, 69) * M(69, 78)
      temp = temp + M(78, 71) * M(71, 78)
      temp = temp + M(78, 72) * M(72, 78)
      temp = temp + M(78, 73) * M(73, 78)
      temp = temp + M(78, 74) * M(74, 78)
      temp = temp + M(78, 75) * M(75, 78)
      temp = temp + M(78, 76) * M(76, 78)
      temp = temp + M(78, 77) * M(77, 78)
      M(78, 78) = M(78, 78) - temp
C     Lower part.
      temp = M(79, 24) * M(24, 78)
      temp = temp + M(79, 26) * M(26, 78)
      temp = temp + M(79, 30) * M(30, 78)
      temp = temp + M(79, 52) * M(52, 78)
      temp = temp + M(79, 56) * M(56, 78)
      temp = temp + M(79, 60) * M(60, 78)
      temp = temp + M(79, 61) * M(61, 78)
      temp = temp + M(79, 63) * M(63, 78)
      temp = temp + M(79, 66) * M(66, 78)
      temp = temp + M(79, 68) * M(68, 78)
      temp = temp + M(79, 71) * M(71, 78)
      temp = temp + M(79, 74) * M(74, 78)
      temp = temp + M(79, 75) * M(75, 78)
      temp = temp + M(79, 76) * M(76, 78)
      M(79, 78) = M(79, 78) - temp
C     Lower part.
      temp = M(80, 11) * M(11, 78)
      temp = temp + M(80, 19) * M(19, 78)
      temp = temp + M(80, 23) * M(23, 78)
      temp = temp + M(80, 25) * M(25, 78)
      temp = temp + M(80, 26) * M(26, 78)
      temp = temp + M(80, 33) * M(33, 78)
      temp = temp + M(80, 35) * M(35, 78)
      temp = temp + M(80, 39) * M(39, 78)
      temp = temp + M(80, 44) * M(44, 78)
      temp = temp + M(80, 45) * M(45, 78)
      temp = temp + M(80, 46) * M(46, 78)
      temp = temp + M(80, 47) * M(47, 78)
      temp = temp + M(80, 49) * M(49, 78)
      temp = temp + M(80, 50) * M(50, 78)
      temp = temp + M(80, 51) * M(51, 78)
      temp = temp + M(80, 52) * M(52, 78)
      temp = temp + M(80, 53) * M(53, 78)
      temp = temp + M(80, 54) * M(54, 78)
      temp = temp + M(80, 55) * M(55, 78)
      temp = temp + M(80, 56) * M(56, 78)
      temp = temp + M(80, 57) * M(57, 78)
      temp = temp + M(80, 58) * M(58, 78)
      temp = temp + M(80, 59) * M(59, 78)
      temp = temp + M(80, 60) * M(60, 78)
      temp = temp + M(80, 61) * M(61, 78)
      temp = temp + M(80, 62) * M(62, 78)
      temp = temp + M(80, 63) * M(63, 78)
      temp = temp + M(80, 65) * M(65, 78)
      temp = temp + M(80, 66) * M(66, 78)
      temp = temp + M(80, 67) * M(67, 78)
      temp = temp + M(80, 68) * M(68, 78)
      temp = temp + M(80, 71) * M(71, 78)
      temp = temp + M(80, 74) * M(74, 78)
      temp = temp + M(80, 76) * M(76, 78)
      M(80, 78) = M(80, 78) - temp
C     Lower part.
      temp = M(81, 5) * M(5, 78)
      temp = temp + M(81, 6) * M(6, 78)
      temp = temp + M(81, 19) * M(19, 78)
      temp = temp + M(81, 33) * M(33, 78)
      temp = temp + M(81, 35) * M(35, 78)
      temp = temp + M(81, 37) * M(37, 78)
      temp = temp + M(81, 46) * M(46, 78)
      temp = temp + M(81, 47) * M(47, 78)
      temp = temp + M(81, 50) * M(50, 78)
      temp = temp + M(81, 60) * M(60, 78)
      temp = temp + M(81, 61) * M(61, 78)
      temp = temp + M(81, 62) * M(62, 78)
      temp = temp + M(81, 63) * M(63, 78)
      temp = temp + M(81, 66) * M(66, 78)
      temp = temp + M(81, 68) * M(68, 78)
      temp = temp + M(81, 69) * M(69, 78)
      temp = temp + M(81, 71) * M(71, 78)
      temp = temp + M(81, 74) * M(74, 78)
      temp = temp + M(81, 76) * M(76, 78)
      M(81, 78) = M(81, 78) - temp
C     Lower part.
      temp = M(82, 19) * M(19, 78)
      temp = temp + M(82, 23) * M(23, 78)
      temp = temp + M(82, 33) * M(33, 78)
      temp = temp + M(82, 34) * M(34, 78)
      temp = temp + M(82, 35) * M(35, 78)
      temp = temp + M(82, 39) * M(39, 78)
      temp = temp + M(82, 44) * M(44, 78)
      temp = temp + M(82, 49) * M(49, 78)
      temp = temp + M(82, 50) * M(50, 78)
      temp = temp + M(82, 51) * M(51, 78)
      temp = temp + M(82, 52) * M(52, 78)
      temp = temp + M(82, 53) * M(53, 78)
      temp = temp + M(82, 54) * M(54, 78)
      temp = temp + M(82, 55) * M(55, 78)
      temp = temp + M(82, 56) * M(56, 78)
      temp = temp + M(82, 57) * M(57, 78)
      temp = temp + M(82, 58) * M(58, 78)
      temp = temp + M(82, 59) * M(59, 78)
      temp = temp + M(82, 60) * M(60, 78)
      temp = temp + M(82, 61) * M(61, 78)
      temp = temp + M(82, 62) * M(62, 78)
      temp = temp + M(82, 63) * M(63, 78)
      temp = temp + M(82, 66) * M(66, 78)
      temp = temp + M(82, 67) * M(67, 78)
      temp = temp + M(82, 68) * M(68, 78)
      temp = temp + M(82, 71) * M(71, 78)
      temp = temp + M(82, 74) * M(74, 78)
      temp = temp + M(82, 76) * M(76, 78)
      temp = temp + M(82, 77) * M(77, 78)
      M(82, 78) = M(82, 78) - temp
C     Lower part.
      temp = M(83, 19) * M(19, 78)
      temp = temp + M(83, 33) * M(33, 78)
      temp = temp + M(83, 35) * M(35, 78)
      temp = temp + M(83, 39) * M(39, 78)
      temp = temp + M(83, 44) * M(44, 78)
      temp = temp + M(83, 45) * M(45, 78)
      temp = temp + M(83, 46) * M(46, 78)
      temp = temp + M(83, 47) * M(47, 78)
      temp = temp + M(83, 49) * M(49, 78)
      temp = temp + M(83, 50) * M(50, 78)
      temp = temp + M(83, 51) * M(51, 78)
      temp = temp + M(83, 53) * M(53, 78)
      temp = temp + M(83, 54) * M(54, 78)
      temp = temp + M(83, 55) * M(55, 78)
      temp = temp + M(83, 57) * M(57, 78)
      temp = temp + M(83, 58) * M(58, 78)
      temp = temp + M(83, 59) * M(59, 78)
      temp = temp + M(83, 60) * M(60, 78)
      temp = temp + M(83, 61) * M(61, 78)
      temp = temp + M(83, 62) * M(62, 78)
      temp = temp + M(83, 63) * M(63, 78)
      temp = temp + M(83, 66) * M(66, 78)
      temp = temp + M(83, 67) * M(67, 78)
      temp = temp + M(83, 68) * M(68, 78)
      temp = temp + M(83, 71) * M(71, 78)
      temp = temp + M(83, 72) * M(72, 78)
      temp = temp + M(83, 74) * M(74, 78)
      temp = temp + M(83, 75) * M(75, 78)
      temp = temp + M(83, 76) * M(76, 78)
      temp = temp + M(83, 77) * M(77, 78)
      M(83, 78) = M(83, 78) - temp
C     Lower part.
      temp = M(84, 32) * M(32, 78)
      temp = temp + M(84, 37) * M(37, 78)
      temp = temp + M(84, 39) * M(39, 78)
      temp = temp + M(84, 44) * M(44, 78)
      temp = temp + M(84, 49) * M(49, 78)
      temp = temp + M(84, 50) * M(50, 78)
      temp = temp + M(84, 51) * M(51, 78)
      temp = temp + M(84, 53) * M(53, 78)
      temp = temp + M(84, 54) * M(54, 78)
      temp = temp + M(84, 55) * M(55, 78)
      temp = temp + M(84, 57) * M(57, 78)
      temp = temp + M(84, 58) * M(58, 78)
      temp = temp + M(84, 59) * M(59, 78)
      temp = temp + M(84, 60) * M(60, 78)
      temp = temp + M(84, 61) * M(61, 78)
      temp = temp + M(84, 63) * M(63, 78)
      temp = temp + M(84, 66) * M(66, 78)
      temp = temp + M(84, 67) * M(67, 78)
      temp = temp + M(84, 68) * M(68, 78)
      temp = temp + M(84, 71) * M(71, 78)
      temp = temp + M(84, 74) * M(74, 78)
      temp = temp + M(84, 76) * M(76, 78)
      M(84, 78) = M(84, 78) - temp
C     Lower part.
      temp = M(85, 19) * M(19, 78)
      temp = temp + M(85, 22) * M(22, 78)
      temp = temp + M(85, 24) * M(24, 78)
      temp = temp + M(85, 25) * M(25, 78)
      temp = temp + M(85, 26) * M(26, 78)
      temp = temp + M(85, 33) * M(33, 78)
      temp = temp + M(85, 37) * M(37, 78)
      temp = temp + M(85, 39) * M(39, 78)
      temp = temp + M(85, 44) * M(44, 78)
      temp = temp + M(85, 46) * M(46, 78)
      temp = temp + M(85, 47) * M(47, 78)
      temp = temp + M(85, 49) * M(49, 78)
      temp = temp + M(85, 50) * M(50, 78)
      temp = temp + M(85, 51) * M(51, 78)
      temp = temp + M(85, 52) * M(52, 78)
      temp = temp + M(85, 53) * M(53, 78)
      temp = temp + M(85, 54) * M(54, 78)
      temp = temp + M(85, 55) * M(55, 78)
      temp = temp + M(85, 56) * M(56, 78)
      temp = temp + M(85, 57) * M(57, 78)
      temp = temp + M(85, 58) * M(58, 78)
      temp = temp + M(85, 59) * M(59, 78)
      temp = temp + M(85, 60) * M(60, 78)
      temp = temp + M(85, 61) * M(61, 78)
      temp = temp + M(85, 62) * M(62, 78)
      temp = temp + M(85, 63) * M(63, 78)
      temp = temp + M(85, 65) * M(65, 78)
      temp = temp + M(85, 66) * M(66, 78)
      temp = temp + M(85, 67) * M(67, 78)
      temp = temp + M(85, 68) * M(68, 78)
      temp = temp + M(85, 71) * M(71, 78)
      temp = temp + M(85, 72) * M(72, 78)
      temp = temp + M(85, 73) * M(73, 78)
      temp = temp + M(85, 74) * M(74, 78)
      temp = temp + M(85, 76) * M(76, 78)
      temp = temp + M(85, 77) * M(77, 78)
      M(85, 78) = M(85, 78) - temp
C     Lower part.
      temp = M(86, 3) * M(3, 78)
      temp = temp + M(86, 4) * M(4, 78)
      temp = temp + M(86, 5) * M(5, 78)
      temp = temp + M(86, 6) * M(6, 78)
      temp = temp + M(86, 9) * M(9, 78)
      temp = temp + M(86, 11) * M(11, 78)
      temp = temp + M(86, 16) * M(16, 78)
      temp = temp + M(86, 18) * M(18, 78)
      temp = temp + M(86, 19) * M(19, 78)
      temp = temp + M(86, 22) * M(22, 78)
      temp = temp + M(86, 23) * M(23, 78)
      temp = temp + M(86, 24) * M(24, 78)
      temp = temp + M(86, 25) * M(25, 78)
      temp = temp + M(86, 26) * M(26, 78)
      temp = temp + M(86, 29) * M(29, 78)
      temp = temp + M(86, 31) * M(31, 78)
      temp = temp + M(86, 33) * M(33, 78)
      temp = temp + M(86, 35) * M(35, 78)
      temp = temp + M(86, 36) * M(36, 78)
      temp = temp + M(86, 37) * M(37, 78)
      temp = temp + M(86, 39) * M(39, 78)
      temp = temp + M(86, 43) * M(43, 78)
      temp = temp + M(86, 44) * M(44, 78)
      temp = temp + M(86, 45) * M(45, 78)
      temp = temp + M(86, 46) * M(46, 78)
      temp = temp + M(86, 49) * M(49, 78)
      temp = temp + M(86, 50) * M(50, 78)
      temp = temp + M(86, 51) * M(51, 78)
      temp = temp + M(86, 52) * M(52, 78)
      temp = temp + M(86, 53) * M(53, 78)
      temp = temp + M(86, 54) * M(54, 78)
      temp = temp + M(86, 55) * M(55, 78)
      temp = temp + M(86, 56) * M(56, 78)
      temp = temp + M(86, 57) * M(57, 78)
      temp = temp + M(86, 58) * M(58, 78)
      temp = temp + M(86, 59) * M(59, 78)
      temp = temp + M(86, 60) * M(60, 78)
      temp = temp + M(86, 61) * M(61, 78)
      temp = temp + M(86, 62) * M(62, 78)
      temp = temp + M(86, 63) * M(63, 78)
      temp = temp + M(86, 64) * M(64, 78)
      temp = temp + M(86, 65) * M(65, 78)
      temp = temp + M(86, 66) * M(66, 78)
      temp = temp + M(86, 67) * M(67, 78)
      temp = temp + M(86, 68) * M(68, 78)
      temp = temp + M(86, 69) * M(69, 78)
      temp = temp + M(86, 71) * M(71, 78)
      temp = temp + M(86, 72) * M(72, 78)
      temp = temp + M(86, 74) * M(74, 78)
      temp = temp + M(86, 76) * M(76, 78)
      temp = temp + M(86, 77) * M(77, 78)
      M(86, 78) = M(86, 78) - temp
C     Lower part.
      temp = M(87, 18) * M(18, 78)
      temp = temp + M(87, 22) * M(22, 78)
      temp = temp + M(87, 29) * M(29, 78)
      temp = temp + M(87, 31) * M(31, 78)
      temp = temp + M(87, 32) * M(32, 78)
      temp = temp + M(87, 36) * M(36, 78)
      temp = temp + M(87, 37) * M(37, 78)
      temp = temp + M(87, 39) * M(39, 78)
      temp = temp + M(87, 44) * M(44, 78)
      temp = temp + M(87, 46) * M(46, 78)
      temp = temp + M(87, 47) * M(47, 78)
      temp = temp + M(87, 49) * M(49, 78)
      temp = temp + M(87, 50) * M(50, 78)
      temp = temp + M(87, 51) * M(51, 78)
      temp = temp + M(87, 53) * M(53, 78)
      temp = temp + M(87, 54) * M(54, 78)
      temp = temp + M(87, 55) * M(55, 78)
      temp = temp + M(87, 57) * M(57, 78)
      temp = temp + M(87, 58) * M(58, 78)
      temp = temp + M(87, 59) * M(59, 78)
      temp = temp + M(87, 60) * M(60, 78)
      temp = temp + M(87, 61) * M(61, 78)
      temp = temp + M(87, 62) * M(62, 78)
      temp = temp + M(87, 63) * M(63, 78)
      temp = temp + M(87, 66) * M(66, 78)
      temp = temp + M(87, 67) * M(67, 78)
      temp = temp + M(87, 68) * M(68, 78)
      temp = temp + M(87, 71) * M(71, 78)
      temp = temp + M(87, 73) * M(73, 78)
      temp = temp + M(87, 74) * M(74, 78)
      temp = temp + M(87, 76) * M(76, 78)
      temp = temp + M(87, 77) * M(77, 78)
      M(87, 78) = M(87, 78) - temp
C     Upper part.
      temp = M(78, 69) * M(69, 79)
      temp = temp + M(78, 71) * M(71, 79)
      temp = temp + M(78, 72) * M(72, 79)
      temp = temp + M(78, 73) * M(73, 79)
      temp = temp + M(78, 74) * M(74, 79)
      temp = temp + M(78, 75) * M(75, 79)
      temp = temp + M(78, 76) * M(76, 79)
      temp = temp + M(78, 77) * M(77, 79)
      M(78, 79) = ( M(78, 79) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 64) * M(64, 80)
      temp = temp + M(78, 73) * M(73, 80)
      M(78, 80) = ( M(78, 80) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 69) * M(69, 81)
      temp = temp + M(78, 71) * M(71, 81)
      temp = temp + M(78, 72) * M(72, 81)
      temp = temp + M(78, 73) * M(73, 81)
      temp = temp + M(78, 74) * M(74, 81)
      temp = temp + M(78, 75) * M(75, 81)
      temp = temp + M(78, 76) * M(76, 81)
      temp = temp + M(78, 77) * M(77, 81)
      M(78, 81) = ( M(78, 81) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 23) * M(23, 82)
      temp = temp + M(78, 45) * M(45, 82)
      temp = temp + M(78, 52) * M(52, 82)
      temp = temp + M(78, 56) * M(56, 82)
      temp = temp + M(78, 60) * M(60, 82)
      temp = temp + M(78, 62) * M(62, 82)
      temp = temp + M(78, 63) * M(63, 82)
      temp = temp + M(78, 64) * M(64, 82)
      temp = temp + M(78, 65) * M(65, 82)
      temp = temp + M(78, 68) * M(68, 82)
      temp = temp + M(78, 69) * M(69, 82)
      temp = temp + M(78, 71) * M(71, 82)
      temp = temp + M(78, 72) * M(72, 82)
      temp = temp + M(78, 73) * M(73, 82)
      temp = temp + M(78, 74) * M(74, 82)
      temp = temp + M(78, 75) * M(75, 82)
      temp = temp + M(78, 76) * M(76, 82)
      temp = temp + M(78, 77) * M(77, 82)
      M(78, 82) = ( M(78, 82) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 35) * M(35, 83)
      temp = temp + M(78, 47) * M(47, 83)
      temp = temp + M(78, 52) * M(52, 83)
      temp = temp + M(78, 56) * M(56, 83)
      temp = temp + M(78, 60) * M(60, 83)
      temp = temp + M(78, 62) * M(62, 83)
      temp = temp + M(78, 63) * M(63, 83)
      temp = temp + M(78, 64) * M(64, 83)
      temp = temp + M(78, 65) * M(65, 83)
      temp = temp + M(78, 68) * M(68, 83)
      temp = temp + M(78, 69) * M(69, 83)
      temp = temp + M(78, 71) * M(71, 83)
      temp = temp + M(78, 72) * M(72, 83)
      temp = temp + M(78, 73) * M(73, 83)
      temp = temp + M(78, 74) * M(74, 83)
      temp = temp + M(78, 75) * M(75, 83)
      temp = temp + M(78, 76) * M(76, 83)
      temp = temp + M(78, 77) * M(77, 83)
      M(78, 83) = ( M(78, 83) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 32) * M(32, 84)
      temp = temp + M(78, 50) * M(50, 84)
      temp = temp + M(78, 52) * M(52, 84)
      temp = temp + M(78, 56) * M(56, 84)
      temp = temp + M(78, 60) * M(60, 84)
      temp = temp + M(78, 62) * M(62, 84)
      temp = temp + M(78, 63) * M(63, 84)
      temp = temp + M(78, 64) * M(64, 84)
      temp = temp + M(78, 65) * M(65, 84)
      temp = temp + M(78, 68) * M(68, 84)
      temp = temp + M(78, 69) * M(69, 84)
      temp = temp + M(78, 71) * M(71, 84)
      temp = temp + M(78, 72) * M(72, 84)
      temp = temp + M(78, 73) * M(73, 84)
      temp = temp + M(78, 74) * M(74, 84)
      temp = temp + M(78, 75) * M(75, 84)
      temp = temp + M(78, 76) * M(76, 84)
      temp = temp + M(78, 77) * M(77, 84)
      M(78, 84) = ( M(78, 84) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 19) * M(19, 85)
      temp = temp + M(78, 24) * M(24, 85)
      temp = temp + M(78, 25) * M(25, 85)
      temp = temp + M(78, 26) * M(26, 85)
      temp = temp + M(78, 33) * M(33, 85)
      temp = temp + M(78, 37) * M(37, 85)
      temp = temp + M(78, 43) * M(43, 85)
      temp = temp + M(78, 46) * M(46, 85)
      temp = temp + M(78, 47) * M(47, 85)
      temp = temp + M(78, 50) * M(50, 85)
      temp = temp + M(78, 52) * M(52, 85)
      temp = temp + M(78, 56) * M(56, 85)
      temp = temp + M(78, 60) * M(60, 85)
      temp = temp + M(78, 62) * M(62, 85)
      temp = temp + M(78, 63) * M(63, 85)
      temp = temp + M(78, 64) * M(64, 85)
      temp = temp + M(78, 65) * M(65, 85)
      temp = temp + M(78, 68) * M(68, 85)
      temp = temp + M(78, 69) * M(69, 85)
      temp = temp + M(78, 71) * M(71, 85)
      temp = temp + M(78, 72) * M(72, 85)
      temp = temp + M(78, 73) * M(73, 85)
      temp = temp + M(78, 74) * M(74, 85)
      temp = temp + M(78, 75) * M(75, 85)
      temp = temp + M(78, 76) * M(76, 85)
      temp = temp + M(78, 77) * M(77, 85)
      M(78, 85) = ( M(78, 85) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 22) * M(22, 86)
      temp = temp + M(78, 23) * M(23, 86)
      temp = temp + M(78, 35) * M(35, 86)
      temp = temp + M(78, 37) * M(37, 86)
      temp = temp + M(78, 43) * M(43, 86)
      temp = temp + M(78, 52) * M(52, 86)
      temp = temp + M(78, 56) * M(56, 86)
      temp = temp + M(78, 60) * M(60, 86)
      temp = temp + M(78, 62) * M(62, 86)
      temp = temp + M(78, 63) * M(63, 86)
      temp = temp + M(78, 64) * M(64, 86)
      temp = temp + M(78, 65) * M(65, 86)
      temp = temp + M(78, 68) * M(68, 86)
      temp = temp + M(78, 69) * M(69, 86)
      temp = temp + M(78, 71) * M(71, 86)
      temp = temp + M(78, 72) * M(72, 86)
      temp = temp + M(78, 73) * M(73, 86)
      temp = temp + M(78, 74) * M(74, 86)
      temp = temp + M(78, 75) * M(75, 86)
      temp = temp + M(78, 76) * M(76, 86)
      temp = temp + M(78, 77) * M(77, 86)
      M(78, 86) = ( M(78, 86) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 18) * M(18, 87)
      temp = temp + M(78, 22) * M(22, 87)
      temp = temp + M(78, 29) * M(29, 87)
      temp = temp + M(78, 31) * M(31, 87)
      temp = temp + M(78, 32) * M(32, 87)
      temp = temp + M(78, 37) * M(37, 87)
      temp = temp + M(78, 46) * M(46, 87)
      temp = temp + M(78, 47) * M(47, 87)
      temp = temp + M(78, 50) * M(50, 87)
      temp = temp + M(78, 52) * M(52, 87)
      temp = temp + M(78, 56) * M(56, 87)
      temp = temp + M(78, 60) * M(60, 87)
      temp = temp + M(78, 62) * M(62, 87)
      temp = temp + M(78, 63) * M(63, 87)
      temp = temp + M(78, 64) * M(64, 87)
      temp = temp + M(78, 65) * M(65, 87)
      temp = temp + M(78, 68) * M(68, 87)
      temp = temp + M(78, 69) * M(69, 87)
      temp = temp + M(78, 71) * M(71, 87)
      temp = temp + M(78, 72) * M(72, 87)
      temp = temp + M(78, 73) * M(73, 87)
      temp = temp + M(78, 74) * M(74, 87)
      temp = temp + M(78, 75) * M(75, 87)
      temp = temp + M(78, 76) * M(76, 87)
      temp = temp + M(78, 77) * M(77, 87)
      M(78, 87) = ( M(78, 87) - temp ) / M(78, 78)

C     Lower part.
      temp = M(79, 71) * M(71, 79)
      temp = temp + M(79, 74) * M(74, 79)
      temp = temp + M(79, 75) * M(75, 79)
      temp = temp + M(79, 76) * M(76, 79)
      temp = temp + M(79, 78) * M(78, 79)
      M(79, 79) = M(79, 79) - temp
C     Lower part.
      temp = M(80, 71) * M(71, 79)
      temp = temp + M(80, 74) * M(74, 79)
      temp = temp + M(80, 76) * M(76, 79)
      temp = temp + M(80, 78) * M(78, 79)
      M(80, 79) = M(80, 79) - temp
C     Lower part.
      temp = M(81, 69) * M(69, 79)
      temp = temp + M(81, 71) * M(71, 79)
      temp = temp + M(81, 74) * M(74, 79)
      temp = temp + M(81, 76) * M(76, 79)
      temp = temp + M(81, 78) * M(78, 79)
      M(81, 79) = M(81, 79) - temp
C     Lower part.
      temp = M(82, 71) * M(71, 79)
      temp = temp + M(82, 74) * M(74, 79)
      temp = temp + M(82, 76) * M(76, 79)
      temp = temp + M(82, 77) * M(77, 79)
      temp = temp + M(82, 78) * M(78, 79)
      M(82, 79) = M(82, 79) - temp
C     Lower part.
      temp = M(83, 71) * M(71, 79)
      temp = temp + M(83, 72) * M(72, 79)
      temp = temp + M(83, 74) * M(74, 79)
      temp = temp + M(83, 75) * M(75, 79)
      temp = temp + M(83, 76) * M(76, 79)
      temp = temp + M(83, 77) * M(77, 79)
      temp = temp + M(83, 78) * M(78, 79)
      M(83, 79) = M(83, 79) - temp
C     Lower part.
      temp = M(84, 71) * M(71, 79)
      temp = temp + M(84, 74) * M(74, 79)
      temp = temp + M(84, 76) * M(76, 79)
      temp = temp + M(84, 78) * M(78, 79)
      M(84, 79) = M(84, 79) - temp
C     Lower part.
      temp = M(85, 71) * M(71, 79)
      temp = temp + M(85, 72) * M(72, 79)
      temp = temp + M(85, 73) * M(73, 79)
      temp = temp + M(85, 74) * M(74, 79)
      temp = temp + M(85, 76) * M(76, 79)
      temp = temp + M(85, 77) * M(77, 79)
      temp = temp + M(85, 78) * M(78, 79)
      M(85, 79) = M(85, 79) - temp
C     Lower part.
      temp = M(86, 69) * M(69, 79)
      temp = temp + M(86, 71) * M(71, 79)
      temp = temp + M(86, 72) * M(72, 79)
      temp = temp + M(86, 74) * M(74, 79)
      temp = temp + M(86, 76) * M(76, 79)
      temp = temp + M(86, 77) * M(77, 79)
      temp = temp + M(86, 78) * M(78, 79)
      M(86, 79) = M(86, 79) - temp
C     Lower part.
      temp = M(87, 71) * M(71, 79)
      temp = temp + M(87, 73) * M(73, 79)
      temp = temp + M(87, 74) * M(74, 79)
      temp = temp + M(87, 76) * M(76, 79)
      temp = temp + M(87, 77) * M(77, 79)
      temp = temp + M(87, 78) * M(78, 79)
      M(87, 79) = M(87, 79) - temp
C     Upper part.
      temp = M(79, 78) * M(78, 80)
      M(79, 80) = ( M(79, 80) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 71) * M(71, 81)
      temp = temp + M(79, 74) * M(74, 81)
      temp = temp + M(79, 75) * M(75, 81)
      temp = temp + M(79, 76) * M(76, 81)
      temp = temp + M(79, 78) * M(78, 81)
      M(79, 81) = ( M(79, 81) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 52) * M(52, 82)
      temp = temp + M(79, 56) * M(56, 82)
      temp = temp + M(79, 60) * M(60, 82)
      temp = temp + M(79, 61) * M(61, 82)
      temp = temp + M(79, 63) * M(63, 82)
      temp = temp + M(79, 66) * M(66, 82)
      temp = temp + M(79, 68) * M(68, 82)
      temp = temp + M(79, 71) * M(71, 82)
      temp = temp + M(79, 74) * M(74, 82)
      temp = temp + M(79, 75) * M(75, 82)
      temp = temp + M(79, 76) * M(76, 82)
      temp = temp + M(79, 78) * M(78, 82)
      M(79, 82) = ( M(79, 82) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 52) * M(52, 83)
      temp = temp + M(79, 56) * M(56, 83)
      temp = temp + M(79, 60) * M(60, 83)
      temp = temp + M(79, 61) * M(61, 83)
      temp = temp + M(79, 63) * M(63, 83)
      temp = temp + M(79, 66) * M(66, 83)
      temp = temp + M(79, 68) * M(68, 83)
      temp = temp + M(79, 71) * M(71, 83)
      temp = temp + M(79, 74) * M(74, 83)
      temp = temp + M(79, 75) * M(75, 83)
      temp = temp + M(79, 76) * M(76, 83)
      temp = temp + M(79, 78) * M(78, 83)
      M(79, 83) = ( M(79, 83) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 52) * M(52, 84)
      temp = temp + M(79, 56) * M(56, 84)
      temp = temp + M(79, 60) * M(60, 84)
      temp = temp + M(79, 61) * M(61, 84)
      temp = temp + M(79, 63) * M(63, 84)
      temp = temp + M(79, 66) * M(66, 84)
      temp = temp + M(79, 68) * M(68, 84)
      temp = temp + M(79, 71) * M(71, 84)
      temp = temp + M(79, 74) * M(74, 84)
      temp = temp + M(79, 75) * M(75, 84)
      temp = temp + M(79, 76) * M(76, 84)
      temp = temp + M(79, 78) * M(78, 84)
      M(79, 84) = ( M(79, 84) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 24) * M(24, 85)
      temp = temp + M(79, 26) * M(26, 85)
      temp = temp + M(79, 52) * M(52, 85)
      temp = temp + M(79, 56) * M(56, 85)
      temp = temp + M(79, 60) * M(60, 85)
      temp = temp + M(79, 61) * M(61, 85)
      temp = temp + M(79, 63) * M(63, 85)
      temp = temp + M(79, 66) * M(66, 85)
      temp = temp + M(79, 68) * M(68, 85)
      temp = temp + M(79, 71) * M(71, 85)
      temp = temp + M(79, 74) * M(74, 85)
      temp = temp + M(79, 75) * M(75, 85)
      temp = temp + M(79, 76) * M(76, 85)
      temp = temp + M(79, 78) * M(78, 85)
      M(79, 85) = ( M(79, 85) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 52) * M(52, 86)
      temp = temp + M(79, 56) * M(56, 86)
      temp = temp + M(79, 60) * M(60, 86)
      temp = temp + M(79, 61) * M(61, 86)
      temp = temp + M(79, 63) * M(63, 86)
      temp = temp + M(79, 66) * M(66, 86)
      temp = temp + M(79, 68) * M(68, 86)
      temp = temp + M(79, 71) * M(71, 86)
      temp = temp + M(79, 74) * M(74, 86)
      temp = temp + M(79, 75) * M(75, 86)
      temp = temp + M(79, 76) * M(76, 86)
      temp = temp + M(79, 78) * M(78, 86)
      M(79, 86) = ( M(79, 86) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 52) * M(52, 87)
      temp = temp + M(79, 56) * M(56, 87)
      temp = temp + M(79, 60) * M(60, 87)
      temp = temp + M(79, 63) * M(63, 87)
      temp = temp + M(79, 68) * M(68, 87)
      temp = temp + M(79, 71) * M(71, 87)
      temp = temp + M(79, 74) * M(74, 87)
      temp = temp + M(79, 75) * M(75, 87)
      temp = temp + M(79, 76) * M(76, 87)
      temp = temp + M(79, 78) * M(78, 87)
      M(79, 87) = ( M(79, 87) - temp ) / M(79, 79)

C     Lower part.
      temp = M(80, 78) * M(78, 80)
      temp = temp + M(80, 79) * M(79, 80)
      M(80, 80) = M(80, 80) - temp
C     Lower part.
      temp = M(81, 78) * M(78, 80)
      temp = temp + M(81, 79) * M(79, 80)
      M(81, 80) = M(81, 80) - temp
C     Lower part.
      temp = M(82, 78) * M(78, 80)
      temp = temp + M(82, 79) * M(79, 80)
      M(82, 80) = M(82, 80) - temp
C     Lower part.
      temp = M(83, 78) * M(78, 80)
      temp = temp + M(83, 79) * M(79, 80)
      M(83, 80) = M(83, 80) - temp
C     Lower part.
      temp = M(84, 78) * M(78, 80)
      temp = temp + M(84, 79) * M(79, 80)
      M(84, 80) = M(84, 80) - temp
C     Lower part.
      temp = M(85, 73) * M(73, 80)
      temp = temp + M(85, 78) * M(78, 80)
      temp = temp + M(85, 79) * M(79, 80)
      M(85, 80) = M(85, 80) - temp
C     Lower part.
      temp = M(86, 64) * M(64, 80)
      temp = temp + M(86, 78) * M(78, 80)
      temp = temp + M(86, 79) * M(79, 80)
      M(86, 80) = M(86, 80) - temp
C     Lower part.
      temp = M(87, 73) * M(73, 80)
      temp = temp + M(87, 78) * M(78, 80)
      temp = temp + M(87, 79) * M(79, 80)
      M(87, 80) = M(87, 80) - temp
C     Upper part.
      temp = M(80, 71) * M(71, 81)
      temp = temp + M(80, 74) * M(74, 81)
      temp = temp + M(80, 76) * M(76, 81)
      temp = temp + M(80, 78) * M(78, 81)
      temp = temp + M(80, 79) * M(79, 81)
      M(80, 81) = ( M(80, 81) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 23) * M(23, 82)
      temp = temp + M(80, 39) * M(39, 82)
      temp = temp + M(80, 44) * M(44, 82)
      temp = temp + M(80, 45) * M(45, 82)
      temp = temp + M(80, 49) * M(49, 82)
      temp = temp + M(80, 51) * M(51, 82)
      temp = temp + M(80, 52) * M(52, 82)
      temp = temp + M(80, 53) * M(53, 82)
      temp = temp + M(80, 54) * M(54, 82)
      temp = temp + M(80, 55) * M(55, 82)
      temp = temp + M(80, 56) * M(56, 82)
      temp = temp + M(80, 57) * M(57, 82)
      temp = temp + M(80, 58) * M(58, 82)
      temp = temp + M(80, 59) * M(59, 82)
      temp = temp + M(80, 60) * M(60, 82)
      temp = temp + M(80, 61) * M(61, 82)
      temp = temp + M(80, 62) * M(62, 82)
      temp = temp + M(80, 63) * M(63, 82)
      temp = temp + M(80, 65) * M(65, 82)
      temp = temp + M(80, 66) * M(66, 82)
      temp = temp + M(80, 67) * M(67, 82)
      temp = temp + M(80, 68) * M(68, 82)
      temp = temp + M(80, 71) * M(71, 82)
      temp = temp + M(80, 74) * M(74, 82)
      temp = temp + M(80, 76) * M(76, 82)
      temp = temp + M(80, 78) * M(78, 82)
      temp = temp + M(80, 79) * M(79, 82)
      M(80, 82) = ( M(80, 82) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 35) * M(35, 83)
      temp = temp + M(80, 39) * M(39, 83)
      temp = temp + M(80, 44) * M(44, 83)
      temp = temp + M(80, 47) * M(47, 83)
      temp = temp + M(80, 49) * M(49, 83)
      temp = temp + M(80, 51) * M(51, 83)
      temp = temp + M(80, 52) * M(52, 83)
      temp = temp + M(80, 53) * M(53, 83)
      temp = temp + M(80, 54) * M(54, 83)
      temp = temp + M(80, 55) * M(55, 83)
      temp = temp + M(80, 56) * M(56, 83)
      temp = temp + M(80, 57) * M(57, 83)
      temp = temp + M(80, 58) * M(58, 83)
      temp = temp + M(80, 59) * M(59, 83)
      temp = temp + M(80, 60) * M(60, 83)
      temp = temp + M(80, 61) * M(61, 83)
      temp = temp + M(80, 62) * M(62, 83)
      temp = temp + M(80, 63) * M(63, 83)
      temp = temp + M(80, 65) * M(65, 83)
      temp = temp + M(80, 66) * M(66, 83)
      temp = temp + M(80, 67) * M(67, 83)
      temp = temp + M(80, 68) * M(68, 83)
      temp = temp + M(80, 71) * M(71, 83)
      temp = temp + M(80, 74) * M(74, 83)
      temp = temp + M(80, 76) * M(76, 83)
      temp = temp + M(80, 78) * M(78, 83)
      temp = temp + M(80, 79) * M(79, 83)
      M(80, 83) = ( M(80, 83) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 39) * M(39, 84)
      temp = temp + M(80, 44) * M(44, 84)
      temp = temp + M(80, 49) * M(49, 84)
      temp = temp + M(80, 50) * M(50, 84)
      temp = temp + M(80, 51) * M(51, 84)
      temp = temp + M(80, 52) * M(52, 84)
      temp = temp + M(80, 53) * M(53, 84)
      temp = temp + M(80, 54) * M(54, 84)
      temp = temp + M(80, 55) * M(55, 84)
      temp = temp + M(80, 56) * M(56, 84)
      temp = temp + M(80, 57) * M(57, 84)
      temp = temp + M(80, 58) * M(58, 84)
      temp = temp + M(80, 59) * M(59, 84)
      temp = temp + M(80, 60) * M(60, 84)
      temp = temp + M(80, 61) * M(61, 84)
      temp = temp + M(80, 62) * M(62, 84)
      temp = temp + M(80, 63) * M(63, 84)
      temp = temp + M(80, 65) * M(65, 84)
      temp = temp + M(80, 66) * M(66, 84)
      temp = temp + M(80, 67) * M(67, 84)
      temp = temp + M(80, 68) * M(68, 84)
      temp = temp + M(80, 71) * M(71, 84)
      temp = temp + M(80, 74) * M(74, 84)
      temp = temp + M(80, 76) * M(76, 84)
      temp = temp + M(80, 78) * M(78, 84)
      temp = temp + M(80, 79) * M(79, 84)
      M(80, 84) = ( M(80, 84) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 19) * M(19, 85)
      temp = temp + M(80, 25) * M(25, 85)
      temp = temp + M(80, 26) * M(26, 85)
      temp = temp + M(80, 33) * M(33, 85)
      temp = temp + M(80, 39) * M(39, 85)
      temp = temp + M(80, 44) * M(44, 85)
      temp = temp + M(80, 46) * M(46, 85)
      temp = temp + M(80, 47) * M(47, 85)
      temp = temp + M(80, 49) * M(49, 85)
      temp = temp + M(80, 50) * M(50, 85)
      temp = temp + M(80, 51) * M(51, 85)
      temp = temp + M(80, 52) * M(52, 85)
      temp = temp + M(80, 53) * M(53, 85)
      temp = temp + M(80, 54) * M(54, 85)
      temp = temp + M(80, 55) * M(55, 85)
      temp = temp + M(80, 56) * M(56, 85)
      temp = temp + M(80, 57) * M(57, 85)
      temp = temp + M(80, 58) * M(58, 85)
      temp = temp + M(80, 59) * M(59, 85)
      temp = temp + M(80, 60) * M(60, 85)
      temp = temp + M(80, 61) * M(61, 85)
      temp = temp + M(80, 62) * M(62, 85)
      temp = temp + M(80, 63) * M(63, 85)
      temp = temp + M(80, 65) * M(65, 85)
      temp = temp + M(80, 66) * M(66, 85)
      temp = temp + M(80, 67) * M(67, 85)
      temp = temp + M(80, 68) * M(68, 85)
      temp = temp + M(80, 71) * M(71, 85)
      temp = temp + M(80, 74) * M(74, 85)
      temp = temp + M(80, 76) * M(76, 85)
      temp = temp + M(80, 78) * M(78, 85)
      temp = temp + M(80, 79) * M(79, 85)
      M(80, 85) = ( M(80, 85) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 23) * M(23, 86)
      temp = temp + M(80, 35) * M(35, 86)
      temp = temp + M(80, 39) * M(39, 86)
      temp = temp + M(80, 44) * M(44, 86)
      temp = temp + M(80, 49) * M(49, 86)
      temp = temp + M(80, 51) * M(51, 86)
      temp = temp + M(80, 52) * M(52, 86)
      temp = temp + M(80, 53) * M(53, 86)
      temp = temp + M(80, 54) * M(54, 86)
      temp = temp + M(80, 55) * M(55, 86)
      temp = temp + M(80, 56) * M(56, 86)
      temp = temp + M(80, 57) * M(57, 86)
      temp = temp + M(80, 58) * M(58, 86)
      temp = temp + M(80, 59) * M(59, 86)
      temp = temp + M(80, 60) * M(60, 86)
      temp = temp + M(80, 61) * M(61, 86)
      temp = temp + M(80, 62) * M(62, 86)
      temp = temp + M(80, 63) * M(63, 86)
      temp = temp + M(80, 65) * M(65, 86)
      temp = temp + M(80, 66) * M(66, 86)
      temp = temp + M(80, 67) * M(67, 86)
      temp = temp + M(80, 68) * M(68, 86)
      temp = temp + M(80, 71) * M(71, 86)
      temp = temp + M(80, 74) * M(74, 86)
      temp = temp + M(80, 76) * M(76, 86)
      temp = temp + M(80, 78) * M(78, 86)
      temp = temp + M(80, 79) * M(79, 86)
      M(80, 86) = ( M(80, 86) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 39) * M(39, 87)
      temp = temp + M(80, 44) * M(44, 87)
      temp = temp + M(80, 46) * M(46, 87)
      temp = temp + M(80, 47) * M(47, 87)
      temp = temp + M(80, 49) * M(49, 87)
      temp = temp + M(80, 50) * M(50, 87)
      temp = temp + M(80, 51) * M(51, 87)
      temp = temp + M(80, 52) * M(52, 87)
      temp = temp + M(80, 53) * M(53, 87)
      temp = temp + M(80, 56) * M(56, 87)
      temp = temp + M(80, 57) * M(57, 87)
      temp = temp + M(80, 58) * M(58, 87)
      temp = temp + M(80, 59) * M(59, 87)
      temp = temp + M(80, 60) * M(60, 87)
      temp = temp + M(80, 62) * M(62, 87)
      temp = temp + M(80, 63) * M(63, 87)
      temp = temp + M(80, 65) * M(65, 87)
      temp = temp + M(80, 67) * M(67, 87)
      temp = temp + M(80, 68) * M(68, 87)
      temp = temp + M(80, 71) * M(71, 87)
      temp = temp + M(80, 74) * M(74, 87)
      temp = temp + M(80, 76) * M(76, 87)
      temp = temp + M(80, 78) * M(78, 87)
      temp = temp + M(80, 79) * M(79, 87)
      M(80, 87) = ( M(80, 87) - temp ) / M(80, 80)

C     Lower part.
      temp = M(81, 69) * M(69, 81)
      temp = temp + M(81, 71) * M(71, 81)
      temp = temp + M(81, 74) * M(74, 81)
      temp = temp + M(81, 76) * M(76, 81)
      temp = temp + M(81, 78) * M(78, 81)
      temp = temp + M(81, 79) * M(79, 81)
      temp = temp + M(81, 80) * M(80, 81)
      M(81, 81) = M(81, 81) - temp
C     Lower part.
      temp = M(82, 71) * M(71, 81)
      temp = temp + M(82, 74) * M(74, 81)
      temp = temp + M(82, 76) * M(76, 81)
      temp = temp + M(82, 77) * M(77, 81)
      temp = temp + M(82, 78) * M(78, 81)
      temp = temp + M(82, 79) * M(79, 81)
      temp = temp + M(82, 80) * M(80, 81)
      M(82, 81) = M(82, 81) - temp
C     Lower part.
      temp = M(83, 71) * M(71, 81)
      temp = temp + M(83, 72) * M(72, 81)
      temp = temp + M(83, 74) * M(74, 81)
      temp = temp + M(83, 75) * M(75, 81)
      temp = temp + M(83, 76) * M(76, 81)
      temp = temp + M(83, 77) * M(77, 81)
      temp = temp + M(83, 78) * M(78, 81)
      temp = temp + M(83, 79) * M(79, 81)
      temp = temp + M(83, 80) * M(80, 81)
      M(83, 81) = M(83, 81) - temp
C     Lower part.
      temp = M(84, 71) * M(71, 81)
      temp = temp + M(84, 74) * M(74, 81)
      temp = temp + M(84, 76) * M(76, 81)
      temp = temp + M(84, 78) * M(78, 81)
      temp = temp + M(84, 79) * M(79, 81)
      temp = temp + M(84, 80) * M(80, 81)
      M(84, 81) = M(84, 81) - temp
C     Lower part.
      temp = M(85, 71) * M(71, 81)
      temp = temp + M(85, 72) * M(72, 81)
      temp = temp + M(85, 73) * M(73, 81)
      temp = temp + M(85, 74) * M(74, 81)
      temp = temp + M(85, 76) * M(76, 81)
      temp = temp + M(85, 77) * M(77, 81)
      temp = temp + M(85, 78) * M(78, 81)
      temp = temp + M(85, 79) * M(79, 81)
      temp = temp + M(85, 80) * M(80, 81)
      M(85, 81) = M(85, 81) - temp
C     Lower part.
      temp = M(86, 69) * M(69, 81)
      temp = temp + M(86, 71) * M(71, 81)
      temp = temp + M(86, 72) * M(72, 81)
      temp = temp + M(86, 74) * M(74, 81)
      temp = temp + M(86, 76) * M(76, 81)
      temp = temp + M(86, 77) * M(77, 81)
      temp = temp + M(86, 78) * M(78, 81)
      temp = temp + M(86, 79) * M(79, 81)
      temp = temp + M(86, 80) * M(80, 81)
      M(86, 81) = M(86, 81) - temp
C     Lower part.
      temp = M(87, 71) * M(71, 81)
      temp = temp + M(87, 73) * M(73, 81)
      temp = temp + M(87, 74) * M(74, 81)
      temp = temp + M(87, 76) * M(76, 81)
      temp = temp + M(87, 77) * M(77, 81)
      temp = temp + M(87, 78) * M(78, 81)
      temp = temp + M(87, 79) * M(79, 81)
      temp = temp + M(87, 80) * M(80, 81)
      M(87, 81) = M(87, 81) - temp
C     Upper part.
      temp = M(81, 60) * M(60, 82)
      temp = temp + M(81, 61) * M(61, 82)
      temp = temp + M(81, 62) * M(62, 82)
      temp = temp + M(81, 63) * M(63, 82)
      temp = temp + M(81, 66) * M(66, 82)
      temp = temp + M(81, 68) * M(68, 82)
      temp = temp + M(81, 69) * M(69, 82)
      temp = temp + M(81, 71) * M(71, 82)
      temp = temp + M(81, 74) * M(74, 82)
      temp = temp + M(81, 76) * M(76, 82)
      temp = temp + M(81, 78) * M(78, 82)
      temp = temp + M(81, 79) * M(79, 82)
      temp = temp + M(81, 80) * M(80, 82)
      M(81, 82) = ( M(81, 82) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 35) * M(35, 83)
      temp = temp + M(81, 47) * M(47, 83)
      temp = temp + M(81, 60) * M(60, 83)
      temp = temp + M(81, 61) * M(61, 83)
      temp = temp + M(81, 62) * M(62, 83)
      temp = temp + M(81, 63) * M(63, 83)
      temp = temp + M(81, 66) * M(66, 83)
      temp = temp + M(81, 68) * M(68, 83)
      temp = temp + M(81, 69) * M(69, 83)
      temp = temp + M(81, 71) * M(71, 83)
      temp = temp + M(81, 74) * M(74, 83)
      temp = temp + M(81, 76) * M(76, 83)
      temp = temp + M(81, 78) * M(78, 83)
      temp = temp + M(81, 79) * M(79, 83)
      temp = temp + M(81, 80) * M(80, 83)
      M(81, 83) = ( M(81, 83) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 50) * M(50, 84)
      temp = temp + M(81, 60) * M(60, 84)
      temp = temp + M(81, 61) * M(61, 84)
      temp = temp + M(81, 62) * M(62, 84)
      temp = temp + M(81, 63) * M(63, 84)
      temp = temp + M(81, 66) * M(66, 84)
      temp = temp + M(81, 68) * M(68, 84)
      temp = temp + M(81, 69) * M(69, 84)
      temp = temp + M(81, 71) * M(71, 84)
      temp = temp + M(81, 74) * M(74, 84)
      temp = temp + M(81, 76) * M(76, 84)
      temp = temp + M(81, 78) * M(78, 84)
      temp = temp + M(81, 79) * M(79, 84)
      temp = temp + M(81, 80) * M(80, 84)
      M(81, 84) = ( M(81, 84) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 19) * M(19, 85)
      temp = temp + M(81, 33) * M(33, 85)
      temp = temp + M(81, 37) * M(37, 85)
      temp = temp + M(81, 46) * M(46, 85)
      temp = temp + M(81, 47) * M(47, 85)
      temp = temp + M(81, 50) * M(50, 85)
      temp = temp + M(81, 60) * M(60, 85)
      temp = temp + M(81, 61) * M(61, 85)
      temp = temp + M(81, 62) * M(62, 85)
      temp = temp + M(81, 63) * M(63, 85)
      temp = temp + M(81, 66) * M(66, 85)
      temp = temp + M(81, 68) * M(68, 85)
      temp = temp + M(81, 69) * M(69, 85)
      temp = temp + M(81, 71) * M(71, 85)
      temp = temp + M(81, 74) * M(74, 85)
      temp = temp + M(81, 76) * M(76, 85)
      temp = temp + M(81, 78) * M(78, 85)
      temp = temp + M(81, 79) * M(79, 85)
      temp = temp + M(81, 80) * M(80, 85)
      M(81, 85) = ( M(81, 85) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 35) * M(35, 86)
      temp = temp + M(81, 37) * M(37, 86)
      temp = temp + M(81, 60) * M(60, 86)
      temp = temp + M(81, 61) * M(61, 86)
      temp = temp + M(81, 62) * M(62, 86)
      temp = temp + M(81, 63) * M(63, 86)
      temp = temp + M(81, 66) * M(66, 86)
      temp = temp + M(81, 68) * M(68, 86)
      temp = temp + M(81, 69) * M(69, 86)
      temp = temp + M(81, 71) * M(71, 86)
      temp = temp + M(81, 74) * M(74, 86)
      temp = temp + M(81, 76) * M(76, 86)
      temp = temp + M(81, 78) * M(78, 86)
      temp = temp + M(81, 79) * M(79, 86)
      temp = temp + M(81, 80) * M(80, 86)
      M(81, 86) = ( M(81, 86) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 37) * M(37, 87)
      temp = temp + M(81, 46) * M(46, 87)
      temp = temp + M(81, 47) * M(47, 87)
      temp = temp + M(81, 50) * M(50, 87)
      temp = temp + M(81, 60) * M(60, 87)
      temp = temp + M(81, 62) * M(62, 87)
      temp = temp + M(81, 63) * M(63, 87)
      temp = temp + M(81, 68) * M(68, 87)
      temp = temp + M(81, 69) * M(69, 87)
      temp = temp + M(81, 71) * M(71, 87)
      temp = temp + M(81, 74) * M(74, 87)
      temp = temp + M(81, 76) * M(76, 87)
      temp = temp + M(81, 78) * M(78, 87)
      temp = temp + M(81, 79) * M(79, 87)
      temp = temp + M(81, 80) * M(80, 87)
      M(81, 87) = ( M(81, 87) - temp ) / M(81, 81)

C     Lower part.
      temp = M(82, 23) * M(23, 82)
      temp = temp + M(82, 39) * M(39, 82)
      temp = temp + M(82, 44) * M(44, 82)
      temp = temp + M(82, 49) * M(49, 82)
      temp = temp + M(82, 51) * M(51, 82)
      temp = temp + M(82, 52) * M(52, 82)
      temp = temp + M(82, 53) * M(53, 82)
      temp = temp + M(82, 54) * M(54, 82)
      temp = temp + M(82, 55) * M(55, 82)
      temp = temp + M(82, 56) * M(56, 82)
      temp = temp + M(82, 57) * M(57, 82)
      temp = temp + M(82, 58) * M(58, 82)
      temp = temp + M(82, 59) * M(59, 82)
      temp = temp + M(82, 60) * M(60, 82)
      temp = temp + M(82, 61) * M(61, 82)
      temp = temp + M(82, 62) * M(62, 82)
      temp = temp + M(82, 63) * M(63, 82)
      temp = temp + M(82, 66) * M(66, 82)
      temp = temp + M(82, 67) * M(67, 82)
      temp = temp + M(82, 68) * M(68, 82)
      temp = temp + M(82, 71) * M(71, 82)
      temp = temp + M(82, 74) * M(74, 82)
      temp = temp + M(82, 76) * M(76, 82)
      temp = temp + M(82, 77) * M(77, 82)
      temp = temp + M(82, 78) * M(78, 82)
      temp = temp + M(82, 79) * M(79, 82)
      temp = temp + M(82, 80) * M(80, 82)
      temp = temp + M(82, 81) * M(81, 82)
      M(82, 82) = M(82, 82) - temp
C     Lower part.
      temp = M(83, 39) * M(39, 82)
      temp = temp + M(83, 44) * M(44, 82)
      temp = temp + M(83, 45) * M(45, 82)
      temp = temp + M(83, 49) * M(49, 82)
      temp = temp + M(83, 51) * M(51, 82)
      temp = temp + M(83, 53) * M(53, 82)
      temp = temp + M(83, 54) * M(54, 82)
      temp = temp + M(83, 55) * M(55, 82)
      temp = temp + M(83, 57) * M(57, 82)
      temp = temp + M(83, 58) * M(58, 82)
      temp = temp + M(83, 59) * M(59, 82)
      temp = temp + M(83, 60) * M(60, 82)
      temp = temp + M(83, 61) * M(61, 82)
      temp = temp + M(83, 62) * M(62, 82)
      temp = temp + M(83, 63) * M(63, 82)
      temp = temp + M(83, 66) * M(66, 82)
      temp = temp + M(83, 67) * M(67, 82)
      temp = temp + M(83, 68) * M(68, 82)
      temp = temp + M(83, 71) * M(71, 82)
      temp = temp + M(83, 72) * M(72, 82)
      temp = temp + M(83, 74) * M(74, 82)
      temp = temp + M(83, 75) * M(75, 82)
      temp = temp + M(83, 76) * M(76, 82)
      temp = temp + M(83, 77) * M(77, 82)
      temp = temp + M(83, 78) * M(78, 82)
      temp = temp + M(83, 79) * M(79, 82)
      temp = temp + M(83, 80) * M(80, 82)
      temp = temp + M(83, 81) * M(81, 82)
      M(83, 82) = M(83, 82) - temp
C     Lower part.
      temp = M(84, 39) * M(39, 82)
      temp = temp + M(84, 44) * M(44, 82)
      temp = temp + M(84, 49) * M(49, 82)
      temp = temp + M(84, 51) * M(51, 82)
      temp = temp + M(84, 53) * M(53, 82)
      temp = temp + M(84, 54) * M(54, 82)
      temp = temp + M(84, 55) * M(55, 82)
      temp = temp + M(84, 57) * M(57, 82)
      temp = temp + M(84, 58) * M(58, 82)
      temp = temp + M(84, 59) * M(59, 82)
      temp = temp + M(84, 60) * M(60, 82)
      temp = temp + M(84, 61) * M(61, 82)
      temp = temp + M(84, 63) * M(63, 82)
      temp = temp + M(84, 66) * M(66, 82)
      temp = temp + M(84, 67) * M(67, 82)
      temp = temp + M(84, 68) * M(68, 82)
      temp = temp + M(84, 71) * M(71, 82)
      temp = temp + M(84, 74) * M(74, 82)
      temp = temp + M(84, 76) * M(76, 82)
      temp = temp + M(84, 78) * M(78, 82)
      temp = temp + M(84, 79) * M(79, 82)
      temp = temp + M(84, 80) * M(80, 82)
      temp = temp + M(84, 81) * M(81, 82)
      M(84, 82) = M(84, 82) - temp
C     Lower part.
      temp = M(85, 39) * M(39, 82)
      temp = temp + M(85, 44) * M(44, 82)
      temp = temp + M(85, 49) * M(49, 82)
      temp = temp + M(85, 51) * M(51, 82)
      temp = temp + M(85, 52) * M(52, 82)
      temp = temp + M(85, 53) * M(53, 82)
      temp = temp + M(85, 54) * M(54, 82)
      temp = temp + M(85, 55) * M(55, 82)
      temp = temp + M(85, 56) * M(56, 82)
      temp = temp + M(85, 57) * M(57, 82)
      temp = temp + M(85, 58) * M(58, 82)
      temp = temp + M(85, 59) * M(59, 82)
      temp = temp + M(85, 60) * M(60, 82)
      temp = temp + M(85, 61) * M(61, 82)
      temp = temp + M(85, 62) * M(62, 82)
      temp = temp + M(85, 63) * M(63, 82)
      temp = temp + M(85, 65) * M(65, 82)
      temp = temp + M(85, 66) * M(66, 82)
      temp = temp + M(85, 67) * M(67, 82)
      temp = temp + M(85, 68) * M(68, 82)
      temp = temp + M(85, 71) * M(71, 82)
      temp = temp + M(85, 72) * M(72, 82)
      temp = temp + M(85, 73) * M(73, 82)
      temp = temp + M(85, 74) * M(74, 82)
      temp = temp + M(85, 76) * M(76, 82)
      temp = temp + M(85, 77) * M(77, 82)
      temp = temp + M(85, 78) * M(78, 82)
      temp = temp + M(85, 79) * M(79, 82)
      temp = temp + M(85, 80) * M(80, 82)
      temp = temp + M(85, 81) * M(81, 82)
      M(85, 82) = M(85, 82) - temp
C     Lower part.
      temp = M(86, 23) * M(23, 82)
      temp = temp + M(86, 39) * M(39, 82)
      temp = temp + M(86, 44) * M(44, 82)
      temp = temp + M(86, 45) * M(45, 82)
      temp = temp + M(86, 49) * M(49, 82)
      temp = temp + M(86, 51) * M(51, 82)
      temp = temp + M(86, 52) * M(52, 82)
      temp = temp + M(86, 53) * M(53, 82)
      temp = temp + M(86, 54) * M(54, 82)
      temp = temp + M(86, 55) * M(55, 82)
      temp = temp + M(86, 56) * M(56, 82)
      temp = temp + M(86, 57) * M(57, 82)
      temp = temp + M(86, 58) * M(58, 82)
      temp = temp + M(86, 59) * M(59, 82)
      temp = temp + M(86, 60) * M(60, 82)
      temp = temp + M(86, 61) * M(61, 82)
      temp = temp + M(86, 62) * M(62, 82)
      temp = temp + M(86, 63) * M(63, 82)
      temp = temp + M(86, 64) * M(64, 82)
      temp = temp + M(86, 65) * M(65, 82)
      temp = temp + M(86, 66) * M(66, 82)
      temp = temp + M(86, 67) * M(67, 82)
      temp = temp + M(86, 68) * M(68, 82)
      temp = temp + M(86, 69) * M(69, 82)
      temp = temp + M(86, 71) * M(71, 82)
      temp = temp + M(86, 72) * M(72, 82)
      temp = temp + M(86, 74) * M(74, 82)
      temp = temp + M(86, 76) * M(76, 82)
      temp = temp + M(86, 77) * M(77, 82)
      temp = temp + M(86, 78) * M(78, 82)
      temp = temp + M(86, 79) * M(79, 82)
      temp = temp + M(86, 80) * M(80, 82)
      temp = temp + M(86, 81) * M(81, 82)
      M(86, 82) = M(86, 82) - temp
C     Lower part.
      temp = M(87, 39) * M(39, 82)
      temp = temp + M(87, 44) * M(44, 82)
      temp = temp + M(87, 49) * M(49, 82)
      temp = temp + M(87, 51) * M(51, 82)
      temp = temp + M(87, 53) * M(53, 82)
      temp = temp + M(87, 54) * M(54, 82)
      temp = temp + M(87, 55) * M(55, 82)
      temp = temp + M(87, 57) * M(57, 82)
      temp = temp + M(87, 58) * M(58, 82)
      temp = temp + M(87, 59) * M(59, 82)
      temp = temp + M(87, 60) * M(60, 82)
      temp = temp + M(87, 61) * M(61, 82)
      temp = temp + M(87, 62) * M(62, 82)
      temp = temp + M(87, 63) * M(63, 82)
      temp = temp + M(87, 66) * M(66, 82)
      temp = temp + M(87, 67) * M(67, 82)
      temp = temp + M(87, 68) * M(68, 82)
      temp = temp + M(87, 71) * M(71, 82)
      temp = temp + M(87, 73) * M(73, 82)
      temp = temp + M(87, 74) * M(74, 82)
      temp = temp + M(87, 76) * M(76, 82)
      temp = temp + M(87, 77) * M(77, 82)
      temp = temp + M(87, 78) * M(78, 82)
      temp = temp + M(87, 79) * M(79, 82)
      temp = temp + M(87, 80) * M(80, 82)
      temp = temp + M(87, 81) * M(81, 82)
      M(87, 82) = M(87, 82) - temp
C     Upper part.
      temp = M(82, 35) * M(35, 83)
      temp = temp + M(82, 39) * M(39, 83)
      temp = temp + M(82, 44) * M(44, 83)
      temp = temp + M(82, 49) * M(49, 83)
      temp = temp + M(82, 51) * M(51, 83)
      temp = temp + M(82, 52) * M(52, 83)
      temp = temp + M(82, 53) * M(53, 83)
      temp = temp + M(82, 54) * M(54, 83)
      temp = temp + M(82, 55) * M(55, 83)
      temp = temp + M(82, 56) * M(56, 83)
      temp = temp + M(82, 57) * M(57, 83)
      temp = temp + M(82, 58) * M(58, 83)
      temp = temp + M(82, 59) * M(59, 83)
      temp = temp + M(82, 60) * M(60, 83)
      temp = temp + M(82, 61) * M(61, 83)
      temp = temp + M(82, 62) * M(62, 83)
      temp = temp + M(82, 63) * M(63, 83)
      temp = temp + M(82, 66) * M(66, 83)
      temp = temp + M(82, 67) * M(67, 83)
      temp = temp + M(82, 68) * M(68, 83)
      temp = temp + M(82, 71) * M(71, 83)
      temp = temp + M(82, 74) * M(74, 83)
      temp = temp + M(82, 76) * M(76, 83)
      temp = temp + M(82, 77) * M(77, 83)
      temp = temp + M(82, 78) * M(78, 83)
      temp = temp + M(82, 79) * M(79, 83)
      temp = temp + M(82, 80) * M(80, 83)
      temp = temp + M(82, 81) * M(81, 83)
      M(82, 83) = ( M(82, 83) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 39) * M(39, 84)
      temp = temp + M(82, 44) * M(44, 84)
      temp = temp + M(82, 49) * M(49, 84)
      temp = temp + M(82, 50) * M(50, 84)
      temp = temp + M(82, 51) * M(51, 84)
      temp = temp + M(82, 52) * M(52, 84)
      temp = temp + M(82, 53) * M(53, 84)
      temp = temp + M(82, 54) * M(54, 84)
      temp = temp + M(82, 55) * M(55, 84)
      temp = temp + M(82, 56) * M(56, 84)
      temp = temp + M(82, 57) * M(57, 84)
      temp = temp + M(82, 58) * M(58, 84)
      temp = temp + M(82, 59) * M(59, 84)
      temp = temp + M(82, 60) * M(60, 84)
      temp = temp + M(82, 61) * M(61, 84)
      temp = temp + M(82, 62) * M(62, 84)
      temp = temp + M(82, 63) * M(63, 84)
      temp = temp + M(82, 66) * M(66, 84)
      temp = temp + M(82, 67) * M(67, 84)
      temp = temp + M(82, 68) * M(68, 84)
      temp = temp + M(82, 71) * M(71, 84)
      temp = temp + M(82, 74) * M(74, 84)
      temp = temp + M(82, 76) * M(76, 84)
      temp = temp + M(82, 77) * M(77, 84)
      temp = temp + M(82, 78) * M(78, 84)
      temp = temp + M(82, 79) * M(79, 84)
      temp = temp + M(82, 80) * M(80, 84)
      temp = temp + M(82, 81) * M(81, 84)
      M(82, 84) = ( M(82, 84) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 19) * M(19, 85)
      temp = temp + M(82, 33) * M(33, 85)
      temp = temp + M(82, 39) * M(39, 85)
      temp = temp + M(82, 44) * M(44, 85)
      temp = temp + M(82, 49) * M(49, 85)
      temp = temp + M(82, 50) * M(50, 85)
      temp = temp + M(82, 51) * M(51, 85)
      temp = temp + M(82, 52) * M(52, 85)
      temp = temp + M(82, 53) * M(53, 85)
      temp = temp + M(82, 54) * M(54, 85)
      temp = temp + M(82, 55) * M(55, 85)
      temp = temp + M(82, 56) * M(56, 85)
      temp = temp + M(82, 57) * M(57, 85)
      temp = temp + M(82, 58) * M(58, 85)
      temp = temp + M(82, 59) * M(59, 85)
      temp = temp + M(82, 60) * M(60, 85)
      temp = temp + M(82, 61) * M(61, 85)
      temp = temp + M(82, 62) * M(62, 85)
      temp = temp + M(82, 63) * M(63, 85)
      temp = temp + M(82, 66) * M(66, 85)
      temp = temp + M(82, 67) * M(67, 85)
      temp = temp + M(82, 68) * M(68, 85)
      temp = temp + M(82, 71) * M(71, 85)
      temp = temp + M(82, 74) * M(74, 85)
      temp = temp + M(82, 76) * M(76, 85)
      temp = temp + M(82, 77) * M(77, 85)
      temp = temp + M(82, 78) * M(78, 85)
      temp = temp + M(82, 79) * M(79, 85)
      temp = temp + M(82, 80) * M(80, 85)
      temp = temp + M(82, 81) * M(81, 85)
      M(82, 85) = ( M(82, 85) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 23) * M(23, 86)
      temp = temp + M(82, 35) * M(35, 86)
      temp = temp + M(82, 39) * M(39, 86)
      temp = temp + M(82, 44) * M(44, 86)
      temp = temp + M(82, 49) * M(49, 86)
      temp = temp + M(82, 51) * M(51, 86)
      temp = temp + M(82, 52) * M(52, 86)
      temp = temp + M(82, 53) * M(53, 86)
      temp = temp + M(82, 54) * M(54, 86)
      temp = temp + M(82, 55) * M(55, 86)
      temp = temp + M(82, 56) * M(56, 86)
      temp = temp + M(82, 57) * M(57, 86)
      temp = temp + M(82, 58) * M(58, 86)
      temp = temp + M(82, 59) * M(59, 86)
      temp = temp + M(82, 60) * M(60, 86)
      temp = temp + M(82, 61) * M(61, 86)
      temp = temp + M(82, 62) * M(62, 86)
      temp = temp + M(82, 63) * M(63, 86)
      temp = temp + M(82, 66) * M(66, 86)
      temp = temp + M(82, 67) * M(67, 86)
      temp = temp + M(82, 68) * M(68, 86)
      temp = temp + M(82, 71) * M(71, 86)
      temp = temp + M(82, 74) * M(74, 86)
      temp = temp + M(82, 76) * M(76, 86)
      temp = temp + M(82, 77) * M(77, 86)
      temp = temp + M(82, 78) * M(78, 86)
      temp = temp + M(82, 79) * M(79, 86)
      temp = temp + M(82, 80) * M(80, 86)
      temp = temp + M(82, 81) * M(81, 86)
      M(82, 86) = ( M(82, 86) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 39) * M(39, 87)
      temp = temp + M(82, 44) * M(44, 87)
      temp = temp + M(82, 49) * M(49, 87)
      temp = temp + M(82, 50) * M(50, 87)
      temp = temp + M(82, 51) * M(51, 87)
      temp = temp + M(82, 52) * M(52, 87)
      temp = temp + M(82, 53) * M(53, 87)
      temp = temp + M(82, 56) * M(56, 87)
      temp = temp + M(82, 57) * M(57, 87)
      temp = temp + M(82, 58) * M(58, 87)
      temp = temp + M(82, 59) * M(59, 87)
      temp = temp + M(82, 60) * M(60, 87)
      temp = temp + M(82, 62) * M(62, 87)
      temp = temp + M(82, 63) * M(63, 87)
      temp = temp + M(82, 67) * M(67, 87)
      temp = temp + M(82, 68) * M(68, 87)
      temp = temp + M(82, 71) * M(71, 87)
      temp = temp + M(82, 74) * M(74, 87)
      temp = temp + M(82, 76) * M(76, 87)
      temp = temp + M(82, 77) * M(77, 87)
      temp = temp + M(82, 78) * M(78, 87)
      temp = temp + M(82, 79) * M(79, 87)
      temp = temp + M(82, 80) * M(80, 87)
      temp = temp + M(82, 81) * M(81, 87)
      M(82, 87) = ( M(82, 87) - temp ) / M(82, 82)

C     Lower part.
      temp = M(83, 35) * M(35, 83)
      temp = temp + M(83, 39) * M(39, 83)
      temp = temp + M(83, 44) * M(44, 83)
      temp = temp + M(83, 47) * M(47, 83)
      temp = temp + M(83, 49) * M(49, 83)
      temp = temp + M(83, 51) * M(51, 83)
      temp = temp + M(83, 53) * M(53, 83)
      temp = temp + M(83, 54) * M(54, 83)
      temp = temp + M(83, 55) * M(55, 83)
      temp = temp + M(83, 57) * M(57, 83)
      temp = temp + M(83, 58) * M(58, 83)
      temp = temp + M(83, 59) * M(59, 83)
      temp = temp + M(83, 60) * M(60, 83)
      temp = temp + M(83, 61) * M(61, 83)
      temp = temp + M(83, 62) * M(62, 83)
      temp = temp + M(83, 63) * M(63, 83)
      temp = temp + M(83, 66) * M(66, 83)
      temp = temp + M(83, 67) * M(67, 83)
      temp = temp + M(83, 68) * M(68, 83)
      temp = temp + M(83, 71) * M(71, 83)
      temp = temp + M(83, 72) * M(72, 83)
      temp = temp + M(83, 74) * M(74, 83)
      temp = temp + M(83, 75) * M(75, 83)
      temp = temp + M(83, 76) * M(76, 83)
      temp = temp + M(83, 77) * M(77, 83)
      temp = temp + M(83, 78) * M(78, 83)
      temp = temp + M(83, 79) * M(79, 83)
      temp = temp + M(83, 80) * M(80, 83)
      temp = temp + M(83, 81) * M(81, 83)
      temp = temp + M(83, 82) * M(82, 83)
      M(83, 83) = M(83, 83) - temp
C     Lower part.
      temp = M(84, 39) * M(39, 83)
      temp = temp + M(84, 44) * M(44, 83)
      temp = temp + M(84, 49) * M(49, 83)
      temp = temp + M(84, 51) * M(51, 83)
      temp = temp + M(84, 53) * M(53, 83)
      temp = temp + M(84, 54) * M(54, 83)
      temp = temp + M(84, 55) * M(55, 83)
      temp = temp + M(84, 57) * M(57, 83)
      temp = temp + M(84, 58) * M(58, 83)
      temp = temp + M(84, 59) * M(59, 83)
      temp = temp + M(84, 60) * M(60, 83)
      temp = temp + M(84, 61) * M(61, 83)
      temp = temp + M(84, 63) * M(63, 83)
      temp = temp + M(84, 66) * M(66, 83)
      temp = temp + M(84, 67) * M(67, 83)
      temp = temp + M(84, 68) * M(68, 83)
      temp = temp + M(84, 71) * M(71, 83)
      temp = temp + M(84, 74) * M(74, 83)
      temp = temp + M(84, 76) * M(76, 83)
      temp = temp + M(84, 78) * M(78, 83)
      temp = temp + M(84, 79) * M(79, 83)
      temp = temp + M(84, 80) * M(80, 83)
      temp = temp + M(84, 81) * M(81, 83)
      temp = temp + M(84, 82) * M(82, 83)
      M(84, 83) = M(84, 83) - temp
C     Lower part.
      temp = M(85, 39) * M(39, 83)
      temp = temp + M(85, 44) * M(44, 83)
      temp = temp + M(85, 47) * M(47, 83)
      temp = temp + M(85, 49) * M(49, 83)
      temp = temp + M(85, 51) * M(51, 83)
      temp = temp + M(85, 52) * M(52, 83)
      temp = temp + M(85, 53) * M(53, 83)
      temp = temp + M(85, 54) * M(54, 83)
      temp = temp + M(85, 55) * M(55, 83)
      temp = temp + M(85, 56) * M(56, 83)
      temp = temp + M(85, 57) * M(57, 83)
      temp = temp + M(85, 58) * M(58, 83)
      temp = temp + M(85, 59) * M(59, 83)
      temp = temp + M(85, 60) * M(60, 83)
      temp = temp + M(85, 61) * M(61, 83)
      temp = temp + M(85, 62) * M(62, 83)
      temp = temp + M(85, 63) * M(63, 83)
      temp = temp + M(85, 65) * M(65, 83)
      temp = temp + M(85, 66) * M(66, 83)
      temp = temp + M(85, 67) * M(67, 83)
      temp = temp + M(85, 68) * M(68, 83)
      temp = temp + M(85, 71) * M(71, 83)
      temp = temp + M(85, 72) * M(72, 83)
      temp = temp + M(85, 73) * M(73, 83)
      temp = temp + M(85, 74) * M(74, 83)
      temp = temp + M(85, 76) * M(76, 83)
      temp = temp + M(85, 77) * M(77, 83)
      temp = temp + M(85, 78) * M(78, 83)
      temp = temp + M(85, 79) * M(79, 83)
      temp = temp + M(85, 80) * M(80, 83)
      temp = temp + M(85, 81) * M(81, 83)
      temp = temp + M(85, 82) * M(82, 83)
      M(85, 83) = M(85, 83) - temp
C     Lower part.
      temp = M(86, 35) * M(35, 83)
      temp = temp + M(86, 39) * M(39, 83)
      temp = temp + M(86, 44) * M(44, 83)
      temp = temp + M(86, 49) * M(49, 83)
      temp = temp + M(86, 51) * M(51, 83)
      temp = temp + M(86, 52) * M(52, 83)
      temp = temp + M(86, 53) * M(53, 83)
      temp = temp + M(86, 54) * M(54, 83)
      temp = temp + M(86, 55) * M(55, 83)
      temp = temp + M(86, 56) * M(56, 83)
      temp = temp + M(86, 57) * M(57, 83)
      temp = temp + M(86, 58) * M(58, 83)
      temp = temp + M(86, 59) * M(59, 83)
      temp = temp + M(86, 60) * M(60, 83)
      temp = temp + M(86, 61) * M(61, 83)
      temp = temp + M(86, 62) * M(62, 83)
      temp = temp + M(86, 63) * M(63, 83)
      temp = temp + M(86, 64) * M(64, 83)
      temp = temp + M(86, 65) * M(65, 83)
      temp = temp + M(86, 66) * M(66, 83)
      temp = temp + M(86, 67) * M(67, 83)
      temp = temp + M(86, 68) * M(68, 83)
      temp = temp + M(86, 69) * M(69, 83)
      temp = temp + M(86, 71) * M(71, 83)
      temp = temp + M(86, 72) * M(72, 83)
      temp = temp + M(86, 74) * M(74, 83)
      temp = temp + M(86, 76) * M(76, 83)
      temp = temp + M(86, 77) * M(77, 83)
      temp = temp + M(86, 78) * M(78, 83)
      temp = temp + M(86, 79) * M(79, 83)
      temp = temp + M(86, 80) * M(80, 83)
      temp = temp + M(86, 81) * M(81, 83)
      temp = temp + M(86, 82) * M(82, 83)
      M(86, 83) = M(86, 83) - temp
C     Lower part.
      temp = M(87, 39) * M(39, 83)
      temp = temp + M(87, 44) * M(44, 83)
      temp = temp + M(87, 47) * M(47, 83)
      temp = temp + M(87, 49) * M(49, 83)
      temp = temp + M(87, 51) * M(51, 83)
      temp = temp + M(87, 53) * M(53, 83)
      temp = temp + M(87, 54) * M(54, 83)
      temp = temp + M(87, 55) * M(55, 83)
      temp = temp + M(87, 57) * M(57, 83)
      temp = temp + M(87, 58) * M(58, 83)
      temp = temp + M(87, 59) * M(59, 83)
      temp = temp + M(87, 60) * M(60, 83)
      temp = temp + M(87, 61) * M(61, 83)
      temp = temp + M(87, 62) * M(62, 83)
      temp = temp + M(87, 63) * M(63, 83)
      temp = temp + M(87, 66) * M(66, 83)
      temp = temp + M(87, 67) * M(67, 83)
      temp = temp + M(87, 68) * M(68, 83)
      temp = temp + M(87, 71) * M(71, 83)
      temp = temp + M(87, 73) * M(73, 83)
      temp = temp + M(87, 74) * M(74, 83)
      temp = temp + M(87, 76) * M(76, 83)
      temp = temp + M(87, 77) * M(77, 83)
      temp = temp + M(87, 78) * M(78, 83)
      temp = temp + M(87, 79) * M(79, 83)
      temp = temp + M(87, 80) * M(80, 83)
      temp = temp + M(87, 81) * M(81, 83)
      temp = temp + M(87, 82) * M(82, 83)
      M(87, 83) = M(87, 83) - temp
C     Upper part.
      temp = M(83, 39) * M(39, 84)
      temp = temp + M(83, 44) * M(44, 84)
      temp = temp + M(83, 49) * M(49, 84)
      temp = temp + M(83, 50) * M(50, 84)
      temp = temp + M(83, 51) * M(51, 84)
      temp = temp + M(83, 53) * M(53, 84)
      temp = temp + M(83, 54) * M(54, 84)
      temp = temp + M(83, 55) * M(55, 84)
      temp = temp + M(83, 57) * M(57, 84)
      temp = temp + M(83, 58) * M(58, 84)
      temp = temp + M(83, 59) * M(59, 84)
      temp = temp + M(83, 60) * M(60, 84)
      temp = temp + M(83, 61) * M(61, 84)
      temp = temp + M(83, 62) * M(62, 84)
      temp = temp + M(83, 63) * M(63, 84)
      temp = temp + M(83, 66) * M(66, 84)
      temp = temp + M(83, 67) * M(67, 84)
      temp = temp + M(83, 68) * M(68, 84)
      temp = temp + M(83, 71) * M(71, 84)
      temp = temp + M(83, 72) * M(72, 84)
      temp = temp + M(83, 74) * M(74, 84)
      temp = temp + M(83, 75) * M(75, 84)
      temp = temp + M(83, 76) * M(76, 84)
      temp = temp + M(83, 77) * M(77, 84)
      temp = temp + M(83, 78) * M(78, 84)
      temp = temp + M(83, 79) * M(79, 84)
      temp = temp + M(83, 80) * M(80, 84)
      temp = temp + M(83, 81) * M(81, 84)
      temp = temp + M(83, 82) * M(82, 84)
      M(83, 84) = ( M(83, 84) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 19) * M(19, 85)
      temp = temp + M(83, 33) * M(33, 85)
      temp = temp + M(83, 39) * M(39, 85)
      temp = temp + M(83, 44) * M(44, 85)
      temp = temp + M(83, 46) * M(46, 85)
      temp = temp + M(83, 47) * M(47, 85)
      temp = temp + M(83, 49) * M(49, 85)
      temp = temp + M(83, 50) * M(50, 85)
      temp = temp + M(83, 51) * M(51, 85)
      temp = temp + M(83, 53) * M(53, 85)
      temp = temp + M(83, 54) * M(54, 85)
      temp = temp + M(83, 55) * M(55, 85)
      temp = temp + M(83, 57) * M(57, 85)
      temp = temp + M(83, 58) * M(58, 85)
      temp = temp + M(83, 59) * M(59, 85)
      temp = temp + M(83, 60) * M(60, 85)
      temp = temp + M(83, 61) * M(61, 85)
      temp = temp + M(83, 62) * M(62, 85)
      temp = temp + M(83, 63) * M(63, 85)
      temp = temp + M(83, 66) * M(66, 85)
      temp = temp + M(83, 67) * M(67, 85)
      temp = temp + M(83, 68) * M(68, 85)
      temp = temp + M(83, 71) * M(71, 85)
      temp = temp + M(83, 72) * M(72, 85)
      temp = temp + M(83, 74) * M(74, 85)
      temp = temp + M(83, 75) * M(75, 85)
      temp = temp + M(83, 76) * M(76, 85)
      temp = temp + M(83, 77) * M(77, 85)
      temp = temp + M(83, 78) * M(78, 85)
      temp = temp + M(83, 79) * M(79, 85)
      temp = temp + M(83, 80) * M(80, 85)
      temp = temp + M(83, 81) * M(81, 85)
      temp = temp + M(83, 82) * M(82, 85)
      M(83, 85) = ( M(83, 85) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 35) * M(35, 86)
      temp = temp + M(83, 39) * M(39, 86)
      temp = temp + M(83, 44) * M(44, 86)
      temp = temp + M(83, 49) * M(49, 86)
      temp = temp + M(83, 51) * M(51, 86)
      temp = temp + M(83, 53) * M(53, 86)
      temp = temp + M(83, 54) * M(54, 86)
      temp = temp + M(83, 55) * M(55, 86)
      temp = temp + M(83, 57) * M(57, 86)
      temp = temp + M(83, 58) * M(58, 86)
      temp = temp + M(83, 59) * M(59, 86)
      temp = temp + M(83, 60) * M(60, 86)
      temp = temp + M(83, 61) * M(61, 86)
      temp = temp + M(83, 62) * M(62, 86)
      temp = temp + M(83, 63) * M(63, 86)
      temp = temp + M(83, 66) * M(66, 86)
      temp = temp + M(83, 67) * M(67, 86)
      temp = temp + M(83, 68) * M(68, 86)
      temp = temp + M(83, 71) * M(71, 86)
      temp = temp + M(83, 72) * M(72, 86)
      temp = temp + M(83, 74) * M(74, 86)
      temp = temp + M(83, 75) * M(75, 86)
      temp = temp + M(83, 76) * M(76, 86)
      temp = temp + M(83, 77) * M(77, 86)
      temp = temp + M(83, 78) * M(78, 86)
      temp = temp + M(83, 79) * M(79, 86)
      temp = temp + M(83, 80) * M(80, 86)
      temp = temp + M(83, 81) * M(81, 86)
      temp = temp + M(83, 82) * M(82, 86)
      M(83, 86) = ( M(83, 86) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 39) * M(39, 87)
      temp = temp + M(83, 44) * M(44, 87)
      temp = temp + M(83, 46) * M(46, 87)
      temp = temp + M(83, 47) * M(47, 87)
      temp = temp + M(83, 49) * M(49, 87)
      temp = temp + M(83, 50) * M(50, 87)
      temp = temp + M(83, 51) * M(51, 87)
      temp = temp + M(83, 53) * M(53, 87)
      temp = temp + M(83, 57) * M(57, 87)
      temp = temp + M(83, 58) * M(58, 87)
      temp = temp + M(83, 59) * M(59, 87)
      temp = temp + M(83, 60) * M(60, 87)
      temp = temp + M(83, 62) * M(62, 87)
      temp = temp + M(83, 63) * M(63, 87)
      temp = temp + M(83, 67) * M(67, 87)
      temp = temp + M(83, 68) * M(68, 87)
      temp = temp + M(83, 71) * M(71, 87)
      temp = temp + M(83, 72) * M(72, 87)
      temp = temp + M(83, 74) * M(74, 87)
      temp = temp + M(83, 75) * M(75, 87)
      temp = temp + M(83, 76) * M(76, 87)
      temp = temp + M(83, 77) * M(77, 87)
      temp = temp + M(83, 78) * M(78, 87)
      temp = temp + M(83, 79) * M(79, 87)
      temp = temp + M(83, 80) * M(80, 87)
      temp = temp + M(83, 81) * M(81, 87)
      temp = temp + M(83, 82) * M(82, 87)
      M(83, 87) = ( M(83, 87) - temp ) / M(83, 83)

C     Lower part.
      temp = M(84, 32) * M(32, 84)
      temp = temp + M(84, 39) * M(39, 84)
      temp = temp + M(84, 44) * M(44, 84)
      temp = temp + M(84, 49) * M(49, 84)
      temp = temp + M(84, 50) * M(50, 84)
      temp = temp + M(84, 51) * M(51, 84)
      temp = temp + M(84, 53) * M(53, 84)
      temp = temp + M(84, 54) * M(54, 84)
      temp = temp + M(84, 55) * M(55, 84)
      temp = temp + M(84, 57) * M(57, 84)
      temp = temp + M(84, 58) * M(58, 84)
      temp = temp + M(84, 59) * M(59, 84)
      temp = temp + M(84, 60) * M(60, 84)
      temp = temp + M(84, 61) * M(61, 84)
      temp = temp + M(84, 63) * M(63, 84)
      temp = temp + M(84, 66) * M(66, 84)
      temp = temp + M(84, 67) * M(67, 84)
      temp = temp + M(84, 68) * M(68, 84)
      temp = temp + M(84, 71) * M(71, 84)
      temp = temp + M(84, 74) * M(74, 84)
      temp = temp + M(84, 76) * M(76, 84)
      temp = temp + M(84, 78) * M(78, 84)
      temp = temp + M(84, 79) * M(79, 84)
      temp = temp + M(84, 80) * M(80, 84)
      temp = temp + M(84, 81) * M(81, 84)
      temp = temp + M(84, 82) * M(82, 84)
      temp = temp + M(84, 83) * M(83, 84)
      M(84, 84) = M(84, 84) - temp
C     Lower part.
      temp = M(85, 39) * M(39, 84)
      temp = temp + M(85, 44) * M(44, 84)
      temp = temp + M(85, 49) * M(49, 84)
      temp = temp + M(85, 50) * M(50, 84)
      temp = temp + M(85, 51) * M(51, 84)
      temp = temp + M(85, 52) * M(52, 84)
      temp = temp + M(85, 53) * M(53, 84)
      temp = temp + M(85, 54) * M(54, 84)
      temp = temp + M(85, 55) * M(55, 84)
      temp = temp + M(85, 56) * M(56, 84)
      temp = temp + M(85, 57) * M(57, 84)
      temp = temp + M(85, 58) * M(58, 84)
      temp = temp + M(85, 59) * M(59, 84)
      temp = temp + M(85, 60) * M(60, 84)
      temp = temp + M(85, 61) * M(61, 84)
      temp = temp + M(85, 62) * M(62, 84)
      temp = temp + M(85, 63) * M(63, 84)
      temp = temp + M(85, 65) * M(65, 84)
      temp = temp + M(85, 66) * M(66, 84)
      temp = temp + M(85, 67) * M(67, 84)
      temp = temp + M(85, 68) * M(68, 84)
      temp = temp + M(85, 71) * M(71, 84)
      temp = temp + M(85, 72) * M(72, 84)
      temp = temp + M(85, 73) * M(73, 84)
      temp = temp + M(85, 74) * M(74, 84)
      temp = temp + M(85, 76) * M(76, 84)
      temp = temp + M(85, 77) * M(77, 84)
      temp = temp + M(85, 78) * M(78, 84)
      temp = temp + M(85, 79) * M(79, 84)
      temp = temp + M(85, 80) * M(80, 84)
      temp = temp + M(85, 81) * M(81, 84)
      temp = temp + M(85, 82) * M(82, 84)
      temp = temp + M(85, 83) * M(83, 84)
      M(85, 84) = M(85, 84) - temp
C     Lower part.
      temp = M(86, 39) * M(39, 84)
      temp = temp + M(86, 44) * M(44, 84)
      temp = temp + M(86, 49) * M(49, 84)
      temp = temp + M(86, 50) * M(50, 84)
      temp = temp + M(86, 51) * M(51, 84)
      temp = temp + M(86, 52) * M(52, 84)
      temp = temp + M(86, 53) * M(53, 84)
      temp = temp + M(86, 54) * M(54, 84)
      temp = temp + M(86, 55) * M(55, 84)
      temp = temp + M(86, 56) * M(56, 84)
      temp = temp + M(86, 57) * M(57, 84)
      temp = temp + M(86, 58) * M(58, 84)
      temp = temp + M(86, 59) * M(59, 84)
      temp = temp + M(86, 60) * M(60, 84)
      temp = temp + M(86, 61) * M(61, 84)
      temp = temp + M(86, 62) * M(62, 84)
      temp = temp + M(86, 63) * M(63, 84)
      temp = temp + M(86, 64) * M(64, 84)
      temp = temp + M(86, 65) * M(65, 84)
      temp = temp + M(86, 66) * M(66, 84)
      temp = temp + M(86, 67) * M(67, 84)
      temp = temp + M(86, 68) * M(68, 84)
      temp = temp + M(86, 69) * M(69, 84)
      temp = temp + M(86, 71) * M(71, 84)
      temp = temp + M(86, 72) * M(72, 84)
      temp = temp + M(86, 74) * M(74, 84)
      temp = temp + M(86, 76) * M(76, 84)
      temp = temp + M(86, 77) * M(77, 84)
      temp = temp + M(86, 78) * M(78, 84)
      temp = temp + M(86, 79) * M(79, 84)
      temp = temp + M(86, 80) * M(80, 84)
      temp = temp + M(86, 81) * M(81, 84)
      temp = temp + M(86, 82) * M(82, 84)
      temp = temp + M(86, 83) * M(83, 84)
      M(86, 84) = M(86, 84) - temp
C     Lower part.
      temp = M(87, 32) * M(32, 84)
      temp = temp + M(87, 39) * M(39, 84)
      temp = temp + M(87, 44) * M(44, 84)
      temp = temp + M(87, 49) * M(49, 84)
      temp = temp + M(87, 50) * M(50, 84)
      temp = temp + M(87, 51) * M(51, 84)
      temp = temp + M(87, 53) * M(53, 84)
      temp = temp + M(87, 54) * M(54, 84)
      temp = temp + M(87, 55) * M(55, 84)
      temp = temp + M(87, 57) * M(57, 84)
      temp = temp + M(87, 58) * M(58, 84)
      temp = temp + M(87, 59) * M(59, 84)
      temp = temp + M(87, 60) * M(60, 84)
      temp = temp + M(87, 61) * M(61, 84)
      temp = temp + M(87, 62) * M(62, 84)
      temp = temp + M(87, 63) * M(63, 84)
      temp = temp + M(87, 66) * M(66, 84)
      temp = temp + M(87, 67) * M(67, 84)
      temp = temp + M(87, 68) * M(68, 84)
      temp = temp + M(87, 71) * M(71, 84)
      temp = temp + M(87, 73) * M(73, 84)
      temp = temp + M(87, 74) * M(74, 84)
      temp = temp + M(87, 76) * M(76, 84)
      temp = temp + M(87, 77) * M(77, 84)
      temp = temp + M(87, 78) * M(78, 84)
      temp = temp + M(87, 79) * M(79, 84)
      temp = temp + M(87, 80) * M(80, 84)
      temp = temp + M(87, 81) * M(81, 84)
      temp = temp + M(87, 82) * M(82, 84)
      temp = temp + M(87, 83) * M(83, 84)
      M(87, 84) = M(87, 84) - temp
C     Upper part.
      temp = M(84, 37) * M(37, 85)
      temp = temp + M(84, 39) * M(39, 85)
      temp = temp + M(84, 44) * M(44, 85)
      temp = temp + M(84, 49) * M(49, 85)
      temp = temp + M(84, 50) * M(50, 85)
      temp = temp + M(84, 51) * M(51, 85)
      temp = temp + M(84, 53) * M(53, 85)
      temp = temp + M(84, 54) * M(54, 85)
      temp = temp + M(84, 55) * M(55, 85)
      temp = temp + M(84, 57) * M(57, 85)
      temp = temp + M(84, 58) * M(58, 85)
      temp = temp + M(84, 59) * M(59, 85)
      temp = temp + M(84, 60) * M(60, 85)
      temp = temp + M(84, 61) * M(61, 85)
      temp = temp + M(84, 63) * M(63, 85)
      temp = temp + M(84, 66) * M(66, 85)
      temp = temp + M(84, 67) * M(67, 85)
      temp = temp + M(84, 68) * M(68, 85)
      temp = temp + M(84, 71) * M(71, 85)
      temp = temp + M(84, 74) * M(74, 85)
      temp = temp + M(84, 76) * M(76, 85)
      temp = temp + M(84, 78) * M(78, 85)
      temp = temp + M(84, 79) * M(79, 85)
      temp = temp + M(84, 80) * M(80, 85)
      temp = temp + M(84, 81) * M(81, 85)
      temp = temp + M(84, 82) * M(82, 85)
      temp = temp + M(84, 83) * M(83, 85)
      M(84, 85) = ( M(84, 85) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 37) * M(37, 86)
      temp = temp + M(84, 39) * M(39, 86)
      temp = temp + M(84, 44) * M(44, 86)
      temp = temp + M(84, 49) * M(49, 86)
      temp = temp + M(84, 51) * M(51, 86)
      temp = temp + M(84, 53) * M(53, 86)
      temp = temp + M(84, 54) * M(54, 86)
      temp = temp + M(84, 55) * M(55, 86)
      temp = temp + M(84, 57) * M(57, 86)
      temp = temp + M(84, 58) * M(58, 86)
      temp = temp + M(84, 59) * M(59, 86)
      temp = temp + M(84, 60) * M(60, 86)
      temp = temp + M(84, 61) * M(61, 86)
      temp = temp + M(84, 63) * M(63, 86)
      temp = temp + M(84, 66) * M(66, 86)
      temp = temp + M(84, 67) * M(67, 86)
      temp = temp + M(84, 68) * M(68, 86)
      temp = temp + M(84, 71) * M(71, 86)
      temp = temp + M(84, 74) * M(74, 86)
      temp = temp + M(84, 76) * M(76, 86)
      temp = temp + M(84, 78) * M(78, 86)
      temp = temp + M(84, 79) * M(79, 86)
      temp = temp + M(84, 80) * M(80, 86)
      temp = temp + M(84, 81) * M(81, 86)
      temp = temp + M(84, 82) * M(82, 86)
      temp = temp + M(84, 83) * M(83, 86)
      M(84, 86) = ( M(84, 86) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 32) * M(32, 87)
      temp = temp + M(84, 37) * M(37, 87)
      temp = temp + M(84, 39) * M(39, 87)
      temp = temp + M(84, 44) * M(44, 87)
      temp = temp + M(84, 49) * M(49, 87)
      temp = temp + M(84, 50) * M(50, 87)
      temp = temp + M(84, 51) * M(51, 87)
      temp = temp + M(84, 53) * M(53, 87)
      temp = temp + M(84, 57) * M(57, 87)
      temp = temp + M(84, 58) * M(58, 87)
      temp = temp + M(84, 59) * M(59, 87)
      temp = temp + M(84, 60) * M(60, 87)
      temp = temp + M(84, 63) * M(63, 87)
      temp = temp + M(84, 67) * M(67, 87)
      temp = temp + M(84, 68) * M(68, 87)
      temp = temp + M(84, 71) * M(71, 87)
      temp = temp + M(84, 74) * M(74, 87)
      temp = temp + M(84, 76) * M(76, 87)
      temp = temp + M(84, 78) * M(78, 87)
      temp = temp + M(84, 79) * M(79, 87)
      temp = temp + M(84, 80) * M(80, 87)
      temp = temp + M(84, 81) * M(81, 87)
      temp = temp + M(84, 82) * M(82, 87)
      temp = temp + M(84, 83) * M(83, 87)
      M(84, 87) = ( M(84, 87) - temp ) / M(84, 84)

C     Lower part.
      temp = M(85, 17) * M(17, 85)
      temp = temp + M(85, 19) * M(19, 85)
      temp = temp + M(85, 24) * M(24, 85)
      temp = temp + M(85, 25) * M(25, 85)
      temp = temp + M(85, 26) * M(26, 85)
      temp = temp + M(85, 33) * M(33, 85)
      temp = temp + M(85, 37) * M(37, 85)
      temp = temp + M(85, 39) * M(39, 85)
      temp = temp + M(85, 44) * M(44, 85)
      temp = temp + M(85, 46) * M(46, 85)
      temp = temp + M(85, 47) * M(47, 85)
      temp = temp + M(85, 49) * M(49, 85)
      temp = temp + M(85, 50) * M(50, 85)
      temp = temp + M(85, 51) * M(51, 85)
      temp = temp + M(85, 52) * M(52, 85)
      temp = temp + M(85, 53) * M(53, 85)
      temp = temp + M(85, 54) * M(54, 85)
      temp = temp + M(85, 55) * M(55, 85)
      temp = temp + M(85, 56) * M(56, 85)
      temp = temp + M(85, 57) * M(57, 85)
      temp = temp + M(85, 58) * M(58, 85)
      temp = temp + M(85, 59) * M(59, 85)
      temp = temp + M(85, 60) * M(60, 85)
      temp = temp + M(85, 61) * M(61, 85)
      temp = temp + M(85, 62) * M(62, 85)
      temp = temp + M(85, 63) * M(63, 85)
      temp = temp + M(85, 65) * M(65, 85)
      temp = temp + M(85, 66) * M(66, 85)
      temp = temp + M(85, 67) * M(67, 85)
      temp = temp + M(85, 68) * M(68, 85)
      temp = temp + M(85, 71) * M(71, 85)
      temp = temp + M(85, 72) * M(72, 85)
      temp = temp + M(85, 73) * M(73, 85)
      temp = temp + M(85, 74) * M(74, 85)
      temp = temp + M(85, 76) * M(76, 85)
      temp = temp + M(85, 77) * M(77, 85)
      temp = temp + M(85, 78) * M(78, 85)
      temp = temp + M(85, 79) * M(79, 85)
      temp = temp + M(85, 80) * M(80, 85)
      temp = temp + M(85, 81) * M(81, 85)
      temp = temp + M(85, 82) * M(82, 85)
      temp = temp + M(85, 83) * M(83, 85)
      temp = temp + M(85, 84) * M(84, 85)
      M(85, 85) = M(85, 85) - temp
C     Lower part.
      temp = M(86, 19) * M(19, 85)
      temp = temp + M(86, 24) * M(24, 85)
      temp = temp + M(86, 25) * M(25, 85)
      temp = temp + M(86, 26) * M(26, 85)
      temp = temp + M(86, 33) * M(33, 85)
      temp = temp + M(86, 36) * M(36, 85)
      temp = temp + M(86, 37) * M(37, 85)
      temp = temp + M(86, 39) * M(39, 85)
      temp = temp + M(86, 43) * M(43, 85)
      temp = temp + M(86, 44) * M(44, 85)
      temp = temp + M(86, 46) * M(46, 85)
      temp = temp + M(86, 49) * M(49, 85)
      temp = temp + M(86, 50) * M(50, 85)
      temp = temp + M(86, 51) * M(51, 85)
      temp = temp + M(86, 52) * M(52, 85)
      temp = temp + M(86, 53) * M(53, 85)
      temp = temp + M(86, 54) * M(54, 85)
      temp = temp + M(86, 55) * M(55, 85)
      temp = temp + M(86, 56) * M(56, 85)
      temp = temp + M(86, 57) * M(57, 85)
      temp = temp + M(86, 58) * M(58, 85)
      temp = temp + M(86, 59) * M(59, 85)
      temp = temp + M(86, 60) * M(60, 85)
      temp = temp + M(86, 61) * M(61, 85)
      temp = temp + M(86, 62) * M(62, 85)
      temp = temp + M(86, 63) * M(63, 85)
      temp = temp + M(86, 64) * M(64, 85)
      temp = temp + M(86, 65) * M(65, 85)
      temp = temp + M(86, 66) * M(66, 85)
      temp = temp + M(86, 67) * M(67, 85)
      temp = temp + M(86, 68) * M(68, 85)
      temp = temp + M(86, 69) * M(69, 85)
      temp = temp + M(86, 71) * M(71, 85)
      temp = temp + M(86, 72) * M(72, 85)
      temp = temp + M(86, 74) * M(74, 85)
      temp = temp + M(86, 76) * M(76, 85)
      temp = temp + M(86, 77) * M(77, 85)
      temp = temp + M(86, 78) * M(78, 85)
      temp = temp + M(86, 79) * M(79, 85)
      temp = temp + M(86, 80) * M(80, 85)
      temp = temp + M(86, 81) * M(81, 85)
      temp = temp + M(86, 82) * M(82, 85)
      temp = temp + M(86, 83) * M(83, 85)
      temp = temp + M(86, 84) * M(84, 85)
      M(86, 85) = M(86, 85) - temp
C     Lower part.
      temp = M(87, 17) * M(17, 85)
      temp = temp + M(87, 36) * M(36, 85)
      temp = temp + M(87, 37) * M(37, 85)
      temp = temp + M(87, 39) * M(39, 85)
      temp = temp + M(87, 44) * M(44, 85)
      temp = temp + M(87, 46) * M(46, 85)
      temp = temp + M(87, 47) * M(47, 85)
      temp = temp + M(87, 49) * M(49, 85)
      temp = temp + M(87, 50) * M(50, 85)
      temp = temp + M(87, 51) * M(51, 85)
      temp = temp + M(87, 53) * M(53, 85)
      temp = temp + M(87, 54) * M(54, 85)
      temp = temp + M(87, 55) * M(55, 85)
      temp = temp + M(87, 57) * M(57, 85)
      temp = temp + M(87, 58) * M(58, 85)
      temp = temp + M(87, 59) * M(59, 85)
      temp = temp + M(87, 60) * M(60, 85)
      temp = temp + M(87, 61) * M(61, 85)
      temp = temp + M(87, 62) * M(62, 85)
      temp = temp + M(87, 63) * M(63, 85)
      temp = temp + M(87, 66) * M(66, 85)
      temp = temp + M(87, 67) * M(67, 85)
      temp = temp + M(87, 68) * M(68, 85)
      temp = temp + M(87, 71) * M(71, 85)
      temp = temp + M(87, 73) * M(73, 85)
      temp = temp + M(87, 74) * M(74, 85)
      temp = temp + M(87, 76) * M(76, 85)
      temp = temp + M(87, 77) * M(77, 85)
      temp = temp + M(87, 78) * M(78, 85)
      temp = temp + M(87, 79) * M(79, 85)
      temp = temp + M(87, 80) * M(80, 85)
      temp = temp + M(87, 81) * M(81, 85)
      temp = temp + M(87, 82) * M(82, 85)
      temp = temp + M(87, 83) * M(83, 85)
      temp = temp + M(87, 84) * M(84, 85)
      M(87, 85) = M(87, 85) - temp
C     Upper part.
      temp = M(85, 22) * M(22, 86)
      temp = temp + M(85, 37) * M(37, 86)
      temp = temp + M(85, 39) * M(39, 86)
      temp = temp + M(85, 44) * M(44, 86)
      temp = temp + M(85, 49) * M(49, 86)
      temp = temp + M(85, 51) * M(51, 86)
      temp = temp + M(85, 52) * M(52, 86)
      temp = temp + M(85, 53) * M(53, 86)
      temp = temp + M(85, 54) * M(54, 86)
      temp = temp + M(85, 55) * M(55, 86)
      temp = temp + M(85, 56) * M(56, 86)
      temp = temp + M(85, 57) * M(57, 86)
      temp = temp + M(85, 58) * M(58, 86)
      temp = temp + M(85, 59) * M(59, 86)
      temp = temp + M(85, 60) * M(60, 86)
      temp = temp + M(85, 61) * M(61, 86)
      temp = temp + M(85, 62) * M(62, 86)
      temp = temp + M(85, 63) * M(63, 86)
      temp = temp + M(85, 65) * M(65, 86)
      temp = temp + M(85, 66) * M(66, 86)
      temp = temp + M(85, 67) * M(67, 86)
      temp = temp + M(85, 68) * M(68, 86)
      temp = temp + M(85, 71) * M(71, 86)
      temp = temp + M(85, 72) * M(72, 86)
      temp = temp + M(85, 73) * M(73, 86)
      temp = temp + M(85, 74) * M(74, 86)
      temp = temp + M(85, 76) * M(76, 86)
      temp = temp + M(85, 77) * M(77, 86)
      temp = temp + M(85, 78) * M(78, 86)
      temp = temp + M(85, 79) * M(79, 86)
      temp = temp + M(85, 80) * M(80, 86)
      temp = temp + M(85, 81) * M(81, 86)
      temp = temp + M(85, 82) * M(82, 86)
      temp = temp + M(85, 83) * M(83, 86)
      temp = temp + M(85, 84) * M(84, 86)
      M(85, 86) = ( M(85, 86) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 17) * M(17, 87)
      temp = temp + M(85, 22) * M(22, 87)
      temp = temp + M(85, 37) * M(37, 87)
      temp = temp + M(85, 39) * M(39, 87)
      temp = temp + M(85, 44) * M(44, 87)
      temp = temp + M(85, 46) * M(46, 87)
      temp = temp + M(85, 47) * M(47, 87)
      temp = temp + M(85, 49) * M(49, 87)
      temp = temp + M(85, 50) * M(50, 87)
      temp = temp + M(85, 51) * M(51, 87)
      temp = temp + M(85, 52) * M(52, 87)
      temp = temp + M(85, 53) * M(53, 87)
      temp = temp + M(85, 56) * M(56, 87)
      temp = temp + M(85, 57) * M(57, 87)
      temp = temp + M(85, 58) * M(58, 87)
      temp = temp + M(85, 59) * M(59, 87)
      temp = temp + M(85, 60) * M(60, 87)
      temp = temp + M(85, 62) * M(62, 87)
      temp = temp + M(85, 63) * M(63, 87)
      temp = temp + M(85, 65) * M(65, 87)
      temp = temp + M(85, 67) * M(67, 87)
      temp = temp + M(85, 68) * M(68, 87)
      temp = temp + M(85, 71) * M(71, 87)
      temp = temp + M(85, 72) * M(72, 87)
      temp = temp + M(85, 73) * M(73, 87)
      temp = temp + M(85, 74) * M(74, 87)
      temp = temp + M(85, 76) * M(76, 87)
      temp = temp + M(85, 77) * M(77, 87)
      temp = temp + M(85, 78) * M(78, 87)
      temp = temp + M(85, 79) * M(79, 87)
      temp = temp + M(85, 80) * M(80, 87)
      temp = temp + M(85, 81) * M(81, 87)
      temp = temp + M(85, 82) * M(82, 87)
      temp = temp + M(85, 83) * M(83, 87)
      temp = temp + M(85, 84) * M(84, 87)
      M(85, 87) = ( M(85, 87) - temp ) / M(85, 85)

C     Lower part.
      temp = M(86, 22) * M(22, 86)
      temp = temp + M(86, 23) * M(23, 86)
      temp = temp + M(86, 35) * M(35, 86)
      temp = temp + M(86, 36) * M(36, 86)
      temp = temp + M(86, 37) * M(37, 86)
      temp = temp + M(86, 39) * M(39, 86)
      temp = temp + M(86, 43) * M(43, 86)
      temp = temp + M(86, 44) * M(44, 86)
      temp = temp + M(86, 49) * M(49, 86)
      temp = temp + M(86, 51) * M(51, 86)
      temp = temp + M(86, 52) * M(52, 86)
      temp = temp + M(86, 53) * M(53, 86)
      temp = temp + M(86, 54) * M(54, 86)
      temp = temp + M(86, 55) * M(55, 86)
      temp = temp + M(86, 56) * M(56, 86)
      temp = temp + M(86, 57) * M(57, 86)
      temp = temp + M(86, 58) * M(58, 86)
      temp = temp + M(86, 59) * M(59, 86)
      temp = temp + M(86, 60) * M(60, 86)
      temp = temp + M(86, 61) * M(61, 86)
      temp = temp + M(86, 62) * M(62, 86)
      temp = temp + M(86, 63) * M(63, 86)
      temp = temp + M(86, 64) * M(64, 86)
      temp = temp + M(86, 65) * M(65, 86)
      temp = temp + M(86, 66) * M(66, 86)
      temp = temp + M(86, 67) * M(67, 86)
      temp = temp + M(86, 68) * M(68, 86)
      temp = temp + M(86, 69) * M(69, 86)
      temp = temp + M(86, 71) * M(71, 86)
      temp = temp + M(86, 72) * M(72, 86)
      temp = temp + M(86, 74) * M(74, 86)
      temp = temp + M(86, 76) * M(76, 86)
      temp = temp + M(86, 77) * M(77, 86)
      temp = temp + M(86, 78) * M(78, 86)
      temp = temp + M(86, 79) * M(79, 86)
      temp = temp + M(86, 80) * M(80, 86)
      temp = temp + M(86, 81) * M(81, 86)
      temp = temp + M(86, 82) * M(82, 86)
      temp = temp + M(86, 83) * M(83, 86)
      temp = temp + M(86, 84) * M(84, 86)
      temp = temp + M(86, 85) * M(85, 86)
      M(86, 86) = M(86, 86) - temp
C     Lower part.
      temp = M(87, 22) * M(22, 86)
      temp = temp + M(87, 36) * M(36, 86)
      temp = temp + M(87, 37) * M(37, 86)
      temp = temp + M(87, 39) * M(39, 86)
      temp = temp + M(87, 44) * M(44, 86)
      temp = temp + M(87, 49) * M(49, 86)
      temp = temp + M(87, 51) * M(51, 86)
      temp = temp + M(87, 53) * M(53, 86)
      temp = temp + M(87, 54) * M(54, 86)
      temp = temp + M(87, 55) * M(55, 86)
      temp = temp + M(87, 57) * M(57, 86)
      temp = temp + M(87, 58) * M(58, 86)
      temp = temp + M(87, 59) * M(59, 86)
      temp = temp + M(87, 60) * M(60, 86)
      temp = temp + M(87, 61) * M(61, 86)
      temp = temp + M(87, 62) * M(62, 86)
      temp = temp + M(87, 63) * M(63, 86)
      temp = temp + M(87, 66) * M(66, 86)
      temp = temp + M(87, 67) * M(67, 86)
      temp = temp + M(87, 68) * M(68, 86)
      temp = temp + M(87, 71) * M(71, 86)
      temp = temp + M(87, 73) * M(73, 86)
      temp = temp + M(87, 74) * M(74, 86)
      temp = temp + M(87, 76) * M(76, 86)
      temp = temp + M(87, 77) * M(77, 86)
      temp = temp + M(87, 78) * M(78, 86)
      temp = temp + M(87, 79) * M(79, 86)
      temp = temp + M(87, 80) * M(80, 86)
      temp = temp + M(87, 81) * M(81, 86)
      temp = temp + M(87, 82) * M(82, 86)
      temp = temp + M(87, 83) * M(83, 86)
      temp = temp + M(87, 84) * M(84, 86)
      temp = temp + M(87, 85) * M(85, 86)
      M(87, 86) = M(87, 86) - temp
C     Upper part.
      temp = M(86, 18) * M(18, 87)
      temp = temp + M(86, 22) * M(22, 87)
      temp = temp + M(86, 29) * M(29, 87)
      temp = temp + M(86, 31) * M(31, 87)
      temp = temp + M(86, 36) * M(36, 87)
      temp = temp + M(86, 37) * M(37, 87)
      temp = temp + M(86, 39) * M(39, 87)
      temp = temp + M(86, 44) * M(44, 87)
      temp = temp + M(86, 46) * M(46, 87)
      temp = temp + M(86, 49) * M(49, 87)
      temp = temp + M(86, 50) * M(50, 87)
      temp = temp + M(86, 51) * M(51, 87)
      temp = temp + M(86, 52) * M(52, 87)
      temp = temp + M(86, 53) * M(53, 87)
      temp = temp + M(86, 56) * M(56, 87)
      temp = temp + M(86, 57) * M(57, 87)
      temp = temp + M(86, 58) * M(58, 87)
      temp = temp + M(86, 59) * M(59, 87)
      temp = temp + M(86, 60) * M(60, 87)
      temp = temp + M(86, 62) * M(62, 87)
      temp = temp + M(86, 63) * M(63, 87)
      temp = temp + M(86, 64) * M(64, 87)
      temp = temp + M(86, 65) * M(65, 87)
      temp = temp + M(86, 67) * M(67, 87)
      temp = temp + M(86, 68) * M(68, 87)
      temp = temp + M(86, 69) * M(69, 87)
      temp = temp + M(86, 71) * M(71, 87)
      temp = temp + M(86, 72) * M(72, 87)
      temp = temp + M(86, 74) * M(74, 87)
      temp = temp + M(86, 76) * M(76, 87)
      temp = temp + M(86, 77) * M(77, 87)
      temp = temp + M(86, 78) * M(78, 87)
      temp = temp + M(86, 79) * M(79, 87)
      temp = temp + M(86, 80) * M(80, 87)
      temp = temp + M(86, 81) * M(81, 87)
      temp = temp + M(86, 82) * M(82, 87)
      temp = temp + M(86, 83) * M(83, 87)
      temp = temp + M(86, 84) * M(84, 87)
      temp = temp + M(86, 85) * M(85, 87)
      M(86, 87) = ( M(86, 87) - temp ) / M(86, 86)

C     Lower part.
      temp = M(87, 17) * M(17, 87)
      temp = temp + M(87, 18) * M(18, 87)
      temp = temp + M(87, 22) * M(22, 87)
      temp = temp + M(87, 29) * M(29, 87)
      temp = temp + M(87, 31) * M(31, 87)
      temp = temp + M(87, 32) * M(32, 87)
      temp = temp + M(87, 36) * M(36, 87)
      temp = temp + M(87, 37) * M(37, 87)
      temp = temp + M(87, 39) * M(39, 87)
      temp = temp + M(87, 44) * M(44, 87)
      temp = temp + M(87, 46) * M(46, 87)
      temp = temp + M(87, 47) * M(47, 87)
      temp = temp + M(87, 49) * M(49, 87)
      temp = temp + M(87, 50) * M(50, 87)
      temp = temp + M(87, 51) * M(51, 87)
      temp = temp + M(87, 53) * M(53, 87)
      temp = temp + M(87, 57) * M(57, 87)
      temp = temp + M(87, 58) * M(58, 87)
      temp = temp + M(87, 59) * M(59, 87)
      temp = temp + M(87, 60) * M(60, 87)
      temp = temp + M(87, 62) * M(62, 87)
      temp = temp + M(87, 63) * M(63, 87)
      temp = temp + M(87, 67) * M(67, 87)
      temp = temp + M(87, 68) * M(68, 87)
      temp = temp + M(87, 71) * M(71, 87)
      temp = temp + M(87, 73) * M(73, 87)
      temp = temp + M(87, 74) * M(74, 87)
      temp = temp + M(87, 76) * M(76, 87)
      temp = temp + M(87, 77) * M(77, 87)
      temp = temp + M(87, 78) * M(78, 87)
      temp = temp + M(87, 79) * M(79, 87)
      temp = temp + M(87, 80) * M(80, 87)
      temp = temp + M(87, 81) * M(81, 87)
      temp = temp + M(87, 82) * M(82, 87)
      temp = temp + M(87, 83) * M(83, 87)
      temp = temp + M(87, 84) * M(84, 87)
      temp = temp + M(87, 85) * M(85, 87)
      temp = temp + M(87, 86) * M(86, 87)
      M(87, 87) = M(87, 87) - temp


      END
