C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc                        (
     $    ns,nr,y,convers_factor,convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM_SORGAM_isop_new
C     Species: _ciRACM_SORGAM_isop.
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc                        (
     $    ns,nr,rk,conc,dw)
 
      JacC( 50, 87) = JacC( 50, 87) + dw(  1, 87)
      JacC( 84, 87) = JacC( 84, 87) + dw(  1, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(  1, 87)
      JacC(  7, 63) = JacC(  7, 63) + dw(  2, 63)
      JacC( 63, 63) = JacC( 63, 63) - dw(  2, 63)
      JacC( 50, 63) = JacC( 50, 63) + dw(  3, 63)
      JacC( 63, 63) = JacC( 63, 63) - dw(  3, 63)
      JacC( 32, 32) = JacC( 32, 32) - dw(  4, 32)
      JacC( 78, 32) = JacC( 78, 32) + dw(  4, 32)
      JacC( 84, 32) = JacC( 84, 32) + dw(  4, 32)
      JacC( 73, 73) = JacC( 73, 73) - dw(  5, 73)
      JacC( 78, 73) = JacC( 78, 73) + dw(  5, 73)
      JacC( 87, 73) = JacC( 87, 73) + dw(  5, 73)
      JacC( 22, 22) = JacC( 22, 22) - dw(  6, 22)
      JacC( 78, 22) = JacC( 78, 22)+ 0.3500000000000000D+00*dw(  6, 22)
      JacC( 85, 22) = JacC( 85, 22)+ 0.3500000000000000D+00*dw(  6, 22)
      JacC( 86, 22) = JacC( 86, 22)+ 0.6500000000000000D+00*dw(  6, 22)
      JacC( 87, 22) = JacC( 87, 22)+ 0.6500000000000000D+00*dw(  6, 22)
      JacC( 84, 85) = JacC( 84, 85) + dw(  7, 85)
      JacC( 85, 85) = JacC( 85, 85) - dw(  7, 85)
      JacC( 50, 85) = JacC( 50, 85) + dw(  8, 85)
      JacC( 85, 85) = JacC( 85, 85) - dw(  8, 85)
      JacC( 87, 85) = JacC( 87, 85) + dw(  8, 85)
      JacC( 43, 43) = JacC( 43, 43) - dw(  9, 43)
      JacC( 78, 43) = JacC( 78, 43)+ 0.2000000000000000D+01*dw(  9, 43)
      JacC( 64, 80) = JacC( 64, 80) + dw( 10, 80)
      JacC( 80, 80) = JacC( 80, 80) - dw( 10, 80)
      JacC( 64, 80) = JacC( 64, 80) + dw( 11, 80)
      JacC( 80, 80) = JacC( 80, 80) - dw( 11, 80)
      JacC( 86, 80) = JacC( 86, 80)+ 0.2000000000000000D+01*dw( 11, 80)
      JacC( 64, 77) = JacC( 64, 77) + dw( 12, 77)
      JacC( 77, 77) = JacC( 77, 77) - dw( 12, 77)
      JacC( 82, 77) = JacC( 82, 77) + dw( 12, 77)
      JacC( 86, 77) = JacC( 86, 77) + dw( 12, 77)
      JacC( 23, 23) = JacC( 23, 23) - dw( 13, 23)
      JacC( 78, 23) = JacC( 78, 23) + dw( 13, 23)
      JacC( 80, 23) = JacC( 80, 23) + dw( 13, 23)
      JacC( 86, 23) = JacC( 86, 23) + dw( 13, 23)
      JacC( 69, 69) = JacC( 69, 69) - dw( 14, 69)
      JacC( 77, 69) = JacC( 77, 69) + dw( 14, 69)
      JacC( 78, 69) = JacC( 78, 69) + dw( 14, 69)
      JacC( 86, 69) = JacC( 86, 69) + dw( 14, 69)
      JacC( 35, 35) = JacC( 35, 35) - dw( 15, 35)
      JacC( 78, 35) = JacC( 78, 35) + dw( 15, 35)
      JacC( 82, 35) = JacC( 82, 35) + dw( 15, 35)
      JacC( 75, 75) = JacC( 75, 75) - dw( 16, 75)
      JacC( 79, 75) = JacC( 79, 75) + dw( 16, 75)
      JacC( 83, 75) = JacC( 83, 75) + dw( 16, 75)
      JacC( 64, 65) = JacC( 64, 65)+ 0.1870000000000000D+01*dw( 17, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw( 17, 65)
      JacC( 80, 65) = JacC( 80, 65)+ 0.1300000000000000D+00*dw( 17, 65)
      JacC( 64, 65) = JacC( 64, 65)+ 0.1550000000000000D+01*dw( 18, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw( 18, 65)
      JacC( 80, 65) = JacC( 80, 65)+ 0.4500000000000000D+00*dw( 18, 65)
      JacC( 86, 65) = JacC( 86, 65)+ 0.8000000000000000D+00*dw( 18, 65)
      JacC( 64, 72) = JacC( 64, 72) + dw( 19, 72)
      JacC( 72, 72) = JacC( 72, 72) - dw( 19, 72)
      JacC( 83, 72) = JacC( 83, 72) + dw( 19, 72)
      JacC( 86, 72) = JacC( 86, 72) + dw( 19, 72)
      JacC( 62, 62) = JacC( 62, 62) - dw( 20, 62)
      JacC( 68, 62) = JacC( 68, 62) + dw( 20, 62)
      JacC( 86, 62) = JacC( 86, 62) + dw( 20, 62)
      JacC( 74, 74) = JacC( 74, 74) - dw( 21, 74)
      JacC( 75, 74) = JacC( 75, 74)+ 0.8000000000000000D+00*dw( 21, 74)
      JacC( 77, 74) = JacC( 77, 74)+ 0.2000000000000000D+00*dw( 21, 74)
      JacC( 86, 74) = JacC( 86, 74) + dw( 21, 74)
      JacC( 87, 74) = JacC( 87, 74) + dw( 21, 74)
      JacC( 60, 60) = JacC( 60, 60) - dw( 22, 60)
      JacC( 64, 60) = JacC( 64, 60) + dw( 22, 60)
      JacC( 80, 60) = JacC( 80, 60) + dw( 22, 60)
      JacC( 83, 60) = JacC( 83, 60) + dw( 22, 60)
      JacC( 86, 60) = JacC( 86, 60) + dw( 22, 60)
      JacC( 45, 45) = JacC( 45, 45) - dw( 23, 45)
      JacC( 80, 45) = JacC( 80, 45) + dw( 23, 45)
      JacC( 83, 45) = JacC( 83, 45) + dw( 23, 45)
      JacC( 86, 45) = JacC( 86, 45) + dw( 23, 45)
      JacC( 50, 50) = JacC( 50, 50) - dw( 24, 50)
      JacC( 63, 50) = JacC( 63, 50) + dw( 24, 50)
      JacC( 50, 50) = JacC( 50, 50) - dw( 25, 50)
      JacC( 50, 63) = JacC( 50, 63) - dw( 25, 63)
      JacC( 63, 50) = JacC( 63, 50) - dw( 25, 50)
      JacC( 63, 63) = JacC( 63, 63) - dw( 25, 63)
      JacC(  7,  7) = JacC(  7,  7) - dw( 26,  7)
      JacC( 50,  7) = JacC( 50,  7) + dw( 26,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 27,  7)
      JacC( 50,  7) = JacC( 50,  7) + dw( 27,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 28,  7)
      JacC( 78,  7) = JacC( 78,  7)+ 0.2000000000000000D+01*dw( 28,  7)
      JacC( 63, 63) = JacC( 63, 63) - dw( 29, 63)
      JacC( 63, 78) = JacC( 63, 78) - dw( 29, 78)
      JacC( 78, 63) = JacC( 78, 63) - dw( 29, 63)
      JacC( 78, 78) = JacC( 78, 78) - dw( 29, 78)
      JacC( 86, 63) = JacC( 86, 63) + dw( 29, 63)
      JacC( 86, 78) = JacC( 86, 78) + dw( 29, 78)
      JacC( 63, 63) = JacC( 63, 63) - dw( 30, 63)
      JacC( 63, 86) = JacC( 63, 86) - dw( 30, 86)
      JacC( 78, 63) = JacC( 78, 63) + dw( 30, 63)
      JacC( 78, 86) = JacC( 78, 86) + dw( 30, 86)
      JacC( 86, 63) = JacC( 86, 63) - dw( 30, 63)
      JacC( 86, 86) = JacC( 86, 86) - dw( 30, 86)
      JacC( 78, 78) = JacC( 78, 78) - dw( 31, 78)
      JacC( 78, 86) = JacC( 78, 86) - dw( 31, 86)
      JacC( 86, 78) = JacC( 86, 78) - dw( 31, 78)
      JacC( 86, 86) = JacC( 86, 86) - dw( 31, 86)
      JacC( 43, 43) = JacC( 43, 43) - dw( 32, 43)
      JacC( 43, 78) = JacC( 43, 78) - dw( 32, 78)
      JacC( 78, 43) = JacC( 78, 43) - dw( 32, 43)
      JacC( 78, 78) = JacC( 78, 78) - dw( 32, 78)
      JacC( 86, 43) = JacC( 86, 43) + dw( 32, 43)
      JacC( 86, 78) = JacC( 86, 78) + dw( 32, 78)
      JacC( 43, 86) = JacC( 43, 86) + dw( 33, 86)
      JacC( 43, 86) = JacC( 43, 86) + dw( 33, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 33, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 33, 86)
      JacC( 43, 86) = JacC( 43, 86) + dw( 34, 86)
      JacC( 43, 86) = JacC( 43, 86) + dw( 34, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 34, 86)
      JacC( 86, 86) = JacC( 86, 86)- 0.2000000000000000D+01*dw( 34, 86)
      JacC( 50, 50) = JacC( 50, 50) - dw( 35, 50)
      JacC( 50, 84) = JacC( 50, 84) - dw( 35, 84)
      JacC( 84, 50) = JacC( 84, 50) - dw( 35, 50)
      JacC( 84, 84) = JacC( 84, 84) - dw( 35, 84)
      JacC( 87, 50) = JacC( 87, 50) + dw( 35, 50)
      JacC( 87, 84) = JacC( 87, 84) + dw( 35, 84)
      JacC( 50, 50) = JacC( 50, 50) - dw( 36, 50)
      JacC( 50, 87) = JacC( 50, 87) - dw( 36, 87)
      JacC( 84, 50) = JacC( 84, 50) + dw( 36, 50)
      JacC( 84, 87) = JacC( 84, 87) + dw( 36, 87)
      JacC( 87, 50) = JacC( 87, 50) - dw( 36, 50)
      JacC( 87, 87) = JacC( 87, 87) - dw( 36, 87)
      JacC( 50, 50) = JacC( 50, 50) - dw( 37, 50)
      JacC( 50, 87) = JacC( 50, 87) - dw( 37, 87)
      JacC( 85, 50) = JacC( 85, 50) + dw( 37, 50)
      JacC( 85, 87) = JacC( 85, 87) + dw( 37, 87)
      JacC( 87, 50) = JacC( 87, 50) - dw( 37, 50)
      JacC( 87, 87) = JacC( 87, 87) - dw( 37, 87)
      JacC( 32, 78) = JacC( 32, 78) + dw( 38, 78)
      JacC( 32, 84) = JacC( 32, 84) + dw( 38, 84)
      JacC( 78, 78) = JacC( 78, 78) - dw( 38, 78)
      JacC( 78, 84) = JacC( 78, 84) - dw( 38, 84)
      JacC( 84, 78) = JacC( 84, 78) - dw( 38, 78)
      JacC( 84, 84) = JacC( 84, 84) - dw( 38, 84)
      JacC( 73, 78) = JacC( 73, 78) + dw( 39, 78)
      JacC( 73, 87) = JacC( 73, 87) + dw( 39, 87)
      JacC( 78, 78) = JacC( 78, 78) - dw( 39, 78)
      JacC( 78, 87) = JacC( 78, 87) - dw( 39, 87)
      JacC( 87, 78) = JacC( 87, 78) - dw( 39, 78)
      JacC( 87, 87) = JacC( 87, 87) - dw( 39, 87)
      JacC( 78, 78) = JacC( 78, 78) - dw( 40, 78)
      JacC( 78, 85) = JacC( 78, 85) - dw( 40, 85)
      JacC( 85, 78) = JacC( 85, 78) - dw( 40, 78)
      JacC( 85, 85) = JacC( 85, 85) - dw( 40, 85)
      JacC( 86, 78) = JacC( 86, 78) + dw( 40, 78)
      JacC( 86, 85) = JacC( 86, 85) + dw( 40, 85)
      JacC( 87, 78) = JacC( 87, 78) + dw( 40, 78)
      JacC( 87, 85) = JacC( 87, 85) + dw( 40, 85)
      JacC( 78, 86) = JacC( 78, 86) + dw( 41, 86)
      JacC( 78, 84) = JacC( 78, 84) + dw( 41, 84)
      JacC( 84, 86) = JacC( 84, 86) - dw( 41, 86)
      JacC( 84, 84) = JacC( 84, 84) - dw( 41, 84)
      JacC( 86, 86) = JacC( 86, 86) - dw( 41, 86)
      JacC( 86, 84) = JacC( 86, 84) - dw( 41, 84)
      JacC( 87, 86) = JacC( 87, 86) + dw( 41, 86)
      JacC( 87, 84) = JacC( 87, 84) + dw( 41, 84)
      JacC( 22, 86) = JacC( 22, 86) + dw( 42, 86)
      JacC( 22, 87) = JacC( 22, 87) + dw( 42, 87)
      JacC( 86, 86) = JacC( 86, 86) - dw( 42, 86)
      JacC( 86, 87) = JacC( 86, 87) - dw( 42, 87)
      JacC( 87, 86) = JacC( 87, 86) - dw( 42, 86)
      JacC( 87, 87) = JacC( 87, 87) - dw( 42, 87)
      JacC( 22, 22) = JacC( 22, 22) - dw( 43, 22)
      JacC( 86, 22) = JacC( 86, 22) + dw( 43, 22)
      JacC( 87, 22) = JacC( 87, 22) + dw( 43, 22)
      JacC( 73, 86) = JacC( 73, 86)+ 0.3000000000000000D+00*dw( 44, 86)
      JacC( 73, 85) = JacC( 73, 85)+ 0.3000000000000000D+00*dw( 44, 85)
      JacC( 78, 86) = JacC( 78, 86)+ 0.7000000000000000D+00*dw( 44, 86)
      JacC( 78, 85) = JacC( 78, 85)+ 0.7000000000000000D+00*dw( 44, 85)
      JacC( 85, 86) = JacC( 85, 86) - dw( 44, 86)
      JacC( 85, 85) = JacC( 85, 85) - dw( 44, 85)
      JacC( 86, 86) = JacC( 86, 86) - dw( 44, 86)
      JacC( 86, 85) = JacC( 86, 85) - dw( 44, 85)
      JacC( 87, 86) = JacC( 87, 86)+ 0.7000000000000000D+00*dw( 44, 86)
      JacC( 87, 85) = JacC( 87, 85)+ 0.7000000000000000D+00*dw( 44, 85)
      JacC( 32, 78) = JacC( 32, 78) - dw( 45, 78)
      JacC( 32, 32) = JacC( 32, 32) - dw( 45, 32)
      JacC( 78, 78) = JacC( 78, 78) - dw( 45, 78)
      JacC( 78, 32) = JacC( 78, 32) - dw( 45, 32)
      JacC( 87, 78) = JacC( 87, 78) + dw( 45, 78)
      JacC( 87, 32) = JacC( 87, 32) + dw( 45, 32)
      JacC( 73, 78) = JacC( 73, 78) - dw( 46, 78)
      JacC( 73, 73) = JacC( 73, 73) - dw( 46, 73)
      JacC( 78, 78) = JacC( 78, 78) - dw( 46, 78)
      JacC( 78, 73) = JacC( 78, 73) - dw( 46, 73)
      JacC( 85, 78) = JacC( 85, 78) + dw( 46, 78)
      JacC( 85, 73) = JacC( 85, 73) + dw( 46, 73)
      JacC( 22, 78) = JacC( 22, 78) - dw( 47, 78)
      JacC( 22, 22) = JacC( 22, 22) - dw( 47, 22)
      JacC( 78, 78) = JacC( 78, 78) - dw( 47, 78)
      JacC( 78, 22) = JacC( 78, 22) - dw( 47, 22)
      JacC( 87, 78) = JacC( 87, 78) + dw( 47, 78)
      JacC( 87, 22) = JacC( 87, 22) + dw( 47, 22)
      JacC( 63, 63) = JacC( 63, 63) - dw( 48, 63)
      JacC( 63, 84) = JacC( 63, 84) - dw( 48, 84)
      JacC( 84, 63) = JacC( 84, 63) - dw( 48, 63)
      JacC( 84, 84) = JacC( 84, 84) - dw( 48, 84)
      JacC( 87, 63) = JacC( 87, 63) + dw( 48, 63)
      JacC( 87, 84) = JacC( 87, 84) + dw( 48, 84)
      JacC( 63, 63) = JacC( 63, 63) - dw( 49, 63)
      JacC( 63, 87) = JacC( 63, 87) - dw( 49, 87)
      JacC( 85, 63) = JacC( 85, 63) + dw( 49, 63)
      JacC( 85, 87) = JacC( 85, 87) + dw( 49, 87)
      JacC( 87, 63) = JacC( 87, 63) - dw( 49, 63)
      JacC( 87, 87) = JacC( 87, 87) - dw( 49, 87)
      JacC( 84, 84) = JacC( 84, 84)- 0.2000000000000000D+01*dw( 50, 84)
      JacC( 84, 84) = JacC( 84, 84)- 0.2000000000000000D+01*dw( 50, 84)
      JacC( 87, 84) = JacC( 87, 84)+ 0.2000000000000000D+01*dw( 50, 84)
      JacC( 87, 84) = JacC( 87, 84)+ 0.2000000000000000D+01*dw( 50, 84)
      JacC( 84, 85) = JacC( 84, 85) - dw( 51, 85)
      JacC( 84, 84) = JacC( 84, 84) - dw( 51, 84)
      JacC( 85, 85) = JacC( 85, 85) - dw( 51, 85)
      JacC( 85, 84) = JacC( 85, 84) - dw( 51, 84)
      JacC( 87, 85) = JacC( 87, 85)+ 0.2000000000000000D+01*dw( 51, 85)
      JacC( 87, 84) = JacC( 87, 84)+ 0.2000000000000000D+01*dw( 51, 84)
      JacC( 84, 85) = JacC( 84, 85) + dw( 52, 85)
      JacC( 84, 87) = JacC( 84, 87) + dw( 52, 87)
      JacC( 85, 85) = JacC( 85, 85) - dw( 52, 85)
      JacC( 85, 87) = JacC( 85, 87) - dw( 52, 87)
      JacC( 17, 85) = JacC( 17, 85) + dw( 53, 85)
      JacC( 17, 87) = JacC( 17, 87) + dw( 53, 87)
      JacC( 85, 85) = JacC( 85, 85) - dw( 53, 85)
      JacC( 85, 87) = JacC( 85, 87) - dw( 53, 87)
      JacC( 87, 85) = JacC( 87, 85) - dw( 53, 85)
      JacC( 87, 87) = JacC( 87, 87) - dw( 53, 87)
      JacC( 17, 17) = JacC( 17, 17) - dw( 54, 17)
      JacC( 85, 17) = JacC( 85, 17) + dw( 54, 17)
      JacC( 87, 17) = JacC( 87, 17) + dw( 54, 17)
      JacC( 85, 85) = JacC( 85, 85)- 0.2000000000000000D+01*dw( 55, 85)
      JacC( 85, 85) = JacC( 85, 85)- 0.2000000000000000D+01*dw( 55, 85)
      JacC( 87, 85) = JacC( 87, 85)+ 0.2000000000000000D+01*dw( 55, 85)
      JacC( 87, 85) = JacC( 87, 85)+ 0.2000000000000000D+01*dw( 55, 85)
      JacC( 78, 78) = JacC( 78, 78) - dw( 56, 78)
      JacC( 86, 78) = JacC( 86, 78) + dw( 56, 78)
      JacC(  9, 78) = JacC(  9, 78) - dw( 57, 78)
      JacC(  9,  9) = JacC(  9,  9) - dw( 57,  9)
      JacC( 10, 78) = JacC( 10, 78) + dw( 57, 78)
      JacC( 10,  9) = JacC( 10,  9) + dw( 57,  9)
      JacC( 78, 78) = JacC( 78, 78) - dw( 57, 78)
      JacC( 78,  9) = JacC( 78,  9) - dw( 57,  9)
      JacC( 86, 78) = JacC( 86, 78) + dw( 57, 78)
      JacC( 86,  9) = JacC( 86,  9) + dw( 57,  9)
      JacC( 64, 64) = JacC( 64, 64) - dw( 58, 64)
      JacC( 64, 78) = JacC( 64, 78) - dw( 58, 78)
      JacC( 78, 64) = JacC( 78, 64) - dw( 58, 64)
      JacC( 78, 78) = JacC( 78, 78) - dw( 58, 78)
      JacC( 86, 64) = JacC( 86, 64) + dw( 58, 64)
      JacC( 86, 78) = JacC( 86, 78) + dw( 58, 78)
      JacC( 33, 33) = JacC( 33, 33) - dw( 59, 33)
      JacC( 33, 50) = JacC( 33, 50) - dw( 59, 50)
      JacC( 50, 33) = JacC( 50, 33) - dw( 59, 33)
      JacC( 50, 50) = JacC( 50, 50) - dw( 59, 50)
      JacC( 52, 33) = JacC( 52, 33)+ 0.8600000000000000D+00*dw( 59, 33)
      JacC( 52, 50) = JacC( 52, 50)+ 0.8600000000000000D+00*dw( 59, 50)
      JacC( 62, 33) = JacC( 62, 33)+ 0.1300000000000000D+00*dw( 59, 33)
      JacC( 62, 50) = JacC( 62, 50)+ 0.1300000000000000D+00*dw( 59, 50)
      JacC( 64, 33) = JacC( 64, 33)+ 0.1000000000000000D-01*dw( 59, 33)
      JacC( 64, 50) = JacC( 64, 50)+ 0.1000000000000000D-01*dw( 59, 50)
      JacC( 78, 33) = JacC( 78, 33)+ 0.2000000000000000D-01*dw( 59, 33)
      JacC( 78, 50) = JacC( 78, 50)+ 0.2000000000000000D-01*dw( 59, 50)
      JacC( 80, 33) = JacC( 80, 33)+ 0.5000000000000000D-01*dw( 59, 33)
      JacC( 80, 50) = JacC( 80, 50)+ 0.5000000000000000D-01*dw( 59, 50)
      JacC( 81, 33) = JacC( 81, 33)+ 0.1500000000000000D+00*dw( 59, 33)
      JacC( 81, 50) = JacC( 81, 50)+ 0.1500000000000000D+00*dw( 59, 50)
      JacC( 86, 33) = JacC( 86, 33)+ 0.2800000000000000D+00*dw( 59, 33)
      JacC( 86, 50) = JacC( 86, 50)+ 0.2800000000000000D+00*dw( 59, 50)
      JacC( 50, 60) = JacC( 50, 60) - dw( 60, 60)
      JacC( 50, 50) = JacC( 50, 50) - dw( 60, 50)
      JacC( 60, 60) = JacC( 60, 60) - dw( 60, 60)
      JacC( 60, 50) = JacC( 60, 50) - dw( 60, 50)
      JacC( 77, 60) = JacC( 77, 60) + dw( 60, 60)
      JacC( 77, 50) = JacC( 77, 50) + dw( 60, 50)
      JacC( 34, 34) = JacC( 34, 34) - dw( 61, 34)
      JacC( 34, 78) = JacC( 34, 78) - dw( 61, 78)
      JacC( 78, 34) = JacC( 78, 34) - dw( 61, 34)
      JacC( 78, 78) = JacC( 78, 78) - dw( 61, 78)
      JacC( 82, 34) = JacC( 82, 34) + dw( 61, 34)
      JacC( 82, 78) = JacC( 82, 78) + dw( 61, 78)
      JacC( 30, 30) = JacC( 30, 30) - dw( 62, 30)
      JacC( 30, 78) = JacC( 30, 78) - dw( 62, 78)
      JacC( 78, 30) = JacC( 78, 30) - dw( 62, 30)
      JacC( 78, 78) = JacC( 78, 78) - dw( 62, 78)
      JacC( 79, 30) = JacC( 79, 30) + dw( 62, 30)
      JacC( 79, 78) = JacC( 79, 78) + dw( 62, 78)
      JacC( 11, 11) = JacC( 11, 11) - dw( 63, 11)
      JacC( 11, 78) = JacC( 11, 78) - dw( 63, 78)
      JacC( 48, 11) = JacC( 48, 11)+ 0.3600000000000000D-01*dw( 63, 11)
      JacC( 48, 78) = JacC( 48, 78)+ 0.3600000000000000D-01*dw( 63, 78)
      JacC( 64, 11) = JacC( 64, 11)+ 0.3600000000000000D-01*dw( 63, 11)
      JacC( 64, 78) = JacC( 64, 78)+ 0.3600000000000000D-01*dw( 63, 78)
      JacC( 65, 11) = JacC( 65, 11)+ 0.3600000000000000D-01*dw( 63, 11)
      JacC( 65, 78) = JacC( 65, 78)+ 0.3600000000000000D-01*dw( 63, 78)
      JacC( 71, 11) = JacC( 71, 11)+ 0.5830000000000000D+00*dw( 63, 11)
      JacC( 71, 78) = JacC( 71, 78)+ 0.5830000000000000D+00*dw( 63, 78)
      JacC( 77, 11) = JacC( 77, 11)+ 0.3350000000000000D+00*dw( 63, 11)
      JacC( 77, 78) = JacC( 77, 78)+ 0.3350000000000000D+00*dw( 63, 78)
      JacC( 78, 11) = JacC( 78, 11)- 0.9640000000000000D+00*dw( 63, 11)
      JacC( 78, 78) = JacC( 78, 78)- 0.9640000000000000D+00*dw( 63, 78)
      JacC( 80, 11) = JacC( 80, 11)+ 0.1000000000000000D-01*dw( 63, 11)
      JacC( 80, 78) = JacC( 80, 78)+ 0.1000000000000000D-01*dw( 63, 78)
      JacC( 86, 11) = JacC( 86, 11)+ 0.3810000000000000D+00*dw( 63, 11)
      JacC( 86, 78) = JacC( 86, 78)+ 0.3810000000000000D+00*dw( 63, 78)
      JacC(  3,  3) = JacC(  3,  3) - dw( 64,  3)
      JacC(  3, 78) = JacC(  3, 78) - dw( 64, 78)
      JacC( 61,  3) = JacC( 61,  3)+ 0.7500000000000000D+00*dw( 64,  3)
      JacC( 61, 78) = JacC( 61, 78)+ 0.7500000000000000D+00*dw( 64, 78)
      JacC( 75,  3) = JacC( 75,  3)+ 0.2500000000000000D+00*dw( 64,  3)
      JacC( 75, 78) = JacC( 75, 78)+ 0.2500000000000000D+00*dw( 64, 78)
      JacC( 78,  3) = JacC( 78,  3) - dw( 64,  3)
      JacC( 78, 78) = JacC( 78, 78) - dw( 64, 78)
      JacC( 86,  3) = JacC( 86,  3)+ 0.2500000000000000D+00*dw( 64,  3)
      JacC( 86, 78) = JacC( 86, 78)+ 0.2500000000000000D+00*dw( 64, 78)
      JacC(  4,  4) = JacC(  4,  4) - dw( 65,  4)
      JacC(  4, 78) = JacC(  4, 78) - dw( 65, 78)
      JacC(  8,  4) = JacC(  8,  4)+ 0.4800000000000000D-01*dw( 65,  4)
      JacC(  8, 78) = JacC(  8, 78)+ 0.4800000000000000D-01*dw( 65, 78)
      JacC( 45,  4) = JacC( 45,  4)+ 0.2400000000000000D-01*dw( 65,  4)
      JacC( 45, 78) = JacC( 45, 78)+ 0.2400000000000000D-01*dw( 65, 78)
      JacC( 66,  4) = JacC( 66,  4)+ 0.9510000000000000D+00*dw( 65,  4)
      JacC( 66, 78) = JacC( 66, 78)+ 0.9510000000000000D+00*dw( 65, 78)
      JacC( 77,  4) = JacC( 77,  4)+ 0.2500000000000000D-01*dw( 65,  4)
      JacC( 77, 78) = JacC( 77, 78)+ 0.2500000000000000D-01*dw( 65, 78)
      JacC( 78,  4) = JacC( 78,  4) - dw( 65,  4)
      JacC( 78, 78) = JacC( 78, 78) - dw( 65, 78)
      JacC( 86,  4) = JacC( 86,  4)+ 0.4900000000000000D-01*dw( 65,  4)
      JacC( 86, 78) = JacC( 86, 78)+ 0.4900000000000000D-01*dw( 65, 78)
      JacC( 25, 25) = JacC( 25, 25) - dw( 66, 25)
      JacC( 25, 78) = JacC( 25, 78) - dw( 66, 78)
      JacC( 67, 25) = JacC( 67, 25) + dw( 66, 25)
      JacC( 67, 78) = JacC( 67, 78) + dw( 66, 78)
      JacC( 78, 25) = JacC( 78, 25) - dw( 66, 25)
      JacC( 78, 78) = JacC( 78, 78) - dw( 66, 78)
      JacC( 38, 52) = JacC( 38, 52)+ 0.8000000000000000D-02*dw( 67, 52)
      JacC( 38, 78) = JacC( 38, 78)+ 0.8000000000000000D-02*dw( 67, 78)
      JacC( 52, 52) = JacC( 52, 52) - dw( 67, 52)
      JacC( 52, 78) = JacC( 52, 78) - dw( 67, 78)
      JacC( 53, 52) = JacC( 53, 52) + dw( 67, 52)
      JacC( 53, 78) = JacC( 53, 78) + dw( 67, 78)
      JacC( 78, 52) = JacC( 78, 52) - dw( 67, 52)
      JacC( 78, 78) = JacC( 78, 78) - dw( 67, 78)
      JacC( 38, 56) = JacC( 38, 56)+ 0.8000000000000000D-02*dw( 68, 56)
      JacC( 38, 78) = JacC( 38, 78)+ 0.8000000000000000D-02*dw( 68, 78)
      JacC( 56, 56) = JacC( 56, 56) - dw( 68, 56)
      JacC( 56, 78) = JacC( 56, 78) - dw( 68, 78)
      JacC( 59, 56) = JacC( 59, 56) + dw( 68, 56)
      JacC( 59, 78) = JacC( 59, 78) + dw( 68, 78)
      JacC( 78, 56) = JacC( 78, 56) - dw( 68, 56)
      JacC( 78, 78) = JacC( 78, 78) - dw( 68, 78)
      JacC( 19, 19) = JacC( 19, 19) - dw( 69, 19)
      JacC( 19, 78) = JacC( 19, 78) - dw( 69, 78)
      JacC( 51, 19) = JacC( 51, 19) + dw( 69, 19)
      JacC( 51, 78) = JacC( 51, 78) + dw( 69, 78)
      JacC( 78, 19) = JacC( 78, 19) - dw( 69, 19)
      JacC( 78, 78) = JacC( 78, 78) - dw( 69, 78)
      JacC( 14, 33) = JacC( 14, 33)+ 0.2320000000000000D+00*dw( 70, 33)
      JacC( 14, 78) = JacC( 14, 78)+ 0.2320000000000000D+00*dw( 70, 78)
      JacC( 15, 33) = JacC( 15, 33)+ 0.2880000000000000D-01*dw( 70, 33)
      JacC( 15, 78) = JacC( 15, 78)+ 0.2880000000000000D-01*dw( 70, 78)
      JacC( 33, 33) = JacC( 33, 33) - dw( 70, 33)
      JacC( 33, 78) = JacC( 33, 78) - dw( 70, 78)
      JacC( 51, 33) = JacC( 51, 33) + dw( 70, 33)
      JacC( 51, 78) = JacC( 51, 78) + dw( 70, 78)
      JacC( 78, 33) = JacC( 78, 33) - dw( 70, 33)
      JacC( 78, 78) = JacC( 78, 78) - dw( 70, 78)
      JacC( 20, 24) = JacC( 20, 24)+ 0.1920000000000000D-01*dw( 71, 24)
      JacC( 20, 78) = JacC( 20, 78)+ 0.1920000000000000D-01*dw( 71, 78)
      JacC( 21, 24) = JacC( 21, 24)+ 0.1650000000000000D+00*dw( 71, 24)
      JacC( 21, 78) = JacC( 21, 78)+ 0.1650000000000000D+00*dw( 71, 78)
      JacC( 24, 24) = JacC( 24, 24) - dw( 71, 24)
      JacC( 24, 78) = JacC( 24, 78) - dw( 71, 78)
      JacC( 54, 24) = JacC( 54, 24) + dw( 71, 24)
      JacC( 54, 78) = JacC( 54, 78) + dw( 71, 78)
      JacC( 78, 24) = JacC( 78, 24) - dw( 71, 24)
      JacC( 78, 78) = JacC( 78, 78) - dw( 71, 78)
      JacC( 26, 26) = JacC( 26, 26) - dw( 72, 26)
      JacC( 26, 78) = JacC( 26, 78) - dw( 72, 78)
      JacC( 27, 26) = JacC( 27, 26)+ 0.1110000000000000D+00*dw( 72, 26)
      JacC( 27, 78) = JacC( 27, 78)+ 0.1110000000000000D+00*dw( 72, 78)
      JacC( 28, 26) = JacC( 28, 26)+ 0.1690000000000000D+00*dw( 72, 26)
      JacC( 28, 78) = JacC( 28, 78)+ 0.1690000000000000D+00*dw( 72, 78)
      JacC( 55, 26) = JacC( 55, 26) + dw( 72, 26)
      JacC( 55, 78) = JacC( 55, 78) + dw( 72, 78)
      JacC( 78, 26) = JacC( 78, 26) - dw( 72, 26)
      JacC( 78, 78) = JacC( 78, 78) - dw( 72, 78)
      JacC(  5,  5) = JacC(  5,  5) - dw( 73,  5)
      JacC(  5, 78) = JacC(  5, 78) - dw( 73, 78)
      JacC( 29,  5) = JacC( 29,  5)+ 0.9000000000000000D+00*dw( 73,  5)
      JacC( 29, 78) = JacC( 29, 78)+ 0.9000000000000000D+00*dw( 73, 78)
      JacC( 78,  5) = JacC( 78,  5) - dw( 73,  5)
      JacC( 78, 78) = JacC( 78, 78) - dw( 73, 78)
      JacC( 81,  5) = JacC( 81,  5)+ 0.1000000000000000D+00*dw( 73,  5)
      JacC( 81, 78) = JacC( 81, 78)+ 0.1000000000000000D+00*dw( 73, 78)
      JacC( 86,  5) = JacC( 86,  5)+ 0.1000000000000000D+00*dw( 73,  5)
      JacC( 86, 78) = JacC( 86, 78)+ 0.1000000000000000D+00*dw( 73, 78)
      JacC(  6,  6) = JacC(  6,  6) - dw( 74,  6)
      JacC(  6, 78) = JacC(  6, 78) - dw( 74, 78)
      JacC( 18,  6) = JacC( 18,  6)+ 0.9000000000000000D+00*dw( 74,  6)
      JacC( 18, 78) = JacC( 18, 78)+ 0.9000000000000000D+00*dw( 74, 78)
      JacC( 78,  6) = JacC( 78,  6) - dw( 74,  6)
      JacC( 78, 78) = JacC( 78, 78) - dw( 74, 78)
      JacC( 81,  6) = JacC( 81,  6)+ 0.1000000000000000D+00*dw( 74,  6)
      JacC( 81, 78) = JacC( 81, 78)+ 0.1000000000000000D+00*dw( 74, 78)
      JacC( 86,  6) = JacC( 86,  6)+ 0.1000000000000000D+00*dw( 74,  6)
      JacC( 86, 78) = JacC( 86, 78)+ 0.1000000000000000D+00*dw( 74, 78)
      JacC( 31, 37) = JacC( 31, 37)+ 0.8500000000000000D+00*dw( 75, 37)
      JacC( 31, 78) = JacC( 31, 78)+ 0.8500000000000000D+00*dw( 75, 78)
      JacC( 36, 37) = JacC( 36, 37)+ 0.1000000000000000D+00*dw( 75, 37)
      JacC( 36, 78) = JacC( 36, 78)+ 0.1000000000000000D+00*dw( 75, 78)
      JacC( 37, 37) = JacC( 37, 37) - dw( 75, 37)
      JacC( 37, 78) = JacC( 37, 78) - dw( 75, 78)
      JacC( 41, 37) = JacC( 41, 37)+ 0.1080000000000000D+00*dw( 75, 37)
      JacC( 41, 78) = JacC( 41, 78)+ 0.1080000000000000D+00*dw( 75, 78)
      JacC( 42, 37) = JacC( 42, 37)+ 0.3900000000000000D-01*dw( 75, 37)
      JacC( 42, 78) = JacC( 42, 78)+ 0.3900000000000000D-01*dw( 75, 78)
      JacC( 78, 37) = JacC( 78, 37) - dw( 75, 37)
      JacC( 78, 78) = JacC( 78, 78) - dw( 75, 78)
      JacC( 81, 37) = JacC( 81, 37)+ 0.5000000000000000D-01*dw( 75, 37)
      JacC( 81, 78) = JacC( 81, 78)+ 0.5000000000000000D-01*dw( 75, 78)
      JacC( 86, 37) = JacC( 86, 37)+ 0.5000000000000000D-01*dw( 75, 37)
      JacC( 86, 78) = JacC( 86, 78)+ 0.5000000000000000D-01*dw( 75, 78)
      JacC( 64, 80) = JacC( 64, 80) + dw( 76, 80)
      JacC( 64, 78) = JacC( 64, 78) + dw( 76, 78)
      JacC( 78, 80) = JacC( 78, 80) - dw( 76, 80)
      JacC( 78, 78) = JacC( 78, 78) - dw( 76, 78)
      JacC( 80, 80) = JacC( 80, 80) - dw( 76, 80)
      JacC( 80, 78) = JacC( 80, 78) - dw( 76, 78)
      JacC( 86, 80) = JacC( 86, 80) + dw( 76, 80)
      JacC( 86, 78) = JacC( 86, 78) + dw( 76, 78)
      JacC( 77, 77) = JacC( 77, 77) - dw( 77, 77)
      JacC( 77, 78) = JacC( 77, 78) - dw( 77, 78)
      JacC( 78, 77) = JacC( 78, 77) - dw( 77, 77)
      JacC( 78, 78) = JacC( 78, 78) - dw( 77, 78)
      JacC( 83, 77) = JacC( 83, 77) + dw( 77, 77)
      JacC( 83, 78) = JacC( 83, 78) + dw( 77, 78)
      JacC( 75, 75) = JacC( 75, 75) - dw( 78, 75)
      JacC( 75, 78) = JacC( 75, 78) - dw( 78, 78)
      JacC( 76, 75) = JacC( 76, 75) + dw( 78, 75)
      JacC( 76, 78) = JacC( 76, 78) + dw( 78, 78)
      JacC( 78, 75) = JacC( 78, 75) - dw( 78, 75)
      JacC( 78, 78) = JacC( 78, 78) - dw( 78, 78)
      JacC( 45, 45) = JacC( 45, 45) - dw( 79, 45)
      JacC( 45, 78) = JacC( 45, 78) - dw( 79, 78)
      JacC( 72, 45) = JacC( 72, 45) + dw( 79, 45)
      JacC( 72, 78) = JacC( 72, 78) + dw( 79, 78)
      JacC( 78, 45) = JacC( 78, 45) - dw( 79, 45)
      JacC( 78, 78) = JacC( 78, 78) - dw( 79, 78)
      JacC( 86, 45) = JacC( 86, 45) + dw( 79, 45)
      JacC( 86, 78) = JacC( 86, 78) + dw( 79, 78)
      JacC( 64, 65) = JacC( 64, 65)+ 0.2000000000000000D+01*dw( 80, 65)
      JacC( 64, 78) = JacC( 64, 78)+ 0.2000000000000000D+01*dw( 80, 78)
      JacC( 65, 65) = JacC( 65, 65) - dw( 80, 65)
      JacC( 65, 78) = JacC( 65, 78) - dw( 80, 78)
      JacC( 78, 65) = JacC( 78, 65) - dw( 80, 65)
      JacC( 78, 78) = JacC( 78, 78) - dw( 80, 78)
      JacC( 86, 65) = JacC( 86, 65) + dw( 80, 65)
      JacC( 86, 78) = JacC( 86, 78) + dw( 80, 78)
      JacC( 64, 72) = JacC( 64, 72) + dw( 81, 72)
      JacC( 64, 78) = JacC( 64, 78) + dw( 81, 78)
      JacC( 72, 72) = JacC( 72, 72) - dw( 81, 72)
      JacC( 72, 78) = JacC( 72, 78) - dw( 81, 78)
      JacC( 78, 72) = JacC( 78, 72) - dw( 81, 72)
      JacC( 78, 78) = JacC( 78, 78) - dw( 81, 78)
      JacC( 83, 72) = JacC( 83, 72) + dw( 81, 72)
      JacC( 83, 78) = JacC( 83, 78) + dw( 81, 78)
      JacC( 45, 60) = JacC( 45, 60)+ 0.4100000000000000D+00*dw( 82, 60)
      JacC( 45, 78) = JacC( 45, 78)+ 0.4100000000000000D+00*dw( 82, 78)
      JacC( 60, 60) = JacC( 60, 60) - dw( 82, 60)
      JacC( 60, 78) = JacC( 60, 78) - dw( 82, 78)
      JacC( 64, 60) = JacC( 64, 60)+ 0.4100000000000000D+00*dw( 82, 60)
      JacC( 64, 78) = JacC( 64, 78)+ 0.4100000000000000D+00*dw( 82, 78)
      JacC( 68, 60) = JacC( 68, 60)+ 0.5100000000000000D+00*dw( 82, 60)
      JacC( 68, 78) = JacC( 68, 78)+ 0.5100000000000000D+00*dw( 82, 78)
      JacC( 72, 60) = JacC( 72, 60)+ 0.8000000000000000D-01*dw( 82, 60)
      JacC( 72, 78) = JacC( 72, 78)+ 0.8000000000000000D-01*dw( 82, 78)
      JacC( 78, 60) = JacC( 78, 60) - dw( 82, 60)
      JacC( 78, 78) = JacC( 78, 78) - dw( 82, 78)
      JacC( 80, 60) = JacC( 80, 60)+ 0.8000000000000000D-01*dw( 82, 60)
      JacC( 80, 78) = JacC( 80, 78)+ 0.8000000000000000D-01*dw( 82, 78)
      JacC( 81, 60) = JacC( 81, 60)+ 0.4900000000000000D+00*dw( 82, 60)
      JacC( 81, 78) = JacC( 81, 78)+ 0.4900000000000000D+00*dw( 82, 78)
      JacC( 86, 60) = JacC( 86, 60)+ 0.4900000000000000D+00*dw( 82, 60)
      JacC( 86, 78) = JacC( 86, 78)+ 0.4900000000000000D+00*dw( 82, 78)
      JacC( 16, 78) = JacC( 16, 78)+ 0.3500000000000000D+00*dw( 83, 78)
      JacC( 16, 62) = JacC( 16, 62)+ 0.3500000000000000D+00*dw( 83, 62)
      JacC( 62, 78) = JacC( 62, 78) - dw( 83, 78)
      JacC( 62, 62) = JacC( 62, 62) - dw( 83, 62)
      JacC( 65, 78) = JacC( 65, 78)+ 0.1500000000000000D+00*dw( 83, 78)
      JacC( 65, 62) = JacC( 65, 62)+ 0.1500000000000000D+00*dw( 83, 62)
      JacC( 68, 78) = JacC( 68, 78)+ 0.5000000000000000D+00*dw( 83, 78)
      JacC( 68, 62) = JacC( 68, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 72, 78) = JacC( 72, 78)+ 0.1500000000000000D+00*dw( 83, 78)
      JacC( 72, 62) = JacC( 72, 62)+ 0.1500000000000000D+00*dw( 83, 62)
      JacC( 78, 78) = JacC( 78, 78) - dw( 83, 78)
      JacC( 78, 62) = JacC( 78, 62) - dw( 83, 62)
      JacC( 81, 78) = JacC( 81, 78)+ 0.5000000000000000D+00*dw( 83, 78)
      JacC( 81, 62) = JacC( 81, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 86, 78) = JacC( 86, 78)+ 0.5000000000000000D+00*dw( 83, 78)
      JacC( 86, 62) = JacC( 86, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 16, 78) = JacC( 16, 78) - dw( 84, 78)
      JacC( 16, 16) = JacC( 16, 16) - dw( 84, 16)
      JacC( 75, 78) = JacC( 75, 78)+ 0.1200000000000000D+00*dw( 84, 78)
      JacC( 75, 16) = JacC( 75, 16)+ 0.1200000000000000D+00*dw( 84, 16)
      JacC( 77, 78) = JacC( 77, 78)+ 0.8800000000000000D+00*dw( 84, 78)
      JacC( 77, 16) = JacC( 77, 16)+ 0.8800000000000000D+00*dw( 84, 16)
      JacC( 78, 78) = JacC( 78, 78) - dw( 84, 78)
      JacC( 78, 16) = JacC( 78, 16) - dw( 84, 16)
      JacC( 86, 78) = JacC( 86, 78) + dw( 84, 78)
      JacC( 86, 16) = JacC( 86, 16) + dw( 84, 16)
      JacC( 23, 23) = JacC( 23, 23) - dw( 85, 23)
      JacC( 23, 78) = JacC( 23, 78) - dw( 85, 78)
      JacC( 78, 23) = JacC( 78, 23)- 0.6500000000000000D+00*dw( 85, 23)
      JacC( 78, 78) = JacC( 78, 78)- 0.6500000000000000D+00*dw( 85, 78)
      JacC( 80, 23) = JacC( 80, 23)+ 0.3500000000000000D+00*dw( 85, 23)
      JacC( 80, 78) = JacC( 80, 78)+ 0.3500000000000000D+00*dw( 85, 78)
      JacC( 82, 23) = JacC( 82, 23)+ 0.6500000000000000D+00*dw( 85, 23)
      JacC( 82, 78) = JacC( 82, 78)+ 0.6500000000000000D+00*dw( 85, 78)
      JacC( 69, 69) = JacC( 69, 69) - dw( 86, 69)
      JacC( 69, 78) = JacC( 69, 78) - dw( 86, 78)
      JacC( 71, 69) = JacC( 71, 69)+ 0.4400000000000000D+00*dw( 86, 69)
      JacC( 71, 78) = JacC( 71, 78)+ 0.4400000000000000D+00*dw( 86, 78)
      JacC( 75, 69) = JacC( 75, 69)+ 0.4100000000000000D+00*dw( 86, 69)
      JacC( 75, 78) = JacC( 75, 78)+ 0.4100000000000000D+00*dw( 86, 78)
      JacC( 77, 69) = JacC( 77, 69)+ 0.8000000000000000D-01*dw( 86, 69)
      JacC( 77, 78) = JacC( 77, 78)+ 0.8000000000000000D-01*dw( 86, 78)
      JacC( 78, 69) = JacC( 78, 69)- 0.5100000000000000D+00*dw( 86, 69)
      JacC( 78, 78) = JacC( 78, 78)- 0.5100000000000000D+00*dw( 86, 78)
      JacC( 81, 69) = JacC( 81, 69)+ 0.7000000000000001D-01*dw( 86, 69)
      JacC( 81, 78) = JacC( 81, 78)+ 0.7000000000000001D-01*dw( 86, 78)
      JacC( 35, 35) = JacC( 35, 35) - dw( 87, 35)
      JacC( 35, 78) = JacC( 35, 78) - dw( 87, 78)
      JacC( 78, 35) = JacC( 78, 35) - dw( 87, 35)
      JacC( 78, 78) = JacC( 78, 78) - dw( 87, 78)
      JacC( 80, 35) = JacC( 80, 35)+ 0.3500000000000000D+00*dw( 87, 35)
      JacC( 80, 78) = JacC( 80, 78)+ 0.3500000000000000D+00*dw( 87, 78)
      JacC( 81, 35) = JacC( 81, 35)+ 0.3500000000000000D+00*dw( 87, 35)
      JacC( 81, 78) = JacC( 81, 78)+ 0.3500000000000000D+00*dw( 87, 78)
      JacC( 83, 35) = JacC( 83, 35)+ 0.6500000000000000D+00*dw( 87, 35)
      JacC( 83, 78) = JacC( 83, 78)+ 0.6500000000000000D+00*dw( 87, 78)
      JacC( 86, 35) = JacC( 86, 35)+ 0.3500000000000000D+00*dw( 87, 35)
      JacC( 86, 78) = JacC( 86, 78)+ 0.3500000000000000D+00*dw( 87, 78)
      JacC( 47, 47) = JacC( 47, 47) - dw( 88, 47)
      JacC( 47, 78) = JacC( 47, 78) - dw( 88, 78)
      JacC( 78, 47) = JacC( 78, 47) - dw( 88, 47)
      JacC( 78, 78) = JacC( 78, 78) - dw( 88, 78)
      JacC( 80, 47) = JacC( 80, 47) + dw( 88, 47)
      JacC( 80, 78) = JacC( 80, 78) + dw( 88, 78)
      JacC( 81, 47) = JacC( 81, 47) + dw( 88, 47)
      JacC( 81, 78) = JacC( 81, 78) + dw( 88, 78)
      JacC( 85, 47) = JacC( 85, 47) + dw( 88, 47)
      JacC( 85, 78) = JacC( 85, 78) + dw( 88, 78)
      JacC( 45, 46) = JacC( 45, 46)+ 0.6000000000000000D+00*dw( 89, 46)
      JacC( 45, 78) = JacC( 45, 78)+ 0.6000000000000000D+00*dw( 89, 78)
      JacC( 46, 46) = JacC( 46, 46) - dw( 89, 46)
      JacC( 46, 78) = JacC( 46, 78) - dw( 89, 78)
      JacC( 47, 46) = JacC( 47, 46)+ 0.4000000000000000D+00*dw( 89, 46)
      JacC( 47, 78) = JacC( 47, 78)+ 0.4000000000000000D+00*dw( 89, 78)
      JacC( 78, 46) = JacC( 78, 46) - dw( 89, 46)
      JacC( 78, 78) = JacC( 78, 78) - dw( 89, 78)
      JacC( 80, 46) = JacC( 80, 46)+ 0.4000000000000000D+00*dw( 89, 46)
      JacC( 80, 78) = JacC( 80, 78)+ 0.4000000000000000D+00*dw( 89, 78)
      JacC( 81, 46) = JacC( 81, 46) + dw( 89, 46)
      JacC( 81, 78) = JacC( 81, 78) + dw( 89, 78)
      JacC( 85, 46) = JacC( 85, 46)+ 0.6000000000000000D+00*dw( 89, 46)
      JacC( 85, 78) = JacC( 85, 78)+ 0.6000000000000000D+00*dw( 89, 78)
      JacC( 86, 46) = JacC( 86, 46)+ 0.4000000000000000D+00*dw( 89, 46)
      JacC( 86, 78) = JacC( 86, 78)+ 0.4000000000000000D+00*dw( 89, 78)
      JacC( 71, 74) = JacC( 71, 74) + dw( 90, 74)
      JacC( 71, 78) = JacC( 71, 78) + dw( 90, 78)
      JacC( 74, 74) = JacC( 74, 74) - dw( 90, 74)
      JacC( 74, 78) = JacC( 74, 78) - dw( 90, 78)
      JacC( 78, 74) = JacC( 78, 74) - dw( 90, 74)
      JacC( 78, 78) = JacC( 78, 78) - dw( 90, 78)
      JacC( 87, 74) = JacC( 87, 74) + dw( 90, 74)
      JacC( 87, 78) = JacC( 87, 78) + dw( 90, 78)
      JacC( 64, 80) = JacC( 64, 80) + dw( 91, 80)
      JacC( 64, 85) = JacC( 64, 85) + dw( 91, 85)
      JacC( 73, 80) = JacC( 73, 80) + dw( 91, 80)
      JacC( 73, 85) = JacC( 73, 85) + dw( 91, 85)
      JacC( 80, 80) = JacC( 80, 80) - dw( 91, 80)
      JacC( 80, 85) = JacC( 80, 85) - dw( 91, 85)
      JacC( 85, 80) = JacC( 85, 80) - dw( 91, 80)
      JacC( 85, 85) = JacC( 85, 85) - dw( 91, 85)
      JacC( 86, 80) = JacC( 86, 80) + dw( 91, 80)
      JacC( 86, 85) = JacC( 86, 85) + dw( 91, 85)
      JacC( 73, 77) = JacC( 73, 77) + dw( 92, 77)
      JacC( 73, 85) = JacC( 73, 85) + dw( 92, 85)
      JacC( 77, 77) = JacC( 77, 77) - dw( 92, 77)
      JacC( 77, 85) = JacC( 77, 85) - dw( 92, 85)
      JacC( 83, 77) = JacC( 83, 77) + dw( 92, 77)
      JacC( 83, 85) = JacC( 83, 85) + dw( 92, 85)
      JacC( 85, 77) = JacC( 85, 77) - dw( 92, 77)
      JacC( 85, 85) = JacC( 85, 85) - dw( 92, 85)
      JacC( 64, 65) = JacC( 64, 65)+ 0.2000000000000000D+01*dw( 93, 65)
      JacC( 64, 85) = JacC( 64, 85)+ 0.2000000000000000D+01*dw( 93, 85)
      JacC( 65, 65) = JacC( 65, 65) - dw( 93, 65)
      JacC( 65, 85) = JacC( 65, 85) - dw( 93, 85)
      JacC( 73, 65) = JacC( 73, 65) + dw( 93, 65)
      JacC( 73, 85) = JacC( 73, 85) + dw( 93, 85)
      JacC( 85, 65) = JacC( 85, 65) - dw( 93, 65)
      JacC( 85, 85) = JacC( 85, 85) - dw( 93, 85)
      JacC( 86, 65) = JacC( 86, 65) + dw( 93, 65)
      JacC( 86, 85) = JacC( 86, 85) + dw( 93, 85)
      JacC( 64, 72) = JacC( 64, 72) + dw( 94, 72)
      JacC( 64, 85) = JacC( 64, 85) + dw( 94, 85)
      JacC( 72, 72) = JacC( 72, 72) - dw( 94, 72)
      JacC( 72, 85) = JacC( 72, 85) - dw( 94, 85)
      JacC( 73, 72) = JacC( 73, 72) + dw( 94, 72)
      JacC( 73, 85) = JacC( 73, 85) + dw( 94, 85)
      JacC( 83, 72) = JacC( 83, 72) + dw( 94, 72)
      JacC( 83, 85) = JacC( 83, 85) + dw( 94, 85)
      JacC( 85, 72) = JacC( 85, 72) - dw( 94, 72)
      JacC( 85, 85) = JacC( 85, 85) - dw( 94, 85)
      JacC( 58, 60) = JacC( 58, 60)+ 0.8000000000000000D+00*dw( 95, 60)
      JacC( 58, 85) = JacC( 58, 85)+ 0.8000000000000000D+00*dw( 95, 85)
      JacC( 60, 60) = JacC( 60, 60) - dw( 95, 60)
      JacC( 60, 85) = JacC( 60, 85) - dw( 95, 85)
      JacC( 64, 60) = JacC( 64, 60)+ 0.8000000000000000D+00*dw( 95, 60)
      JacC( 64, 85) = JacC( 64, 85)+ 0.8000000000000000D+00*dw( 95, 85)
      JacC( 68, 60) = JacC( 68, 60)+ 0.2000000000000000D+00*dw( 95, 60)
      JacC( 68, 85) = JacC( 68, 85)+ 0.2000000000000000D+00*dw( 95, 85)
      JacC( 73, 60) = JacC( 73, 60)+ 0.2000000000000000D+00*dw( 95, 60)
      JacC( 73, 85) = JacC( 73, 85)+ 0.2000000000000000D+00*dw( 95, 85)
      JacC( 85, 60) = JacC( 85, 60) - dw( 95, 60)
      JacC( 85, 85) = JacC( 85, 85) - dw( 95, 85)
      JacC( 62, 62) = JacC( 62, 62) - dw( 96, 62)
      JacC( 62, 85) = JacC( 62, 85) - dw( 96, 85)
      JacC( 65, 62) = JacC( 65, 62)+ 0.2500000000000000D+00*dw( 96, 62)
      JacC( 65, 85) = JacC( 65, 85)+ 0.2500000000000000D+00*dw( 96, 85)
      JacC( 68, 62) = JacC( 68, 62)+ 0.5000000000000000D+00*dw( 96, 62)
      JacC( 68, 85) = JacC( 68, 85)+ 0.5000000000000000D+00*dw( 96, 85)
      JacC( 72, 62) = JacC( 72, 62)+ 0.2500000000000000D+00*dw( 96, 62)
      JacC( 72, 85) = JacC( 72, 85)+ 0.2500000000000000D+00*dw( 96, 85)
      JacC( 73, 62) = JacC( 73, 62)+ 0.5000000000000000D+00*dw( 96, 62)
      JacC( 73, 85) = JacC( 73, 85)+ 0.5000000000000000D+00*dw( 96, 85)
      JacC( 75, 62) = JacC( 75, 62)+ 0.3000000000000000D-01*dw( 96, 62)
      JacC( 75, 85) = JacC( 75, 85)+ 0.3000000000000000D-01*dw( 96, 85)
      JacC( 77, 62) = JacC( 77, 62)+ 0.2500000000000000D+00*dw( 96, 62)
      JacC( 77, 85) = JacC( 77, 85)+ 0.2500000000000000D+00*dw( 96, 85)
      JacC( 81, 62) = JacC( 81, 62)+ 0.5000000000000000D+00*dw( 96, 62)
      JacC( 81, 85) = JacC( 81, 85)+ 0.5000000000000000D+00*dw( 96, 85)
      JacC( 85, 62) = JacC( 85, 62) - dw( 96, 62)
      JacC( 85, 85) = JacC( 85, 85) - dw( 96, 85)
      JacC( 86, 62) = JacC( 86, 62)+ 0.5000000000000000D+00*dw( 96, 62)
      JacC( 86, 85) = JacC( 86, 85)+ 0.5000000000000000D+00*dw( 96, 85)
      JacC( 87, 62) = JacC( 87, 62)+ 0.5000000000000000D+00*dw( 96, 62)
      JacC( 87, 85) = JacC( 87, 85)+ 0.5000000000000000D+00*dw( 96, 85)
      JacC( 36, 37) = JacC( 36, 37) + dw( 97, 37)
      JacC( 36, 85) = JacC( 36, 85) + dw( 97, 85)
      JacC( 37, 37) = JacC( 37, 37) - dw( 97, 37)
      JacC( 37, 85) = JacC( 37, 85) - dw( 97, 85)
      JacC( 41, 37) = JacC( 41, 37)+ 0.1080000000000000D+00*dw( 97, 37)
      JacC( 41, 85) = JacC( 41, 85)+ 0.1080000000000000D+00*dw( 97, 85)
      JacC( 42, 37) = JacC( 42, 37)+ 0.3900000000000000D-01*dw( 97, 37)
      JacC( 42, 85) = JacC( 42, 85)+ 0.3900000000000000D-01*dw( 97, 85)
      JacC( 73, 37) = JacC( 73, 37) + dw( 97, 37)
      JacC( 73, 85) = JacC( 73, 85) + dw( 97, 85)
      JacC( 85, 37) = JacC( 85, 37) - dw( 97, 37)
      JacC( 85, 85) = JacC( 85, 85) - dw( 97, 85)
      JacC( 25, 25) = JacC( 25, 25) - dw( 98, 25)
      JacC( 25, 85) = JacC( 25, 85) - dw( 98, 85)
      JacC( 57, 25) = JacC( 57, 25)+ 0.2000000000000000D+00*dw( 98, 25)
      JacC( 57, 85) = JacC( 57, 85)+ 0.2000000000000000D+00*dw( 98, 85)
      JacC( 58, 25) = JacC( 58, 25)+ 0.8000000000000000D+00*dw( 98, 25)
      JacC( 58, 85) = JacC( 58, 85)+ 0.8000000000000000D+00*dw( 98, 85)
      JacC( 85, 25) = JacC( 85, 25) - dw( 98, 25)
      JacC( 85, 85) = JacC( 85, 85) - dw( 98, 85)
      JacC( 38, 52) = JacC( 38, 52)+ 0.8000000000000000D-02*dw( 99, 52)
      JacC( 38, 85) = JacC( 38, 85)+ 0.8000000000000000D-02*dw( 99, 85)
      JacC( 52, 52) = JacC( 52, 52) - dw( 99, 52)
      JacC( 52, 85) = JacC( 52, 85) - dw( 99, 85)
      JacC( 57, 52) = JacC( 57, 52)+ 0.5700000000000000D+00*dw( 99, 52)
      JacC( 57, 85) = JacC( 57, 85)+ 0.5700000000000000D+00*dw( 99, 85)
      JacC( 58, 52) = JacC( 58, 52)+ 0.4300000000000000D+00*dw( 99, 52)
      JacC( 58, 85) = JacC( 58, 85)+ 0.4300000000000000D+00*dw( 99, 85)
      JacC( 85, 52) = JacC( 85, 52) - dw( 99, 52)
      JacC( 85, 85) = JacC( 85, 85) - dw( 99, 85)
      JacC( 38, 56) = JacC( 38, 56)+ 0.8000000000000000D-02*dw(100, 56)
      JacC( 38, 85) = JacC( 38, 85)+ 0.8000000000000000D-02*dw(100, 85)
      JacC( 56, 56) = JacC( 56, 56) - dw(100, 56)
      JacC( 56, 85) = JacC( 56, 85) - dw(100, 85)
      JacC( 57, 56) = JacC( 57, 56)+ 0.8900000000000000D+00*dw(100, 56)
      JacC( 57, 85) = JacC( 57, 85)+ 0.8900000000000000D+00*dw(100, 85)
      JacC( 58, 56) = JacC( 58, 56)+ 0.1100000000000000D+00*dw(100, 56)
      JacC( 58, 85) = JacC( 58, 85)+ 0.1100000000000000D+00*dw(100, 85)
      JacC( 85, 56) = JacC( 85, 56) - dw(100, 56)
      JacC( 85, 85) = JacC( 85, 85) - dw(100, 85)
      JacC( 19, 19) = JacC( 19, 19) - dw(101, 19)
      JacC( 19, 85) = JacC( 19, 85) - dw(101, 85)
      JacC( 57, 19) = JacC( 57, 19)+ 0.1000000000000000D+00*dw(101, 19)
      JacC( 57, 85) = JacC( 57, 85)+ 0.1000000000000000D+00*dw(101, 85)
      JacC( 58, 19) = JacC( 58, 19)+ 0.9000000000000000D+00*dw(101, 19)
      JacC( 58, 85) = JacC( 58, 85)+ 0.9000000000000000D+00*dw(101, 85)
      JacC( 60, 19) = JacC( 60, 19)+ 0.9000000000000000D+00*dw(101, 19)
      JacC( 60, 85) = JacC( 60, 85)+ 0.9000000000000000D+00*dw(101, 85)
      JacC( 85, 19) = JacC( 85, 19) - dw(101, 19)
      JacC( 85, 85) = JacC( 85, 85) - dw(101, 85)
      JacC( 33, 33) = JacC( 33, 33) - dw(102, 33)
      JacC( 33, 85) = JacC( 33, 85) - dw(102, 85)
      JacC( 57, 33) = JacC( 57, 33)+ 0.1000000000000000D+00*dw(102, 33)
      JacC( 57, 85) = JacC( 57, 85)+ 0.1000000000000000D+00*dw(102, 85)
      JacC( 58, 33) = JacC( 58, 33)+ 0.9000000000000000D+00*dw(102, 33)
      JacC( 58, 85) = JacC( 58, 85)+ 0.9000000000000000D+00*dw(102, 85)
      JacC( 60, 33) = JacC( 60, 33)+ 0.9000000000000000D+00*dw(102, 33)
      JacC( 60, 85) = JacC( 60, 85)+ 0.9000000000000000D+00*dw(102, 85)
      JacC( 85, 33) = JacC( 85, 33) - dw(102, 33)
      JacC( 85, 85) = JacC( 85, 85) - dw(102, 85)
      JacC( 24, 24) = JacC( 24, 24) - dw(103, 24)
      JacC( 24, 85) = JacC( 24, 85) - dw(103, 85)
      JacC( 57, 24) = JacC( 57, 24)+ 0.9000000000000000D+00*dw(103, 24)
      JacC( 57, 85) = JacC( 57, 85)+ 0.9000000000000000D+00*dw(103, 85)
      JacC( 58, 24) = JacC( 58, 24)+ 0.1000000000000000D+00*dw(103, 24)
      JacC( 58, 85) = JacC( 58, 85)+ 0.1000000000000000D+00*dw(103, 85)
      JacC( 85, 24) = JacC( 85, 24) - dw(103, 24)
      JacC( 85, 85) = JacC( 85, 85) - dw(103, 85)
      JacC( 26, 26) = JacC( 26, 26) - dw(104, 26)
      JacC( 26, 85) = JacC( 26, 85) - dw(104, 85)
      JacC( 57, 26) = JacC( 57, 26)+ 0.8700000000000000D+00*dw(104, 26)
      JacC( 57, 85) = JacC( 57, 85)+ 0.8700000000000000D+00*dw(104, 85)
      JacC( 58, 26) = JacC( 58, 26)+ 0.1300000000000000D+00*dw(104, 26)
      JacC( 58, 85) = JacC( 58, 85)+ 0.1300000000000000D+00*dw(104, 85)
      JacC( 85, 26) = JacC( 85, 26) - dw(104, 26)
      JacC( 85, 85) = JacC( 85, 85) - dw(104, 85)
      JacC( 46, 46) = JacC( 46, 46) - dw(105, 46)
      JacC( 46, 85) = JacC( 46, 85) - dw(105, 85)
      JacC( 47, 46) = JacC( 47, 46)+ 0.4000000000000000D+00*dw(105, 46)
      JacC( 47, 85) = JacC( 47, 85)+ 0.4000000000000000D+00*dw(105, 85)
      JacC( 74, 46) = JacC( 74, 46)+ 0.6000000000000000D+00*dw(105, 46)
      JacC( 74, 85) = JacC( 74, 85)+ 0.6000000000000000D+00*dw(105, 85)
      JacC( 80, 46) = JacC( 80, 46)+ 0.4000000000000000D+00*dw(105, 46)
      JacC( 80, 85) = JacC( 80, 85)+ 0.4000000000000000D+00*dw(105, 85)
      JacC( 81, 46) = JacC( 81, 46) + dw(105, 46)
      JacC( 81, 85) = JacC( 81, 85) + dw(105, 85)
      JacC( 85, 46) = JacC( 85, 46)- 0.4000000000000000D+00*dw(105, 46)
      JacC( 85, 85) = JacC( 85, 85)- 0.4000000000000000D+00*dw(105, 85)
      JacC( 87, 46) = JacC( 87, 46)+ 0.4000000000000000D+00*dw(105, 46)
      JacC( 87, 85) = JacC( 87, 85)+ 0.4000000000000000D+00*dw(105, 85)
      JacC( 25, 25) = JacC( 25, 25) - dw(106, 25)
      JacC( 25, 63) = JacC( 25, 63) - dw(106, 63)
      JacC( 48, 25) = JacC( 48, 25)+ 0.3700000000000000D+00*dw(106, 25)
      JacC( 48, 63) = JacC( 48, 63)+ 0.3700000000000000D+00*dw(106, 63)
      JacC( 63, 25) = JacC( 63, 25) - dw(106, 25)
      JacC( 63, 63) = JacC( 63, 63) - dw(106, 63)
      JacC( 64, 25) = JacC( 64, 25)+ 0.4300000000000000D+00*dw(106, 25)
      JacC( 64, 63) = JacC( 64, 63)+ 0.4300000000000000D+00*dw(106, 63)
      JacC( 78, 25) = JacC( 78, 25)+ 0.1200000000000000D+00*dw(106, 25)
      JacC( 78, 63) = JacC( 78, 63)+ 0.1200000000000000D+00*dw(106, 63)
      JacC( 80, 25) = JacC( 80, 25) + dw(106, 25)
      JacC( 80, 63) = JacC( 80, 63) + dw(106, 63)
      JacC( 86, 25) = JacC( 86, 25)+ 0.2600000000000000D+00*dw(106, 25)
      JacC( 86, 63) = JacC( 86, 63)+ 0.2600000000000000D+00*dw(106, 63)
      JacC( 30, 52) = JacC( 30, 52)+ 0.3000000000000000D-01*dw(107, 52)
      JacC( 30, 63) = JacC( 30, 63)+ 0.3000000000000000D-01*dw(107, 63)
      JacC( 34, 52) = JacC( 34, 52)+ 0.6000000000000000D-01*dw(107, 52)
      JacC( 34, 63) = JacC( 34, 63)+ 0.6000000000000000D-01*dw(107, 63)
      JacC( 38, 52) = JacC( 38, 52)+ 0.8000000000000000D-02*dw(107, 52)
      JacC( 38, 63) = JacC( 38, 63)+ 0.8000000000000000D-02*dw(107, 63)
      JacC( 43, 52) = JacC( 43, 52)+ 0.6000000000000000D-02*dw(107, 52)
      JacC( 43, 63) = JacC( 43, 63)+ 0.6000000000000000D-02*dw(107, 63)
      JacC( 48, 52) = JacC( 48, 52)+ 0.1400000000000000D+00*dw(107, 52)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1400000000000000D+00*dw(107, 63)
      JacC( 52, 52) = JacC( 52, 52) - dw(107, 52)
      JacC( 52, 63) = JacC( 52, 63) - dw(107, 63)
      JacC( 63, 52) = JacC( 63, 52) - dw(107, 52)
      JacC( 63, 63) = JacC( 63, 63) - dw(107, 63)
      JacC( 64, 52) = JacC( 64, 52)+ 0.3700000000000000D+00*dw(107, 52)
      JacC( 64, 63) = JacC( 64, 63)+ 0.3700000000000000D+00*dw(107, 63)
      JacC( 70, 52) = JacC( 70, 52)+ 0.1000000000000000D+00*dw(107, 52)
      JacC( 70, 63) = JacC( 70, 63)+ 0.1000000000000000D+00*dw(107, 63)
      JacC( 75, 52) = JacC( 75, 52)+ 0.3000000000000000D-01*dw(107, 52)
      JacC( 75, 63) = JacC( 75, 63)+ 0.3000000000000000D-01*dw(107, 63)
      JacC( 76, 52) = JacC( 76, 52)+ 0.3000000000000000D-01*dw(107, 52)
      JacC( 76, 63) = JacC( 76, 63)+ 0.3000000000000000D-01*dw(107, 63)
      JacC( 77, 52) = JacC( 77, 52)+ 0.4400000000000000D+00*dw(107, 52)
      JacC( 77, 63) = JacC( 77, 63)+ 0.4400000000000000D+00*dw(107, 63)
      JacC( 78, 52) = JacC( 78, 52)+ 0.4000000000000000D+00*dw(107, 52)
      JacC( 78, 63) = JacC( 78, 63)+ 0.4000000000000000D+00*dw(107, 63)
      JacC( 79, 52) = JacC( 79, 52)+ 0.1000000000000000D+00*dw(107, 52)
      JacC( 79, 63) = JacC( 79, 63)+ 0.1000000000000000D+00*dw(107, 63)
      JacC( 80, 52) = JacC( 80, 52)+ 0.6400000000000000D+00*dw(107, 52)
      JacC( 80, 63) = JacC( 80, 63)+ 0.6400000000000000D+00*dw(107, 63)
      JacC( 82, 52) = JacC( 82, 52)+ 0.1900000000000000D+00*dw(107, 52)
      JacC( 82, 63) = JacC( 82, 63)+ 0.1900000000000000D+00*dw(107, 63)
      JacC( 86, 52) = JacC( 86, 52)+ 0.2500000000000000D+00*dw(107, 52)
      JacC( 86, 63) = JacC( 86, 63)+ 0.2500000000000000D+00*dw(107, 63)
      JacC( 30, 56) = JacC( 30, 56)+ 0.6000000000000000D-01*dw(108, 56)
      JacC( 30, 63) = JacC( 30, 63)+ 0.6000000000000000D-01*dw(108, 63)
      JacC( 34, 56) = JacC( 34, 56)+ 0.7000000000000001D-01*dw(108, 56)
      JacC( 34, 63) = JacC( 34, 63)+ 0.7000000000000001D-01*dw(108, 63)
      JacC( 38, 56) = JacC( 38, 56)+ 0.8000000000000000D-02*dw(108, 56)
      JacC( 38, 63) = JacC( 38, 63)+ 0.8000000000000000D-02*dw(108, 63)
      JacC( 43, 56) = JacC( 43, 56)+ 0.1100000000000000D-01*dw(108, 56)
      JacC( 43, 63) = JacC( 43, 63)+ 0.1100000000000000D-01*dw(108, 63)
      JacC( 56, 56) = JacC( 56, 56) - dw(108, 56)
      JacC( 56, 63) = JacC( 56, 63) - dw(108, 63)
      JacC( 63, 56) = JacC( 63, 56) - dw(108, 56)
      JacC( 63, 63) = JacC( 63, 63) - dw(108, 63)
      JacC( 64, 56) = JacC( 64, 56)+ 0.3000000000000000D+00*dw(108, 56)
      JacC( 64, 63) = JacC( 64, 63)+ 0.3000000000000000D+00*dw(108, 63)
      JacC( 70, 56) = JacC( 70, 56)+ 0.1400000000000000D+00*dw(108, 56)
      JacC( 70, 63) = JacC( 70, 63)+ 0.1400000000000000D+00*dw(108, 63)
      JacC( 75, 56) = JacC( 75, 56)+ 0.1600000000000000D+00*dw(108, 56)
      JacC( 75, 63) = JacC( 75, 63)+ 0.1600000000000000D+00*dw(108, 63)
      JacC( 76, 56) = JacC( 76, 56)+ 0.1200000000000000D+00*dw(108, 56)
      JacC( 76, 63) = JacC( 76, 63)+ 0.1200000000000000D+00*dw(108, 63)
      JacC( 77, 56) = JacC( 77, 56)+ 0.9900000000000000D+00*dw(108, 56)
      JacC( 77, 63) = JacC( 77, 63)+ 0.9900000000000000D+00*dw(108, 63)
      JacC( 78, 56) = JacC( 78, 56)+ 0.6300000000000000D+00*dw(108, 56)
      JacC( 78, 63) = JacC( 78, 63)+ 0.6300000000000000D+00*dw(108, 63)
      JacC( 79, 56) = JacC( 79, 56)+ 0.1800000000000000D+00*dw(108, 56)
      JacC( 79, 63) = JacC( 79, 63)+ 0.1800000000000000D+00*dw(108, 63)
      JacC( 80, 56) = JacC( 80, 56)+ 0.2000000000000000D-01*dw(108, 56)
      JacC( 80, 63) = JacC( 80, 63)+ 0.2000000000000000D-01*dw(108, 63)
      JacC( 82, 56) = JacC( 82, 56)+ 0.2300000000000000D+00*dw(108, 56)
      JacC( 82, 63) = JacC( 82, 63)+ 0.2300000000000000D+00*dw(108, 63)
      JacC( 86, 56) = JacC( 86, 56)+ 0.2200000000000000D+00*dw(108, 56)
      JacC( 86, 63) = JacC( 86, 63)+ 0.2200000000000000D+00*dw(108, 63)
      JacC( 19, 19) = JacC( 19, 19) - dw(109, 19)
      JacC( 19, 63) = JacC( 19, 63) - dw(109, 63)
      JacC( 43, 19) = JacC( 43, 19)+ 0.1000000000000000D-02*dw(109, 19)
      JacC( 43, 63) = JacC( 43, 63)+ 0.1000000000000000D-02*dw(109, 63)
      JacC( 48, 19) = JacC( 48, 19)+ 0.1500000000000000D+00*dw(109, 19)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1500000000000000D+00*dw(109, 63)
      JacC( 50, 19) = JacC( 50, 19)+ 0.9000000000000000D-01*dw(109, 19)
      JacC( 50, 63) = JacC( 50, 63)+ 0.9000000000000000D-01*dw(109, 63)
      JacC( 52, 19) = JacC( 52, 19)+ 0.3500000000000000D+00*dw(109, 19)
      JacC( 52, 63) = JacC( 52, 63)+ 0.3500000000000000D+00*dw(109, 63)
      JacC( 60, 19) = JacC( 60, 19)+ 0.3900000000000000D+00*dw(109, 19)
      JacC( 60, 63) = JacC( 60, 63)+ 0.3900000000000000D+00*dw(109, 63)
      JacC( 63, 19) = JacC( 63, 19) - dw(109, 19)
      JacC( 63, 63) = JacC( 63, 63) - dw(109, 63)
      JacC( 64, 19) = JacC( 64, 19)+ 0.3600000000000000D+00*dw(109, 19)
      JacC( 64, 63) = JacC( 64, 63)+ 0.3600000000000000D+00*dw(109, 63)
      JacC( 76, 19) = JacC( 76, 19)+ 0.2000000000000000D-01*dw(109, 19)
      JacC( 76, 63) = JacC( 76, 63)+ 0.2000000000000000D-01*dw(109, 63)
      JacC( 78, 19) = JacC( 78, 19)+ 0.2800000000000000D+00*dw(109, 19)
      JacC( 78, 63) = JacC( 78, 63)+ 0.2800000000000000D+00*dw(109, 63)
      JacC( 80, 19) = JacC( 80, 19)+ 0.9000000000000000D+00*dw(109, 19)
      JacC( 80, 63) = JacC( 80, 63)+ 0.9000000000000000D+00*dw(109, 63)
      JacC( 81, 19) = JacC( 81, 19)+ 0.1300000000000000D+00*dw(109, 19)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1300000000000000D+00*dw(109, 63)
      JacC( 82, 19) = JacC( 82, 19)+ 0.3000000000000000D-01*dw(109, 19)
      JacC( 82, 63) = JacC( 82, 63)+ 0.3000000000000000D-01*dw(109, 63)
      JacC( 83, 19) = JacC( 83, 19)+ 0.1500000000000000D+00*dw(109, 19)
      JacC( 83, 63) = JacC( 83, 63)+ 0.1500000000000000D+00*dw(109, 63)
      JacC( 86, 19) = JacC( 86, 19)+ 0.3000000000000000D+00*dw(109, 19)
      JacC( 86, 63) = JacC( 86, 63)+ 0.3000000000000000D+00*dw(109, 63)
      JacC( 33, 33) = JacC( 33, 33) - dw(110, 33)
      JacC( 33, 63) = JacC( 33, 63) - dw(110, 63)
      JacC( 43, 33) = JacC( 43, 33)+ 0.1000000000000000D-02*dw(110, 33)
      JacC( 43, 63) = JacC( 43, 63)+ 0.1000000000000000D-02*dw(110, 63)
      JacC( 48, 33) = JacC( 48, 33)+ 0.1500000000000000D+00*dw(110, 33)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1500000000000000D+00*dw(110, 63)
      JacC( 50, 33) = JacC( 50, 33)+ 0.9000000000000000D-01*dw(110, 33)
      JacC( 50, 63) = JacC( 50, 63)+ 0.9000000000000000D-01*dw(110, 63)
      JacC( 52, 33) = JacC( 52, 33)+ 0.3500000000000000D+00*dw(110, 33)
      JacC( 52, 63) = JacC( 52, 63)+ 0.3500000000000000D+00*dw(110, 63)
      JacC( 60, 33) = JacC( 60, 33)+ 0.3900000000000000D+00*dw(110, 33)
      JacC( 60, 63) = JacC( 60, 63)+ 0.3900000000000000D+00*dw(110, 63)
      JacC( 63, 33) = JacC( 63, 33) - dw(110, 33)
      JacC( 63, 63) = JacC( 63, 63) - dw(110, 63)
      JacC( 64, 33) = JacC( 64, 33)+ 0.3600000000000000D+00*dw(110, 33)
      JacC( 64, 63) = JacC( 64, 63)+ 0.3600000000000000D+00*dw(110, 63)
      JacC( 76, 33) = JacC( 76, 33)+ 0.2000000000000000D-01*dw(110, 33)
      JacC( 76, 63) = JacC( 76, 63)+ 0.2000000000000000D-01*dw(110, 63)
      JacC( 78, 33) = JacC( 78, 33)+ 0.2800000000000000D+00*dw(110, 33)
      JacC( 78, 63) = JacC( 78, 63)+ 0.2800000000000000D+00*dw(110, 63)
      JacC( 80, 33) = JacC( 80, 33)+ 0.9000000000000000D+00*dw(110, 33)
      JacC( 80, 63) = JacC( 80, 63)+ 0.9000000000000000D+00*dw(110, 63)
      JacC( 81, 33) = JacC( 81, 33)+ 0.1300000000000000D+00*dw(110, 33)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1300000000000000D+00*dw(110, 63)
      JacC( 82, 33) = JacC( 82, 33)+ 0.3000000000000000D-01*dw(110, 33)
      JacC( 82, 63) = JacC( 82, 63)+ 0.3000000000000000D-01*dw(110, 63)
      JacC( 83, 33) = JacC( 83, 33)+ 0.1500000000000000D+00*dw(110, 33)
      JacC( 83, 63) = JacC( 83, 63)+ 0.1500000000000000D+00*dw(110, 63)
      JacC( 86, 33) = JacC( 86, 33)+ 0.3000000000000000D+00*dw(110, 33)
      JacC( 86, 63) = JacC( 86, 63)+ 0.3000000000000000D+00*dw(110, 63)
      JacC( 20, 24) = JacC( 20, 24)+ 0.2160000000000000D-01*dw(111, 24)
      JacC( 20, 63) = JacC( 20, 63)+ 0.2160000000000000D-01*dw(111, 63)
      JacC( 21, 24) = JacC( 21, 24)+ 0.1860000000000000D+00*dw(111, 24)
      JacC( 21, 63) = JacC( 21, 63)+ 0.1860000000000000D+00*dw(111, 63)
      JacC( 24, 24) = JacC( 24, 24) - dw(111, 24)
      JacC( 24, 63) = JacC( 24, 63) - dw(111, 63)
      JacC( 43, 24) = JacC( 43, 24)+ 0.2000000000000000D-01*dw(111, 24)
      JacC( 43, 63) = JacC( 43, 63)+ 0.2000000000000000D-01*dw(111, 63)
      JacC( 63, 24) = JacC( 63, 24) - dw(111, 24)
      JacC( 63, 63) = JacC( 63, 63) - dw(111, 63)
      JacC( 64, 24) = JacC( 64, 24)+ 0.1400000000000000D+00*dw(111, 24)
      JacC( 64, 63) = JacC( 64, 63)+ 0.1400000000000000D+00*dw(111, 63)
      JacC( 75, 24) = JacC( 75, 24)+ 0.5300000000000000D+00*dw(111, 24)
      JacC( 75, 63) = JacC( 75, 63)+ 0.5300000000000000D+00*dw(111, 63)
      JacC( 76, 24) = JacC( 76, 24)+ 0.4200000000000000D+00*dw(111, 24)
      JacC( 76, 63) = JacC( 76, 63)+ 0.4200000000000000D+00*dw(111, 63)
      JacC( 77, 24) = JacC( 77, 24)+ 0.6500000000000000D+00*dw(111, 24)
      JacC( 77, 63) = JacC( 77, 63)+ 0.6500000000000000D+00*dw(111, 63)
      JacC( 78, 24) = JacC( 78, 24)+ 0.8500000000000000D+00*dw(111, 24)
      JacC( 78, 63) = JacC( 78, 63)+ 0.8500000000000000D+00*dw(111, 63)
      JacC( 79, 24) = JacC( 79, 24)+ 0.2000000000000000D+00*dw(111, 24)
      JacC( 79, 63) = JacC( 79, 63)+ 0.2000000000000000D+00*dw(111, 63)
      JacC( 86, 24) = JacC( 86, 24)+ 0.1000000000000000D+00*dw(111, 24)
      JacC( 86, 63) = JacC( 86, 63)+ 0.1000000000000000D+00*dw(111, 63)
      JacC( 26, 26) = JacC( 26, 26) - dw(112, 26)
      JacC( 26, 63) = JacC( 26, 63) - dw(112, 63)
      JacC( 27, 26) = JacC( 27, 26)+ 0.1260000000000000D+00*dw(112, 26)
      JacC( 27, 63) = JacC( 27, 63)+ 0.1260000000000000D+00*dw(112, 63)
      JacC( 28, 26) = JacC( 28, 26)+ 0.1900000000000000D+00*dw(112, 26)
      JacC( 28, 63) = JacC( 28, 63)+ 0.1900000000000000D+00*dw(112, 63)
      JacC( 43, 26) = JacC( 43, 26)+ 0.2000000000000000D-01*dw(112, 26)
      JacC( 43, 63) = JacC( 43, 63)+ 0.2000000000000000D-01*dw(112, 63)
      JacC( 48, 26) = JacC( 48, 26)+ 0.1000000000000000D-01*dw(112, 26)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1000000000000000D-01*dw(112, 63)
      JacC( 52, 26) = JacC( 52, 26)+ 0.4600000000000000D+00*dw(112, 26)
      JacC( 52, 63) = JacC( 52, 63)+ 0.4600000000000000D+00*dw(112, 63)
      JacC( 60, 26) = JacC( 60, 26)+ 0.7900000000000000D+00*dw(112, 26)
      JacC( 60, 63) = JacC( 60, 63)+ 0.7900000000000000D+00*dw(112, 63)
      JacC( 63, 26) = JacC( 63, 26) - dw(112, 26)
      JacC( 63, 63) = JacC( 63, 63) - dw(112, 63)
      JacC( 64, 26) = JacC( 64, 26)+ 0.1400000000000000D+00*dw(112, 26)
      JacC( 64, 63) = JacC( 64, 63)+ 0.1400000000000000D+00*dw(112, 63)
      JacC( 70, 26) = JacC( 70, 26)+ 0.7000000000000001D-01*dw(112, 26)
      JacC( 70, 63) = JacC( 70, 63)+ 0.7000000000000001D-01*dw(112, 63)
      JacC( 76, 26) = JacC( 76, 26)+ 0.4200000000000000D+00*dw(112, 26)
      JacC( 76, 63) = JacC( 76, 63)+ 0.4200000000000000D+00*dw(112, 63)
      JacC( 78, 26) = JacC( 78, 26)+ 0.8500000000000000D+00*dw(112, 26)
      JacC( 78, 63) = JacC( 78, 63)+ 0.8500000000000000D+00*dw(112, 63)
      JacC( 79, 26) = JacC( 79, 26)+ 0.1600000000000000D+00*dw(112, 26)
      JacC( 79, 63) = JacC( 79, 63)+ 0.1600000000000000D+00*dw(112, 63)
      JacC( 80, 26) = JacC( 80, 26)+ 0.4000000000000000D-01*dw(112, 26)
      JacC( 80, 63) = JacC( 80, 63)+ 0.4000000000000000D-01*dw(112, 63)
      JacC( 86, 26) = JacC( 86, 26)+ 0.1000000000000000D+00*dw(112, 26)
      JacC( 86, 63) = JacC( 86, 63)+ 0.1000000000000000D+00*dw(112, 63)
      JacC( 48, 60) = JacC( 48, 60)+ 0.2200000000000000D+00*dw(113, 60)
      JacC( 48, 63) = JacC( 48, 63)+ 0.2200000000000000D+00*dw(113, 63)
      JacC( 60, 60) = JacC( 60, 60) - dw(113, 60)
      JacC( 60, 63) = JacC( 60, 63) - dw(113, 63)
      JacC( 63, 60) = JacC( 63, 60) - dw(113, 60)
      JacC( 63, 63) = JacC( 63, 63) - dw(113, 63)
      JacC( 64, 60) = JacC( 64, 60)+ 0.5400000000000000D+00*dw(113, 60)
      JacC( 64, 63) = JacC( 64, 63)+ 0.5400000000000000D+00*dw(113, 63)
      JacC( 69, 60) = JacC( 69, 60)+ 0.1300000000000000D+00*dw(113, 60)
      JacC( 69, 63) = JacC( 69, 63)+ 0.1300000000000000D+00*dw(113, 63)
      JacC( 70, 60) = JacC( 70, 60)+ 0.1300000000000000D+00*dw(113, 60)
      JacC( 70, 63) = JacC( 70, 63)+ 0.1300000000000000D+00*dw(113, 63)
      JacC( 72, 60) = JacC( 72, 60)+ 0.6000000000000000D+00*dw(113, 60)
      JacC( 72, 63) = JacC( 72, 63)+ 0.6000000000000000D+00*dw(113, 63)
      JacC( 78, 60) = JacC( 78, 60)+ 0.7000000000000001D-01*dw(113, 60)
      JacC( 78, 63) = JacC( 78, 63)+ 0.7000000000000001D-01*dw(113, 63)
      JacC( 80, 60) = JacC( 80, 60)+ 0.4000000000000000D+00*dw(113, 60)
      JacC( 80, 63) = JacC( 80, 63)+ 0.4000000000000000D+00*dw(113, 63)
      JacC( 83, 60) = JacC( 83, 60)+ 0.1300000000000000D+00*dw(113, 60)
      JacC( 83, 63) = JacC( 83, 63)+ 0.1300000000000000D+00*dw(113, 63)
      JacC( 86, 60) = JacC( 86, 60)+ 0.2900000000000000D+00*dw(113, 60)
      JacC( 86, 63) = JacC( 86, 63)+ 0.2900000000000000D+00*dw(113, 63)
      JacC( 35, 62) = JacC( 35, 62)+ 0.1100000000000000D+00*dw(114, 62)
      JacC( 35, 63) = JacC( 35, 63)+ 0.1100000000000000D+00*dw(114, 63)
      JacC( 48, 62) = JacC( 48, 62)+ 0.1100000000000000D+00*dw(114, 62)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1100000000000000D+00*dw(114, 63)
      JacC( 62, 62) = JacC( 62, 62) - dw(114, 62)
      JacC( 62, 63) = JacC( 62, 63) - dw(114, 63)
      JacC( 63, 62) = JacC( 63, 62) - dw(114, 62)
      JacC( 63, 63) = JacC( 63, 63) - dw(114, 63)
      JacC( 64, 62) = JacC( 64, 62)+ 0.6600000000000000D+00*dw(114, 62)
      JacC( 64, 63) = JacC( 64, 63)+ 0.6600000000000000D+00*dw(114, 63)
      JacC( 65, 62) = JacC( 65, 62)+ 0.5000000000000000D+00*dw(114, 62)
      JacC( 65, 63) = JacC( 65, 63)+ 0.5000000000000000D+00*dw(114, 63)
      JacC( 70, 62) = JacC( 70, 62)+ 0.2100000000000000D+00*dw(114, 62)
      JacC( 70, 63) = JacC( 70, 63)+ 0.2100000000000000D+00*dw(114, 63)
      JacC( 72, 62) = JacC( 72, 62)+ 0.6200000000000000D+00*dw(114, 62)
      JacC( 72, 63) = JacC( 72, 63)+ 0.6200000000000000D+00*dw(114, 63)
      JacC( 77, 62) = JacC( 77, 62)+ 0.1600000000000000D+00*dw(114, 62)
      JacC( 77, 63) = JacC( 77, 63)+ 0.1600000000000000D+00*dw(114, 63)
      JacC( 78, 62) = JacC( 78, 62)+ 0.2100000000000000D+00*dw(114, 62)
      JacC( 78, 63) = JacC( 78, 63)+ 0.2100000000000000D+00*dw(114, 63)
      JacC( 83, 62) = JacC( 83, 62)+ 0.2800000000000000D+00*dw(114, 62)
      JacC( 83, 63) = JacC( 83, 63)+ 0.2800000000000000D+00*dw(114, 63)
      JacC( 86, 62) = JacC( 86, 62)+ 0.2900000000000000D+00*dw(114, 62)
      JacC( 86, 63) = JacC( 86, 63)+ 0.2900000000000000D+00*dw(114, 63)
      JacC( 46, 46) = JacC( 46, 46) - dw(115, 46)
      JacC( 46, 63) = JacC( 46, 63) - dw(115, 63)
      JacC( 47, 46) = JacC( 47, 46)+ 0.3000000000000000D+00*dw(115, 46)
      JacC( 47, 63) = JacC( 47, 63)+ 0.3000000000000000D+00*dw(115, 63)
      JacC( 48, 46) = JacC( 48, 46)+ 0.1100000000000000D+00*dw(115, 46)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1100000000000000D+00*dw(115, 63)
      JacC( 63, 46) = JacC( 63, 46) - dw(115, 46)
      JacC( 63, 63) = JacC( 63, 63) - dw(115, 63)
      JacC( 64, 46) = JacC( 64, 46)+ 0.1300000000000000D+00*dw(115, 46)
      JacC( 64, 63) = JacC( 64, 63)+ 0.1300000000000000D+00*dw(115, 63)
      JacC( 78, 46) = JacC( 78, 46)+ 0.3600000000000000D-01*dw(115, 46)
      JacC( 78, 63) = JacC( 78, 63)+ 0.3600000000000000D-01*dw(115, 63)
      JacC( 80, 46) = JacC( 80, 46)+ 0.7000000000000000D+00*dw(115, 46)
      JacC( 80, 63) = JacC( 80, 63)+ 0.7000000000000000D+00*dw(115, 63)
      JacC( 83, 46) = JacC( 83, 46)+ 0.7000000000000000D+00*dw(115, 46)
      JacC( 83, 63) = JacC( 83, 63)+ 0.7000000000000000D+00*dw(115, 63)
      JacC( 86, 46) = JacC( 86, 46)+ 0.8000000000000000D-01*dw(115, 46)
      JacC( 86, 63) = JacC( 86, 63)+ 0.8000000000000000D-01*dw(115, 63)
      JacC( 87, 46) = JacC( 87, 46)+ 0.7000000000000000D+00*dw(115, 46)
      JacC( 87, 63) = JacC( 87, 63)+ 0.7000000000000000D+00*dw(115, 63)
      JacC( 36, 36) = JacC( 36, 36) - dw(116, 36)
      JacC( 36, 87) = JacC( 36, 87) - dw(116, 87)
      JacC( 37, 36) = JacC( 37, 36)+ 0.1000000000000000D+00*dw(116, 36)
      JacC( 37, 87) = JacC( 37, 87)+ 0.1000000000000000D+00*dw(116, 87)
      JacC( 74, 36) = JacC( 74, 36) + dw(116, 36)
      JacC( 74, 87) = JacC( 74, 87) + dw(116, 87)
      JacC( 87, 36) = JacC( 87, 36) - dw(116, 36)
      JacC( 87, 87) = JacC( 87, 87) - dw(116, 87)
      JacC( 36, 36) = JacC( 36, 36) - dw(117, 36)
      JacC( 36, 86) = JacC( 36, 86) - dw(117, 86)
      JacC( 37, 36) = JacC( 37, 36) + dw(117, 36)
      JacC( 37, 86) = JacC( 37, 86) + dw(117, 86)
      JacC( 86, 36) = JacC( 86, 36) - dw(117, 36)
      JacC( 86, 86) = JacC( 86, 86) - dw(117, 86)
      JacC( 29, 29) = JacC( 29, 29) - dw(118, 29)
      JacC( 29, 87) = JacC( 29, 87) - dw(118, 87)
      JacC( 32, 29) = JacC( 32, 29) + dw(118, 29)
      JacC( 32, 87) = JacC( 32, 87) + dw(118, 87)
      JacC( 37, 29) = JacC( 37, 29) + dw(118, 29)
      JacC( 37, 87) = JacC( 37, 87) + dw(118, 87)
      JacC( 87, 29) = JacC( 87, 29) - dw(118, 29)
      JacC( 87, 87) = JacC( 87, 87) - dw(118, 87)
      JacC( 29, 29) = JacC( 29, 29) - dw(119, 29)
      JacC( 37, 29) = JacC( 37, 29)+ 0.2000000000000000D-01*dw(119, 29)
      JacC( 39, 29) = JacC( 39, 29)+ 0.9800000000000000D+00*dw(119, 29)
      JacC( 86, 29) = JacC( 86, 29)+ 0.2000000000000000D-01*dw(119, 29)
      JacC( 29, 29) = JacC( 29, 29) - dw(120, 29)
      JacC( 29, 63) = JacC( 29, 63) - dw(120, 63)
      JacC( 37, 29) = JacC( 37, 29) + dw(120, 29)
      JacC( 37, 63) = JacC( 37, 63) + dw(120, 63)
      JacC( 63, 29) = JacC( 63, 29) - dw(120, 29)
      JacC( 63, 63) = JacC( 63, 63) - dw(120, 63)
      JacC( 78, 29) = JacC( 78, 29) + dw(120, 29)
      JacC( 78, 63) = JacC( 78, 63) + dw(120, 63)
      JacC( 18, 18) = JacC( 18, 18) - dw(121, 18)
      JacC( 18, 87) = JacC( 18, 87) - dw(121, 87)
      JacC( 32, 18) = JacC( 32, 18) + dw(121, 18)
      JacC( 32, 87) = JacC( 32, 87) + dw(121, 87)
      JacC( 37, 18) = JacC( 37, 18) + dw(121, 18)
      JacC( 37, 87) = JacC( 37, 87) + dw(121, 87)
      JacC( 87, 18) = JacC( 87, 18) - dw(121, 18)
      JacC( 87, 87) = JacC( 87, 87) - dw(121, 87)
      JacC( 18, 18) = JacC( 18, 18) - dw(122, 18)
      JacC( 37, 18) = JacC( 37, 18)+ 0.2000000000000000D-01*dw(122, 18)
      JacC( 44, 18) = JacC( 44, 18)+ 0.9800000000000000D+00*dw(122, 18)
      JacC( 86, 18) = JacC( 86, 18)+ 0.2000000000000000D-01*dw(122, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(123, 18)
      JacC( 18, 63) = JacC( 18, 63) - dw(123, 63)
      JacC( 37, 18) = JacC( 37, 18) + dw(123, 18)
      JacC( 37, 63) = JacC( 37, 63) + dw(123, 63)
      JacC( 63, 18) = JacC( 63, 18) - dw(123, 18)
      JacC( 63, 63) = JacC( 63, 63) - dw(123, 63)
      JacC( 78, 18) = JacC( 78, 18) + dw(123, 18)
      JacC( 78, 63) = JacC( 78, 63) + dw(123, 63)
      JacC( 31, 31) = JacC( 31, 31) - dw(124, 31)
      JacC( 31, 87) = JacC( 31, 87) - dw(124, 87)
      JacC( 32, 31) = JacC( 32, 31) + dw(124, 31)
      JacC( 32, 87) = JacC( 32, 87) + dw(124, 87)
      JacC( 37, 31) = JacC( 37, 31) + dw(124, 31)
      JacC( 37, 87) = JacC( 37, 87) + dw(124, 87)
      JacC( 87, 31) = JacC( 87, 31) - dw(124, 31)
      JacC( 87, 87) = JacC( 87, 87) - dw(124, 87)
      JacC( 31, 31) = JacC( 31, 31) - dw(125, 31)
      JacC( 37, 31) = JacC( 37, 31)+ 0.2000000000000000D-01*dw(125, 31)
      JacC( 49, 31) = JacC( 49, 31)+ 0.9800000000000000D+00*dw(125, 31)
      JacC( 86, 31) = JacC( 86, 31)+ 0.2000000000000000D-01*dw(125, 31)
      JacC( 31, 31) = JacC( 31, 31) - dw(126, 31)
      JacC( 31, 63) = JacC( 31, 63) - dw(126, 63)
      JacC( 37, 31) = JacC( 37, 31) + dw(126, 31)
      JacC( 37, 63) = JacC( 37, 63) + dw(126, 63)
      JacC( 63, 31) = JacC( 63, 31) - dw(126, 31)
      JacC( 63, 63) = JacC( 63, 63) - dw(126, 63)
      JacC( 78, 31) = JacC( 78, 31) + dw(126, 31)
      JacC( 78, 63) = JacC( 78, 63) + dw(126, 63)
      JacC( 47, 83) = JacC( 47, 83) + dw(127, 83)
      JacC( 47, 87) = JacC( 47, 87) + dw(127, 87)
      JacC( 83, 83) = JacC( 83, 83) - dw(127, 83)
      JacC( 83, 87) = JacC( 83, 87) - dw(127, 87)
      JacC( 87, 83) = JacC( 87, 83) - dw(127, 83)
      JacC( 87, 87) = JacC( 87, 87) - dw(127, 87)
      JacC( 47, 47) = JacC( 47, 47) - dw(128, 47)
      JacC( 83, 47) = JacC( 83, 47) + dw(128, 47)
      JacC( 87, 47) = JacC( 87, 47) + dw(128, 47)
      JacC( 46, 68) = JacC( 46, 68) + dw(129, 68)
      JacC( 46, 87) = JacC( 46, 87) + dw(129, 87)
      JacC( 68, 68) = JacC( 68, 68) - dw(129, 68)
      JacC( 68, 87) = JacC( 68, 87) - dw(129, 87)
      JacC( 87, 68) = JacC( 87, 68) - dw(129, 68)
      JacC( 87, 87) = JacC( 87, 87) - dw(129, 87)
      JacC( 46, 46) = JacC( 46, 46) - dw(130, 46)
      JacC( 68, 46) = JacC( 68, 46) + dw(130, 46)
      JacC( 87, 46) = JacC( 87, 46) + dw(130, 46)
      JacC( 80, 82) = JacC( 80, 82) + dw(131, 82)
      JacC( 80, 84) = JacC( 80, 84) + dw(131, 84)
      JacC( 82, 82) = JacC( 82, 82) - dw(131, 82)
      JacC( 82, 84) = JacC( 82, 84) - dw(131, 84)
      JacC( 84, 82) = JacC( 84, 82) - dw(131, 82)
      JacC( 84, 84) = JacC( 84, 84) - dw(131, 84)
      JacC( 86, 82) = JacC( 86, 82) + dw(131, 82)
      JacC( 86, 84) = JacC( 86, 84) + dw(131, 84)
      JacC( 87, 82) = JacC( 87, 82) + dw(131, 82)
      JacC( 87, 84) = JacC( 87, 84) + dw(131, 84)
      JacC( 77, 79) = JacC( 77, 79) + dw(132, 79)
      JacC( 77, 84) = JacC( 77, 84) + dw(132, 84)
      JacC( 79, 79) = JacC( 79, 79) - dw(132, 79)
      JacC( 79, 84) = JacC( 79, 84) - dw(132, 84)
      JacC( 84, 79) = JacC( 84, 79) - dw(132, 79)
      JacC( 84, 84) = JacC( 84, 84) - dw(132, 84)
      JacC( 86, 79) = JacC( 86, 79) + dw(132, 79)
      JacC( 86, 84) = JacC( 86, 84) + dw(132, 84)
      JacC( 87, 79) = JacC( 87, 79) + dw(132, 79)
      JacC( 87, 84) = JacC( 87, 84) + dw(132, 84)
      JacC( 65, 71) = JacC( 65, 71)+ 0.6300000000000000D-01*dw(133, 71)
      JacC( 65, 84) = JacC( 65, 84)+ 0.6300000000000000D-01*dw(133, 84)
      JacC( 71, 71) = JacC( 71, 71) - dw(133, 71)
      JacC( 71, 84) = JacC( 71, 84) - dw(133, 84)
      JacC( 74, 71) = JacC( 74, 71)+ 0.5900000000000000D-01*dw(133, 71)
      JacC( 74, 84) = JacC( 74, 84)+ 0.5900000000000000D-01*dw(133, 84)
      JacC( 75, 71) = JacC( 75, 71)+ 0.6230000000000000D+00*dw(133, 71)
      JacC( 75, 84) = JacC( 75, 84)+ 0.6230000000000000D+00*dw(133, 84)
      JacC( 77, 71) = JacC( 77, 71)+ 0.2330000000000000D+00*dw(133, 71)
      JacC( 77, 84) = JacC( 77, 84)+ 0.2330000000000000D+00*dw(133, 84)
      JacC( 79, 71) = JacC( 79, 71)+ 0.4800000000000000D-01*dw(133, 71)
      JacC( 79, 84) = JacC( 79, 84)+ 0.4800000000000000D-01*dw(133, 84)
      JacC( 80, 71) = JacC( 80, 71)+ 0.4700000000000000D-01*dw(133, 71)
      JacC( 80, 84) = JacC( 80, 84)+ 0.4700000000000000D-01*dw(133, 84)
      JacC( 81, 71) = JacC( 81, 71)+ 0.4800000000000000D-01*dw(133, 71)
      JacC( 81, 84) = JacC( 81, 84)+ 0.4800000000000000D-01*dw(133, 84)
      JacC( 82, 71) = JacC( 82, 71)+ 0.1500000000000000D+00*dw(133, 71)
      JacC( 82, 84) = JacC( 82, 84)+ 0.1500000000000000D+00*dw(133, 84)
      JacC( 84, 71) = JacC( 84, 71) - dw(133, 71)
      JacC( 84, 84) = JacC( 84, 84) - dw(133, 84)
      JacC( 86, 71) = JacC( 86, 71)+ 0.7420000000000000D+00*dw(133, 71)
      JacC( 86, 84) = JacC( 86, 84)+ 0.7420000000000000D+00*dw(133, 84)
      JacC( 87, 71) = JacC( 87, 71)+ 0.9409999999999999D+00*dw(133, 71)
      JacC( 87, 84) = JacC( 87, 84)+ 0.9409999999999999D+00*dw(133, 84)
      JacC( 61, 61) = JacC( 61, 61) - dw(134, 61)
      JacC( 61, 84) = JacC( 61, 84) - dw(134, 84)
      JacC( 74, 61) = JacC( 74, 61)+ 0.1240000000000000D+00*dw(134, 61)
      JacC( 74, 84) = JacC( 74, 84)+ 0.1240000000000000D+00*dw(134, 84)
      JacC( 75, 61) = JacC( 75, 61)+ 0.7220000000000000D+00*dw(134, 61)
      JacC( 75, 84) = JacC( 75, 84)+ 0.7220000000000000D+00*dw(134, 84)
      JacC( 77, 61) = JacC( 77, 61)+ 0.2110000000000000D+00*dw(134, 61)
      JacC( 77, 84) = JacC( 77, 84)+ 0.2110000000000000D+00*dw(134, 84)
      JacC( 79, 61) = JacC( 79, 61)+ 0.2450000000000000D+00*dw(134, 61)
      JacC( 79, 84) = JacC( 79, 84)+ 0.2450000000000000D+00*dw(134, 84)
      JacC( 80, 61) = JacC( 80, 61)+ 0.2100000000000000D-01*dw(134, 61)
      JacC( 80, 84) = JacC( 80, 84)+ 0.2100000000000000D-01*dw(134, 84)
      JacC( 81, 61) = JacC( 81, 61)+ 0.3340000000000000D+00*dw(134, 61)
      JacC( 81, 84) = JacC( 81, 84)+ 0.3340000000000000D+00*dw(134, 84)
      JacC( 82, 61) = JacC( 82, 61)+ 0.3100000000000000D-01*dw(134, 61)
      JacC( 82, 84) = JacC( 82, 84)+ 0.3100000000000000D-01*dw(134, 84)
      JacC( 84, 61) = JacC( 84, 61) - dw(134, 61)
      JacC( 84, 84) = JacC( 84, 84) - dw(134, 84)
      JacC( 86, 61) = JacC( 86, 61)+ 0.5990000000000000D+00*dw(134, 61)
      JacC( 86, 84) = JacC( 86, 84)+ 0.5990000000000000D+00*dw(134, 84)
      JacC( 87, 61) = JacC( 87, 61)+ 0.8760000000000000D+00*dw(134, 61)
      JacC( 87, 84) = JacC( 87, 84)+ 0.8760000000000000D+00*dw(134, 84)
      JacC( 66, 66) = JacC( 66, 66) - dw(135, 66)
      JacC( 66, 84) = JacC( 66, 84) - dw(135, 84)
      JacC( 74, 66) = JacC( 74, 66)+ 0.2610000000000000D+00*dw(135, 66)
      JacC( 74, 84) = JacC( 74, 84)+ 0.2610000000000000D+00*dw(135, 84)
      JacC( 75, 66) = JacC( 75, 66)+ 0.6420000000000000D+00*dw(135, 66)
      JacC( 75, 84) = JacC( 75, 84)+ 0.6420000000000000D+00*dw(135, 84)
      JacC( 77, 66) = JacC( 77, 66)+ 0.1500000000000000D+00*dw(135, 66)
      JacC( 77, 84) = JacC( 77, 84)+ 0.1500000000000000D+00*dw(135, 84)
      JacC( 79, 66) = JacC( 79, 66)+ 0.1330000000000000D+00*dw(135, 66)
      JacC( 79, 84) = JacC( 79, 84)+ 0.1330000000000000D+00*dw(135, 84)
      JacC( 81, 66) = JacC( 81, 66)+ 0.4160000000000000D+00*dw(135, 66)
      JacC( 81, 84) = JacC( 81, 84)+ 0.4160000000000000D+00*dw(135, 84)
      JacC( 84, 66) = JacC( 84, 66) - dw(135, 66)
      JacC( 84, 84) = JacC( 84, 84) - dw(135, 84)
      JacC( 86, 66) = JacC( 86, 66)+ 0.6060000000000000D+00*dw(135, 66)
      JacC( 86, 84) = JacC( 86, 84)+ 0.6060000000000000D+00*dw(135, 84)
      JacC( 87, 66) = JacC( 87, 66)+ 0.7390000000000000D+00*dw(135, 66)
      JacC( 87, 84) = JacC( 87, 84)+ 0.7390000000000000D+00*dw(135, 84)
      JacC( 67, 67) = JacC( 67, 67) - dw(136, 67)
      JacC( 67, 84) = JacC( 67, 84) - dw(136, 84)
      JacC( 77, 67) = JacC( 77, 67)+ 0.2000000000000000D+00*dw(136, 67)
      JacC( 77, 84) = JacC( 77, 84)+ 0.2000000000000000D+00*dw(136, 84)
      JacC( 80, 67) = JacC( 80, 67)+ 0.1600000000000000D+01*dw(136, 67)
      JacC( 80, 84) = JacC( 80, 84)+ 0.1600000000000000D+01*dw(136, 84)
      JacC( 84, 67) = JacC( 84, 67) - dw(136, 67)
      JacC( 84, 84) = JacC( 84, 84) - dw(136, 84)
      JacC( 86, 67) = JacC( 86, 67) + dw(136, 67)
      JacC( 86, 84) = JacC( 86, 84) + dw(136, 84)
      JacC( 87, 67) = JacC( 87, 67) + dw(136, 67)
      JacC( 87, 84) = JacC( 87, 84) + dw(136, 84)
      JacC( 53, 53) = JacC( 53, 53) - dw(137, 53)
      JacC( 53, 84) = JacC( 53, 84) - dw(137, 84)
      JacC( 75, 53) = JacC( 75, 53)+ 0.6000000000000000D-01*dw(137, 53)
      JacC( 75, 84) = JacC( 75, 84)+ 0.6000000000000000D-01*dw(137, 84)
      JacC( 77, 53) = JacC( 77, 53)+ 0.9399999999999999D+00*dw(137, 53)
      JacC( 77, 84) = JacC( 77, 84)+ 0.9399999999999999D+00*dw(137, 84)
      JacC( 80, 53) = JacC( 80, 53) + dw(137, 53)
      JacC( 80, 84) = JacC( 80, 84) + dw(137, 84)
      JacC( 84, 53) = JacC( 84, 53) - dw(137, 53)
      JacC( 84, 84) = JacC( 84, 84) - dw(137, 84)
      JacC( 86, 53) = JacC( 86, 53) + dw(137, 53)
      JacC( 86, 84) = JacC( 86, 84) + dw(137, 84)
      JacC( 87, 53) = JacC( 87, 53) + dw(137, 53)
      JacC( 87, 84) = JacC( 87, 84) + dw(137, 84)
      JacC( 59, 59) = JacC( 59, 59) - dw(138, 59)
      JacC( 59, 84) = JacC( 59, 84) - dw(138, 84)
      JacC( 75, 59) = JacC( 75, 59)+ 0.2900000000000000D+00*dw(138, 59)
      JacC( 75, 84) = JacC( 75, 84)+ 0.2900000000000000D+00*dw(138, 84)
      JacC( 77, 59) = JacC( 77, 59)+ 0.1710000000000000D+01*dw(138, 59)
      JacC( 77, 84) = JacC( 77, 84)+ 0.1710000000000000D+01*dw(138, 84)
      JacC( 84, 59) = JacC( 84, 59) - dw(138, 59)
      JacC( 84, 84) = JacC( 84, 84) - dw(138, 84)
      JacC( 86, 59) = JacC( 86, 59) + dw(138, 59)
      JacC( 86, 84) = JacC( 86, 84) + dw(138, 84)
      JacC( 87, 59) = JacC( 87, 59) + dw(138, 59)
      JacC( 87, 84) = JacC( 87, 84) + dw(138, 84)
      JacC( 51, 51) = JacC( 51, 51) - dw(139, 51)
      JacC( 51, 84) = JacC( 51, 84) - dw(139, 84)
      JacC( 52, 51) = JacC( 52, 51)+ 0.3540000000000000D+00*dw(139, 51)
      JacC( 52, 84) = JacC( 52, 84)+ 0.3540000000000000D+00*dw(139, 84)
      JacC( 60, 51) = JacC( 60, 51)+ 0.4460000000000000D+00*dw(139, 51)
      JacC( 60, 84) = JacC( 60, 84)+ 0.4460000000000000D+00*dw(139, 84)
      JacC( 74, 51) = JacC( 74, 51)+ 0.1530000000000000D+00*dw(139, 51)
      JacC( 74, 84) = JacC( 74, 84)+ 0.1530000000000000D+00*dw(139, 84)
      JacC( 80, 51) = JacC( 80, 51)+ 0.6060000000000000D+00*dw(139, 51)
      JacC( 80, 84) = JacC( 80, 84)+ 0.6060000000000000D+00*dw(139, 84)
      JacC( 84, 51) = JacC( 84, 51) - dw(139, 51)
      JacC( 84, 84) = JacC( 84, 84) - dw(139, 84)
      JacC( 86, 51) = JacC( 86, 51)+ 0.8470000000000000D+00*dw(139, 51)
      JacC( 86, 84) = JacC( 86, 84)+ 0.8470000000000000D+00*dw(139, 84)
      JacC( 87, 51) = JacC( 87, 51)+ 0.8470000000000000D+00*dw(139, 51)
      JacC( 87, 84) = JacC( 87, 84)+ 0.8470000000000000D+00*dw(139, 84)
      JacC( 54, 54) = JacC( 54, 54) - dw(140, 54)
      JacC( 54, 84) = JacC( 54, 84) - dw(140, 84)
      JacC( 74, 54) = JacC( 74, 54)+ 0.2000000000000000D+00*dw(140, 54)
      JacC( 74, 84) = JacC( 74, 84)+ 0.2000000000000000D+00*dw(140, 84)
      JacC( 75, 54) = JacC( 75, 54)+ 0.8000000000000000D+00*dw(140, 54)
      JacC( 75, 84) = JacC( 75, 84)+ 0.8000000000000000D+00*dw(140, 84)
      JacC( 77, 54) = JacC( 77, 54)+ 0.8000000000000000D+00*dw(140, 54)
      JacC( 77, 84) = JacC( 77, 84)+ 0.8000000000000000D+00*dw(140, 84)
      JacC( 84, 54) = JacC( 84, 54) - dw(140, 54)
      JacC( 84, 84) = JacC( 84, 84) - dw(140, 84)
      JacC( 86, 54) = JacC( 86, 54)+ 0.8000000000000000D+00*dw(140, 54)
      JacC( 86, 84) = JacC( 86, 84)+ 0.8000000000000000D+00*dw(140, 84)
      JacC( 87, 54) = JacC( 87, 54)+ 0.8000000000000000D+00*dw(140, 54)
      JacC( 87, 84) = JacC( 87, 84)+ 0.8000000000000000D+00*dw(140, 84)
      JacC( 55, 55) = JacC( 55, 55) - dw(141, 55)
      JacC( 55, 84) = JacC( 55, 84) - dw(141, 84)
      JacC( 56, 55) = JacC( 56, 55)+ 0.2500000000000000D+00*dw(141, 55)
      JacC( 56, 84) = JacC( 56, 84)+ 0.2500000000000000D+00*dw(141, 84)
      JacC( 60, 55) = JacC( 60, 55)+ 0.4000000000000000D+00*dw(141, 55)
      JacC( 60, 84) = JacC( 60, 84)+ 0.4000000000000000D+00*dw(141, 84)
      JacC( 74, 55) = JacC( 74, 55)+ 0.3500000000000000D+00*dw(141, 55)
      JacC( 74, 84) = JacC( 74, 84)+ 0.3500000000000000D+00*dw(141, 84)
      JacC( 80, 55) = JacC( 80, 55)+ 0.2500000000000000D+00*dw(141, 55)
      JacC( 80, 84) = JacC( 80, 84)+ 0.2500000000000000D+00*dw(141, 84)
      JacC( 84, 55) = JacC( 84, 55) - dw(141, 55)
      JacC( 84, 84) = JacC( 84, 84) - dw(141, 84)
      JacC( 86, 55) = JacC( 86, 55)+ 0.6500000000000000D+00*dw(141, 55)
      JacC( 86, 84) = JacC( 86, 84)+ 0.6500000000000000D+00*dw(141, 84)
      JacC( 87, 55) = JacC( 87, 55)+ 0.6500000000000000D+00*dw(141, 55)
      JacC( 87, 84) = JacC( 87, 84)+ 0.6500000000000000D+00*dw(141, 84)
      JacC( 39, 39) = JacC( 39, 39) - dw(142, 39)
      JacC( 39, 84) = JacC( 39, 84) - dw(142, 84)
      JacC( 41, 39) = JacC( 41, 39)+ 0.1220000000000000D+00*dw(142, 39)
      JacC( 41, 84) = JacC( 41, 84)+ 0.1220000000000000D+00*dw(142, 84)
      JacC( 42, 39) = JacC( 42, 39)+ 0.4400000000000000D-01*dw(142, 39)
      JacC( 42, 84) = JacC( 42, 84)+ 0.4400000000000000D-01*dw(142, 84)
      JacC( 62, 39) = JacC( 62, 39)+ 0.5000000000000000D+00*dw(142, 39)
      JacC( 62, 84) = JacC( 62, 84)+ 0.5000000000000000D+00*dw(142, 84)
      JacC( 65, 39) = JacC( 65, 39)+ 0.1200000000000000D+01*dw(142, 39)
      JacC( 65, 84) = JacC( 65, 84)+ 0.1200000000000000D+01*dw(142, 84)
      JacC( 72, 39) = JacC( 72, 39)+ 0.6500000000000000D+00*dw(142, 39)
      JacC( 72, 84) = JacC( 72, 84)+ 0.6500000000000000D+00*dw(142, 84)
      JacC( 74, 39) = JacC( 74, 39)+ 0.5000000000000000D-01*dw(142, 39)
      JacC( 74, 84) = JacC( 74, 84)+ 0.5000000000000000D-01*dw(142, 84)
      JacC( 84, 39) = JacC( 84, 39) - dw(142, 39)
      JacC( 84, 84) = JacC( 84, 84) - dw(142, 84)
      JacC( 86, 39) = JacC( 86, 39)+ 0.9500000000000000D+00*dw(142, 39)
      JacC( 86, 84) = JacC( 86, 84)+ 0.9500000000000000D+00*dw(142, 84)
      JacC( 87, 39) = JacC( 87, 39)+ 0.9500000000000000D+00*dw(142, 39)
      JacC( 87, 84) = JacC( 87, 84)+ 0.9500000000000000D+00*dw(142, 84)
      JacC( 41, 44) = JacC( 41, 44)+ 0.1220000000000000D+00*dw(143, 44)
      JacC( 41, 84) = JacC( 41, 84)+ 0.1220000000000000D+00*dw(143, 84)
      JacC( 42, 44) = JacC( 42, 44)+ 0.4400000000000000D-01*dw(143, 44)
      JacC( 42, 84) = JacC( 42, 84)+ 0.4400000000000000D-01*dw(143, 84)
      JacC( 44, 44) = JacC( 44, 44) - dw(143, 44)
      JacC( 44, 84) = JacC( 44, 84) - dw(143, 84)
      JacC( 62, 44) = JacC( 62, 44)+ 0.9500000000000000D+00*dw(143, 44)
      JacC( 62, 84) = JacC( 62, 84)+ 0.9500000000000000D+00*dw(143, 84)
      JacC( 65, 44) = JacC( 65, 44)+ 0.3500000000000000D+00*dw(143, 44)
      JacC( 65, 84) = JacC( 65, 84)+ 0.3500000000000000D+00*dw(143, 84)
      JacC( 72, 44) = JacC( 72, 44)+ 0.6000000000000000D+00*dw(143, 44)
      JacC( 72, 84) = JacC( 72, 84)+ 0.6000000000000000D+00*dw(143, 84)
      JacC( 74, 44) = JacC( 74, 44)+ 0.5000000000000000D-01*dw(143, 44)
      JacC( 74, 84) = JacC( 74, 84)+ 0.5000000000000000D-01*dw(143, 84)
      JacC( 84, 44) = JacC( 84, 44) - dw(143, 44)
      JacC( 84, 84) = JacC( 84, 84) - dw(143, 84)
      JacC( 86, 44) = JacC( 86, 44)+ 0.9500000000000000D+00*dw(143, 44)
      JacC( 86, 84) = JacC( 86, 84)+ 0.9500000000000000D+00*dw(143, 84)
      JacC( 87, 44) = JacC( 87, 44)+ 0.9500000000000000D+00*dw(143, 44)
      JacC( 87, 84) = JacC( 87, 84)+ 0.9500000000000000D+00*dw(143, 84)
      JacC( 49, 49) = JacC( 49, 49) - dw(144, 49)
      JacC( 49, 84) = JacC( 49, 84) - dw(144, 84)
      JacC( 65, 49) = JacC( 65, 49) + dw(144, 49)
      JacC( 65, 84) = JacC( 65, 84) + dw(144, 84)
      JacC( 72, 49) = JacC( 72, 49) + dw(144, 49)
      JacC( 72, 84) = JacC( 72, 84) + dw(144, 84)
      JacC( 84, 49) = JacC( 84, 49) - dw(144, 49)
      JacC( 84, 84) = JacC( 84, 84) - dw(144, 84)
      JacC( 86, 49) = JacC( 86, 49) + dw(144, 49)
      JacC( 86, 84) = JacC( 86, 84) + dw(144, 84)
      JacC( 87, 49) = JacC( 87, 49) + dw(144, 49)
      JacC( 87, 84) = JacC( 87, 84) + dw(144, 84)
      JacC( 82, 83) = JacC( 82, 83) + dw(145, 83)
      JacC( 82, 84) = JacC( 82, 84) + dw(145, 84)
      JacC( 83, 83) = JacC( 83, 83) - dw(145, 83)
      JacC( 83, 84) = JacC( 83, 84) - dw(145, 84)
      JacC( 84, 83) = JacC( 84, 83) - dw(145, 83)
      JacC( 84, 84) = JacC( 84, 84) - dw(145, 84)
      JacC( 87, 83) = JacC( 87, 83) + dw(145, 83)
      JacC( 87, 84) = JacC( 87, 84) + dw(145, 84)
      JacC( 68, 68) = JacC( 68, 68) - dw(146, 68)
      JacC( 68, 84) = JacC( 68, 84) - dw(146, 84)
      JacC( 80, 68) = JacC( 80, 68) + dw(146, 68)
      JacC( 80, 84) = JacC( 80, 84) + dw(146, 84)
      JacC( 83, 68) = JacC( 83, 68) + dw(146, 68)
      JacC( 83, 84) = JacC( 83, 84) + dw(146, 84)
      JacC( 84, 68) = JacC( 84, 68) - dw(146, 68)
      JacC( 84, 84) = JacC( 84, 84) - dw(146, 84)
      JacC( 87, 68) = JacC( 87, 68) + dw(146, 68)
      JacC( 87, 84) = JacC( 87, 84) + dw(146, 84)
      JacC( 72, 76) = JacC( 72, 76)+ 0.5400000000000000D+00*dw(147, 76)
      JacC( 72, 84) = JacC( 72, 84)+ 0.5400000000000000D+00*dw(147, 84)
      JacC( 76, 76) = JacC( 76, 76) - dw(147, 76)
      JacC( 76, 84) = JacC( 76, 84) - dw(147, 84)
      JacC( 77, 76) = JacC( 77, 76)+ 0.4600000000000000D+00*dw(147, 76)
      JacC( 77, 84) = JacC( 77, 84)+ 0.4600000000000000D+00*dw(147, 84)
      JacC( 81, 76) = JacC( 81, 76)+ 0.1600000000000000D+00*dw(147, 76)
      JacC( 81, 84) = JacC( 81, 84)+ 0.1600000000000000D+00*dw(147, 84)
      JacC( 83, 76) = JacC( 83, 76)+ 0.2300000000000000D+00*dw(147, 76)
      JacC( 83, 84) = JacC( 83, 84)+ 0.2300000000000000D+00*dw(147, 84)
      JacC( 84, 76) = JacC( 84, 76) - dw(147, 76)
      JacC( 84, 84) = JacC( 84, 84) - dw(147, 84)
      JacC( 86, 76) = JacC( 86, 76)+ 0.7700000000000000D+00*dw(147, 76)
      JacC( 86, 84) = JacC( 86, 84)+ 0.7700000000000000D+00*dw(147, 84)
      JacC( 87, 76) = JacC( 87, 76) + dw(147, 76)
      JacC( 87, 84) = JacC( 87, 84) + dw(147, 84)
      JacC( 58, 58) = JacC( 58, 58) - dw(148, 58)
      JacC( 58, 84) = JacC( 58, 84) - dw(148, 84)
      JacC( 74, 58) = JacC( 74, 58) + dw(148, 58)
      JacC( 74, 84) = JacC( 74, 84) + dw(148, 84)
      JacC( 84, 58) = JacC( 84, 58) - dw(148, 58)
      JacC( 84, 84) = JacC( 84, 84) - dw(148, 84)
      JacC( 86, 58) = JacC( 86, 58) + dw(148, 58)
      JacC( 86, 84) = JacC( 86, 84) + dw(148, 84)
      JacC( 87, 58) = JacC( 87, 58) + dw(148, 58)
      JacC( 87, 84) = JacC( 87, 84) + dw(148, 84)
      JacC( 57, 57) = JacC( 57, 57) - dw(149, 57)
      JacC( 57, 84) = JacC( 57, 84) - dw(149, 84)
      JacC( 75, 57) = JacC( 75, 57)+ 0.4640000000000000D+00*dw(149, 57)
      JacC( 75, 84) = JacC( 75, 84)+ 0.4640000000000000D+00*dw(149, 84)
      JacC( 77, 57) = JacC( 77, 57)+ 0.1240000000000000D+01*dw(149, 57)
      JacC( 77, 84) = JacC( 77, 84)+ 0.1240000000000000D+01*dw(149, 84)
      JacC( 80, 57) = JacC( 80, 57)+ 0.2870000000000000D+00*dw(149, 57)
      JacC( 80, 84) = JacC( 80, 84)+ 0.2870000000000000D+00*dw(149, 84)
      JacC( 84, 57) = JacC( 84, 57) - dw(149, 57)
      JacC( 84, 84) = JacC( 84, 84) - dw(149, 84)
      JacC( 87, 57) = JacC( 87, 57)+ 0.2000000000000000D+01*dw(149, 57)
      JacC( 87, 84) = JacC( 87, 84)+ 0.2000000000000000D+01*dw(149, 84)
      JacC( 23, 82) = JacC( 23, 82) + dw(150, 82)
      JacC( 23, 86) = JacC( 23, 86) + dw(150, 86)
      JacC( 82, 82) = JacC( 82, 82) - dw(150, 82)
      JacC( 82, 86) = JacC( 82, 86) - dw(150, 86)
      JacC( 86, 82) = JacC( 86, 82) - dw(150, 82)
      JacC( 86, 86) = JacC( 86, 86) - dw(150, 86)
      JacC( 69, 79) = JacC( 69, 79) + dw(151, 79)
      JacC( 69, 86) = JacC( 69, 86) + dw(151, 86)
      JacC( 79, 79) = JacC( 79, 79) - dw(151, 79)
      JacC( 79, 86) = JacC( 79, 86) - dw(151, 86)
      JacC( 86, 79) = JacC( 86, 79) - dw(151, 79)
      JacC( 86, 86) = JacC( 86, 86) - dw(151, 86)
      JacC( 69, 71) = JacC( 69, 71) + dw(152, 71)
      JacC( 69, 86) = JacC( 69, 86) + dw(152, 86)
      JacC( 71, 71) = JacC( 71, 71) - dw(152, 71)
      JacC( 71, 86) = JacC( 71, 86) - dw(152, 86)
      JacC( 86, 71) = JacC( 86, 71) - dw(152, 71)
      JacC( 86, 86) = JacC( 86, 86) - dw(152, 86)
      JacC( 61, 61) = JacC( 61, 61) - dw(153, 61)
      JacC( 61, 86) = JacC( 61, 86) - dw(153, 86)
      JacC( 69, 61) = JacC( 69, 61) + dw(153, 61)
      JacC( 69, 86) = JacC( 69, 86) + dw(153, 86)
      JacC( 86, 61) = JacC( 86, 61) - dw(153, 61)
      JacC( 86, 86) = JacC( 86, 86) - dw(153, 86)
      JacC( 66, 66) = JacC( 66, 66) - dw(154, 66)
      JacC( 66, 86) = JacC( 66, 86) - dw(154, 86)
      JacC( 69, 66) = JacC( 69, 66) + dw(154, 66)
      JacC( 69, 86) = JacC( 69, 86) + dw(154, 86)
      JacC( 86, 66) = JacC( 86, 66) - dw(154, 66)
      JacC( 86, 86) = JacC( 86, 86) - dw(154, 86)
      JacC( 67, 67) = JacC( 67, 67) - dw(155, 67)
      JacC( 67, 86) = JacC( 67, 86) - dw(155, 86)
      JacC( 69, 67) = JacC( 69, 67) + dw(155, 67)
      JacC( 69, 86) = JacC( 69, 86) + dw(155, 86)
      JacC( 86, 67) = JacC( 86, 67) - dw(155, 67)
      JacC( 86, 86) = JacC( 86, 86) - dw(155, 86)
      JacC( 53, 53) = JacC( 53, 53) - dw(156, 53)
      JacC( 53, 86) = JacC( 53, 86) - dw(156, 86)
      JacC( 69, 53) = JacC( 69, 53) + dw(156, 53)
      JacC( 69, 86) = JacC( 69, 86) + dw(156, 86)
      JacC( 86, 53) = JacC( 86, 53) - dw(156, 53)
      JacC( 86, 86) = JacC( 86, 86) - dw(156, 86)
      JacC( 59, 59) = JacC( 59, 59) - dw(157, 59)
      JacC( 59, 86) = JacC( 59, 86) - dw(157, 86)
      JacC( 69, 59) = JacC( 69, 59) + dw(157, 59)
      JacC( 69, 86) = JacC( 69, 86) + dw(157, 86)
      JacC( 86, 59) = JacC( 86, 59) - dw(157, 59)
      JacC( 86, 86) = JacC( 86, 86) - dw(157, 86)
      JacC( 51, 51) = JacC( 51, 51) - dw(158, 51)
      JacC( 51, 86) = JacC( 51, 86) - dw(158, 86)
      JacC( 69, 51) = JacC( 69, 51) + dw(158, 51)
      JacC( 69, 86) = JacC( 69, 86) + dw(158, 86)
      JacC( 86, 51) = JacC( 86, 51) - dw(158, 51)
      JacC( 86, 86) = JacC( 86, 86) - dw(158, 86)
      JacC( 54, 54) = JacC( 54, 54) - dw(159, 54)
      JacC( 54, 86) = JacC( 54, 86) - dw(159, 86)
      JacC( 69, 54) = JacC( 69, 54) + dw(159, 54)
      JacC( 69, 86) = JacC( 69, 86) + dw(159, 86)
      JacC( 86, 54) = JacC( 86, 54) - dw(159, 54)
      JacC( 86, 86) = JacC( 86, 86) - dw(159, 86)
      JacC( 55, 55) = JacC( 55, 55) - dw(160, 55)
      JacC( 55, 86) = JacC( 55, 86) - dw(160, 86)
      JacC( 69, 55) = JacC( 69, 55) + dw(160, 55)
      JacC( 69, 86) = JacC( 69, 86) + dw(160, 86)
      JacC( 86, 55) = JacC( 86, 55) - dw(160, 55)
      JacC( 86, 86) = JacC( 86, 86) - dw(160, 86)
      JacC( 39, 39) = JacC( 39, 39) - dw(161, 39)
      JacC( 39, 86) = JacC( 39, 86) - dw(161, 86)
      JacC( 40, 39) = JacC( 40, 39)+ 0.2200000000000000D+00*dw(161, 39)
      JacC( 40, 86) = JacC( 40, 86)+ 0.2200000000000000D+00*dw(161, 86)
      JacC( 69, 39) = JacC( 69, 39) + dw(161, 39)
      JacC( 69, 86) = JacC( 69, 86) + dw(161, 86)
      JacC( 86, 39) = JacC( 86, 39) - dw(161, 39)
      JacC( 86, 86) = JacC( 86, 86) - dw(161, 86)
      JacC( 40, 44) = JacC( 40, 44)+ 0.2200000000000000D+00*dw(162, 44)
      JacC( 40, 86) = JacC( 40, 86)+ 0.2200000000000000D+00*dw(162, 86)
      JacC( 44, 44) = JacC( 44, 44) - dw(162, 44)
      JacC( 44, 86) = JacC( 44, 86) - dw(162, 86)
      JacC( 69, 44) = JacC( 69, 44) + dw(162, 44)
      JacC( 69, 86) = JacC( 69, 86) + dw(162, 86)
      JacC( 86, 44) = JacC( 86, 44) - dw(162, 44)
      JacC( 86, 86) = JacC( 86, 86) - dw(162, 86)
      JacC( 49, 49) = JacC( 49, 49) - dw(163, 49)
      JacC( 49, 86) = JacC( 49, 86) - dw(163, 86)
      JacC( 69, 49) = JacC( 69, 49) + dw(163, 49)
      JacC( 69, 86) = JacC( 69, 86) + dw(163, 86)
      JacC( 86, 49) = JacC( 86, 49) - dw(163, 49)
      JacC( 86, 86) = JacC( 86, 86) - dw(163, 86)
      JacC( 35, 83) = JacC( 35, 83) + dw(164, 83)
      JacC( 35, 86) = JacC( 35, 86) + dw(164, 86)
      JacC( 83, 83) = JacC( 83, 83) - dw(164, 83)
      JacC( 83, 86) = JacC( 83, 86) - dw(164, 86)
      JacC( 86, 83) = JacC( 86, 83) - dw(164, 83)
      JacC( 86, 86) = JacC( 86, 86) - dw(164, 86)
      JacC( 63, 83) = JacC( 63, 83) + dw(165, 83)
      JacC( 63, 86) = JacC( 63, 86) + dw(165, 86)
      JacC( 70, 83) = JacC( 70, 83) + dw(165, 83)
      JacC( 70, 86) = JacC( 70, 86) + dw(165, 86)
      JacC( 83, 83) = JacC( 83, 83) - dw(165, 83)
      JacC( 83, 86) = JacC( 83, 86) - dw(165, 86)
      JacC( 86, 83) = JacC( 86, 83) - dw(165, 83)
      JacC( 86, 86) = JacC( 86, 86) - dw(165, 86)
      JacC( 68, 68) = JacC( 68, 68) - dw(166, 68)
      JacC( 68, 86) = JacC( 68, 86) - dw(166, 86)
      JacC( 69, 68) = JacC( 69, 68) + dw(166, 68)
      JacC( 69, 86) = JacC( 69, 86) + dw(166, 86)
      JacC( 86, 68) = JacC( 86, 68) - dw(166, 68)
      JacC( 86, 86) = JacC( 86, 86) - dw(166, 86)
      JacC( 63, 68) = JacC( 63, 68) + dw(167, 68)
      JacC( 63, 86) = JacC( 63, 86) + dw(167, 86)
      JacC( 68, 68) = JacC( 68, 68) - dw(167, 68)
      JacC( 68, 86) = JacC( 68, 86) - dw(167, 86)
      JacC( 70, 68) = JacC( 70, 68) + dw(167, 68)
      JacC( 70, 86) = JacC( 70, 86) + dw(167, 86)
      JacC( 86, 68) = JacC( 86, 68) - dw(167, 68)
      JacC( 86, 86) = JacC( 86, 86) - dw(167, 86)
      JacC( 69, 76) = JacC( 69, 76) + dw(168, 76)
      JacC( 69, 86) = JacC( 69, 86) + dw(168, 86)
      JacC( 76, 76) = JacC( 76, 76) - dw(168, 76)
      JacC( 76, 86) = JacC( 76, 86) - dw(168, 86)
      JacC( 86, 76) = JacC( 86, 76) - dw(168, 76)
      JacC( 86, 86) = JacC( 86, 86) - dw(168, 86)
      JacC( 58, 58) = JacC( 58, 58) - dw(169, 58)
      JacC( 58, 86) = JacC( 58, 86) - dw(169, 86)
      JacC( 74, 58) = JacC( 74, 58) + dw(169, 58)
      JacC( 74, 86) = JacC( 74, 86) + dw(169, 86)
      JacC( 86, 58) = JacC( 86, 58) - dw(169, 58)
      JacC( 86, 86) = JacC( 86, 86) - dw(169, 86)
      JacC( 57, 57) = JacC( 57, 57) - dw(170, 57)
      JacC( 57, 86) = JacC( 57, 86) - dw(170, 86)
      JacC( 74, 57) = JacC( 74, 57) + dw(170, 57)
      JacC( 74, 86) = JacC( 74, 86) + dw(170, 86)
      JacC( 86, 57) = JacC( 86, 57) - dw(170, 57)
      JacC( 86, 86) = JacC( 86, 86) - dw(170, 86)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1330000000000000D+01*dw(171, 82)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1330000000000000D+01*dw(171, 82)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(171, 82)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(171, 82)
      JacC( 86, 82) = JacC( 86, 82)+ 0.6600000000000000D+00*dw(171, 82)
      JacC( 86, 82) = JacC( 86, 82)+ 0.6600000000000000D+00*dw(171, 82)
      JacC( 77, 79) = JacC( 77, 79)+ 0.7500000000000000D+00*dw(172, 79)
      JacC( 77, 82) = JacC( 77, 82)+ 0.7500000000000000D+00*dw(172, 82)
      JacC( 79, 79) = JacC( 79, 79) - dw(172, 79)
      JacC( 79, 82) = JacC( 79, 82) - dw(172, 82)
      JacC( 80, 79) = JacC( 80, 79)+ 0.7500000000000000D+00*dw(172, 79)
      JacC( 80, 82) = JacC( 80, 82)+ 0.7500000000000000D+00*dw(172, 82)
      JacC( 82, 79) = JacC( 82, 79) - dw(172, 79)
      JacC( 82, 82) = JacC( 82, 82) - dw(172, 82)
      JacC( 86, 79) = JacC( 86, 79) + dw(172, 79)
      JacC( 86, 82) = JacC( 86, 82) + dw(172, 82)
      JacC( 65, 71) = JacC( 65, 71)+ 0.1190000000000000D+00*dw(173, 71)
      JacC( 65, 82) = JacC( 65, 82)+ 0.1190000000000000D+00*dw(173, 82)
      JacC( 71, 71) = JacC( 71, 71) - dw(173, 71)
      JacC( 71, 82) = JacC( 71, 82) - dw(173, 82)
      JacC( 72, 71) = JacC( 72, 71)+ 0.5000000000000000D-02*dw(173, 71)
      JacC( 72, 82) = JacC( 72, 82)+ 0.5000000000000000D-02*dw(173, 82)
      JacC( 75, 71) = JacC( 75, 71)+ 0.1800000000000000D-01*dw(173, 71)
      JacC( 75, 82) = JacC( 75, 82)+ 0.1800000000000000D-01*dw(173, 82)
      JacC( 77, 71) = JacC( 77, 71)+ 0.5800000000000000D+00*dw(173, 71)
      JacC( 77, 82) = JacC( 77, 82)+ 0.5800000000000000D+00*dw(173, 82)
      JacC( 80, 71) = JacC( 80, 71)+ 0.8100000000000001D+00*dw(173, 71)
      JacC( 80, 82) = JacC( 80, 82)+ 0.8100000000000001D+00*dw(173, 82)
      JacC( 81, 71) = JacC( 81, 71)+ 0.8500000000000001D-01*dw(173, 71)
      JacC( 81, 82) = JacC( 81, 82)+ 0.8500000000000001D-01*dw(173, 82)
      JacC( 82, 71) = JacC( 82, 71)- 0.9930000000000000D+00*dw(173, 71)
      JacC( 82, 82) = JacC( 82, 82)- 0.9930000000000000D+00*dw(173, 82)
      JacC( 86, 71) = JacC( 86, 71)+ 0.9920000000000000D+00*dw(173, 71)
      JacC( 86, 82) = JacC( 86, 82)+ 0.9920000000000000D+00*dw(173, 82)
      JacC( 61, 61) = JacC( 61, 61) - dw(174, 61)
      JacC( 61, 82) = JacC( 61, 82) - dw(174, 82)
      JacC( 75, 61) = JacC( 75, 61)+ 0.2400000000000000D+00*dw(174, 61)
      JacC( 75, 82) = JacC( 75, 82)+ 0.2400000000000000D+00*dw(174, 82)
      JacC( 77, 61) = JacC( 77, 61)+ 0.5230000000000000D+00*dw(174, 61)
      JacC( 77, 82) = JacC( 77, 82)+ 0.5230000000000000D+00*dw(174, 82)
      JacC( 79, 61) = JacC( 79, 61)+ 0.1400000000000000D-01*dw(174, 61)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1400000000000000D-01*dw(174, 82)
      JacC( 80, 61) = JacC( 80, 61)+ 0.8290000000000000D+00*dw(174, 61)
      JacC( 80, 82) = JacC( 80, 82)+ 0.8290000000000000D+00*dw(174, 82)
      JacC( 81, 61) = JacC( 81, 61)+ 0.2450000000000000D+00*dw(174, 61)
      JacC( 81, 82) = JacC( 81, 82)+ 0.2450000000000000D+00*dw(174, 82)
      JacC( 82, 61) = JacC( 82, 61)- 0.9510000000000000D+00*dw(174, 61)
      JacC( 82, 82) = JacC( 82, 82)- 0.9510000000000000D+00*dw(174, 82)
      JacC( 86, 61) = JacC( 86, 61)+ 0.9460000000000000D+00*dw(174, 61)
      JacC( 86, 82) = JacC( 86, 82)+ 0.9460000000000000D+00*dw(174, 82)
      JacC( 66, 66) = JacC( 66, 66) - dw(175, 66)
      JacC( 66, 82) = JacC( 66, 82) - dw(175, 82)
      JacC( 75, 66) = JacC( 75, 66)+ 0.4190000000000000D+00*dw(175, 66)
      JacC( 75, 82) = JacC( 75, 82)+ 0.4190000000000000D+00*dw(175, 82)
      JacC( 77, 66) = JacC( 77, 66)+ 0.4110000000000000D+00*dw(175, 66)
      JacC( 77, 82) = JacC( 77, 82)+ 0.4110000000000000D+00*dw(175, 82)
      JacC( 79, 66) = JacC( 79, 66)+ 0.1300000000000000D-01*dw(175, 66)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1300000000000000D-01*dw(175, 82)
      JacC( 80, 66) = JacC( 80, 66)+ 0.7530000000000000D+00*dw(175, 66)
      JacC( 80, 82) = JacC( 80, 82)+ 0.7530000000000000D+00*dw(175, 82)
      JacC( 81, 66) = JacC( 81, 66)+ 0.3220000000000000D+00*dw(175, 66)
      JacC( 81, 82) = JacC( 81, 82)+ 0.3220000000000000D+00*dw(175, 82)
      JacC( 82, 66) = JacC( 82, 66) - dw(175, 66)
      JacC( 82, 82) = JacC( 82, 82) - dw(175, 82)
      JacC( 86, 66) = JacC( 86, 66)+ 0.9930000000000000D+00*dw(175, 66)
      JacC( 86, 82) = JacC( 86, 82)+ 0.9930000000000000D+00*dw(175, 82)
      JacC( 67, 67) = JacC( 67, 67) - dw(176, 67)
      JacC( 67, 82) = JacC( 67, 82) - dw(176, 82)
      JacC( 77, 67) = JacC( 77, 67)+ 0.3500000000000000D+00*dw(176, 67)
      JacC( 77, 82) = JacC( 77, 82)+ 0.3500000000000000D+00*dw(176, 82)
      JacC( 80, 67) = JacC( 80, 67)+ 0.1550000000000000D+01*dw(176, 67)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1550000000000000D+01*dw(176, 82)
      JacC( 82, 67) = JacC( 82, 67) - dw(176, 67)
      JacC( 82, 82) = JacC( 82, 82) - dw(176, 82)
      JacC( 86, 67) = JacC( 86, 67) + dw(176, 67)
      JacC( 86, 82) = JacC( 86, 82) + dw(176, 82)
      JacC( 53, 53) = JacC( 53, 53) - dw(177, 53)
      JacC( 53, 82) = JacC( 53, 82) - dw(177, 82)
      JacC( 75, 53) = JacC( 75, 53)+ 0.8100000000000000D-01*dw(177, 53)
      JacC( 75, 82) = JacC( 75, 82)+ 0.8100000000000000D-01*dw(177, 82)
      JacC( 77, 53) = JacC( 77, 53)+ 0.6690000000000000D+00*dw(177, 53)
      JacC( 77, 82) = JacC( 77, 82)+ 0.6690000000000000D+00*dw(177, 82)
      JacC( 80, 53) = JacC( 80, 53)+ 0.1250000000000000D+01*dw(177, 53)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1250000000000000D+01*dw(177, 82)
      JacC( 82, 53) = JacC( 82, 53) - dw(177, 53)
      JacC( 82, 82) = JacC( 82, 82) - dw(177, 82)
      JacC( 86, 53) = JacC( 86, 53) + dw(177, 53)
      JacC( 86, 82) = JacC( 86, 82) + dw(177, 82)
      JacC( 59, 59) = JacC( 59, 59) - dw(178, 59)
      JacC( 59, 82) = JacC( 59, 82) - dw(178, 82)
      JacC( 75, 59) = JacC( 75, 59)+ 0.3130000000000000D+00*dw(178, 59)
      JacC( 75, 82) = JacC( 75, 82)+ 0.3130000000000000D+00*dw(178, 82)
      JacC( 77, 59) = JacC( 77, 59)+ 0.9320000000000001D+00*dw(178, 59)
      JacC( 77, 82) = JacC( 77, 82)+ 0.9320000000000001D+00*dw(178, 82)
      JacC( 80, 59) = JacC( 80, 59)+ 0.7550000000000000D+00*dw(178, 59)
      JacC( 80, 82) = JacC( 80, 82)+ 0.7550000000000000D+00*dw(178, 82)
      JacC( 82, 59) = JacC( 82, 59) - dw(178, 59)
      JacC( 82, 82) = JacC( 82, 82) - dw(178, 82)
      JacC( 86, 59) = JacC( 86, 59) + dw(178, 59)
      JacC( 86, 82) = JacC( 86, 82) + dw(178, 82)
      JacC( 51, 51) = JacC( 51, 51) - dw(179, 51)
      JacC( 51, 82) = JacC( 51, 82) - dw(179, 82)
      JacC( 52, 51) = JacC( 52, 51)+ 0.3700000000000000D+00*dw(179, 51)
      JacC( 52, 82) = JacC( 52, 82)+ 0.3700000000000000D+00*dw(179, 82)
      JacC( 56, 51) = JacC( 56, 51)+ 0.8000000000000000D-01*dw(179, 51)
      JacC( 56, 82) = JacC( 56, 82)+ 0.8000000000000000D-01*dw(179, 82)
      JacC( 60, 51) = JacC( 60, 51)+ 0.5500000000000000D+00*dw(179, 51)
      JacC( 60, 82) = JacC( 60, 82)+ 0.5500000000000000D+00*dw(179, 82)
      JacC( 80, 51) = JacC( 80, 51)+ 0.1090000000000000D+01*dw(179, 51)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1090000000000000D+01*dw(179, 82)
      JacC( 82, 51) = JacC( 82, 51) - dw(179, 51)
      JacC( 82, 82) = JacC( 82, 82) - dw(179, 82)
      JacC( 86, 51) = JacC( 86, 51) + dw(179, 51)
      JacC( 86, 82) = JacC( 86, 82) + dw(179, 82)
      JacC( 54, 54) = JacC( 54, 54) - dw(180, 54)
      JacC( 54, 82) = JacC( 54, 82) - dw(180, 82)
      JacC( 75, 54) = JacC( 75, 54) + dw(180, 54)
      JacC( 75, 82) = JacC( 75, 82) + dw(180, 82)
      JacC( 77, 54) = JacC( 77, 54) + dw(180, 54)
      JacC( 77, 82) = JacC( 77, 82) + dw(180, 82)
      JacC( 80, 54) = JacC( 80, 54) + dw(180, 54)
      JacC( 80, 82) = JacC( 80, 82) + dw(180, 82)
      JacC( 82, 54) = JacC( 82, 54) - dw(180, 54)
      JacC( 82, 82) = JacC( 82, 82) - dw(180, 82)
      JacC( 86, 54) = JacC( 86, 54)+ 0.2000000000000000D+01*dw(180, 54)
      JacC( 86, 82) = JacC( 86, 82)+ 0.2000000000000000D+01*dw(180, 82)
      JacC( 55, 55) = JacC( 55, 55) - dw(181, 55)
      JacC( 55, 82) = JacC( 55, 82) - dw(181, 82)
      JacC( 56, 55) = JacC( 56, 55)+ 0.4000000000000000D+00*dw(181, 55)
      JacC( 56, 82) = JacC( 56, 82)+ 0.4000000000000000D+00*dw(181, 82)
      JacC( 60, 55) = JacC( 60, 55)+ 0.6000000000000000D+00*dw(181, 55)
      JacC( 60, 82) = JacC( 60, 82)+ 0.6000000000000000D+00*dw(181, 82)
      JacC( 80, 55) = JacC( 80, 55)+ 0.1400000000000000D+01*dw(181, 55)
      JacC( 80, 82) = JacC( 80, 82)+ 0.1400000000000000D+01*dw(181, 82)
      JacC( 82, 55) = JacC( 82, 55) - dw(181, 55)
      JacC( 82, 82) = JacC( 82, 82) - dw(181, 82)
      JacC( 86, 55) = JacC( 86, 55)+ 0.2000000000000000D+01*dw(181, 55)
      JacC( 86, 82) = JacC( 86, 82)+ 0.2000000000000000D+01*dw(181, 82)
      JacC( 39, 39) = JacC( 39, 39) - dw(182, 39)
      JacC( 39, 82) = JacC( 39, 82) - dw(182, 82)
      JacC( 40, 39) = JacC( 40, 39)+ 0.2200000000000000D+00*dw(182, 39)
      JacC( 40, 82) = JacC( 40, 82)+ 0.2200000000000000D+00*dw(182, 82)
      JacC( 62, 39) = JacC( 62, 39) + dw(182, 39)
      JacC( 62, 82) = JacC( 62, 82) + dw(182, 82)
      JacC( 65, 39) = JacC( 65, 39)+ 0.6500000000000000D+00*dw(182, 39)
      JacC( 65, 82) = JacC( 65, 82)+ 0.6500000000000000D+00*dw(182, 82)
      JacC( 72, 39) = JacC( 72, 39)+ 0.3500000000000000D+00*dw(182, 39)
      JacC( 72, 82) = JacC( 72, 82)+ 0.3500000000000000D+00*dw(182, 82)
      JacC( 80, 39) = JacC( 80, 39) + dw(182, 39)
      JacC( 80, 82) = JacC( 80, 82) + dw(182, 82)
      JacC( 82, 39) = JacC( 82, 39) - dw(182, 39)
      JacC( 82, 82) = JacC( 82, 82) - dw(182, 82)
      JacC( 86, 39) = JacC( 86, 39) + dw(182, 39)
      JacC( 86, 82) = JacC( 86, 82) + dw(182, 82)
      JacC( 40, 44) = JacC( 40, 44)+ 0.2200000000000000D+00*dw(183, 44)
      JacC( 40, 82) = JacC( 40, 82)+ 0.2200000000000000D+00*dw(183, 82)
      JacC( 44, 44) = JacC( 44, 44) - dw(183, 44)
      JacC( 44, 82) = JacC( 44, 82) - dw(183, 82)
      JacC( 62, 44) = JacC( 62, 44) + dw(183, 44)
      JacC( 62, 82) = JacC( 62, 82) + dw(183, 82)
      JacC( 65, 44) = JacC( 65, 44)+ 0.3700000000000000D+00*dw(183, 44)
      JacC( 65, 82) = JacC( 65, 82)+ 0.3700000000000000D+00*dw(183, 82)
      JacC( 72, 44) = JacC( 72, 44)+ 0.6300000000000000D+00*dw(183, 44)
      JacC( 72, 82) = JacC( 72, 82)+ 0.6300000000000000D+00*dw(183, 82)
      JacC( 80, 44) = JacC( 80, 44) + dw(183, 44)
      JacC( 80, 82) = JacC( 80, 82) + dw(183, 82)
      JacC( 82, 44) = JacC( 82, 44) - dw(183, 44)
      JacC( 82, 82) = JacC( 82, 82) - dw(183, 82)
      JacC( 86, 44) = JacC( 86, 44) + dw(183, 44)
      JacC( 86, 82) = JacC( 86, 82) + dw(183, 82)
      JacC( 49, 49) = JacC( 49, 49) - dw(184, 49)
      JacC( 49, 82) = JacC( 49, 82) - dw(184, 82)
      JacC( 65, 49) = JacC( 65, 49) + dw(184, 49)
      JacC( 65, 82) = JacC( 65, 82) + dw(184, 82)
      JacC( 72, 49) = JacC( 72, 49) + dw(184, 49)
      JacC( 72, 82) = JacC( 72, 82) + dw(184, 82)
      JacC( 80, 49) = JacC( 80, 49) + dw(184, 49)
      JacC( 80, 82) = JacC( 80, 82) + dw(184, 82)
      JacC( 82, 49) = JacC( 82, 49) - dw(184, 49)
      JacC( 82, 82) = JacC( 82, 82) - dw(184, 82)
      JacC( 86, 49) = JacC( 86, 49)+ 0.2000000000000000D+01*dw(184, 49)
      JacC( 86, 82) = JacC( 86, 82)+ 0.2000000000000000D+01*dw(184, 82)
      JacC( 80, 83) = JacC( 80, 83) + dw(185, 83)
      JacC( 80, 82) = JacC( 80, 82) + dw(185, 82)
      JacC( 83, 83) = JacC( 83, 83) - dw(185, 83)
      JacC( 83, 82) = JacC( 83, 82) - dw(185, 82)
      JacC( 86, 83) = JacC( 86, 83) + dw(185, 83)
      JacC( 86, 82) = JacC( 86, 82) + dw(185, 82)
      JacC( 70, 83) = JacC( 70, 83) + dw(186, 83)
      JacC( 70, 82) = JacC( 70, 82) + dw(186, 82)
      JacC( 80, 83) = JacC( 80, 83) + dw(186, 83)
      JacC( 80, 82) = JacC( 80, 82) + dw(186, 82)
      JacC( 82, 83) = JacC( 82, 83) - dw(186, 83)
      JacC( 82, 82) = JacC( 82, 82) - dw(186, 82)
      JacC( 83, 83) = JacC( 83, 83) - dw(186, 83)
      JacC( 83, 82) = JacC( 83, 82) - dw(186, 82)
      JacC( 68, 68) = JacC( 68, 68) - dw(187, 68)
      JacC( 68, 82) = JacC( 68, 82) - dw(187, 82)
      JacC( 80, 68) = JacC( 80, 68)+ 0.2000000000000000D+01*dw(187, 68)
      JacC( 80, 82) = JacC( 80, 82)+ 0.2000000000000000D+01*dw(187, 82)
      JacC( 82, 68) = JacC( 82, 68) - dw(187, 68)
      JacC( 82, 82) = JacC( 82, 82) - dw(187, 82)
      JacC( 83, 68) = JacC( 83, 68) + dw(187, 68)
      JacC( 83, 82) = JacC( 83, 82) + dw(187, 82)
      JacC( 86, 68) = JacC( 86, 68) + dw(187, 68)
      JacC( 86, 82) = JacC( 86, 82) + dw(187, 82)
      JacC( 68, 68) = JacC( 68, 68) - dw(188, 68)
      JacC( 68, 82) = JacC( 68, 82) - dw(188, 82)
      JacC( 70, 68) = JacC( 70, 68) + dw(188, 68)
      JacC( 70, 82) = JacC( 70, 82) + dw(188, 82)
      JacC( 80, 68) = JacC( 80, 68) + dw(188, 68)
      JacC( 80, 82) = JacC( 80, 82) + dw(188, 82)
      JacC( 82, 68) = JacC( 82, 68) - dw(188, 68)
      JacC( 82, 82) = JacC( 82, 82) - dw(188, 82)
      JacC( 45, 76) = JacC( 45, 76)+ 0.3000000000000000D+00*dw(189, 76)
      JacC( 45, 82) = JacC( 45, 82)+ 0.3000000000000000D+00*dw(189, 82)
      JacC( 72, 76) = JacC( 72, 76)+ 0.4000000000000000D+00*dw(189, 76)
      JacC( 72, 82) = JacC( 72, 82)+ 0.4000000000000000D+00*dw(189, 82)
      JacC( 76, 76) = JacC( 76, 76) - dw(189, 76)
      JacC( 76, 82) = JacC( 76, 82) - dw(189, 82)
      JacC( 77, 76) = JacC( 77, 76)+ 0.3000000000000000D+00*dw(189, 76)
      JacC( 77, 82) = JacC( 77, 82)+ 0.3000000000000000D+00*dw(189, 82)
      JacC( 80, 76) = JacC( 80, 76)+ 0.7500000000000000D+00*dw(189, 76)
      JacC( 80, 82) = JacC( 80, 82)+ 0.7500000000000000D+00*dw(189, 82)
      JacC( 81, 76) = JacC( 81, 76)+ 0.8000000000000000D-01*dw(189, 76)
      JacC( 81, 82) = JacC( 81, 82)+ 0.8000000000000000D-01*dw(189, 82)
      JacC( 82, 76) = JacC( 82, 76) - dw(189, 76)
      JacC( 82, 82) = JacC( 82, 82) - dw(189, 82)
      JacC( 83, 76) = JacC( 83, 76)+ 0.1200000000000000D+00*dw(189, 76)
      JacC( 83, 82) = JacC( 83, 82)+ 0.1200000000000000D+00*dw(189, 82)
      JacC( 86, 76) = JacC( 86, 76)+ 0.8800000000000000D+00*dw(189, 76)
      JacC( 86, 82) = JacC( 86, 82)+ 0.8800000000000000D+00*dw(189, 82)
      JacC( 58, 58) = JacC( 58, 58) - dw(190, 58)
      JacC( 58, 82) = JacC( 58, 82) - dw(190, 82)
      JacC( 74, 58) = JacC( 74, 58) + dw(190, 58)
      JacC( 74, 82) = JacC( 74, 82) + dw(190, 82)
      JacC( 80, 58) = JacC( 80, 58)+ 0.7500000000000000D+00*dw(190, 58)
      JacC( 80, 82) = JacC( 80, 82)+ 0.7500000000000000D+00*dw(190, 82)
      JacC( 82, 58) = JacC( 82, 58) - dw(190, 58)
      JacC( 82, 82) = JacC( 82, 82) - dw(190, 82)
      JacC( 86, 58) = JacC( 86, 58) + dw(190, 58)
      JacC( 86, 82) = JacC( 86, 82) + dw(190, 82)
      JacC( 57, 57) = JacC( 57, 57) - dw(191, 57)
      JacC( 57, 82) = JacC( 57, 82) - dw(191, 82)
      JacC( 74, 57) = JacC( 74, 57)+ 0.5000000000000000D+00*dw(191, 57)
      JacC( 74, 82) = JacC( 74, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 75, 57) = JacC( 75, 57)+ 0.1490000000000000D+00*dw(191, 57)
      JacC( 75, 82) = JacC( 75, 82)+ 0.1490000000000000D+00*dw(191, 82)
      JacC( 77, 57) = JacC( 77, 57)+ 0.6400000000000000D+00*dw(191, 57)
      JacC( 77, 82) = JacC( 77, 82)+ 0.6400000000000000D+00*dw(191, 82)
      JacC( 80, 57) = JacC( 80, 57)+ 0.9600000000000000D+00*dw(191, 57)
      JacC( 80, 82) = JacC( 80, 82)+ 0.9600000000000000D+00*dw(191, 82)
      JacC( 82, 57) = JacC( 82, 57) - dw(191, 57)
      JacC( 82, 82) = JacC( 82, 82) - dw(191, 82)
      JacC( 86, 57) = JacC( 86, 57)+ 0.5000000000000000D+00*dw(191, 57)
      JacC( 86, 82) = JacC( 86, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 87, 57) = JacC( 87, 57)+ 0.5000000000000000D+00*dw(191, 57)
      JacC( 87, 82) = JacC( 87, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 70, 79) = JacC( 70, 79)+ 0.5000000000000000D+00*dw(192, 79)
      JacC( 70, 83) = JacC( 70, 83)+ 0.5000000000000000D+00*dw(192, 83)
      JacC( 77, 79) = JacC( 77, 79) + dw(192, 79)
      JacC( 77, 83) = JacC( 77, 83) + dw(192, 83)
      JacC( 79, 79) = JacC( 79, 79) - dw(192, 79)
      JacC( 79, 83) = JacC( 79, 83) - dw(192, 83)
      JacC( 82, 79) = JacC( 82, 79)+ 0.5000000000000000D+00*dw(192, 79)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5000000000000000D+00*dw(192, 83)
      JacC( 83, 79) = JacC( 83, 79) - dw(192, 79)
      JacC( 83, 83) = JacC( 83, 83) - dw(192, 83)
      JacC( 86, 79) = JacC( 86, 79)+ 0.5000000000000000D+00*dw(192, 79)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5000000000000000D+00*dw(192, 83)
      JacC( 65, 71) = JacC( 65, 71)+ 0.1000000000000000D+00*dw(193, 71)
      JacC( 65, 83) = JacC( 65, 83)+ 0.1000000000000000D+00*dw(193, 83)
      JacC( 70, 71) = JacC( 70, 71)+ 0.4990000000000000D+00*dw(193, 71)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4990000000000000D+00*dw(193, 83)
      JacC( 71, 71) = JacC( 71, 71) - dw(193, 71)
      JacC( 71, 83) = JacC( 71, 83) - dw(193, 83)
      JacC( 72, 71) = JacC( 72, 71)+ 0.4000000000000000D-02*dw(193, 71)
      JacC( 72, 83) = JacC( 72, 83)+ 0.4000000000000000D-02*dw(193, 83)
      JacC( 75, 71) = JacC( 75, 71)+ 0.1270000000000000D+00*dw(193, 71)
      JacC( 75, 83) = JacC( 75, 83)+ 0.1270000000000000D+00*dw(193, 83)
      JacC( 77, 71) = JacC( 77, 71)+ 0.7240000000000000D+00*dw(193, 71)
      JacC( 77, 83) = JacC( 77, 83)+ 0.7240000000000000D+00*dw(193, 83)
      JacC( 79, 71) = JacC( 79, 71)+ 0.6000000000000000D-02*dw(193, 71)
      JacC( 79, 83) = JacC( 79, 83)+ 0.6000000000000000D-02*dw(193, 83)
      JacC( 80, 71) = JacC( 80, 71)+ 0.9100000000000000D-01*dw(193, 71)
      JacC( 80, 83) = JacC( 80, 83)+ 0.9100000000000000D-01*dw(193, 83)
      JacC( 81, 71) = JacC( 81, 71)+ 0.7099999999999999D-01*dw(193, 71)
      JacC( 81, 83) = JacC( 81, 83)+ 0.7099999999999999D-01*dw(193, 83)
      JacC( 82, 71) = JacC( 82, 71)+ 0.5080000000000000D+00*dw(193, 71)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5080000000000000D+00*dw(193, 83)
      JacC( 83, 71) = JacC( 83, 71) - dw(193, 71)
      JacC( 83, 83) = JacC( 83, 83) - dw(193, 83)
      JacC( 86, 71) = JacC( 86, 71)+ 0.4880000000000000D+00*dw(193, 71)
      JacC( 86, 83) = JacC( 86, 83)+ 0.4880000000000000D+00*dw(193, 83)
      JacC( 61, 61) = JacC( 61, 61) - dw(194, 61)
      JacC( 61, 83) = JacC( 61, 83) - dw(194, 83)
      JacC( 70, 61) = JacC( 70, 61)+ 0.4950000000000000D+00*dw(194, 61)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4950000000000000D+00*dw(194, 83)
      JacC( 75, 61) = JacC( 75, 61)+ 0.3300000000000000D+00*dw(194, 61)
      JacC( 75, 83) = JacC( 75, 83)+ 0.3300000000000000D+00*dw(194, 83)
      JacC( 77, 61) = JacC( 77, 61)+ 0.6770000000000000D+00*dw(194, 61)
      JacC( 77, 83) = JacC( 77, 83)+ 0.6770000000000000D+00*dw(194, 83)
      JacC( 79, 61) = JacC( 79, 61)+ 0.1800000000000000D-01*dw(194, 61)
      JacC( 79, 83) = JacC( 79, 83)+ 0.1800000000000000D-01*dw(194, 83)
      JacC( 80, 61) = JacC( 80, 61)+ 0.7600000000000000D-01*dw(194, 61)
      JacC( 80, 83) = JacC( 80, 83)+ 0.7600000000000000D-01*dw(194, 83)
      JacC( 81, 61) = JacC( 81, 61)+ 0.2370000000000000D+00*dw(194, 61)
      JacC( 81, 83) = JacC( 81, 83)+ 0.2370000000000000D+00*dw(194, 83)
      JacC( 82, 61) = JacC( 82, 61)+ 0.5540000000000000D+00*dw(194, 61)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5540000000000000D+00*dw(194, 83)
      JacC( 83, 61) = JacC( 83, 61) - dw(194, 61)
      JacC( 83, 83) = JacC( 83, 83) - dw(194, 83)
      JacC( 86, 61) = JacC( 86, 61)+ 0.4380000000000000D+00*dw(194, 61)
      JacC( 86, 83) = JacC( 86, 83)+ 0.4380000000000000D+00*dw(194, 83)
      JacC( 66, 66) = JacC( 66, 66) - dw(195, 66)
      JacC( 66, 83) = JacC( 66, 83) - dw(195, 83)
      JacC( 70, 66) = JacC( 70, 66)+ 0.4950000000000000D+00*dw(195, 66)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4950000000000000D+00*dw(195, 83)
      JacC( 75, 66) = JacC( 75, 66)+ 0.5810000000000000D+00*dw(195, 66)
      JacC( 75, 83) = JacC( 75, 83)+ 0.5810000000000000D+00*dw(195, 83)
      JacC( 77, 66) = JacC( 77, 66)+ 0.4970000000000000D+00*dw(195, 66)
      JacC( 77, 83) = JacC( 77, 83)+ 0.4970000000000000D+00*dw(195, 83)
      JacC( 79, 66) = JacC( 79, 66)+ 0.1500000000000000D-01*dw(195, 66)
      JacC( 79, 83) = JacC( 79, 83)+ 0.1500000000000000D-01*dw(195, 83)
      JacC( 81, 66) = JacC( 81, 66)+ 0.3180000000000000D+00*dw(195, 66)
      JacC( 81, 83) = JacC( 81, 83)+ 0.3180000000000000D+00*dw(195, 83)
      JacC( 82, 66) = JacC( 82, 66)+ 0.5070000000000000D+00*dw(195, 66)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5070000000000000D+00*dw(195, 83)
      JacC( 83, 66) = JacC( 83, 66) - dw(195, 66)
      JacC( 83, 83) = JacC( 83, 83) - dw(195, 83)
      JacC( 86, 66) = JacC( 86, 66)+ 0.4890000000000000D+00*dw(195, 66)
      JacC( 86, 83) = JacC( 86, 83)+ 0.4890000000000000D+00*dw(195, 83)
      JacC( 67, 67) = JacC( 67, 67) - dw(196, 67)
      JacC( 67, 83) = JacC( 67, 83) - dw(196, 83)
      JacC( 70, 67) = JacC( 70, 67)+ 0.5000000000000000D+00*dw(196, 67)
      JacC( 70, 83) = JacC( 70, 83)+ 0.5000000000000000D+00*dw(196, 83)
      JacC( 77, 67) = JacC( 77, 67)+ 0.6000000000000000D+00*dw(196, 67)
      JacC( 77, 83) = JacC( 77, 83)+ 0.6000000000000000D+00*dw(196, 83)
      JacC( 80, 67) = JacC( 80, 67)+ 0.8000000000000000D+00*dw(196, 67)
      JacC( 80, 83) = JacC( 80, 83)+ 0.8000000000000000D+00*dw(196, 83)
      JacC( 82, 67) = JacC( 82, 67)+ 0.5000000000000000D+00*dw(196, 67)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5000000000000000D+00*dw(196, 83)
      JacC( 83, 67) = JacC( 83, 67) - dw(196, 67)
      JacC( 83, 83) = JacC( 83, 83) - dw(196, 83)
      JacC( 86, 67) = JacC( 86, 67)+ 0.5000000000000000D+00*dw(196, 67)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5000000000000000D+00*dw(196, 83)
      JacC( 53, 53) = JacC( 53, 53) - dw(197, 53)
      JacC( 53, 83) = JacC( 53, 83) - dw(197, 83)
      JacC( 70, 53) = JacC( 70, 53)+ 0.4990000000000000D+00*dw(197, 53)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4990000000000000D+00*dw(197, 83)
      JacC( 75, 53) = JacC( 75, 53)+ 0.1410000000000000D+00*dw(197, 53)
      JacC( 75, 83) = JacC( 75, 83)+ 0.1410000000000000D+00*dw(197, 83)
      JacC( 77, 53) = JacC( 77, 53)+ 0.8590000000000000D+00*dw(197, 53)
      JacC( 77, 83) = JacC( 77, 83)+ 0.8590000000000000D+00*dw(197, 83)
      JacC( 80, 53) = JacC( 80, 53)+ 0.5010000000000000D+00*dw(197, 53)
      JacC( 80, 83) = JacC( 80, 83)+ 0.5010000000000000D+00*dw(197, 83)
      JacC( 82, 53) = JacC( 82, 53)+ 0.5010000000000000D+00*dw(197, 53)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5010000000000000D+00*dw(197, 83)
      JacC( 83, 53) = JacC( 83, 53) - dw(197, 53)
      JacC( 83, 83) = JacC( 83, 83) - dw(197, 83)
      JacC( 86, 53) = JacC( 86, 53)+ 0.5010000000000000D+00*dw(197, 53)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5010000000000000D+00*dw(197, 83)
      JacC( 59, 59) = JacC( 59, 59) - dw(198, 59)
      JacC( 59, 83) = JacC( 59, 83) - dw(198, 83)
      JacC( 70, 59) = JacC( 70, 59)+ 0.4900000000000000D+00*dw(198, 59)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4900000000000000D+00*dw(198, 83)
      JacC( 75, 59) = JacC( 75, 59)+ 0.5690000000000000D+00*dw(198, 59)
      JacC( 75, 83) = JacC( 75, 83)+ 0.5690000000000000D+00*dw(198, 83)
      JacC( 77, 59) = JacC( 77, 59)+ 0.9409999999999999D+00*dw(198, 59)
      JacC( 77, 83) = JacC( 77, 83)+ 0.9409999999999999D+00*dw(198, 83)
      JacC( 82, 59) = JacC( 82, 59)+ 0.5100000000000000D+00*dw(198, 59)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5100000000000000D+00*dw(198, 83)
      JacC( 83, 59) = JacC( 83, 59) - dw(198, 59)
      JacC( 83, 83) = JacC( 83, 83) - dw(198, 83)
      JacC( 86, 59) = JacC( 86, 59)+ 0.5100000000000000D+00*dw(198, 59)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5100000000000000D+00*dw(198, 83)
      JacC( 51, 51) = JacC( 51, 51) - dw(199, 51)
      JacC( 51, 83) = JacC( 51, 83) - dw(199, 83)
      JacC( 52, 51) = JacC( 52, 51)+ 0.2290000000000000D+00*dw(199, 51)
      JacC( 52, 83) = JacC( 52, 83)+ 0.2290000000000000D+00*dw(199, 83)
      JacC( 60, 51) = JacC( 60, 51)+ 0.7710000000000000D+00*dw(199, 51)
      JacC( 60, 83) = JacC( 60, 83)+ 0.7710000000000000D+00*dw(199, 83)
      JacC( 70, 51) = JacC( 70, 51)+ 0.4940000000000000D+00*dw(199, 51)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4940000000000000D+00*dw(199, 83)
      JacC( 80, 51) = JacC( 80, 51)+ 0.3400000000000000D+00*dw(199, 51)
      JacC( 80, 83) = JacC( 80, 83)+ 0.3400000000000000D+00*dw(199, 83)
      JacC( 82, 51) = JacC( 82, 51)+ 0.5060000000000000D+00*dw(199, 51)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5060000000000000D+00*dw(199, 83)
      JacC( 83, 51) = JacC( 83, 51) - dw(199, 51)
      JacC( 83, 83) = JacC( 83, 83) - dw(199, 83)
      JacC( 86, 51) = JacC( 86, 51)+ 0.5060000000000000D+00*dw(199, 51)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5060000000000000D+00*dw(199, 83)
      JacC( 54, 54) = JacC( 54, 54) - dw(200, 54)
      JacC( 54, 83) = JacC( 54, 83) - dw(200, 83)
      JacC( 75, 54) = JacC( 75, 54) + dw(200, 54)
      JacC( 75, 83) = JacC( 75, 83) + dw(200, 83)
      JacC( 77, 54) = JacC( 77, 54) + dw(200, 54)
      JacC( 77, 83) = JacC( 77, 83) + dw(200, 83)
      JacC( 82, 54) = JacC( 82, 54) + dw(200, 54)
      JacC( 82, 83) = JacC( 82, 83) + dw(200, 83)
      JacC( 83, 54) = JacC( 83, 54) - dw(200, 54)
      JacC( 83, 83) = JacC( 83, 83) - dw(200, 83)
      JacC( 86, 54) = JacC( 86, 54) + dw(200, 54)
      JacC( 86, 83) = JacC( 86, 83) + dw(200, 83)
      JacC( 55, 55) = JacC( 55, 55) - dw(201, 55)
      JacC( 55, 83) = JacC( 55, 83) - dw(201, 83)
      JacC( 56, 55) = JacC( 56, 55)+ 0.4000000000000000D+00*dw(201, 55)
      JacC( 56, 83) = JacC( 56, 83)+ 0.4000000000000000D+00*dw(201, 83)
      JacC( 60, 55) = JacC( 60, 55)+ 0.6000000000000000D+00*dw(201, 55)
      JacC( 60, 83) = JacC( 60, 83)+ 0.6000000000000000D+00*dw(201, 83)
      JacC( 80, 55) = JacC( 80, 55)+ 0.4000000000000000D+00*dw(201, 55)
      JacC( 80, 83) = JacC( 80, 83)+ 0.4000000000000000D+00*dw(201, 83)
      JacC( 82, 55) = JacC( 82, 55) + dw(201, 55)
      JacC( 82, 83) = JacC( 82, 83) + dw(201, 83)
      JacC( 83, 55) = JacC( 83, 55) - dw(201, 55)
      JacC( 83, 83) = JacC( 83, 83) - dw(201, 83)
      JacC( 86, 55) = JacC( 86, 55) + dw(201, 55)
      JacC( 86, 83) = JacC( 86, 83) + dw(201, 83)
      JacC( 39, 39) = JacC( 39, 39) - dw(202, 39)
      JacC( 39, 83) = JacC( 39, 83) - dw(202, 83)
      JacC( 40, 39) = JacC( 40, 39)+ 0.2200000000000000D+00*dw(202, 39)
      JacC( 40, 83) = JacC( 40, 83)+ 0.2200000000000000D+00*dw(202, 83)
      JacC( 62, 39) = JacC( 62, 39) + dw(202, 39)
      JacC( 62, 83) = JacC( 62, 83) + dw(202, 83)
      JacC( 65, 39) = JacC( 65, 39)+ 0.6500000000000000D+00*dw(202, 39)
      JacC( 65, 83) = JacC( 65, 83)+ 0.6500000000000000D+00*dw(202, 83)
      JacC( 72, 39) = JacC( 72, 39)+ 0.3500000000000000D+00*dw(202, 39)
      JacC( 72, 83) = JacC( 72, 83)+ 0.3500000000000000D+00*dw(202, 83)
      JacC( 82, 39) = JacC( 82, 39) + dw(202, 39)
      JacC( 82, 83) = JacC( 82, 83) + dw(202, 83)
      JacC( 83, 39) = JacC( 83, 39) - dw(202, 39)
      JacC( 83, 83) = JacC( 83, 83) - dw(202, 83)
      JacC( 86, 39) = JacC( 86, 39) + dw(202, 39)
      JacC( 86, 83) = JacC( 86, 83) + dw(202, 83)
      JacC( 40, 44) = JacC( 40, 44)+ 0.2200000000000000D+00*dw(203, 44)
      JacC( 40, 83) = JacC( 40, 83)+ 0.2200000000000000D+00*dw(203, 83)
      JacC( 44, 44) = JacC( 44, 44) - dw(203, 44)
      JacC( 44, 83) = JacC( 44, 83) - dw(203, 83)
      JacC( 62, 44) = JacC( 62, 44) + dw(203, 44)
      JacC( 62, 83) = JacC( 62, 83) + dw(203, 83)
      JacC( 65, 44) = JacC( 65, 44)+ 0.3700000000000000D+00*dw(203, 44)
      JacC( 65, 83) = JacC( 65, 83)+ 0.3700000000000000D+00*dw(203, 83)
      JacC( 72, 44) = JacC( 72, 44)+ 0.6300000000000000D+00*dw(203, 44)
      JacC( 72, 83) = JacC( 72, 83)+ 0.6300000000000000D+00*dw(203, 83)
      JacC( 82, 44) = JacC( 82, 44) + dw(203, 44)
      JacC( 82, 83) = JacC( 82, 83) + dw(203, 83)
      JacC( 83, 44) = JacC( 83, 44) - dw(203, 44)
      JacC( 83, 83) = JacC( 83, 83) - dw(203, 83)
      JacC( 86, 44) = JacC( 86, 44) + dw(203, 44)
      JacC( 86, 83) = JacC( 86, 83) + dw(203, 83)
      JacC( 49, 49) = JacC( 49, 49) - dw(204, 49)
      JacC( 49, 83) = JacC( 49, 83) - dw(204, 83)
      JacC( 65, 49) = JacC( 65, 49) + dw(204, 49)
      JacC( 65, 83) = JacC( 65, 83) + dw(204, 83)
      JacC( 72, 49) = JacC( 72, 49) + dw(204, 49)
      JacC( 72, 83) = JacC( 72, 83) + dw(204, 83)
      JacC( 82, 49) = JacC( 82, 49) + dw(204, 49)
      JacC( 82, 83) = JacC( 82, 83) + dw(204, 83)
      JacC( 83, 49) = JacC( 83, 49) - dw(204, 49)
      JacC( 83, 83) = JacC( 83, 83) - dw(204, 83)
      JacC( 86, 49) = JacC( 86, 49) + dw(204, 49)
      JacC( 86, 83) = JacC( 86, 83) + dw(204, 83)
      JacC( 82, 83) = JacC( 82, 83)+ 0.2000000000000000D+01*dw(205, 83)
      JacC( 82, 83) = JacC( 82, 83)+ 0.2000000000000000D+01*dw(205, 83)
      JacC( 83, 83) = JacC( 83, 83)- 0.2000000000000000D+01*dw(205, 83)
      JacC( 83, 83) = JacC( 83, 83)- 0.2000000000000000D+01*dw(205, 83)
      JacC( 68, 68) = JacC( 68, 68) - dw(206, 68)
      JacC( 68, 83) = JacC( 68, 83) - dw(206, 83)
      JacC( 80, 68) = JacC( 80, 68) + dw(206, 68)
      JacC( 80, 83) = JacC( 80, 83) + dw(206, 83)
      JacC( 82, 68) = JacC( 82, 68) + dw(206, 68)
      JacC( 82, 83) = JacC( 82, 83) + dw(206, 83)
      JacC( 70, 76) = JacC( 70, 76)+ 0.5000000000000000D+00*dw(207, 76)
      JacC( 70, 83) = JacC( 70, 83)+ 0.5000000000000000D+00*dw(207, 83)
      JacC( 72, 76) = JacC( 72, 76)+ 0.5400000000000000D+00*dw(207, 76)
      JacC( 72, 83) = JacC( 72, 83)+ 0.5400000000000000D+00*dw(207, 83)
      JacC( 75, 76) = JacC( 75, 76)+ 0.1100000000000000D+00*dw(207, 76)
      JacC( 75, 83) = JacC( 75, 83)+ 0.1100000000000000D+00*dw(207, 83)
      JacC( 76, 76) = JacC( 76, 76) - dw(207, 76)
      JacC( 76, 83) = JacC( 76, 83) - dw(207, 83)
      JacC( 77, 76) = JacC( 77, 76)+ 0.3500000000000000D+00*dw(207, 76)
      JacC( 77, 83) = JacC( 77, 83)+ 0.3500000000000000D+00*dw(207, 83)
      JacC( 81, 76) = JacC( 81, 76)+ 0.8000000000000000D-01*dw(207, 76)
      JacC( 81, 83) = JacC( 81, 83)+ 0.8000000000000000D-01*dw(207, 83)
      JacC( 82, 76) = JacC( 82, 76)+ 0.5000000000000000D+00*dw(207, 76)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5000000000000000D+00*dw(207, 83)
      JacC( 83, 76) = JacC( 83, 76)- 0.8800000000000000D+00*dw(207, 76)
      JacC( 83, 83) = JacC( 83, 83)- 0.8800000000000000D+00*dw(207, 83)
      JacC( 86, 76) = JacC( 86, 76)+ 0.3800000000000000D+00*dw(207, 76)
      JacC( 86, 83) = JacC( 86, 83)+ 0.3800000000000000D+00*dw(207, 83)
      JacC( 58, 58) = JacC( 58, 58) - dw(208, 58)
      JacC( 58, 83) = JacC( 58, 83) - dw(208, 83)
      JacC( 70, 58) = JacC( 70, 58)+ 0.5000000000000000D+00*dw(208, 58)
      JacC( 70, 83) = JacC( 70, 83)+ 0.5000000000000000D+00*dw(208, 83)
      JacC( 74, 58) = JacC( 74, 58) + dw(208, 58)
      JacC( 74, 83) = JacC( 74, 83) + dw(208, 83)
      JacC( 82, 58) = JacC( 82, 58)+ 0.5000000000000000D+00*dw(208, 58)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5000000000000000D+00*dw(208, 83)
      JacC( 83, 58) = JacC( 83, 58) - dw(208, 58)
      JacC( 83, 83) = JacC( 83, 83) - dw(208, 83)
      JacC( 86, 58) = JacC( 86, 58)+ 0.5000000000000000D+00*dw(208, 58)
      JacC( 86, 83) = JacC( 86, 83)+ 0.5000000000000000D+00*dw(208, 83)
      JacC( 57, 57) = JacC( 57, 57) - dw(209, 57)
      JacC( 57, 83) = JacC( 57, 83) - dw(209, 83)
      JacC( 70, 57) = JacC( 70, 57)+ 0.4840000000000000D+00*dw(209, 57)
      JacC( 70, 83) = JacC( 70, 83)+ 0.4840000000000000D+00*dw(209, 83)
      JacC( 74, 57) = JacC( 74, 57)+ 0.4840000000000000D+00*dw(209, 57)
      JacC( 74, 83) = JacC( 74, 83)+ 0.4840000000000000D+00*dw(209, 83)
      JacC( 75, 57) = JacC( 75, 57)+ 0.1670000000000000D+00*dw(209, 57)
      JacC( 75, 83) = JacC( 75, 83)+ 0.1670000000000000D+00*dw(209, 83)
      JacC( 77, 57) = JacC( 77, 57)+ 0.6500000000000000D+00*dw(209, 57)
      JacC( 77, 83) = JacC( 77, 83)+ 0.6500000000000000D+00*dw(209, 83)
      JacC( 80, 57) = JacC( 80, 57)+ 0.2070000000000000D+00*dw(209, 57)
      JacC( 80, 83) = JacC( 80, 83)+ 0.2070000000000000D+00*dw(209, 83)
      JacC( 82, 57) = JacC( 82, 57)+ 0.5160000000000000D+00*dw(209, 57)
      JacC( 82, 83) = JacC( 82, 83)+ 0.5160000000000000D+00*dw(209, 83)
      JacC( 83, 57) = JacC( 83, 57) - dw(209, 57)
      JacC( 83, 83) = JacC( 83, 83) - dw(209, 83)
      JacC( 87, 57) = JacC( 87, 57)+ 0.5160000000000000D+00*dw(209, 57)
      JacC( 87, 83) = JacC( 87, 83)+ 0.5160000000000000D+00*dw(209, 83)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(210, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(210, 58)
      JacC( 74, 58) = JacC( 74, 58)+ 0.2000000000000000D+01*dw(210, 58)
      JacC( 74, 58) = JacC( 74, 58)+ 0.2000000000000000D+01*dw(210, 58)
      JacC( 86, 58) = JacC( 86, 58) + dw(210, 58)
      JacC( 86, 58) = JacC( 86, 58) + dw(210, 58)
      JacC( 57, 58) = JacC( 57, 58) - dw(211, 58)
      JacC( 57, 57) = JacC( 57, 57) - dw(211, 57)
      JacC( 58, 58) = JacC( 58, 58) - dw(211, 58)
      JacC( 58, 57) = JacC( 58, 57) - dw(211, 57)
      JacC( 74, 58) = JacC( 74, 58)+ 0.1500000000000000D+01*dw(211, 58)
      JacC( 74, 57) = JacC( 74, 57)+ 0.1500000000000000D+01*dw(211, 57)
      JacC( 75, 58) = JacC( 75, 58)+ 0.1490000000000000D+00*dw(211, 58)
      JacC( 75, 57) = JacC( 75, 57)+ 0.1490000000000000D+00*dw(211, 57)
      JacC( 77, 58) = JacC( 77, 58)+ 0.6400000000000000D+00*dw(211, 58)
      JacC( 77, 57) = JacC( 77, 57)+ 0.6400000000000000D+00*dw(211, 57)
      JacC( 80, 58) = JacC( 80, 58)+ 0.2020000000000000D+00*dw(211, 58)
      JacC( 80, 57) = JacC( 80, 57)+ 0.2020000000000000D+00*dw(211, 57)
      JacC( 86, 58) = JacC( 86, 58)+ 0.5000000000000000D+00*dw(211, 58)
      JacC( 86, 57) = JacC( 86, 57)+ 0.5000000000000000D+00*dw(211, 57)
      JacC( 87, 58) = JacC( 87, 58)+ 0.5000000000000000D+00*dw(211, 58)
      JacC( 87, 57) = JacC( 87, 57)+ 0.5000000000000000D+00*dw(211, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(212, 57)
      JacC( 57, 57) = JacC( 57, 57)- 0.2000000000000000D+01*dw(212, 57)
      JacC( 74, 57) = JacC( 74, 57) + dw(212, 57)
      JacC( 74, 57) = JacC( 74, 57) + dw(212, 57)
      JacC( 75, 57) = JacC( 75, 57)+ 0.2850000000000000D+00*dw(212, 57)
      JacC( 75, 57) = JacC( 75, 57)+ 0.2850000000000000D+00*dw(212, 57)
      JacC( 77, 57) = JacC( 77, 57)+ 0.1210000000000000D+01*dw(212, 57)
      JacC( 77, 57) = JacC( 77, 57)+ 0.1210000000000000D+01*dw(212, 57)
      JacC( 80, 57) = JacC( 80, 57)+ 0.5040000000000000D+00*dw(212, 57)
      JacC( 80, 57) = JacC( 80, 57)+ 0.5040000000000000D+00*dw(212, 57)
      JacC( 87, 57) = JacC( 87, 57) + dw(212, 57)
      JacC( 87, 57) = JacC( 87, 57) + dw(212, 57)
      JacC( 80, 82) = JacC( 80, 82) + dw(213, 82)
      JacC( 80, 85) = JacC( 80, 85) + dw(213, 85)
      JacC( 82, 82) = JacC( 82, 82) - dw(213, 82)
      JacC( 82, 85) = JacC( 82, 85) - dw(213, 85)
      JacC( 85, 82) = JacC( 85, 82) - dw(213, 82)
      JacC( 85, 85) = JacC( 85, 85) - dw(213, 85)
      JacC( 86, 82) = JacC( 86, 82) + dw(213, 82)
      JacC( 86, 85) = JacC( 86, 85) + dw(213, 85)
      JacC( 87, 82) = JacC( 87, 82) + dw(213, 82)
      JacC( 87, 85) = JacC( 87, 85) + dw(213, 85)
      JacC( 77, 79) = JacC( 77, 79) + dw(214, 79)
      JacC( 77, 85) = JacC( 77, 85) + dw(214, 85)
      JacC( 79, 79) = JacC( 79, 79) - dw(214, 79)
      JacC( 79, 85) = JacC( 79, 85) - dw(214, 85)
      JacC( 85, 79) = JacC( 85, 79) - dw(214, 79)
      JacC( 85, 85) = JacC( 85, 85) - dw(214, 85)
      JacC( 86, 79) = JacC( 86, 79) + dw(214, 79)
      JacC( 86, 85) = JacC( 86, 85) + dw(214, 85)
      JacC( 87, 79) = JacC( 87, 79) + dw(214, 79)
      JacC( 87, 85) = JacC( 87, 85) + dw(214, 85)
      JacC( 65, 71) = JacC( 65, 71)+ 0.6300000000000000D-01*dw(215, 71)
      JacC( 65, 85) = JacC( 65, 85)+ 0.6300000000000000D-01*dw(215, 85)
      JacC( 71, 71) = JacC( 71, 71) - dw(215, 71)
      JacC( 71, 85) = JacC( 71, 85) - dw(215, 85)
      JacC( 75, 71) = JacC( 75, 71)+ 0.6700000000000000D+00*dw(215, 71)
      JacC( 75, 85) = JacC( 75, 85)+ 0.6700000000000000D+00*dw(215, 85)
      JacC( 77, 71) = JacC( 77, 71)+ 0.2430000000000000D+00*dw(215, 71)
      JacC( 77, 85) = JacC( 77, 85)+ 0.2430000000000000D+00*dw(215, 85)
      JacC( 79, 71) = JacC( 79, 71)+ 0.5300000000000000D-01*dw(215, 71)
      JacC( 79, 85) = JacC( 79, 85)+ 0.5300000000000000D-01*dw(215, 85)
      JacC( 80, 71) = JacC( 80, 71)+ 0.4800000000000000D-01*dw(215, 71)
      JacC( 80, 85) = JacC( 80, 85)+ 0.4800000000000000D-01*dw(215, 85)
      JacC( 81, 71) = JacC( 81, 71)+ 0.5100000000000000D-01*dw(215, 71)
      JacC( 81, 85) = JacC( 81, 85)+ 0.5100000000000000D-01*dw(215, 85)
      JacC( 82, 71) = JacC( 82, 71)+ 0.1550000000000000D+00*dw(215, 71)
      JacC( 82, 85) = JacC( 82, 85)+ 0.1550000000000000D+00*dw(215, 85)
      JacC( 85, 71) = JacC( 85, 71) - dw(215, 71)
      JacC( 85, 85) = JacC( 85, 85) - dw(215, 85)
      JacC( 86, 71) = JacC( 86, 71)+ 0.7920000000000000D+00*dw(215, 71)
      JacC( 86, 85) = JacC( 86, 85)+ 0.7920000000000000D+00*dw(215, 85)
      JacC( 87, 71) = JacC( 87, 71) + dw(215, 71)
      JacC( 87, 85) = JacC( 87, 85) + dw(215, 85)
      JacC( 61, 61) = JacC( 61, 61) - dw(216, 61)
      JacC( 61, 85) = JacC( 61, 85) - dw(216, 85)
      JacC( 75, 61) = JacC( 75, 61)+ 0.8280000000000000D+00*dw(216, 61)
      JacC( 75, 85) = JacC( 75, 85)+ 0.8280000000000000D+00*dw(216, 85)
      JacC( 77, 61) = JacC( 77, 61)+ 0.2390000000000000D+00*dw(216, 61)
      JacC( 77, 85) = JacC( 77, 85)+ 0.2390000000000000D+00*dw(216, 85)
      JacC( 79, 61) = JacC( 79, 61)+ 0.2620000000000000D+00*dw(216, 61)
      JacC( 79, 85) = JacC( 79, 85)+ 0.2620000000000000D+00*dw(216, 85)
      JacC( 80, 61) = JacC( 80, 61)+ 0.2100000000000000D-01*dw(216, 61)
      JacC( 80, 85) = JacC( 80, 85)+ 0.2100000000000000D-01*dw(216, 85)
      JacC( 81, 61) = JacC( 81, 61)+ 0.3910000000000000D+00*dw(216, 61)
      JacC( 81, 85) = JacC( 81, 85)+ 0.3910000000000000D+00*dw(216, 85)
      JacC( 82, 61) = JacC( 82, 61)+ 0.4000000000000000D-01*dw(216, 61)
      JacC( 82, 85) = JacC( 82, 85)+ 0.4000000000000000D-01*dw(216, 85)
      JacC( 85, 61) = JacC( 85, 61) - dw(216, 61)
      JacC( 85, 85) = JacC( 85, 85) - dw(216, 85)
      JacC( 86, 61) = JacC( 86, 61)+ 0.6990000000000000D+00*dw(216, 61)
      JacC( 86, 85) = JacC( 86, 85)+ 0.6990000000000000D+00*dw(216, 85)
      JacC( 87, 61) = JacC( 87, 61) + dw(216, 61)
      JacC( 87, 85) = JacC( 87, 85) + dw(216, 85)
      JacC( 66, 66) = JacC( 66, 66) - dw(217, 66)
      JacC( 66, 85) = JacC( 66, 85) - dw(217, 85)
      JacC( 75, 66) = JacC( 75, 66)+ 0.8800000000000000D+00*dw(217, 66)
      JacC( 75, 85) = JacC( 75, 85)+ 0.8800000000000000D+00*dw(217, 85)
      JacC( 77, 66) = JacC( 77, 66)+ 0.1870000000000000D+00*dw(217, 66)
      JacC( 77, 85) = JacC( 77, 85)+ 0.1870000000000000D+00*dw(217, 85)
      JacC( 79, 66) = JacC( 79, 66)+ 0.1550000000000000D+00*dw(217, 66)
      JacC( 79, 85) = JacC( 79, 85)+ 0.1550000000000000D+00*dw(217, 85)
      JacC( 81, 66) = JacC( 81, 66)+ 0.5870000000000000D+00*dw(217, 66)
      JacC( 81, 85) = JacC( 81, 85)+ 0.5870000000000000D+00*dw(217, 85)
      JacC( 85, 66) = JacC( 85, 66) - dw(217, 66)
      JacC( 85, 85) = JacC( 85, 85) - dw(217, 85)
      JacC( 86, 66) = JacC( 86, 66)+ 0.8450000000000000D+00*dw(217, 66)
      JacC( 86, 85) = JacC( 86, 85)+ 0.8450000000000000D+00*dw(217, 85)
      JacC( 87, 66) = JacC( 87, 66) + dw(217, 66)
      JacC( 87, 85) = JacC( 87, 85) + dw(217, 85)
      JacC( 67, 67) = JacC( 67, 67) - dw(218, 67)
      JacC( 67, 85) = JacC( 67, 85) - dw(218, 85)
      JacC( 77, 67) = JacC( 77, 67)+ 0.2000000000000000D+00*dw(218, 67)
      JacC( 77, 85) = JacC( 77, 85)+ 0.2000000000000000D+00*dw(218, 85)
      JacC( 80, 67) = JacC( 80, 67)+ 0.1600000000000000D+01*dw(218, 67)
      JacC( 80, 85) = JacC( 80, 85)+ 0.1600000000000000D+01*dw(218, 85)
      JacC( 85, 67) = JacC( 85, 67) - dw(218, 67)
      JacC( 85, 85) = JacC( 85, 85) - dw(218, 85)
      JacC( 86, 67) = JacC( 86, 67) + dw(218, 67)
      JacC( 86, 85) = JacC( 86, 85) + dw(218, 85)
      JacC( 87, 67) = JacC( 87, 67) + dw(218, 67)
      JacC( 87, 85) = JacC( 87, 85) + dw(218, 85)
      JacC( 53, 53) = JacC( 53, 53) - dw(219, 53)
      JacC( 53, 85) = JacC( 53, 85) - dw(219, 85)
      JacC( 75, 53) = JacC( 75, 53)+ 0.6000000000000000D-01*dw(219, 53)
      JacC( 75, 85) = JacC( 75, 85)+ 0.6000000000000000D-01*dw(219, 85)
      JacC( 77, 53) = JacC( 77, 53)+ 0.9399999999999999D+00*dw(219, 53)
      JacC( 77, 85) = JacC( 77, 85)+ 0.9399999999999999D+00*dw(219, 85)
      JacC( 80, 53) = JacC( 80, 53) + dw(219, 53)
      JacC( 80, 85) = JacC( 80, 85) + dw(219, 85)
      JacC( 85, 53) = JacC( 85, 53) - dw(219, 53)
      JacC( 85, 85) = JacC( 85, 85) - dw(219, 85)
      JacC( 86, 53) = JacC( 86, 53) + dw(219, 53)
      JacC( 86, 85) = JacC( 86, 85) + dw(219, 85)
      JacC( 87, 53) = JacC( 87, 53) + dw(219, 53)
      JacC( 87, 85) = JacC( 87, 85) + dw(219, 85)
      JacC( 59, 59) = JacC( 59, 59) - dw(220, 59)
      JacC( 59, 85) = JacC( 59, 85) - dw(220, 85)
      JacC( 75, 59) = JacC( 75, 59)+ 0.2900000000000000D+00*dw(220, 59)
      JacC( 75, 85) = JacC( 75, 85)+ 0.2900000000000000D+00*dw(220, 85)
      JacC( 77, 59) = JacC( 77, 59)+ 0.1710000000000000D+01*dw(220, 59)
      JacC( 77, 85) = JacC( 77, 85)+ 0.1710000000000000D+01*dw(220, 85)
      JacC( 85, 59) = JacC( 85, 59) - dw(220, 59)
      JacC( 85, 85) = JacC( 85, 85) - dw(220, 85)
      JacC( 86, 59) = JacC( 86, 59) + dw(220, 59)
      JacC( 86, 85) = JacC( 86, 85) + dw(220, 85)
      JacC( 87, 59) = JacC( 87, 59) + dw(220, 59)
      JacC( 87, 85) = JacC( 87, 85) + dw(220, 85)
      JacC( 51, 51) = JacC( 51, 51) - dw(221, 51)
      JacC( 51, 85) = JacC( 51, 85) - dw(221, 85)
      JacC( 52, 51) = JacC( 52, 51)+ 0.4000000000000000D+00*dw(221, 51)
      JacC( 52, 85) = JacC( 52, 85)+ 0.4000000000000000D+00*dw(221, 85)
      JacC( 60, 51) = JacC( 60, 51)+ 0.6000000000000000D+00*dw(221, 51)
      JacC( 60, 85) = JacC( 60, 85)+ 0.6000000000000000D+00*dw(221, 85)
      JacC( 80, 51) = JacC( 80, 51)+ 0.6860000000000001D+00*dw(221, 51)
      JacC( 80, 85) = JacC( 80, 85)+ 0.6860000000000001D+00*dw(221, 85)
      JacC( 85, 51) = JacC( 85, 51) - dw(221, 51)
      JacC( 85, 85) = JacC( 85, 85) - dw(221, 85)
      JacC( 86, 51) = JacC( 86, 51) + dw(221, 51)
      JacC( 86, 85) = JacC( 86, 85) + dw(221, 85)
      JacC( 87, 51) = JacC( 87, 51) + dw(221, 51)
      JacC( 87, 85) = JacC( 87, 85) + dw(221, 85)
      JacC( 54, 54) = JacC( 54, 54) - dw(222, 54)
      JacC( 54, 85) = JacC( 54, 85) - dw(222, 85)
      JacC( 75, 54) = JacC( 75, 54) + dw(222, 54)
      JacC( 75, 85) = JacC( 75, 85) + dw(222, 85)
      JacC( 77, 54) = JacC( 77, 54) + dw(222, 54)
      JacC( 77, 85) = JacC( 77, 85) + dw(222, 85)
      JacC( 85, 54) = JacC( 85, 54) - dw(222, 54)
      JacC( 85, 85) = JacC( 85, 85) - dw(222, 85)
      JacC( 86, 54) = JacC( 86, 54) + dw(222, 54)
      JacC( 86, 85) = JacC( 86, 85) + dw(222, 85)
      JacC( 87, 54) = JacC( 87, 54) + dw(222, 54)
      JacC( 87, 85) = JacC( 87, 85) + dw(222, 85)
      JacC( 55, 55) = JacC( 55, 55) - dw(223, 55)
      JacC( 55, 85) = JacC( 55, 85) - dw(223, 85)
      JacC( 56, 55) = JacC( 56, 55)+ 0.4000000000000000D+00*dw(223, 55)
      JacC( 56, 85) = JacC( 56, 85)+ 0.4000000000000000D+00*dw(223, 85)
      JacC( 60, 55) = JacC( 60, 55)+ 0.6000000000000000D+00*dw(223, 55)
      JacC( 60, 85) = JacC( 60, 85)+ 0.6000000000000000D+00*dw(223, 85)
      JacC( 80, 55) = JacC( 80, 55)+ 0.4000000000000000D+00*dw(223, 55)
      JacC( 80, 85) = JacC( 80, 85)+ 0.4000000000000000D+00*dw(223, 85)
      JacC( 85, 55) = JacC( 85, 55) - dw(223, 55)
      JacC( 85, 85) = JacC( 85, 85) - dw(223, 85)
      JacC( 86, 55) = JacC( 86, 55) + dw(223, 55)
      JacC( 86, 85) = JacC( 86, 85) + dw(223, 85)
      JacC( 87, 55) = JacC( 87, 55) + dw(223, 55)
      JacC( 87, 85) = JacC( 87, 85) + dw(223, 85)
      JacC( 39, 39) = JacC( 39, 39) - dw(224, 39)
      JacC( 39, 85) = JacC( 39, 85) - dw(224, 85)
      JacC( 41, 39) = JacC( 41, 39)+ 0.1220000000000000D+00*dw(224, 39)
      JacC( 41, 85) = JacC( 41, 85)+ 0.1220000000000000D+00*dw(224, 85)
      JacC( 42, 39) = JacC( 42, 39)+ 0.4400000000000000D-01*dw(224, 39)
      JacC( 42, 85) = JacC( 42, 85)+ 0.4400000000000000D-01*dw(224, 85)
      JacC( 62, 39) = JacC( 62, 39)+ 0.5000000000000000D+00*dw(224, 39)
      JacC( 62, 85) = JacC( 62, 85)+ 0.5000000000000000D+00*dw(224, 85)
      JacC( 65, 39) = JacC( 65, 39)+ 0.1300000000000000D+01*dw(224, 39)
      JacC( 65, 85) = JacC( 65, 85)+ 0.1300000000000000D+01*dw(224, 85)
      JacC( 72, 39) = JacC( 72, 39)+ 0.7000000000000000D+00*dw(224, 39)
      JacC( 72, 85) = JacC( 72, 85)+ 0.7000000000000000D+00*dw(224, 85)
      JacC( 85, 39) = JacC( 85, 39) - dw(224, 39)
      JacC( 85, 85) = JacC( 85, 85) - dw(224, 85)
      JacC( 86, 39) = JacC( 86, 39) + dw(224, 39)
      JacC( 86, 85) = JacC( 86, 85) + dw(224, 85)
      JacC( 87, 39) = JacC( 87, 39) + dw(224, 39)
      JacC( 87, 85) = JacC( 87, 85) + dw(224, 85)
      JacC( 41, 44) = JacC( 41, 44)+ 0.1220000000000000D+00*dw(225, 44)
      JacC( 41, 85) = JacC( 41, 85)+ 0.1220000000000000D+00*dw(225, 85)
      JacC( 42, 44) = JacC( 42, 44)+ 0.4400000000000000D-01*dw(225, 44)
      JacC( 42, 85) = JacC( 42, 85)+ 0.4400000000000000D-01*dw(225, 85)
      JacC( 44, 44) = JacC( 44, 44) - dw(225, 44)
      JacC( 44, 85) = JacC( 44, 85) - dw(225, 85)
      JacC( 62, 44) = JacC( 62, 44) + dw(225, 44)
      JacC( 62, 85) = JacC( 62, 85) + dw(225, 85)
      JacC( 65, 44) = JacC( 65, 44)+ 0.7400000000000000D+00*dw(225, 44)
      JacC( 65, 85) = JacC( 65, 85)+ 0.7400000000000000D+00*dw(225, 85)
      JacC( 72, 44) = JacC( 72, 44)+ 0.1260000000000000D+01*dw(225, 44)
      JacC( 72, 85) = JacC( 72, 85)+ 0.1260000000000000D+01*dw(225, 85)
      JacC( 85, 44) = JacC( 85, 44) - dw(225, 44)
      JacC( 85, 85) = JacC( 85, 85) - dw(225, 85)
      JacC( 86, 44) = JacC( 86, 44) + dw(225, 44)
      JacC( 86, 85) = JacC( 86, 85) + dw(225, 85)
      JacC( 87, 44) = JacC( 87, 44) + dw(225, 44)
      JacC( 87, 85) = JacC( 87, 85) + dw(225, 85)
      JacC( 49, 49) = JacC( 49, 49) - dw(226, 49)
      JacC( 49, 85) = JacC( 49, 85) - dw(226, 85)
      JacC( 65, 49) = JacC( 65, 49) + dw(226, 49)
      JacC( 65, 85) = JacC( 65, 85) + dw(226, 85)
      JacC( 72, 49) = JacC( 72, 49) + dw(226, 49)
      JacC( 72, 85) = JacC( 72, 85) + dw(226, 85)
      JacC( 85, 49) = JacC( 85, 49) - dw(226, 49)
      JacC( 85, 85) = JacC( 85, 85) - dw(226, 85)
      JacC( 86, 49) = JacC( 86, 49) + dw(226, 49)
      JacC( 86, 85) = JacC( 86, 85) + dw(226, 85)
      JacC( 87, 49) = JacC( 87, 49) + dw(226, 49)
      JacC( 87, 85) = JacC( 87, 85) + dw(226, 85)
      JacC( 82, 83) = JacC( 82, 83) + dw(227, 83)
      JacC( 82, 85) = JacC( 82, 85) + dw(227, 85)
      JacC( 83, 83) = JacC( 83, 83) - dw(227, 83)
      JacC( 83, 85) = JacC( 83, 85) - dw(227, 85)
      JacC( 85, 83) = JacC( 85, 83) - dw(227, 83)
      JacC( 85, 85) = JacC( 85, 85) - dw(227, 85)
      JacC( 87, 83) = JacC( 87, 83) + dw(227, 83)
      JacC( 87, 85) = JacC( 87, 85) + dw(227, 85)
      JacC( 68, 68) = JacC( 68, 68) - dw(228, 68)
      JacC( 68, 85) = JacC( 68, 85) - dw(228, 85)
      JacC( 80, 68) = JacC( 80, 68) + dw(228, 68)
      JacC( 80, 85) = JacC( 80, 85) + dw(228, 85)
      JacC( 83, 68) = JacC( 83, 68) + dw(228, 68)
      JacC( 83, 85) = JacC( 83, 85) + dw(228, 85)
      JacC( 85, 68) = JacC( 85, 68) - dw(228, 68)
      JacC( 85, 85) = JacC( 85, 85) - dw(228, 85)
      JacC( 87, 68) = JacC( 87, 68) + dw(228, 68)
      JacC( 87, 85) = JacC( 87, 85) + dw(228, 85)
      JacC( 72, 76) = JacC( 72, 76)+ 0.5400000000000000D+00*dw(229, 76)
      JacC( 72, 85) = JacC( 72, 85)+ 0.5400000000000000D+00*dw(229, 85)
      JacC( 76, 76) = JacC( 76, 76) - dw(229, 76)
      JacC( 76, 85) = JacC( 76, 85) - dw(229, 85)
      JacC( 77, 76) = JacC( 77, 76)+ 0.4600000000000000D+00*dw(229, 76)
      JacC( 77, 85) = JacC( 77, 85)+ 0.4600000000000000D+00*dw(229, 85)
      JacC( 81, 76) = JacC( 81, 76)+ 0.1600000000000000D+00*dw(229, 76)
      JacC( 81, 85) = JacC( 81, 85)+ 0.1600000000000000D+00*dw(229, 85)
      JacC( 83, 76) = JacC( 83, 76)+ 0.2300000000000000D+00*dw(229, 76)
      JacC( 83, 85) = JacC( 83, 85)+ 0.2300000000000000D+00*dw(229, 85)
      JacC( 85, 76) = JacC( 85, 76) - dw(229, 76)
      JacC( 85, 85) = JacC( 85, 85) - dw(229, 85)
      JacC( 86, 76) = JacC( 86, 76)+ 0.7700000000000000D+00*dw(229, 76)
      JacC( 86, 85) = JacC( 86, 85)+ 0.7700000000000000D+00*dw(229, 85)
      JacC( 87, 76) = JacC( 87, 76) + dw(229, 76)
      JacC( 87, 85) = JacC( 87, 85) + dw(229, 85)
      JacC( 58, 58) = JacC( 58, 58) - dw(230, 58)
      JacC( 58, 85) = JacC( 58, 85) - dw(230, 85)
      JacC( 74, 58) = JacC( 74, 58) + dw(230, 58)
      JacC( 74, 85) = JacC( 74, 85) + dw(230, 85)
      JacC( 85, 58) = JacC( 85, 58) - dw(230, 58)
      JacC( 85, 85) = JacC( 85, 85) - dw(230, 85)
      JacC( 86, 58) = JacC( 86, 58) + dw(230, 58)
      JacC( 86, 85) = JacC( 86, 85) + dw(230, 85)
      JacC( 87, 58) = JacC( 87, 58) + dw(230, 58)
      JacC( 87, 85) = JacC( 87, 85) + dw(230, 85)
      JacC( 57, 57) = JacC( 57, 57) - dw(231, 57)
      JacC( 57, 85) = JacC( 57, 85) - dw(231, 85)
      JacC( 75, 57) = JacC( 75, 57)+ 0.4690000000000000D+00*dw(231, 57)
      JacC( 75, 85) = JacC( 75, 85)+ 0.4690000000000000D+00*dw(231, 85)
      JacC( 77, 57) = JacC( 77, 57)+ 0.1240000000000000D+01*dw(231, 57)
      JacC( 77, 85) = JacC( 77, 85)+ 0.1240000000000000D+01*dw(231, 85)
      JacC( 80, 57) = JacC( 80, 57)+ 0.2800000000000000D+00*dw(231, 57)
      JacC( 80, 85) = JacC( 80, 85)+ 0.2800000000000000D+00*dw(231, 85)
      JacC( 85, 57) = JacC( 85, 57) - dw(231, 57)
      JacC( 85, 85) = JacC( 85, 85) - dw(231, 85)
      JacC( 87, 57) = JacC( 87, 57)+ 0.2000000000000000D+01*dw(231, 57)
      JacC( 87, 85) = JacC( 87, 85)+ 0.2000000000000000D+01*dw(231, 85)
      JacC( 69, 81) = JacC( 69, 81) + dw(232, 81)
      JacC( 69, 86) = JacC( 69, 86) + dw(232, 86)
      JacC( 81, 81) = JacC( 81, 81) - dw(232, 81)
      JacC( 81, 86) = JacC( 81, 86) - dw(232, 86)
      JacC( 86, 81) = JacC( 86, 81) - dw(232, 81)
      JacC( 86, 86) = JacC( 86, 86) - dw(232, 86)
      JacC( 80, 81) = JacC( 80, 81) + dw(233, 81)
      JacC( 80, 82) = JacC( 80, 82) + dw(233, 82)
      JacC( 81, 81) = JacC( 81, 81) - dw(233, 81)
      JacC( 81, 82) = JacC( 81, 82) - dw(233, 82)
      JacC( 82, 81) = JacC( 82, 81) - dw(233, 81)
      JacC( 82, 82) = JacC( 82, 82) - dw(233, 82)
      JacC( 86, 81) = JacC( 86, 81) + dw(233, 81)
      JacC( 86, 82) = JacC( 86, 82) + dw(233, 82)
      JacC( 81, 81) = JacC( 81, 81) - dw(234, 81)
      JacC( 81, 83) = JacC( 81, 83) - dw(234, 83)
      JacC( 82, 81) = JacC( 82, 81) + dw(234, 81)
      JacC( 82, 83) = JacC( 82, 83) + dw(234, 83)
      JacC( 83, 81) = JacC( 83, 81) - dw(234, 81)
      JacC( 83, 83) = JacC( 83, 83) - dw(234, 83)
      JacC( 81, 81) = JacC( 81, 81)- 0.2000000000000000D+01*dw(235, 81)
      JacC( 81, 81) = JacC( 81, 81)- 0.2000000000000000D+01*dw(235, 81)
      JacC( 81, 81) = JacC( 81, 81) - dw(236, 81)
      JacC( 81, 84) = JacC( 81, 84) - dw(236, 84)
      JacC( 84, 81) = JacC( 84, 81) - dw(236, 81)
      JacC( 84, 84) = JacC( 84, 84) - dw(236, 84)
      JacC( 87, 81) = JacC( 87, 81) + dw(236, 81)
      JacC( 87, 84) = JacC( 87, 84) + dw(236, 84)
      JacC( 81, 81) = JacC( 81, 81) - dw(237, 81)
      JacC( 81, 85) = JacC( 81, 85) - dw(237, 85)
      JacC( 85, 81) = JacC( 85, 81) - dw(237, 81)
      JacC( 85, 85) = JacC( 85, 85) - dw(237, 85)
      JacC( 87, 81) = JacC( 87, 81) + dw(237, 81)
      JacC( 87, 85) = JacC( 87, 85) + dw(237, 85)
      JacC( 43, 86) = JacC( 43, 86)+ 0.5000000000000000D+00*dw(238, 86)
      JacC( 86, 86) = JacC( 86, 86) - dw(238, 86)
      JacC( 32, 87) = JacC( 32, 87)+ 0.5000000000000000D+00*dw(239, 87)
      JacC( 73, 87) = JacC( 73, 87)+ 0.5000000000000000D+00*dw(239, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(239, 87)
      JacC( 73, 85) = JacC( 73, 85) + dw(240, 85)
      JacC( 85, 85) = JacC( 85, 85) - dw(240, 85)
      JacC( 17, 17) = JacC( 17, 17) - dw(241, 17)
      JacC( 73, 17) = JacC( 73, 17)+ 0.2000000000000000D+01*dw(241, 17)
      JacC( 12, 12) = JacC( 12, 12) - dw(242, 12)
      JacC( 12, 78) = JacC( 12, 78) - dw(242, 78)
      JacC( 13, 12) = JacC( 13, 12) + dw(242, 12)
      JacC( 13, 78) = JacC( 13, 78) + dw(242, 78)
      JacC( 78, 12) = JacC( 78, 12) - dw(242, 12)
      JacC( 78, 78) = JacC( 78, 78) - dw(242, 78)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
