C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc                        (
     $    ns,nr,y,convers_factor,convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2_SORGAM_isop_tp
C     Species: _ciRACM2_SORGAM_iso2
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc                        (
     $    ns,nr,rk,conc,dw)
 
      JacC( 51,123) = JacC( 51,123) + dw(  1,123)
      JacC(123,123) = JacC(123,123) - dw(  1,123)
      JacC(125,123) = JacC(125,123) + dw(  1,123)
      JacC(  3, 97) = JacC(  3, 97) + dw(  2, 97)
      JacC( 97, 97) = JacC( 97, 97) - dw(  2, 97)
      JacC( 51, 97) = JacC( 51, 97) + dw(  3, 97)
      JacC( 97, 97) = JacC( 97, 97) - dw(  3, 97)
      JacC( 28, 28) = JacC( 28, 28) - dw(  4, 28)
      JacC(125, 28) = JacC(125, 28) + dw(  4, 28)
      JacC(131, 28) = JacC(131, 28) + dw(  4, 28)
      JacC(111,111) = JacC(111,111) - dw(  5,111)
      JacC(123,111) = JacC(123,111) + dw(  5,111)
      JacC(131,111) = JacC(131,111) + dw(  5,111)
      JacC( 48, 48) = JacC( 48, 48) - dw(  6, 48)
      JacC(123, 48) = JacC(123, 48)+ 0.8000000000000000D+00*dw(  6, 48)
      JacC(129, 48) = JacC(129, 48)+ 0.2000000000000000D+00*dw(  6, 48)
      JacC(130, 48) = JacC(130, 48)+ 0.8000000000000000D+00*dw(  6, 48)
      JacC(131, 48) = JacC(131, 48)+ 0.2000000000000000D+00*dw(  6, 48)
      JacC(125,129) = JacC(125,129) + dw(  7,129)
      JacC(129,129) = JacC(129,129) - dw(  7,129)
      JacC( 51,129) = JacC( 51,129) + dw(  8,129)
      JacC(123,129) = JacC(123,129) + dw(  8,129)
      JacC(129,129) = JacC(129,129) - dw(  8,129)
      JacC( 53, 53) = JacC( 53, 53) - dw(  9, 53)
      JacC(131, 53) = JacC(131, 53)+ 0.2000000000000000D+01*dw(  9, 53)
      JacC(113,128) = JacC(113,128) + dw( 10,128)
      JacC(128,128) = JacC(128,128) - dw( 10,128)
      JacC(113,128) = JacC(113,128) + dw( 11,128)
      JacC(128,128) = JacC(128,128) - dw( 11,128)
      JacC(130,128) = JacC(130,128)+ 0.2000000000000000D+01*dw( 11,128)
      JacC( 95, 95) = JacC( 95, 95) - dw( 12, 95)
      JacC(113, 95) = JacC(113, 95) + dw( 12, 95)
      JacC(122, 95) = JacC(122, 95) + dw( 12, 95)
      JacC(130, 95) = JacC(130, 95) + dw( 12, 95)
      JacC(113,119) = JacC(113,119) + dw( 13,119)
      JacC(119,119) = JacC(119,119) - dw( 13,119)
      JacC(121,119) = JacC(121,119) + dw( 13,119)
      JacC(130,119) = JacC(130,119) + dw( 13,119)
      JacC( 78, 78) = JacC( 78, 78) - dw( 14, 78)
      JacC(122, 78) = JacC(122, 78) + dw( 14, 78)
      JacC(124, 78) = JacC(124, 78) + dw( 14, 78)
      JacC( 41, 41) = JacC( 41, 41) - dw( 15, 41)
      JacC(121, 41) = JacC(121, 41)+ 0.5000000000000000D+00*dw( 15, 41)
      JacC(122, 41) = JacC(122, 41)+ 0.5000000000000000D+00*dw( 15, 41)
      JacC(124, 41) = JacC(124, 41) + dw( 15, 41)
      JacC(116,116) = JacC(116,116) - dw( 16,116)
      JacC(121,116) = JacC(121,116) + dw( 16,116)
      JacC(124,116) = JacC(124,116) + dw( 16,116)
      JacC( 75, 75) = JacC( 75, 75) - dw( 17, 75)
      JacC(124, 75) = JacC(124, 75) + dw( 17, 75)
      JacC(128, 75) = JacC(128, 75) + dw( 17, 75)
      JacC(130, 75) = JacC(130, 75) + dw( 17, 75)
      JacC( 96, 96) = JacC( 96, 96) - dw( 18, 96)
      JacC(109, 96) = JacC(109, 96)+ 0.3300000000000000D+00*dw( 18, 96)
      JacC(113, 96) = JacC(113, 96)+ 0.6700000000000000D+00*dw( 18, 96)
      JacC(124, 96) = JacC(124, 96)+ 0.6700000000000000D+00*dw( 18, 96)
      JacC(127, 96) = JacC(127, 96)+ 0.3400000000000000D+00*dw( 18, 96)
      JacC(128, 96) = JacC(128, 96)+ 0.6700000000000000D+00*dw( 18, 96)
      JacC(130, 96) = JacC(130, 96)+ 0.6600000000000000D+00*dw( 18, 96)
      JacC(131, 96) = JacC(131, 96)+ 0.3400000000000000D+00*dw( 18, 96)
      JacC( 84, 84) = JacC( 84, 84) - dw( 19, 84)
      JacC( 85, 84) = JacC( 85, 84)+ 0.7000000000000000D+00*dw( 19, 84)
      JacC(109, 84) = JacC(109, 84)+ 0.3000000000000000D+00*dw( 19, 84)
      JacC(113, 84) = JacC(113, 84)+ 0.7000000000000000D+00*dw( 19, 84)
      JacC(122, 84) = JacC(122, 84)+ 0.3000000000000000D+00*dw( 19, 84)
      JacC( 85, 85) = JacC( 85, 85) - dw( 20, 85)
      JacC(113, 85) = JacC(113, 85)+ 0.1220000000000000D+01*dw( 20, 85)
      JacC(116, 85) = JacC(116, 85)+ 0.2160000000000000D+00*dw( 20, 85)
      JacC(119, 85) = JacC(119, 85)+ 0.4340000000000000D+00*dw( 20, 85)
      JacC(124, 85) = JacC(124, 85)+ 0.7840000000000000D+00*dw( 20, 85)
      JacC(128, 85) = JacC(128, 85)+ 0.3500000000000000D+00*dw( 20, 85)
      JacC(130, 85) = JacC(130, 85)+ 0.1220000000000000D+01*dw( 20, 85)
      JacC(108,108) = JacC(108,108) - dw( 21,108)
      JacC(113,108) = JacC(113,108)+ 0.2000000000000000D+01*dw( 21,108)
      JacC(130,108) = JacC(130,108)+ 0.2000000000000000D+01*dw( 21,108)
      JacC(108,108) = JacC(108,108) - dw( 22,108)
      JacC(113,108) = JacC(113,108)+ 0.2000000000000000D+01*dw( 22,108)
      JacC(108,108) = JacC(108,108) - dw( 23,108)
      JacC(113,108) = JacC(113,108)+ 0.2000000000000000D+01*dw( 23,108)
      JacC(128,108) = JacC(128,108) + dw( 23,108)
      JacC(110,110) = JacC(110,110) - dw( 24,110)
      JacC(113,110) = JacC(113,110) + dw( 24,110)
      JacC(124,110) = JacC(124,110) + dw( 24,110)
      JacC(130,110) = JacC(130,110) + dw( 24,110)
      JacC( 76, 76) = JacC( 76, 76) - dw( 25, 76)
      JacC(108, 76) = JacC(108, 76)+ 0.5000000000000000D+00*dw( 25, 76)
      JacC(110, 76) = JacC(110, 76)+ 0.5000000000000000D+00*dw( 25, 76)
      JacC(113, 76) = JacC(113, 76) + dw( 25, 76)
      JacC(124, 76) = JacC(124, 76)+ 0.5000000000000000D+00*dw( 25, 76)
      JacC(127, 76) = JacC(127, 76)+ 0.2000000000000000D+01*dw( 25, 76)
      JacC(130, 76) = JacC(130, 76)+ 0.1500000000000000D+01*dw( 25, 76)
      JacC( 68, 68) = JacC( 68, 68) - dw( 26, 68)
      JacC(108, 68) = JacC(108, 68)+ 0.5000000000000000D+00*dw( 26, 68)
      JacC(110, 68) = JacC(110, 68)+ 0.5000000000000000D+00*dw( 26, 68)
      JacC(113, 68) = JacC(113, 68) + dw( 26, 68)
      JacC(124, 68) = JacC(124, 68)+ 0.5000000000000000D+00*dw( 26, 68)
      JacC(127, 68) = JacC(127, 68)+ 0.2000000000000000D+01*dw( 26, 68)
      JacC(130, 68) = JacC(130, 68)+ 0.1500000000000000D+01*dw( 26, 68)
      JacC( 98, 98) = JacC( 98, 98) - dw( 27, 98)
      JacC(101, 98) = JacC(101, 98) + dw( 27, 98)
      JacC(113, 98) = JacC(113, 98) + dw( 27, 98)
      JacC(124, 98) = JacC(124, 98) + dw( 27, 98)
      JacC(130, 98) = JacC(130, 98) + dw( 27, 98)
      JacC( 64, 66) = JacC( 64, 66) + dw( 28, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw( 28, 66)
      JacC(113, 66) = JacC(113, 66) + dw( 28, 66)
      JacC(130, 66) = JacC(130, 66) + dw( 28, 66)
      JacC( 45, 45) = JacC( 45, 45) - dw( 29, 45)
      JacC(128, 45) = JacC(128, 45) + dw( 29, 45)
      JacC(130, 45) = JacC(130, 45) + dw( 29, 45)
      JacC(131, 45) = JacC(131, 45) + dw( 29, 45)
      JacC(119,126) = JacC(119,126) + dw( 30,126)
      JacC(126,126) = JacC(126,126) - dw( 30,126)
      JacC(130,126) = JacC(130,126) + dw( 30,126)
      JacC(131,126) = JacC(131,126) + dw( 30,126)
      JacC( 74, 74) = JacC( 74, 74) - dw( 31, 74)
      JacC(122, 74) = JacC(122, 74) + dw( 31, 74)
      JacC(131, 74) = JacC(131, 74) + dw( 31, 74)
      JacC(116,118) = JacC(116,118)+ 0.8000000000000000D+00*dw( 32,118)
      JacC(118,118) = JacC(118,118) - dw( 32,118)
      JacC(119,118) = JacC(119,118)+ 0.2000000000000000D+00*dw( 32,118)
      JacC(123,118) = JacC(123,118) + dw( 32,118)
      JacC(130,118) = JacC(130,118) + dw( 32,118)
      JacC( 46, 46) = JacC( 46, 46) - dw( 33, 46)
      JacC(123, 46) = JacC(123, 46) + dw( 33, 46)
      JacC(124, 46) = JacC(124, 46) + dw( 33, 46)
      JacC( 46, 46) = JacC( 46, 46) - dw( 34, 46)
      JacC(122, 46) = JacC(122, 46) + dw( 34, 46)
      JacC(129, 46) = JacC(129, 46) + dw( 34, 46)
      JacC( 51, 51) = JacC( 51, 51) - dw( 35, 51)
      JacC( 97, 51) = JacC( 97, 51) + dw( 35, 51)
      JacC( 51, 51) = JacC( 51, 51) - dw( 36, 51)
      JacC( 51, 97) = JacC( 51, 97) - dw( 36, 97)
      JacC( 97, 51) = JacC( 97, 51) - dw( 36, 51)
      JacC( 97, 97) = JacC( 97, 97) - dw( 36, 97)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 51,  3) = JacC( 51,  3) + dw( 37,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 38,  3)
      JacC( 51,  3) = JacC( 51,  3) + dw( 38,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 39,  3)
      JacC(131,  3) = JacC(131,  3)+ 0.2000000000000000D+01*dw( 39,  3)
      JacC( 97, 97) = JacC( 97, 97) - dw( 40, 97)
      JacC( 97,131) = JacC( 97,131) - dw( 40,131)
      JacC(130, 97) = JacC(130, 97) + dw( 40, 97)
      JacC(130,131) = JacC(130,131) + dw( 40,131)
      JacC(131, 97) = JacC(131, 97) - dw( 40, 97)
      JacC(131,131) = JacC(131,131) - dw( 40,131)
      JacC( 97, 97) = JacC( 97, 97) - dw( 41, 97)
      JacC( 97,130) = JacC( 97,130) - dw( 41,130)
      JacC(130, 97) = JacC(130, 97) - dw( 41, 97)
      JacC(130,130) = JacC(130,130) - dw( 41,130)
      JacC(131, 97) = JacC(131, 97) + dw( 41, 97)
      JacC(131,130) = JacC(131,130) + dw( 41,130)
      JacC(130,131) = JacC(130,131) - dw( 42,131)
      JacC(130,130) = JacC(130,130) - dw( 42,130)
      JacC(131,131) = JacC(131,131) - dw( 42,131)
      JacC(131,130) = JacC(131,130) - dw( 42,130)
      JacC( 53, 53) = JacC( 53, 53) - dw( 43, 53)
      JacC( 53,131) = JacC( 53,131) - dw( 43,131)
      JacC(130, 53) = JacC(130, 53) + dw( 43, 53)
      JacC(130,131) = JacC(130,131) + dw( 43,131)
      JacC(131, 53) = JacC(131, 53) - dw( 43, 53)
      JacC(131,131) = JacC(131,131) - dw( 43,131)
      JacC( 53,130) = JacC( 53,130) + dw( 44,130)
      JacC( 53,130) = JacC( 53,130) + dw( 44,130)
      JacC(130,130) = JacC(130,130)- 0.2000000000000000D+01*dw( 44,130)
      JacC(130,130) = JacC(130,130)- 0.2000000000000000D+01*dw( 44,130)
      JacC( 53,130) = JacC( 53,130) + dw( 45,130)
      JacC( 53,130) = JacC( 53,130) + dw( 45,130)
      JacC(130,130) = JacC(130,130)- 0.2000000000000000D+01*dw( 45,130)
      JacC(130,130) = JacC(130,130)- 0.2000000000000000D+01*dw( 45,130)
      JacC( 51, 51) = JacC( 51, 51) - dw( 46, 51)
      JacC( 51,125) = JacC( 51,125) - dw( 46,125)
      JacC(123, 51) = JacC(123, 51) + dw( 46, 51)
      JacC(123,125) = JacC(123,125) + dw( 46,125)
      JacC(125, 51) = JacC(125, 51) - dw( 46, 51)
      JacC(125,125) = JacC(125,125) - dw( 46,125)
      JacC( 51, 51) = JacC( 51, 51) - dw( 47, 51)
      JacC( 51,123) = JacC( 51,123) - dw( 47,123)
      JacC(123, 51) = JacC(123, 51) - dw( 47, 51)
      JacC(123,123) = JacC(123,123) - dw( 47,123)
      JacC(125, 51) = JacC(125, 51) + dw( 47, 51)
      JacC(125,123) = JacC(125,123) + dw( 47,123)
      JacC( 51, 51) = JacC( 51, 51) - dw( 48, 51)
      JacC( 51,123) = JacC( 51,123) - dw( 48,123)
      JacC(123, 51) = JacC(123, 51) - dw( 48, 51)
      JacC(123,123) = JacC(123,123) - dw( 48,123)
      JacC(129, 51) = JacC(129, 51) + dw( 48, 51)
      JacC(129,123) = JacC(129,123) + dw( 48,123)
      JacC( 28,131) = JacC( 28,131) + dw( 49,131)
      JacC( 28,125) = JacC( 28,125) + dw( 49,125)
      JacC(125,131) = JacC(125,131) - dw( 49,131)
      JacC(125,125) = JacC(125,125) - dw( 49,125)
      JacC(131,131) = JacC(131,131) - dw( 49,131)
      JacC(131,125) = JacC(131,125) - dw( 49,125)
      JacC(111,131) = JacC(111,131) + dw( 50,131)
      JacC(111,123) = JacC(111,123) + dw( 50,123)
      JacC(123,131) = JacC(123,131) - dw( 50,131)
      JacC(123,123) = JacC(123,123) - dw( 50,123)
      JacC(131,131) = JacC(131,131) - dw( 50,131)
      JacC(131,123) = JacC(131,123) - dw( 50,123)
      JacC(123,131) = JacC(123,131) + dw( 51,131)
      JacC(123,129) = JacC(123,129) + dw( 51,129)
      JacC(129,131) = JacC(129,131) - dw( 51,131)
      JacC(129,129) = JacC(129,129) - dw( 51,129)
      JacC(130,131) = JacC(130,131) + dw( 51,131)
      JacC(130,129) = JacC(130,129) + dw( 51,129)
      JacC(131,131) = JacC(131,131) - dw( 51,131)
      JacC(131,129) = JacC(131,129) - dw( 51,129)
      JacC(123,130) = JacC(123,130) + dw( 52,130)
      JacC(123,125) = JacC(123,125) + dw( 52,125)
      JacC(125,130) = JacC(125,130) - dw( 52,130)
      JacC(125,125) = JacC(125,125) - dw( 52,125)
      JacC(130,130) = JacC(130,130) - dw( 52,130)
      JacC(130,125) = JacC(130,125) - dw( 52,125)
      JacC(131,130) = JacC(131,130) + dw( 52,130)
      JacC(131,125) = JacC(131,125) + dw( 52,125)
      JacC( 48,130) = JacC( 48,130) + dw( 53,130)
      JacC( 48,123) = JacC( 48,123) + dw( 53,123)
      JacC(123,130) = JacC(123,130) - dw( 53,130)
      JacC(123,123) = JacC(123,123) - dw( 53,123)
      JacC(130,130) = JacC(130,130) - dw( 53,130)
      JacC(130,123) = JacC(130,123) - dw( 53,123)
      JacC( 48, 48) = JacC( 48, 48) - dw( 54, 48)
      JacC(123, 48) = JacC(123, 48) + dw( 54, 48)
      JacC(130, 48) = JacC(130, 48) + dw( 54, 48)
      JacC(111,130) = JacC(111,130)+ 0.3000000000000000D+00*dw( 55,130)
      JacC(111,129) = JacC(111,129)+ 0.3000000000000000D+00*dw( 55,129)
      JacC(123,130) = JacC(123,130)+ 0.7000000000000000D+00*dw( 55,130)
      JacC(123,129) = JacC(123,129)+ 0.7000000000000000D+00*dw( 55,129)
      JacC(129,130) = JacC(129,130) - dw( 55,130)
      JacC(129,129) = JacC(129,129) - dw( 55,129)
      JacC(130,130) = JacC(130,130) - dw( 55,130)
      JacC(130,129) = JacC(130,129) - dw( 55,129)
      JacC(131,130) = JacC(131,130)+ 0.7000000000000000D+00*dw( 55,130)
      JacC(131,129) = JacC(131,129)+ 0.7000000000000000D+00*dw( 55,129)
      JacC( 28,131) = JacC( 28,131) - dw( 56,131)
      JacC( 28, 28) = JacC( 28, 28) - dw( 56, 28)
      JacC(123,131) = JacC(123,131) + dw( 56,131)
      JacC(123, 28) = JacC(123, 28) + dw( 56, 28)
      JacC(131,131) = JacC(131,131) - dw( 56,131)
      JacC(131, 28) = JacC(131, 28) - dw( 56, 28)
      JacC(111,131) = JacC(111,131) - dw( 57,131)
      JacC(111,111) = JacC(111,111) - dw( 57,111)
      JacC(129,131) = JacC(129,131) + dw( 57,131)
      JacC(129,111) = JacC(129,111) + dw( 57,111)
      JacC(131,131) = JacC(131,131) - dw( 57,131)
      JacC(131,111) = JacC(131,111) - dw( 57,111)
      JacC( 48,131) = JacC( 48,131) - dw( 58,131)
      JacC( 48, 48) = JacC( 48, 48) - dw( 58, 48)
      JacC(123,131) = JacC(123,131) + dw( 58,131)
      JacC(123, 48) = JacC(123, 48) + dw( 58, 48)
      JacC(131,131) = JacC(131,131) - dw( 58,131)
      JacC(131, 48) = JacC(131, 48) - dw( 58, 48)
      JacC( 97, 97) = JacC( 97, 97) - dw( 59, 97)
      JacC( 97,125) = JacC( 97,125) - dw( 59,125)
      JacC(123, 97) = JacC(123, 97) + dw( 59, 97)
      JacC(123,125) = JacC(123,125) + dw( 59,125)
      JacC(125, 97) = JacC(125, 97) - dw( 59, 97)
      JacC(125,125) = JacC(125,125) - dw( 59,125)
      JacC( 97, 97) = JacC( 97, 97) - dw( 60, 97)
      JacC( 97,123) = JacC( 97,123) - dw( 60,123)
      JacC(123, 97) = JacC(123, 97) - dw( 60, 97)
      JacC(123,123) = JacC(123,123) - dw( 60,123)
      JacC(129, 97) = JacC(129, 97) + dw( 60, 97)
      JacC(129,123) = JacC(129,123) + dw( 60,123)
      JacC(123,125) = JacC(123,125)+ 0.2000000000000000D+01*dw( 61,125)
      JacC(123,125) = JacC(123,125)+ 0.2000000000000000D+01*dw( 61,125)
      JacC(125,125) = JacC(125,125)- 0.2000000000000000D+01*dw( 61,125)
      JacC(125,125) = JacC(125,125)- 0.2000000000000000D+01*dw( 61,125)
      JacC(123,129) = JacC(123,129)+ 0.2000000000000000D+01*dw( 62,129)
      JacC(123,125) = JacC(123,125)+ 0.2000000000000000D+01*dw( 62,125)
      JacC(125,129) = JacC(125,129) - dw( 62,129)
      JacC(125,125) = JacC(125,125) - dw( 62,125)
      JacC(129,129) = JacC(129,129) - dw( 62,129)
      JacC(129,125) = JacC(129,125) - dw( 62,125)
      JacC(125,129) = JacC(125,129) + dw( 63,129)
      JacC(125,123) = JacC(125,123) + dw( 63,123)
      JacC(129,129) = JacC(129,129) - dw( 63,129)
      JacC(129,123) = JacC(129,123) - dw( 63,123)
      JacC( 20,129) = JacC( 20,129) + dw( 64,129)
      JacC( 20,123) = JacC( 20,123) + dw( 64,123)
      JacC(123,129) = JacC(123,129) - dw( 64,129)
      JacC(123,123) = JacC(123,123) - dw( 64,123)
      JacC(129,129) = JacC(129,129) - dw( 64,129)
      JacC(129,123) = JacC(129,123) - dw( 64,123)
      JacC( 20, 20) = JacC( 20, 20) - dw( 65, 20)
      JacC(123, 20) = JacC(123, 20) + dw( 65, 20)
      JacC(129, 20) = JacC(129, 20) + dw( 65, 20)
      JacC( 20, 20) = JacC( 20, 20) - dw( 66, 20)
      JacC(111, 20) = JacC(111, 20)+ 0.2000000000000000D+01*dw( 66, 20)
      JacC(123,129) = JacC(123,129)+ 0.2000000000000000D+01*dw( 67,129)
      JacC(123,129) = JacC(123,129)+ 0.2000000000000000D+01*dw( 67,129)
      JacC(129,129) = JacC(129,129)- 0.2000000000000000D+01*dw( 67,129)
      JacC(129,129) = JacC(129,129)- 0.2000000000000000D+01*dw( 67,129)
      JacC(130,131) = JacC(130,131) + dw( 68,131)
      JacC(131,131) = JacC(131,131) - dw( 68,131)
      JacC(  4,131) = JacC(  4,131) - dw( 69,131)
      JacC(  4,  4) = JacC(  4,  4) - dw( 69,  4)
      JacC(  5,131) = JacC(  5,131) + dw( 69,131)
      JacC(  5,  4) = JacC(  5,  4) + dw( 69,  4)
      JacC(130,131) = JacC(130,131) + dw( 69,131)
      JacC(130,  4) = JacC(130,  4) + dw( 69,  4)
      JacC(131,131) = JacC(131,131) - dw( 69,131)
      JacC(131,  4) = JacC(131,  4) - dw( 69,  4)
      JacC(113,113) = JacC(113,113) - dw( 70,113)
      JacC(113,131) = JacC(113,131) - dw( 70,131)
      JacC(130,113) = JacC(130,113) + dw( 70,113)
      JacC(130,131) = JacC(130,131) + dw( 70,131)
      JacC(131,113) = JacC(131,113) - dw( 70,113)
      JacC(131,131) = JacC(131,131) - dw( 70,131)
      JacC( 43, 43) = JacC( 43, 43) - dw( 71, 43)
      JacC( 43,131) = JacC( 43,131) - dw( 71,131)
      JacC(122, 43) = JacC(122, 43) + dw( 71, 43)
      JacC(122,131) = JacC(122,131) + dw( 71,131)
      JacC(131, 43) = JacC(131, 43) - dw( 71, 43)
      JacC(131,131) = JacC(131,131) - dw( 71,131)
      JacC( 44, 44) = JacC( 44, 44) - dw( 72, 44)
      JacC( 44,131) = JacC( 44,131) - dw( 72,131)
      JacC(121, 44) = JacC(121, 44) + dw( 72, 44)
      JacC(121,131) = JacC(121,131) + dw( 72,131)
      JacC(131, 44) = JacC(131, 44) - dw( 72, 44)
      JacC(131,131) = JacC(131,131) - dw( 72,131)
      JacC(102,102) = JacC(102,102) - dw( 73,102)
      JacC(102,131) = JacC(102,131) - dw( 73,131)
      JacC(128,102) = JacC(128,102) + dw( 73,102)
      JacC(128,131) = JacC(128,131) + dw( 73,131)
      JacC(130,102) = JacC(130,102) + dw( 73,102)
      JacC(130,131) = JacC(130,131) + dw( 73,131)
      JacC(131,102) = JacC(131,102) - dw( 73,102)
      JacC(131,131) = JacC(131,131) - dw( 73,131)
      JacC( 30, 30) = JacC( 30, 30) - dw( 74, 30)
      JacC( 30,131) = JacC( 30,131) - dw( 74,131)
      JacC( 95, 30) = JacC( 95, 30) + dw( 74, 30)
      JacC( 95,131) = JacC( 95,131) + dw( 74,131)
      JacC(130, 30) = JacC(130, 30) + dw( 74, 30)
      JacC(130,131) = JacC(130,131) + dw( 74,131)
      JacC(131, 30) = JacC(131, 30) - dw( 74, 30)
      JacC(131,131) = JacC(131,131) - dw( 74,131)
      JacC( 94, 94) = JacC( 94, 94) - dw( 75, 94)
      JacC( 94,131) = JacC( 94,131) - dw( 75,131)
      JacC( 95, 94) = JacC( 95, 94)+ 0.1840000000000000D+00*dw( 75, 94)
      JacC( 95,131) = JacC( 95,131)+ 0.1840000000000000D+00*dw( 75,131)
      JacC(119, 94) = JacC(119, 94)+ 0.7190000000000000D+00*dw( 75, 94)
      JacC(119,131) = JacC(119,131)+ 0.7190000000000000D+00*dw( 75,131)
      JacC(130, 94) = JacC(130, 94) + dw( 75, 94)
      JacC(130,131) = JacC(130,131) + dw( 75,131)
      JacC(131, 94) = JacC(131, 94) - dw( 75, 94)
      JacC(131,131) = JacC(131,131) - dw( 75,131)
      JacC(  6,  6) = JacC(  6,  6) - dw( 76,  6)
      JacC(  6,131) = JacC(  6,131) - dw( 76,131)
      JacC( 86,  6) = JacC( 86,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC( 86,131) = JacC( 86,131)+ 0.3500000000000000D+00*dw( 76,131)
      JacC(108,  6) = JacC(108,  6)+ 0.6500000000000000D+00*dw( 76,  6)
      JacC(108,131) = JacC(108,131)+ 0.6500000000000000D+00*dw( 76,131)
      JacC(113,  6) = JacC(113,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(113,131) = JacC(113,131)+ 0.3500000000000000D+00*dw( 76,131)
      JacC(130,  6) = JacC(130,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(130,131) = JacC(130,131)+ 0.3500000000000000D+00*dw( 76,131)
      JacC(131,  6) = JacC(131,  6)- 0.3500000000000000D+00*dw( 76,  6)
      JacC(131,131) = JacC(131,131)- 0.3500000000000000D+00*dw( 76,131)
      JacC(  8,  8) = JacC(  8,  8) - dw( 77,  8)
      JacC(  8,131) = JacC(  8,131) - dw( 77,131)
      JacC(117,  8) = JacC(117,  8) + dw( 77,  8)
      JacC(117,131) = JacC(117,131) + dw( 77,131)
      JacC(131,  8) = JacC(131,  8) - dw( 77,  8)
      JacC(131,131) = JacC(131,131) - dw( 77,131)
      JacC(  9,  9) = JacC(  9,  9) - dw( 78,  9)
      JacC(  9,131) = JacC(  9,131) - dw( 78,131)
      JacC( 92,  9) = JacC( 92,  9) + dw( 78,  9)
      JacC( 92,131) = JacC( 92,131) + dw( 78,131)
      JacC(131,  9) = JacC(131,  9) - dw( 78,  9)
      JacC(131,131) = JacC(131,131) - dw( 78,131)
      JacC( 10, 10) = JacC( 10, 10) - dw( 79, 10)
      JacC( 10,131) = JacC( 10,131) - dw( 79,131)
      JacC( 17, 10) = JacC( 17, 10)+ 0.4800000000000000D-01*dw( 79, 10)
      JacC( 17,131) = JacC( 17,131)+ 0.4800000000000000D-01*dw( 79,131)
      JacC( 69, 10) = JacC( 69, 10)+ 0.9510000000000000D+00*dw( 79, 10)
      JacC( 69,131) = JacC( 69,131)+ 0.9510000000000000D+00*dw( 79,131)
      JacC( 75, 10) = JacC( 75, 10)+ 0.2400000000000000D-01*dw( 79, 10)
      JacC( 75,131) = JacC( 75,131)+ 0.2400000000000000D-01*dw( 79,131)
      JacC(119, 10) = JacC(119, 10)+ 0.2500000000000000D-01*dw( 79, 10)
      JacC(119,131) = JacC(119,131)+ 0.2500000000000000D-01*dw( 79,131)
      JacC(130, 10) = JacC(130, 10)+ 0.4900000000000000D-01*dw( 79, 10)
      JacC(130,131) = JacC(130,131)+ 0.4900000000000000D-01*dw( 79,131)
      JacC(131, 10) = JacC(131, 10) - dw( 79, 10)
      JacC(131,131) = JacC(131,131) - dw( 79,131)
      JacC( 32, 32) = JacC( 32, 32) - dw( 80, 32)
      JacC( 32,131) = JacC( 32,131) - dw( 80,131)
      JacC( 73, 32) = JacC( 73, 32) + dw( 80, 32)
      JacC( 73,131) = JacC( 73,131) + dw( 80,131)
      JacC(131, 32) = JacC(131, 32) - dw( 80, 32)
      JacC(131,131) = JacC(131,131) - dw( 80,131)
      JacC( 42, 42) = JacC( 42, 42) - dw( 81, 42)
      JacC( 42,131) = JacC( 42,131) - dw( 81,131)
      JacC( 52, 42) = JacC( 52, 42)+ 0.8000000000000000D-02*dw( 81, 42)
      JacC( 52,131) = JacC( 52,131)+ 0.8000000000000000D-02*dw( 81,131)
      JacC( 72, 42) = JacC( 72, 42) + dw( 81, 42)
      JacC( 72,131) = JacC( 72,131) + dw( 81,131)
      JacC(131, 42) = JacC(131, 42) - dw( 81, 42)
      JacC(131,131) = JacC(131,131) - dw( 81,131)
      JacC( 52, 80) = JacC( 52, 80)+ 0.8000000000000000D-02*dw( 82, 80)
      JacC( 52,131) = JacC( 52,131)+ 0.8000000000000000D-02*dw( 82,131)
      JacC( 80, 80) = JacC( 80, 80) - dw( 82, 80)
      JacC( 80,131) = JacC( 80,131) - dw( 82,131)
      JacC(101, 80) = JacC(101, 80) + dw( 82, 80)
      JacC(101,131) = JacC(101,131) + dw( 82,131)
      JacC(131, 80) = JacC(131, 80) - dw( 82, 80)
      JacC(131,131) = JacC(131,131) - dw( 82,131)
      JacC( 29, 29) = JacC( 29, 29) - dw( 83, 29)
      JacC( 29,131) = JacC( 29,131) - dw( 83,131)
      JacC(101, 29) = JacC(101, 29) + dw( 83, 29)
      JacC(101,131) = JacC(101,131) + dw( 83,131)
      JacC(131, 29) = JacC(131, 29) - dw( 83, 29)
      JacC(131,131) = JacC(131,131) - dw( 83,131)
      JacC( 23, 35) = JacC( 23, 35)+ 0.1340000000000000D+00*dw( 84, 35)
      JacC( 23,131) = JacC( 23,131)+ 0.1340000000000000D+00*dw( 84,131)
      JacC( 24, 35) = JacC( 24, 35)+ 0.1440000000000000D-01*dw( 84, 35)
      JacC( 24,131) = JacC( 24,131)+ 0.1440000000000000D-01*dw( 84,131)
      JacC( 35, 35) = JacC( 35, 35) - dw( 84, 35)
      JacC( 35,131) = JacC( 35,131) - dw( 84,131)
      JacC( 83, 35) = JacC( 83, 35) + dw( 84, 35)
      JacC( 83,131) = JacC( 83,131) + dw( 84,131)
      JacC(131, 35) = JacC(131, 35) - dw( 84, 35)
      JacC(131,131) = JacC(131,131) - dw( 84,131)
      JacC( 25, 25) = JacC( 25, 25) - dw( 85, 25)
      JacC( 25,131) = JacC( 25,131) - dw( 85,131)
      JacC( 26, 25) = JacC( 26, 25)+ 0.1920000000000000D-01*dw( 85, 25)
      JacC( 26,131) = JacC( 26,131)+ 0.1920000000000000D-01*dw( 85,131)
      JacC( 27, 25) = JacC( 27, 25)+ 0.1650000000000000D+00*dw( 85, 25)
      JacC( 27,131) = JacC( 27,131)+ 0.1650000000000000D+00*dw( 85,131)
      JacC( 93, 25) = JacC( 93, 25) + dw( 85, 25)
      JacC( 93,131) = JacC( 93,131) + dw( 85,131)
      JacC(131, 25) = JacC(131, 25) - dw( 85, 25)
      JacC(131,131) = JacC(131,131) - dw( 85,131)
      JacC( 36, 36) = JacC( 36, 36) - dw( 86, 36)
      JacC( 36,131) = JacC( 36,131) - dw( 86,131)
      JacC( 37, 36) = JacC( 37, 36)+ 0.1110000000000000D+00*dw( 86, 36)
      JacC( 37,131) = JacC( 37,131)+ 0.1110000000000000D+00*dw( 86,131)
      JacC( 38, 36) = JacC( 38, 36)+ 0.1690000000000000D+00*dw( 86, 36)
      JacC( 38,131) = JacC( 38,131)+ 0.1690000000000000D+00*dw( 86,131)
      JacC( 77, 36) = JacC( 77, 36) + dw( 86, 36)
      JacC( 77,131) = JacC( 77,131) + dw( 86,131)
      JacC(131, 36) = JacC(131, 36) - dw( 86, 36)
      JacC(131,131) = JacC(131,131) - dw( 86,131)
      JacC( 34, 34) = JacC( 34, 34) - dw( 87, 34)
      JacC( 34,131) = JacC( 34,131) - dw( 87,131)
      JacC( 96, 34) = JacC( 96, 34) + dw( 87, 34)
      JacC( 96,131) = JacC( 96,131) + dw( 87,131)
      JacC( 21, 49) = JacC( 21, 49) + dw( 88, 49)
      JacC( 21,131) = JacC( 21,131) + dw( 88,131)
      JacC( 49, 49) = JacC( 49, 49) - dw( 88, 49)
      JacC( 49,131) = JacC( 49,131) - dw( 88,131)
      JacC( 89, 49) = JacC( 89, 49) + dw( 88, 49)
      JacC( 89,131) = JacC( 89,131) + dw( 88,131)
      JacC(131, 49) = JacC(131, 49) - dw( 88, 49)
      JacC(131,131) = JacC(131,131) - dw( 88,131)
      JacC( 39, 39) = JacC( 39, 39) - dw( 89, 39)
      JacC( 39,131) = JacC( 39,131) - dw( 89,131)
      JacC(109, 39) = JacC(109, 39) + dw( 89, 39)
      JacC(109,131) = JacC(109,131) + dw( 89,131)
      JacC(131, 39) = JacC(131, 39) - dw( 89, 39)
      JacC(131,131) = JacC(131,131) - dw( 89,131)
      JacC( 89, 89) = JacC( 89, 89) - dw( 90, 89)
      JacC( 89,131) = JacC( 89,131) - dw( 90,131)
      JacC(110, 89) = JacC(110, 89) + dw( 90, 89)
      JacC(110,131) = JacC(110,131) + dw( 90,131)
      JacC(130, 89) = JacC(130, 89) + dw( 90, 89)
      JacC(130,131) = JacC(130,131) + dw( 90,131)
      JacC(131, 89) = JacC(131, 89) - dw( 90, 89)
      JacC(131,131) = JacC(131,131) - dw( 90,131)
      JacC( 21, 21) = JacC( 21, 21) - dw( 91, 21)
      JacC( 21,131) = JacC( 21,131) - dw( 91,131)
      JacC(113, 21) = JacC(113, 21) + dw( 91, 21)
      JacC(113,131) = JacC(113,131) + dw( 91,131)
      JacC(123, 21) = JacC(123, 21) + dw( 91, 21)
      JacC(123,131) = JacC(123,131) + dw( 91,131)
      JacC(128, 21) = JacC(128, 21) + dw( 91, 21)
      JacC(128,131) = JacC(128,131) + dw( 91,131)
      JacC(131, 21) = JacC(131, 21) - dw( 91, 21)
      JacC(131,131) = JacC(131,131) - dw( 91,131)
      JacC( 33, 33) = JacC( 33, 33) - dw( 92, 33)
      JacC( 33,131) = JacC( 33,131) - dw( 92,131)
      JacC(119, 33) = JacC(119, 33) + dw( 92, 33)
      JacC(119,131) = JacC(119,131) + dw( 92,131)
      JacC(130, 33) = JacC(130, 33) + dw( 92, 33)
      JacC(130,131) = JacC(130,131) + dw( 92,131)
      JacC(131, 33) = JacC(131, 33) - dw( 92, 33)
      JacC(131,131) = JacC(131,131) - dw( 92,131)
      JacC(  7,  7) = JacC(  7,  7) - dw( 93,  7)
      JacC(  7,131) = JacC(  7,131) - dw( 93,131)
      JacC( 22,  7) = JacC( 22,  7)+ 0.5300000000000000D+00*dw( 93,  7)
      JacC( 22,131) = JacC( 22,131)+ 0.5300000000000000D+00*dw( 93,131)
      JacC( 71,  7) = JacC( 71,  7)+ 0.3520000000000000D+00*dw( 93,  7)
      JacC( 71,131) = JacC( 71,131)+ 0.3520000000000000D+00*dw( 93,131)
      JacC( 85,  7) = JacC( 85,  7)+ 0.1180000000000000D+00*dw( 93,  7)
      JacC( 85,131) = JacC( 85,131)+ 0.1180000000000000D+00*dw( 93,131)
      JacC(130,  7) = JacC(130,  7)+ 0.6480000000000000D+00*dw( 93,  7)
      JacC(130,131) = JacC(130,131)+ 0.6480000000000000D+00*dw( 93,131)
      JacC(131,  7) = JacC(131,  7) - dw( 93,  7)
      JacC(131,131) = JacC(131,131) - dw( 93,131)
      JacC( 11, 11) = JacC( 11, 11) - dw( 94, 11)
      JacC( 11,131) = JacC( 11,131) - dw( 94,131)
      JacC( 12, 11) = JacC( 12, 11)+ 0.8900000000000000D+00*dw( 94, 11)
      JacC( 12,131) = JacC( 12,131)+ 0.8900000000000000D+00*dw( 94,131)
      JacC( 57, 11) = JacC( 57, 11)+ 0.6000000000000000D-01*dw( 94, 11)
      JacC( 57,131) = JacC( 57,131)+ 0.6000000000000000D-01*dw( 94,131)
      JacC( 62, 11) = JacC( 62, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC( 62,131) = JacC( 62,131)+ 0.5000000000000000D-01*dw( 94,131)
      JacC(105, 11) = JacC(105, 11)+ 0.2500000000000000D+00*dw( 94, 11)
      JacC(105,131) = JacC(105,131)+ 0.2500000000000000D+00*dw( 94,131)
      JacC(130, 11) = JacC(130, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC(130,131) = JacC(130,131)+ 0.5000000000000000D-01*dw( 94,131)
      JacC(131, 11) = JacC(131, 11) - dw( 94, 11)
      JacC(131,131) = JacC(131,131) - dw( 94,131)
      JacC( 57, 57) = JacC( 57, 57) - dw( 95, 57)
      JacC( 57,125) = JacC( 57,125) - dw( 95,125)
      JacC( 66, 57) = JacC( 66, 57) + dw( 95, 57)
      JacC( 66,125) = JacC( 66,125) + dw( 95,125)
      JacC(123, 57) = JacC(123, 57) + dw( 95, 57)
      JacC(123,125) = JacC(123,125) + dw( 95,125)
      JacC(125, 57) = JacC(125, 57) - dw( 95, 57)
      JacC(125,125) = JacC(125,125) - dw( 95,125)
      JacC( 12, 12) = JacC( 12, 12) - dw( 96, 12)
      JacC( 31, 12) = JacC( 31, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 56, 12) = JacC( 56, 12)+ 0.1500000000000000D+00*dw( 96, 12)
      JacC( 58, 12) = JacC( 58, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 62, 12) = JacC( 62, 12)+ 0.1000000000000000D-01*dw( 96, 12)
      JacC( 68, 12) = JacC( 68, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC(130, 12) = JacC(130, 12)+ 0.2900000000000000D+00*dw( 96, 12)
      JacC(131, 12) = JacC(131, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 56, 58) = JacC( 56, 58)+ 0.5000000000000000D+00*dw( 97, 58)
      JacC( 58, 58) = JacC( 58, 58) - dw( 97, 58)
      JacC( 62, 58) = JacC( 62, 58)+ 0.1000000000000000D-01*dw( 97, 58)
      JacC( 68, 58) = JacC( 68, 58)+ 0.4900000000000000D+00*dw( 97, 58)
      JacC(130, 58) = JacC(130, 58)+ 0.1000000000000000D-01*dw( 97, 58)
      JacC(131, 58) = JacC(131, 58)+ 0.4900000000000000D+00*dw( 97, 58)
      JacC( 58, 58) = JacC( 58, 58) - dw( 98, 58)
      JacC( 58,125) = JacC( 58,125) - dw( 98,125)
      JacC( 68, 58) = JacC( 68, 58)+ 0.9500000000000000D+00*dw( 98, 58)
      JacC( 68,125) = JacC( 68,125)+ 0.9500000000000000D+00*dw( 98,125)
      JacC(118, 58) = JacC(118, 58)+ 0.5000000000000000D-01*dw( 98, 58)
      JacC(118,125) = JacC(118,125)+ 0.5000000000000000D-01*dw( 98,125)
      JacC(123, 58) = JacC(123, 58)+ 0.9500000000000000D+00*dw( 98, 58)
      JacC(123,125) = JacC(123,125)+ 0.9500000000000000D+00*dw( 98,125)
      JacC(125, 58) = JacC(125, 58) - dw( 98, 58)
      JacC(125,125) = JacC(125,125) - dw( 98,125)
      JacC(130, 58) = JacC(130, 58)+ 0.9500000000000000D+00*dw( 98, 58)
      JacC(130,125) = JacC(130,125)+ 0.9500000000000000D+00*dw( 98,125)
      JacC( 56, 56) = JacC( 56, 56) - dw( 99, 56)
      JacC( 56,125) = JacC( 56,125) - dw( 99,125)
      JacC( 76, 56) = JacC( 76, 56)+ 0.9500000000000000D+00*dw( 99, 56)
      JacC( 76,125) = JacC( 76,125)+ 0.9500000000000000D+00*dw( 99,125)
      JacC(110, 56) = JacC(110, 56)+ 0.9500000000000000D+00*dw( 99, 56)
      JacC(110,125) = JacC(110,125)+ 0.9500000000000000D+00*dw( 99,125)
      JacC(118, 56) = JacC(118, 56)+ 0.5000000000000000D-01*dw( 99, 56)
      JacC(118,125) = JacC(118,125)+ 0.5000000000000000D-01*dw( 99,125)
      JacC(123, 56) = JacC(123, 56)+ 0.9500000000000000D+00*dw( 99, 56)
      JacC(123,125) = JacC(123,125)+ 0.9500000000000000D+00*dw( 99,125)
      JacC(125, 56) = JacC(125, 56) - dw( 99, 56)
      JacC(125,125) = JacC(125,125) - dw( 99,125)
      JacC(130, 56) = JacC(130, 56)+ 0.9500000000000000D+00*dw( 99, 56)
      JacC(130,125) = JacC(130,125)+ 0.9500000000000000D+00*dw( 99,125)
      JacC( 15, 15) = JacC( 15, 15) - dw(100, 15)
      JacC( 15,131) = JacC( 15,131) - dw(100,131)
      JacC( 16, 15) = JacC( 16, 15)+ 0.8900000000000000D+00*dw(100, 15)
      JacC( 16,131) = JacC( 16,131)+ 0.8900000000000000D+00*dw(100,131)
      JacC( 59, 15) = JacC( 59, 15)+ 0.6000000000000000D-01*dw(100, 15)
      JacC( 59,131) = JacC( 59,131)+ 0.6000000000000000D-01*dw(100,131)
      JacC( 62, 15) = JacC( 62, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC( 62,131) = JacC( 62,131)+ 0.5000000000000000D-01*dw(100,131)
      JacC(107, 15) = JacC(107, 15)+ 0.2740000000000000D+00*dw(100, 15)
      JacC(107,131) = JacC(107,131)+ 0.2740000000000000D+00*dw(100,131)
      JacC(130, 15) = JacC(130, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC(130,131) = JacC(130,131)+ 0.5000000000000000D-01*dw(100,131)
      JacC(131, 15) = JacC(131, 15) - dw(100, 15)
      JacC(131,131) = JacC(131,131) - dw(100,131)
      JacC( 13, 13) = JacC( 13, 13) - dw(101, 13)
      JacC( 13,131) = JacC( 13,131) - dw(101,131)
      JacC( 14, 13) = JacC( 14, 13)+ 0.8900000000000000D+00*dw(101, 13)
      JacC( 14,131) = JacC( 14,131)+ 0.8900000000000000D+00*dw(101,131)
      JacC( 59, 13) = JacC( 59, 13)+ 0.6000000000000000D-01*dw(101, 13)
      JacC( 59,131) = JacC( 59,131)+ 0.6000000000000000D-01*dw(101,131)
      JacC( 62, 13) = JacC( 62, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC( 62,131) = JacC( 62,131)+ 0.5000000000000000D-01*dw(101,131)
      JacC(106, 13) = JacC(106, 13)+ 0.2740000000000000D+00*dw(101, 13)
      JacC(106,131) = JacC(106,131)+ 0.2740000000000000D+00*dw(101,131)
      JacC(130, 13) = JacC(130, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC(130,131) = JacC(130,131)+ 0.5000000000000000D-01*dw(101,131)
      JacC(131, 13) = JacC(131, 13) - dw(101, 13)
      JacC(131,131) = JacC(131,131) - dw(101,131)
      JacC( 59, 59) = JacC( 59, 59) - dw(102, 59)
      JacC( 59,125) = JacC( 59,125) - dw(102,125)
      JacC( 66, 59) = JacC( 66, 59) + dw(102, 59)
      JacC( 66,125) = JacC( 66,125) + dw(102,125)
      JacC(123, 59) = JacC(123, 59) + dw(102, 59)
      JacC(123,125) = JacC(123,125) + dw(102,125)
      JacC(125, 59) = JacC(125, 59) - dw(102, 59)
      JacC(125,125) = JacC(125,125) - dw(102,125)
      JacC( 14, 14) = JacC( 14, 14) - dw(103, 14)
      JacC( 31, 14) = JacC( 31, 14)+ 0.8400000000000000D+00*dw(103, 14)
      JacC( 60, 14) = JacC( 60, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 61, 14) = JacC( 61, 14)+ 0.1500000000000000D+00*dw(103, 14)
      JacC( 62, 14) = JacC( 62, 14)+ 0.1000000000000000D-01*dw(103, 14)
      JacC( 68, 14) = JacC( 68, 14)+ 0.2240000000000000D+00*dw(103, 14)
      JacC(130, 14) = JacC(130, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC(131, 14) = JacC(131, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 16, 16) = JacC( 16, 16) - dw(104, 16)
      JacC( 31, 16) = JacC( 31, 16)+ 0.8400000000000000D+00*dw(104, 16)
      JacC( 61, 16) = JacC( 61, 16)+ 0.1500000000000000D+00*dw(104, 16)
      JacC( 62, 16) = JacC( 62, 16)+ 0.1000000000000000D-01*dw(104, 16)
      JacC( 65, 16) = JacC( 65, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 68, 16) = JacC( 68, 16)+ 0.2240000000000000D+00*dw(104, 16)
      JacC(130, 16) = JacC(130, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC(131, 16) = JacC(131, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 60, 60) = JacC( 60, 60) - dw(105, 60)
      JacC( 61, 60) = JacC( 61, 60)+ 0.5000000000000000D+00*dw(105, 60)
      JacC( 62, 60) = JacC( 62, 60)+ 0.1000000000000000D-01*dw(105, 60)
      JacC( 68, 60) = JacC( 68, 60)+ 0.4900000000000000D+00*dw(105, 60)
      JacC(130, 60) = JacC(130, 60)+ 0.1000000000000000D-01*dw(105, 60)
      JacC(131, 60) = JacC(131, 60)+ 0.4900000000000000D+00*dw(105, 60)
      JacC( 61, 65) = JacC( 61, 65)+ 0.5000000000000000D+00*dw(106, 65)
      JacC( 62, 65) = JacC( 62, 65)+ 0.1000000000000000D-01*dw(106, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(106, 65)
      JacC( 68, 65) = JacC( 68, 65)+ 0.4900000000000000D+00*dw(106, 65)
      JacC(130, 65) = JacC(130, 65)+ 0.1000000000000000D-01*dw(106, 65)
      JacC(131, 65) = JacC(131, 65)+ 0.4900000000000000D+00*dw(106, 65)
      JacC( 60, 60) = JacC( 60, 60) - dw(107, 60)
      JacC( 60,125) = JacC( 60,125) - dw(107,125)
      JacC( 68, 60) = JacC( 68, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC( 68,125) = JacC( 68,125)+ 0.9500000000000000D+00*dw(107,125)
      JacC(118, 60) = JacC(118, 60)+ 0.5000000000000000D-01*dw(107, 60)
      JacC(118,125) = JacC(118,125)+ 0.5000000000000000D-01*dw(107,125)
      JacC(123, 60) = JacC(123, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC(123,125) = JacC(123,125)+ 0.9500000000000000D+00*dw(107,125)
      JacC(125, 60) = JacC(125, 60) - dw(107, 60)
      JacC(125,125) = JacC(125,125) - dw(107,125)
      JacC(130, 60) = JacC(130, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC(130,125) = JacC(130,125)+ 0.9500000000000000D+00*dw(107,125)
      JacC( 61, 61) = JacC( 61, 61) - dw(108, 61)
      JacC( 61,125) = JacC( 61,125) - dw(108,125)
      JacC( 76, 61) = JacC( 76, 61)+ 0.9500000000000000D+00*dw(108, 61)
      JacC( 76,125) = JacC( 76,125)+ 0.9500000000000000D+00*dw(108,125)
      JacC( 98, 61) = JacC( 98, 61)+ 0.1950000000000000D+01*dw(108, 61)
      JacC( 98,125) = JacC( 98,125)+ 0.1950000000000000D+01*dw(108,125)
      JacC(110, 61) = JacC(110, 61)+ 0.9500000000000000D+00*dw(108, 61)
      JacC(110,125) = JacC(110,125)+ 0.9500000000000000D+00*dw(108,125)
      JacC(118, 61) = JacC(118, 61)+ 0.5000000000000000D-01*dw(108, 61)
      JacC(118,125) = JacC(118,125)+ 0.5000000000000000D-01*dw(108,125)
      JacC(123, 61) = JacC(123, 61)+ 0.9500000000000000D+00*dw(108, 61)
      JacC(123,125) = JacC(123,125)+ 0.9500000000000000D+00*dw(108,125)
      JacC(125, 61) = JacC(125, 61) - dw(108, 61)
      JacC(125,125) = JacC(125,125) - dw(108,125)
      JacC(130, 61) = JacC(130, 61)+ 0.9500000000000000D+00*dw(108, 61)
      JacC(130,125) = JacC(130,125)+ 0.9500000000000000D+00*dw(108,125)
      JacC( 66, 66) = JacC( 66, 66) - dw(109, 66)
      JacC( 66,131) = JacC( 66,131) - dw(109,131)
      JacC( 67, 66) = JacC( 67, 66) + dw(109, 66)
      JacC( 67,131) = JacC( 67,131) + dw(109,131)
      JacC(131, 66) = JacC(131, 66) - dw(109, 66)
      JacC(131,131) = JacC(131,131) - dw(109,131)
      JacC( 54, 67) = JacC( 54, 67) + dw(110, 67)
      JacC( 54,125) = JacC( 54,125) + dw(110,125)
      JacC( 67, 67) = JacC( 67, 67) - dw(110, 67)
      JacC( 67,125) = JacC( 67,125) - dw(110,125)
      JacC(123, 67) = JacC(123, 67) + dw(110, 67)
      JacC(123,125) = JacC(123,125) + dw(110,125)
      JacC(125, 67) = JacC(125, 67) - dw(110, 67)
      JacC(125,125) = JacC(125,125) - dw(110,125)
      JacC( 54, 54) = JacC( 54, 54) - dw(111, 54)
      JacC( 54,125) = JacC( 54,125) - dw(111,125)
      JacC( 55, 54) = JacC( 55, 54) + dw(111, 54)
      JacC( 55,125) = JacC( 55,125) + dw(111,125)
      JacC(123, 54) = JacC(123, 54) + dw(111, 54)
      JacC(123,125) = JacC(123,125) + dw(111,125)
      JacC(125, 54) = JacC(125, 54) - dw(111, 54)
      JacC(125,125) = JacC(125,125) - dw(111,125)
      JacC( 55, 55) = JacC( 55, 55) - dw(112, 55)
      JacC( 55,123) = JacC( 55,123) - dw(112,123)
      JacC(118, 55) = JacC(118, 55) + dw(112, 55)
      JacC(118,123) = JacC(118,123) + dw(112,123)
      JacC(123, 55) = JacC(123, 55) - dw(112, 55)
      JacC(123,123) = JacC(123,123) - dw(112,123)
      JacC( 22, 22) = JacC( 22, 22) - dw(113, 22)
      JacC( 22,131) = JacC( 22,131) - dw(113,131)
      JacC( 40, 22) = JacC( 40, 22)+ 0.7300000000000000D+00*dw(113, 22)
      JacC( 40,131) = JacC( 40,131)+ 0.7300000000000000D+00*dw(113,131)
      JacC( 64, 22) = JacC( 64, 22)+ 0.7000000000000001D-01*dw(113, 22)
      JacC( 64,131) = JacC( 64,131)+ 0.7000000000000001D-01*dw(113,131)
      JacC( 90, 22) = JacC( 90, 22)+ 0.3900000000000000D-01*dw(113, 22)
      JacC( 90,131) = JacC( 90,131)+ 0.3900000000000000D-01*dw(113,131)
      JacC( 91, 22) = JacC( 91, 22)+ 0.1080000000000000D+00*dw(113, 22)
      JacC( 91,131) = JacC( 91,131)+ 0.1080000000000000D+00*dw(113,131)
      JacC(104, 22) = JacC(104, 22)+ 0.2000000000000000D+00*dw(113, 22)
      JacC(104,131) = JacC(104,131)+ 0.2000000000000000D+00*dw(113,131)
      JacC(130, 22) = JacC(130, 22)+ 0.7300000000000000D+00*dw(113, 22)
      JacC(130,131) = JacC(130,131)+ 0.7300000000000000D+00*dw(113,131)
      JacC(131, 22) = JacC(131, 22) - dw(113, 22)
      JacC(131,131) = JacC(131,131) - dw(113,131)
      JacC( 40, 62) = JacC( 40, 62)+ 0.7300000000000000D+00*dw(114, 62)
      JacC( 40,131) = JacC( 40,131)+ 0.7300000000000000D+00*dw(114,131)
      JacC( 62, 62) = JacC( 62, 62) - dw(114, 62)
      JacC( 62,131) = JacC( 62,131) - dw(114,131)
      JacC( 64, 62) = JacC( 64, 62)+ 0.7000000000000001D-01*dw(114, 62)
      JacC( 64,131) = JacC( 64,131)+ 0.7000000000000001D-01*dw(114,131)
      JacC( 90, 62) = JacC( 90, 62)+ 0.3900000000000000D-01*dw(114, 62)
      JacC( 90,131) = JacC( 90,131)+ 0.3900000000000000D-01*dw(114,131)
      JacC( 91, 62) = JacC( 91, 62)+ 0.1080000000000000D+00*dw(114, 62)
      JacC( 91,131) = JacC( 91,131)+ 0.1080000000000000D+00*dw(114,131)
      JacC(104, 62) = JacC(104, 62)+ 0.2000000000000000D+00*dw(114, 62)
      JacC(104,131) = JacC(104,131)+ 0.2000000000000000D+00*dw(114,131)
      JacC(130, 62) = JacC(130, 62)+ 0.7300000000000000D+00*dw(114, 62)
      JacC(130,131) = JacC(130,131)+ 0.7300000000000000D+00*dw(114,131)
      JacC(131, 62) = JacC(131, 62) - dw(114, 62)
      JacC(131,131) = JacC(131,131) - dw(114,131)
      JacC( 40, 40) = JacC( 40, 40) - dw(115, 40)
      JacC( 40,131) = JacC( 40,131) - dw(115,131)
      JacC(100, 40) = JacC(100, 40) + dw(115, 40)
      JacC(100,131) = JacC(100,131) + dw(115,131)
      JacC(131, 40) = JacC(131, 40) - dw(115, 40)
      JacC(131,131) = JacC(131,131) - dw(115,131)
      JacC( 40, 40) = JacC( 40, 40) - dw(116, 40)
      JacC( 40,129) = JacC( 40,129) - dw(116,129)
      JacC(100, 40) = JacC(100, 40) + dw(116, 40)
      JacC(100,129) = JacC(100,129) + dw(116,129)
      JacC(111, 40) = JacC(111, 40) + dw(116, 40)
      JacC(111,129) = JacC(111,129) + dw(116,129)
      JacC(129, 40) = JacC(129, 40) - dw(116, 40)
      JacC(129,129) = JacC(129,129) - dw(116,129)
      JacC( 97,100) = JacC( 97,100) - dw(117,100)
      JacC( 97, 97) = JacC( 97, 97) - dw(117, 97)
      JacC( 99,100) = JacC( 99,100) + dw(117,100)
      JacC( 99, 97) = JacC( 99, 97) + dw(117, 97)
      JacC(100,100) = JacC(100,100) - dw(117,100)
      JacC(100, 97) = JacC(100, 97) - dw(117, 97)
      JacC(100,100) = JacC(100,100) - dw(118,100)
      JacC(100,123) = JacC(100,123) - dw(118,123)
      JacC(118,100) = JacC(118,100) + dw(118,100)
      JacC(118,123) = JacC(118,123) + dw(118,123)
      JacC(123,100) = JacC(123,100) - dw(118,100)
      JacC(123,123) = JacC(123,123) - dw(118,123)
      JacC( 99, 99) = JacC( 99, 99) - dw(119, 99)
      JacC( 99,125) = JacC( 99,125) - dw(119,125)
      JacC(100, 99) = JacC(100, 99) + dw(119, 99)
      JacC(100,125) = JacC(100,125) + dw(119,125)
      JacC(123, 99) = JacC(123, 99) + dw(119, 99)
      JacC(123,125) = JacC(123,125) + dw(119,125)
      JacC(125, 99) = JacC(125, 99) - dw(119, 99)
      JacC(125,125) = JacC(125,125) - dw(119,125)
      JacC( 99, 99) = JacC( 99, 99) - dw(120, 99)
      JacC( 99,122) = JacC( 99,122) - dw(120,122)
      JacC(100, 99) = JacC(100, 99) + dw(120, 99)
      JacC(100,122) = JacC(100,122) + dw(120,122)
      JacC(122, 99) = JacC(122, 99) - dw(120, 99)
      JacC(122,122) = JacC(122,122) - dw(120,122)
      JacC(128, 99) = JacC(128, 99) + dw(120, 99)
      JacC(128,122) = JacC(128,122) + dw(120,122)
      JacC(130, 99) = JacC(130, 99) + dw(120, 99)
      JacC(130,122) = JacC(130,122) + dw(120,122)
      JacC( 99, 99) = JacC( 99, 99) - dw(121, 99)
      JacC( 99,124) = JacC( 99,124) - dw(121,124)
      JacC(100, 99) = JacC(100, 99) + dw(121, 99)
      JacC(100,124) = JacC(100,124) + dw(121,124)
      JacC(122, 99) = JacC(122, 99) + dw(121, 99)
      JacC(122,124) = JacC(122,124) + dw(121,124)
      JacC(124, 99) = JacC(124, 99) - dw(121, 99)
      JacC(124,124) = JacC(124,124) - dw(121,124)
      JacC(130, 99) = JacC(130, 99) + dw(121, 99)
      JacC(130,124) = JacC(130,124) + dw(121,124)
      JacC( 99, 99) = JacC( 99, 99) - dw(122, 99)
      JacC( 99,130) = JacC( 99,130) - dw(122,130)
      JacC(126, 99) = JacC(126, 99) + dw(122, 99)
      JacC(126,130) = JacC(126,130) + dw(122,130)
      JacC(130, 99) = JacC(130, 99) - dw(122, 99)
      JacC(130,130) = JacC(130,130) - dw(122,130)
      JacC( 99, 99) = JacC( 99, 99) - dw(123, 99)
      JacC( 99,129) = JacC( 99,129) - dw(123,129)
      JacC(100, 99) = JacC(100, 99) + dw(123, 99)
      JacC(100,129) = JacC(100,129) + dw(123,129)
      JacC(123, 99) = JacC(123, 99) + dw(123, 99)
      JacC(123,129) = JacC(123,129) + dw(123,129)
      JacC(129, 99) = JacC(129, 99) - dw(123, 99)
      JacC(129,129) = JacC(129,129) - dw(123,129)
      JacC(113,128) = JacC(113,128) + dw(124,128)
      JacC(113,131) = JacC(113,131) + dw(124,131)
      JacC(128,128) = JacC(128,128) - dw(124,128)
      JacC(128,131) = JacC(128,131) - dw(124,131)
      JacC(130,128) = JacC(130,128) + dw(124,128)
      JacC(130,131) = JacC(130,131) + dw(124,131)
      JacC(131,128) = JacC(131,128) - dw(124,128)
      JacC(131,131) = JacC(131,131) - dw(124,131)
      JacC( 95, 95) = JacC( 95, 95) - dw(125, 95)
      JacC( 95,131) = JacC( 95,131) - dw(125,131)
      JacC(124, 95) = JacC(124, 95) + dw(125, 95)
      JacC(124,131) = JacC(124,131) + dw(125,131)
      JacC(131, 95) = JacC(131, 95) - dw(125, 95)
      JacC(131,131) = JacC(131,131) - dw(125,131)
      JacC(119,119) = JacC(119,119) - dw(126,119)
      JacC(119,131) = JacC(119,131) - dw(126,131)
      JacC(120,119) = JacC(120,119) + dw(126,119)
      JacC(120,131) = JacC(120,131) + dw(126,131)
      JacC(131,119) = JacC(131,119) - dw(126,119)
      JacC(131,131) = JacC(131,131) - dw(126,131)
      JacC( 78, 78) = JacC( 78, 78) - dw(127, 78)
      JacC( 78,131) = JacC( 78,131) - dw(127,131)
      JacC( 79, 78) = JacC( 79, 78) + dw(127, 78)
      JacC( 79,131) = JacC( 79,131) + dw(127,131)
      JacC(131, 78) = JacC(131, 78) - dw(127, 78)
      JacC(131,131) = JacC(131,131) - dw(127,131)
      JacC( 41, 41) = JacC( 41, 41) - dw(128, 41)
      JacC( 41,131) = JacC( 41,131) - dw(128,131)
      JacC( 70, 41) = JacC( 70, 41) + dw(128, 41)
      JacC( 70,131) = JacC( 70,131) + dw(128,131)
      JacC(131, 41) = JacC(131, 41) - dw(128, 41)
      JacC(131,131) = JacC(131,131) - dw(128,131)
      JacC(114,116) = JacC(114,116) + dw(129,116)
      JacC(114,131) = JacC(114,131) + dw(129,131)
      JacC(116,116) = JacC(116,116) - dw(129,116)
      JacC(116,131) = JacC(116,131) - dw(129,131)
      JacC(131,116) = JacC(131,116) - dw(129,116)
      JacC(131,131) = JacC(131,131) - dw(129,131)
      JacC( 75, 75) = JacC( 75, 75) - dw(130, 75)
      JacC( 75,131) = JacC( 75,131) - dw(130,131)
      JacC(110, 75) = JacC(110, 75) + dw(130, 75)
      JacC(110,131) = JacC(110,131) + dw(130,131)
      JacC(130, 75) = JacC(130, 75) + dw(130, 75)
      JacC(130,131) = JacC(130,131) + dw(130,131)
      JacC(131, 75) = JacC(131, 75) - dw(130, 75)
      JacC(131,131) = JacC(131,131) - dw(130,131)
      JacC(108,108) = JacC(108,108) - dw(131,108)
      JacC(108,131) = JacC(108,131) - dw(131,131)
      JacC(113,108) = JacC(113,108)+ 0.2000000000000000D+01*dw(131,108)
      JacC(113,131) = JacC(113,131)+ 0.2000000000000000D+01*dw(131,131)
      JacC(130,108) = JacC(130,108) + dw(131,108)
      JacC(130,131) = JacC(130,131) + dw(131,131)
      JacC(131,108) = JacC(131,108) - dw(131,108)
      JacC(131,131) = JacC(131,131) - dw(131,131)
      JacC(110,110) = JacC(110,110) - dw(132,110)
      JacC(110,131) = JacC(110,131) - dw(132,131)
      JacC(113,110) = JacC(113,110) + dw(132,110)
      JacC(113,131) = JacC(113,131) + dw(132,131)
      JacC(124,110) = JacC(124,110) + dw(132,110)
      JacC(124,131) = JacC(124,131) + dw(132,131)
      JacC(131,110) = JacC(131,110) - dw(132,110)
      JacC(131,131) = JacC(131,131) - dw(132,131)
      JacC( 96, 96) = JacC( 96, 96) - dw(133, 96)
      JacC( 96,131) = JacC( 96,131) - dw(133,131)
      JacC(109, 96) = JacC(109, 96) + dw(133, 96)
      JacC(109,131) = JacC(109,131) + dw(133,131)
      JacC(131, 96) = JacC(131, 96) - dw(133, 96)
      JacC(131,131) = JacC(131,131) - dw(133,131)
      JacC( 84, 84) = JacC( 84, 84) - dw(134, 84)
      JacC( 84,131) = JacC( 84,131) - dw(134,131)
      JacC( 88, 84) = JacC( 88, 84) + dw(134, 84)
      JacC( 88,131) = JacC( 88,131) + dw(134,131)
      JacC(131, 84) = JacC(131, 84) - dw(134, 84)
      JacC(131,131) = JacC(131,131) - dw(134,131)
      JacC( 85, 85) = JacC( 85, 85) - dw(135, 85)
      JacC( 85,131) = JacC( 85,131) - dw(135,131)
      JacC( 87, 85) = JacC( 87, 85)+ 0.6870000000000001D+00*dw(135, 85)
      JacC( 87,131) = JacC( 87,131)+ 0.6870000000000001D+00*dw(135,131)
      JacC(124, 85) = JacC(124, 85)+ 0.3130000000000000D+00*dw(135, 85)
      JacC(124,131) = JacC(124,131)+ 0.3130000000000000D+00*dw(135,131)
      JacC(131, 85) = JacC(131, 85) - dw(135, 85)
      JacC(131,131) = JacC(131,131) - dw(135,131)
      JacC( 31, 31) = JacC( 31, 31) - dw(136, 31)
      JacC( 31,131) = JacC( 31,131) - dw(136,131)
      JacC(113, 31) = JacC(113, 31) + dw(136, 31)
      JacC(113,131) = JacC(113,131) + dw(136,131)
      JacC(119, 31) = JacC(119, 31) + dw(136, 31)
      JacC(119,131) = JacC(119,131) + dw(136,131)
      JacC(127, 31) = JacC(127, 31) + dw(136, 31)
      JacC(127,131) = JacC(127,131) + dw(136,131)
      JacC(130, 31) = JacC(130, 31) + dw(136, 31)
      JacC(130,131) = JacC(130,131) + dw(136,131)
      JacC(131, 31) = JacC(131, 31) - dw(136, 31)
      JacC(131,131) = JacC(131,131) - dw(136,131)
      JacC( 68, 68) = JacC( 68, 68) - dw(137, 68)
      JacC( 68,131) = JacC( 68,131) - dw(137,131)
      JacC(119, 68) = JacC(119, 68) + dw(137, 68)
      JacC(119,131) = JacC(119,131) + dw(137,131)
      JacC(124, 68) = JacC(124, 68) + dw(137, 68)
      JacC(124,131) = JacC(124,131) + dw(137,131)
      JacC(127, 68) = JacC(127, 68) + dw(137, 68)
      JacC(127,131) = JacC(127,131) + dw(137,131)
      JacC(131, 68) = JacC(131, 68) - dw(137, 68)
      JacC(131,131) = JacC(131,131) - dw(137,131)
      JacC( 76, 76) = JacC( 76, 76) - dw(138, 76)
      JacC( 76,131) = JacC( 76,131) - dw(138,131)
      JacC(119, 76) = JacC(119, 76) + dw(138, 76)
      JacC(119,131) = JacC(119,131) + dw(138,131)
      JacC(124, 76) = JacC(124, 76) + dw(138, 76)
      JacC(124,131) = JacC(124,131) + dw(138,131)
      JacC(127, 76) = JacC(127, 76) + dw(138, 76)
      JacC(127,131) = JacC(127,131) + dw(138,131)
      JacC(131, 76) = JacC(131, 76) - dw(138, 76)
      JacC(131,131) = JacC(131,131) - dw(138,131)
      JacC( 98, 98) = JacC( 98, 98) - dw(139, 98)
      JacC( 98,131) = JacC( 98,131) - dw(139,131)
      JacC(113, 98) = JacC(113, 98) + dw(139, 98)
      JacC(113,131) = JacC(113,131) + dw(139,131)
      JacC(124, 98) = JacC(124, 98) + dw(139, 98)
      JacC(124,131) = JacC(124,131) + dw(139,131)
      JacC(131, 98) = JacC(131, 98) - dw(139, 98)
      JacC(131,131) = JacC(131,131) - dw(139,131)
      JacC( 45, 45) = JacC( 45, 45) - dw(140, 45)
      JacC( 45,131) = JacC( 45,131) - dw(140,131)
      JacC(122, 45) = JacC(122, 45)+ 0.6500000000000000D+00*dw(140, 45)
      JacC(122,131) = JacC(122,131)+ 0.6500000000000000D+00*dw(140,131)
      JacC(128, 45) = JacC(128, 45)+ 0.3500000000000000D+00*dw(140, 45)
      JacC(128,131) = JacC(128,131)+ 0.3500000000000000D+00*dw(140,131)
      JacC(131, 45) = JacC(131, 45)- 0.6500000000000000D+00*dw(140, 45)
      JacC(131,131) = JacC(131,131)- 0.6500000000000000D+00*dw(140,131)
      JacC(116,126) = JacC(116,126)+ 0.4100000000000000D+00*dw(141,126)
      JacC(116,131) = JacC(116,131)+ 0.4100000000000000D+00*dw(141,131)
      JacC(117,126) = JacC(117,126)+ 0.4400000000000000D+00*dw(141,126)
      JacC(117,131) = JacC(117,131)+ 0.4400000000000000D+00*dw(141,131)
      JacC(119,126) = JacC(119,126)+ 0.8000000000000000D-01*dw(141,126)
      JacC(119,131) = JacC(119,131)+ 0.8000000000000000D-01*dw(141,131)
      JacC(126,126) = JacC(126,126) - dw(141,126)
      JacC(126,131) = JacC(126,131) - dw(141,131)
      JacC(127,126) = JacC(127,126)+ 0.7000000000000001D-01*dw(141,126)
      JacC(127,131) = JacC(127,131)+ 0.7000000000000001D-01*dw(141,131)
      JacC(131,126) = JacC(131,126)- 0.5100000000000000D+00*dw(141,126)
      JacC(131,131) = JacC(131,131)- 0.5100000000000000D+00*dw(141,131)
      JacC( 74, 74) = JacC( 74, 74) - dw(142, 74)
      JacC( 74,131) = JacC( 74,131) - dw(142,131)
      JacC(124, 74) = JacC(124, 74)+ 0.6500000000000000D+00*dw(142, 74)
      JacC(124,131) = JacC(124,131)+ 0.6500000000000000D+00*dw(142,131)
      JacC(127, 74) = JacC(127, 74)+ 0.3500000000000000D+00*dw(142, 74)
      JacC(127,131) = JacC(127,131)+ 0.3500000000000000D+00*dw(142,131)
      JacC(128, 74) = JacC(128, 74)+ 0.3500000000000000D+00*dw(142, 74)
      JacC(128,131) = JacC(128,131)+ 0.3500000000000000D+00*dw(142,131)
      JacC(131, 74) = JacC(131, 74)- 0.6500000000000000D+00*dw(142, 74)
      JacC(131,131) = JacC(131,131)- 0.6500000000000000D+00*dw(142,131)
      JacC( 46, 46) = JacC( 46, 46) - dw(143, 46)
      JacC( 46,131) = JacC( 46,131) - dw(143,131)
      JacC(127, 46) = JacC(127, 46) + dw(143, 46)
      JacC(127,131) = JacC(127,131) + dw(143,131)
      JacC(128, 46) = JacC(128, 46) + dw(143, 46)
      JacC(128,131) = JacC(128,131) + dw(143,131)
      JacC(129, 46) = JacC(129, 46) + dw(143, 46)
      JacC(129,131) = JacC(129,131) + dw(143,131)
      JacC(131, 46) = JacC(131, 46) - dw(143, 46)
      JacC(131,131) = JacC(131,131) - dw(143,131)
      JacC( 47, 47) = JacC( 47, 47) - dw(144, 47)
      JacC( 47,131) = JacC( 47,131) - dw(144,131)
      JacC(127, 47) = JacC(127, 47) + dw(144, 47)
      JacC(127,131) = JacC(127,131) + dw(144,131)
      JacC(128, 47) = JacC(128, 47) + dw(144, 47)
      JacC(128,131) = JacC(128,131) + dw(144,131)
      JacC(129, 47) = JacC(129, 47) + dw(144, 47)
      JacC(129,131) = JacC(129,131) + dw(144,131)
      JacC(131, 47) = JacC(131, 47) - dw(144, 47)
      JacC(131,131) = JacC(131,131) - dw(144,131)
      JacC( 50, 50) = JacC( 50, 50) - dw(145, 50)
      JacC( 50,131) = JacC( 50,131) - dw(145,131)
      JacC( 89, 50) = JacC( 89, 50) + dw(145, 50)
      JacC( 89,131) = JacC( 89,131) + dw(145,131)
      JacC(123, 50) = JacC(123, 50) + dw(145, 50)
      JacC(123,131) = JacC(123,131) + dw(145,131)
      JacC(131, 50) = JacC(131, 50) - dw(145, 50)
      JacC(131,131) = JacC(131,131) - dw(145,131)
      JacC(117,118) = JacC(117,118) + dw(146,118)
      JacC(117,131) = JacC(117,131) + dw(146,131)
      JacC(118,118) = JacC(118,118) - dw(146,118)
      JacC(118,131) = JacC(118,131) - dw(146,131)
      JacC(123,118) = JacC(123,118) + dw(146,118)
      JacC(123,131) = JacC(123,131) + dw(146,131)
      JacC(131,118) = JacC(131,118) - dw(146,118)
      JacC(131,131) = JacC(131,131) - dw(146,131)
      JacC( 86, 86) = JacC( 86, 86) - dw(147, 86)
      JacC( 86,131) = JacC( 86,131) - dw(147,131)
      JacC(130, 86) = JacC(130, 86) + dw(147, 86)
      JacC(130,131) = JacC(130,131) + dw(147,131)
      JacC(131, 86) = JacC(131, 86) - dw(147, 86)
      JacC(131,131) = JacC(131,131) - dw(147,131)
      JacC(112,115) = JacC(112,115)+ 0.3600000000000000D+00*dw(148,115)
      JacC(112,131) = JacC(112,131)+ 0.3600000000000000D+00*dw(148,131)
      JacC(115,115) = JacC(115,115) - dw(148,115)
      JacC(115,131) = JacC(115,131) - dw(148,131)
      JacC(122,115) = JacC(122,115)+ 0.6400000000000000D+00*dw(148,115)
      JacC(122,131) = JacC(122,131)+ 0.6400000000000000D+00*dw(148,131)
      JacC(131,115) = JacC(131,115) - dw(148,115)
      JacC(131,131) = JacC(131,131) - dw(148,131)
      JacC(111,128) = JacC(111,128) + dw(149,128)
      JacC(111,129) = JacC(111,129) + dw(149,129)
      JacC(113,128) = JacC(113,128) + dw(149,128)
      JacC(113,129) = JacC(113,129) + dw(149,129)
      JacC(128,128) = JacC(128,128) - dw(149,128)
      JacC(128,129) = JacC(128,129) - dw(149,129)
      JacC(129,128) = JacC(129,128) - dw(149,128)
      JacC(129,129) = JacC(129,129) - dw(149,129)
      JacC(130,128) = JacC(130,128) + dw(149,128)
      JacC(130,129) = JacC(130,129) + dw(149,129)
      JacC( 95, 95) = JacC( 95, 95) - dw(150, 95)
      JacC( 95,129) = JacC( 95,129) - dw(150,129)
      JacC(111, 95) = JacC(111, 95) + dw(150, 95)
      JacC(111,129) = JacC(111,129) + dw(150,129)
      JacC(124, 95) = JacC(124, 95) + dw(150, 95)
      JacC(124,129) = JacC(124,129) + dw(150,129)
      JacC(129, 95) = JacC(129, 95) - dw(150, 95)
      JacC(129,129) = JacC(129,129) - dw(150,129)
      JacC(111,119) = JacC(111,119) + dw(151,119)
      JacC(111,129) = JacC(111,129) + dw(151,129)
      JacC(119,119) = JacC(119,119) - dw(151,119)
      JacC(119,129) = JacC(119,129) - dw(151,129)
      JacC(120,119) = JacC(120,119) + dw(151,119)
      JacC(120,129) = JacC(120,129) + dw(151,129)
      JacC(129,119) = JacC(129,119) - dw(151,119)
      JacC(129,129) = JacC(129,129) - dw(151,129)
      JacC(108,108) = JacC(108,108) - dw(152,108)
      JacC(108,129) = JacC(108,129) - dw(152,129)
      JacC(111,108) = JacC(111,108) + dw(152,108)
      JacC(111,129) = JacC(111,129) + dw(152,129)
      JacC(113,108) = JacC(113,108)+ 0.2000000000000000D+01*dw(152,108)
      JacC(113,129) = JacC(113,129)+ 0.2000000000000000D+01*dw(152,129)
      JacC(129,108) = JacC(129,108) - dw(152,108)
      JacC(129,129) = JacC(129,129) - dw(152,129)
      JacC(130,108) = JacC(130,108) + dw(152,108)
      JacC(130,129) = JacC(130,129) + dw(152,129)
      JacC(110,110) = JacC(110,110) - dw(153,110)
      JacC(110,129) = JacC(110,129) - dw(153,129)
      JacC(111,110) = JacC(111,110) + dw(153,110)
      JacC(111,129) = JacC(111,129) + dw(153,129)
      JacC(113,110) = JacC(113,110) + dw(153,110)
      JacC(113,129) = JacC(113,129) + dw(153,129)
      JacC(124,110) = JacC(124,110) + dw(153,110)
      JacC(124,129) = JacC(124,129) + dw(153,129)
      JacC(129,110) = JacC(129,110) - dw(153,110)
      JacC(129,129) = JacC(129,129) - dw(153,129)
      JacC( 31, 31) = JacC( 31, 31) - dw(154, 31)
      JacC( 31,129) = JacC( 31,129) - dw(154,129)
      JacC(108, 31) = JacC(108, 31) + dw(154, 31)
      JacC(108,129) = JacC(108,129) + dw(154,129)
      JacC(111, 31) = JacC(111, 31)+ 0.5000000000000000D+00*dw(154, 31)
      JacC(111,129) = JacC(111,129)+ 0.5000000000000000D+00*dw(154,129)
      JacC(113, 31) = JacC(113, 31)+ 0.1500000000000000D+01*dw(154, 31)
      JacC(113,129) = JacC(113,129)+ 0.1500000000000000D+01*dw(154,129)
      JacC(123, 31) = JacC(123, 31)+ 0.5000000000000000D+00*dw(154, 31)
      JacC(123,129) = JacC(123,129)+ 0.5000000000000000D+00*dw(154,129)
      JacC(129, 31) = JacC(129, 31) - dw(154, 31)
      JacC(129,129) = JacC(129,129) - dw(154,129)
      JacC(130, 31) = JacC(130, 31)+ 0.1500000000000000D+01*dw(154, 31)
      JacC(130,129) = JacC(130,129)+ 0.1500000000000000D+01*dw(154,129)
      JacC(131, 31) = JacC(131, 31)+ 0.5000000000000000D+00*dw(154, 31)
      JacC(131,129) = JacC(131,129)+ 0.5000000000000000D+00*dw(154,129)
      JacC( 22, 22) = JacC( 22, 22) - dw(155, 22)
      JacC( 22,129) = JacC( 22,129) - dw(155,129)
      JacC( 63, 22) = JacC( 63, 22)+ 0.5000000000000000D+00*dw(155, 22)
      JacC( 63,129) = JacC( 63,129)+ 0.5000000000000000D+00*dw(155,129)
      JacC( 64, 22) = JacC( 64, 22)+ 0.4000000000000000D+00*dw(155, 22)
      JacC( 64,129) = JacC( 64,129)+ 0.4000000000000000D+00*dw(155,129)
      JacC( 90, 22) = JacC( 90, 22)+ 0.3900000000000000D-01*dw(155, 22)
      JacC( 90,129) = JacC( 90,129)+ 0.3900000000000000D-01*dw(155,129)
      JacC( 91, 22) = JacC( 91, 22)+ 0.1080000000000000D+00*dw(155, 22)
      JacC( 91,129) = JacC( 91,129)+ 0.1080000000000000D+00*dw(155,129)
      JacC(104, 22) = JacC(104, 22)+ 0.1000000000000000D+00*dw(155, 22)
      JacC(104,129) = JacC(104,129)+ 0.1000000000000000D+00*dw(155,129)
      JacC(111, 22) = JacC(111, 22)+ 0.5000000000000000D+00*dw(155, 22)
      JacC(111,129) = JacC(111,129)+ 0.5000000000000000D+00*dw(155,129)
      JacC(129, 22) = JacC(129, 22) - dw(155, 22)
      JacC(129,129) = JacC(129,129) - dw(155,129)
      JacC( 62, 62) = JacC( 62, 62) - dw(156, 62)
      JacC( 62,129) = JacC( 62,129) - dw(156,129)
      JacC( 63, 62) = JacC( 63, 62)+ 0.5000000000000000D+00*dw(156, 62)
      JacC( 63,129) = JacC( 63,129)+ 0.5000000000000000D+00*dw(156,129)
      JacC( 64, 62) = JacC( 64, 62)+ 0.4000000000000000D+00*dw(156, 62)
      JacC( 64,129) = JacC( 64,129)+ 0.4000000000000000D+00*dw(156,129)
      JacC( 90, 62) = JacC( 90, 62)+ 0.3900000000000000D-01*dw(156, 62)
      JacC( 90,129) = JacC( 90,129)+ 0.3900000000000000D-01*dw(156,129)
      JacC( 91, 62) = JacC( 91, 62)+ 0.1080000000000000D+00*dw(156, 62)
      JacC( 91,129) = JacC( 91,129)+ 0.1080000000000000D+00*dw(156,129)
      JacC(104, 62) = JacC(104, 62)+ 0.1000000000000000D+00*dw(156, 62)
      JacC(104,129) = JacC(104,129)+ 0.1000000000000000D+00*dw(156,129)
      JacC(111, 62) = JacC(111, 62)+ 0.5000000000000000D+00*dw(156, 62)
      JacC(111,129) = JacC(111,129)+ 0.5000000000000000D+00*dw(156,129)
      JacC(129, 62) = JacC(129, 62) - dw(156, 62)
      JacC(129,129) = JacC(129,129) - dw(156,129)
      JacC( 63, 63) = JacC( 63, 63) - dw(157, 63)
      JacC( 63,125) = JacC( 63,125) - dw(157,125)
      JacC(108, 63) = JacC(108, 63) + dw(157, 63)
      JacC(108,125) = JacC(108,125) + dw(157,125)
      JacC(123, 63) = JacC(123, 63)+ 0.2000000000000000D+01*dw(157, 63)
      JacC(123,125) = JacC(123,125)+ 0.2000000000000000D+01*dw(157,125)
      JacC(125, 63) = JacC(125, 63) - dw(157, 63)
      JacC(125,125) = JacC(125,125) - dw(157,125)
      JacC(126, 63) = JacC(126, 63) + dw(157, 63)
      JacC(126,125) = JacC(126,125) + dw(157,125)
      JacC( 63, 63) = JacC( 63, 63) - dw(158, 63)
      JacC( 63,129) = JacC( 63,129) - dw(158,129)
      JacC(108, 63) = JacC(108, 63) + dw(158, 63)
      JacC(108,129) = JacC(108,129) + dw(158,129)
      JacC(123, 63) = JacC(123, 63)+ 0.2000000000000000D+01*dw(158, 63)
      JacC(123,129) = JacC(123,129)+ 0.2000000000000000D+01*dw(158,129)
      JacC(126, 63) = JacC(126, 63) + dw(158, 63)
      JacC(126,129) = JacC(126,129) + dw(158,129)
      JacC(129, 63) = JacC(129, 63) - dw(158, 63)
      JacC(129,129) = JacC(129,129) - dw(158,129)
      JacC( 63, 63) = JacC( 63, 63) - dw(159, 63)
      JacC( 63,122) = JacC( 63,122) - dw(159,122)
      JacC(108, 63) = JacC(108, 63)+ 0.7000000000000000D+00*dw(159, 63)
      JacC(108,122) = JacC(108,122)+ 0.7000000000000000D+00*dw(159,122)
      JacC(118, 63) = JacC(118, 63)+ 0.3000000000000000D+00*dw(159, 63)
      JacC(118,122) = JacC(118,122)+ 0.3000000000000000D+00*dw(159,122)
      JacC(122, 63) = JacC(122, 63) - dw(159, 63)
      JacC(122,122) = JacC(122,122) - dw(159,122)
      JacC(123, 63) = JacC(123, 63)+ 0.7000000000000000D+00*dw(159, 63)
      JacC(123,122) = JacC(123,122)+ 0.7000000000000000D+00*dw(159,122)
      JacC(126, 63) = JacC(126, 63)+ 0.7000000000000000D+00*dw(159, 63)
      JacC(126,122) = JacC(126,122)+ 0.7000000000000000D+00*dw(159,122)
      JacC(128, 63) = JacC(128, 63) + dw(159, 63)
      JacC(128,122) = JacC(128,122) + dw(159,122)
      JacC(130, 63) = JacC(130, 63) + dw(159, 63)
      JacC(130,122) = JacC(130,122) + dw(159,122)
      JacC( 63, 63) = JacC( 63, 63) - dw(160, 63)
      JacC( 63,124) = JacC( 63,124) - dw(160,124)
      JacC(108, 63) = JacC(108, 63)+ 0.7000000000000000D+00*dw(160, 63)
      JacC(108,124) = JacC(108,124)+ 0.7000000000000000D+00*dw(160,124)
      JacC(118, 63) = JacC(118, 63)+ 0.3000000000000000D+00*dw(160, 63)
      JacC(118,124) = JacC(118,124)+ 0.3000000000000000D+00*dw(160,124)
      JacC(122, 63) = JacC(122, 63) + dw(160, 63)
      JacC(122,124) = JacC(122,124) + dw(160,124)
      JacC(123, 63) = JacC(123, 63)+ 0.7000000000000000D+00*dw(160, 63)
      JacC(123,124) = JacC(123,124)+ 0.7000000000000000D+00*dw(160,124)
      JacC(124, 63) = JacC(124, 63) - dw(160, 63)
      JacC(124,124) = JacC(124,124) - dw(160,124)
      JacC(126, 63) = JacC(126, 63)+ 0.7000000000000000D+00*dw(160, 63)
      JacC(126,124) = JacC(126,124)+ 0.7000000000000000D+00*dw(160,124)
      JacC(130, 63) = JacC(130, 63) + dw(160, 63)
      JacC(130,124) = JacC(130,124) + dw(160,124)
      JacC( 63, 63) = JacC( 63, 63) - dw(161, 63)
      JacC( 63,130) = JacC( 63,130) - dw(161,130)
      JacC(126, 63) = JacC(126, 63) + dw(161, 63)
      JacC(126,130) = JacC(126,130) + dw(161,130)
      JacC(130, 63) = JacC(130, 63) - dw(161, 63)
      JacC(130,130) = JacC(130,130) - dw(161,130)
      JacC( 32, 32) = JacC( 32, 32) - dw(162, 32)
      JacC( 32,129) = JacC( 32,129) - dw(162,129)
      JacC( 81, 32) = JacC( 81, 32)+ 0.2000000000000000D+00*dw(162, 32)
      JacC( 81,129) = JacC( 81,129)+ 0.2000000000000000D+00*dw(162,129)
      JacC( 82, 32) = JacC( 82, 32)+ 0.8000000000000000D+00*dw(162, 32)
      JacC( 82,129) = JacC( 82,129)+ 0.8000000000000000D+00*dw(162,129)
      JacC(129, 32) = JacC(129, 32) - dw(162, 32)
      JacC(129,129) = JacC(129,129) - dw(162,129)
      JacC( 42, 42) = JacC( 42, 42) - dw(163, 42)
      JacC( 42,129) = JacC( 42,129) - dw(163,129)
      JacC( 52, 42) = JacC( 52, 42)+ 0.8000000000000000D-02*dw(163, 42)
      JacC( 52,129) = JacC( 52,129)+ 0.8000000000000000D-02*dw(163,129)
      JacC( 81, 42) = JacC( 81, 42)+ 0.5700000000000000D+00*dw(163, 42)
      JacC( 81,129) = JacC( 81,129)+ 0.5700000000000000D+00*dw(163,129)
      JacC( 82, 42) = JacC( 82, 42)+ 0.4300000000000000D+00*dw(163, 42)
      JacC( 82,129) = JacC( 82,129)+ 0.4300000000000000D+00*dw(163,129)
      JacC(129, 42) = JacC(129, 42) - dw(163, 42)
      JacC(129,129) = JacC(129,129) - dw(163,129)
      JacC( 52, 80) = JacC( 52, 80)+ 0.8000000000000000D-02*dw(164, 80)
      JacC( 52,129) = JacC( 52,129)+ 0.8000000000000000D-02*dw(164,129)
      JacC( 80, 80) = JacC( 80, 80) - dw(164, 80)
      JacC( 80,129) = JacC( 80,129) - dw(164,129)
      JacC( 81, 80) = JacC( 81, 80)+ 0.8900000000000000D+00*dw(164, 80)
      JacC( 81,129) = JacC( 81,129)+ 0.8900000000000000D+00*dw(164,129)
      JacC( 82, 80) = JacC( 82, 80)+ 0.1100000000000000D+00*dw(164, 80)
      JacC( 82,129) = JacC( 82,129)+ 0.1100000000000000D+00*dw(164,129)
      JacC(129, 80) = JacC(129, 80) - dw(164, 80)
      JacC(129,129) = JacC(129,129) - dw(164,129)
      JacC( 29, 29) = JacC( 29, 29) - dw(165, 29)
      JacC( 29,129) = JacC( 29,129) - dw(165,129)
      JacC( 81, 29) = JacC( 81, 29)+ 0.1000000000000000D+00*dw(165, 29)
      JacC( 81,129) = JacC( 81,129)+ 0.1000000000000000D+00*dw(165,129)
      JacC( 82, 29) = JacC( 82, 29)+ 0.9000000000000000D+00*dw(165, 29)
      JacC( 82,129) = JacC( 82,129)+ 0.9000000000000000D+00*dw(165,129)
      JacC( 96, 29) = JacC( 96, 29)+ 0.9000000000000000D+00*dw(165, 29)
      JacC( 96,129) = JacC( 96,129)+ 0.9000000000000000D+00*dw(165,129)
      JacC(129, 29) = JacC(129, 29) - dw(165, 29)
      JacC(129,129) = JacC(129,129) - dw(165,129)
      JacC( 35, 35) = JacC( 35, 35) - dw(166, 35)
      JacC( 35,129) = JacC( 35,129) - dw(166,129)
      JacC( 49, 35) = JacC( 49, 35) + dw(166, 35)
      JacC( 49,129) = JacC( 49,129) + dw(166,129)
      JacC(129, 35) = JacC(129, 35) - dw(166, 35)
      JacC(129,129) = JacC(129,129) - dw(166,129)
      JacC( 96, 96) = JacC( 96, 96) - dw(167, 96)
      JacC( 96,129) = JacC( 96,129) - dw(167,129)
      JacC(109, 96) = JacC(109, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(109,129) = JacC(109,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC(111, 96) = JacC(111, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(111,129) = JacC(111,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC(113, 96) = JacC(113, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(113,129) = JacC(113,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC(118, 96) = JacC(118, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(118,129) = JacC(118,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC(127, 96) = JacC(127, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(127,129) = JacC(127,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC(129, 96) = JacC(129, 96) - dw(167, 96)
      JacC(129,129) = JacC(129,129) - dw(167,129)
      JacC(130, 96) = JacC(130, 96)+ 0.5000000000000000D+00*dw(167, 96)
      JacC(130,129) = JacC(130,129)+ 0.5000000000000000D+00*dw(167,129)
      JacC( 85, 85) = JacC( 85, 85) - dw(168, 85)
      JacC( 85,129) = JacC( 85,129) - dw(168,129)
      JacC(113, 85) = JacC(113, 85)+ 0.6680000000000000D+00*dw(168, 85)
      JacC(113,129) = JacC(113,129)+ 0.6680000000000000D+00*dw(168,129)
      JacC(118, 85) = JacC(118, 85) + dw(168, 85)
      JacC(118,129) = JacC(118,129) + dw(168,129)
      JacC(119, 85) = JacC(119, 85)+ 0.3320000000000000D+00*dw(168, 85)
      JacC(119,129) = JacC(119,129)+ 0.3320000000000000D+00*dw(168,129)
      JacC(127, 85) = JacC(127, 85) + dw(168, 85)
      JacC(127,129) = JacC(127,129) + dw(168,129)
      JacC(128, 85) = JacC(128, 85)+ 0.3320000000000000D+00*dw(168, 85)
      JacC(128,129) = JacC(128,129)+ 0.3320000000000000D+00*dw(168,129)
      JacC(129, 85) = JacC(129, 85) - dw(168, 85)
      JacC(129,129) = JacC(129,129) - dw(168,129)
      JacC(130, 85) = JacC(130, 85) + dw(168, 85)
      JacC(130,129) = JacC(130,129) + dw(168,129)
      JacC( 25, 25) = JacC( 25, 25) - dw(169, 25)
      JacC( 25,129) = JacC( 25,129) - dw(169,129)
      JacC( 81, 25) = JacC( 81, 25)+ 0.9000000000000000D+00*dw(169, 25)
      JacC( 81,129) = JacC( 81,129)+ 0.9000000000000000D+00*dw(169,129)
      JacC( 82, 25) = JacC( 82, 25)+ 0.1000000000000000D+00*dw(169, 25)
      JacC( 82,129) = JacC( 82,129)+ 0.1000000000000000D+00*dw(169,129)
      JacC(129, 25) = JacC(129, 25) - dw(169, 25)
      JacC(129,129) = JacC(129,129) - dw(169,129)
      JacC( 36, 36) = JacC( 36, 36) - dw(170, 36)
      JacC( 36,129) = JacC( 36,129) - dw(170,129)
      JacC( 81, 36) = JacC( 81, 36)+ 0.8700000000000000D+00*dw(170, 36)
      JacC( 81,129) = JacC( 81,129)+ 0.8700000000000000D+00*dw(170,129)
      JacC( 82, 36) = JacC( 82, 36)+ 0.1300000000000000D+00*dw(170, 36)
      JacC( 82,129) = JacC( 82,129)+ 0.1300000000000000D+00*dw(170,129)
      JacC(129, 36) = JacC(129, 36) - dw(170, 36)
      JacC(129,129) = JacC(129,129) - dw(170,129)
      JacC( 50, 50) = JacC( 50, 50) - dw(171, 50)
      JacC( 50,129) = JacC( 50,129) - dw(171,129)
      JacC(109, 50) = JacC(109, 50) + dw(171, 50)
      JacC(109,129) = JacC(109,129) + dw(171,129)
      JacC(123, 50) = JacC(123, 50) + dw(171, 50)
      JacC(123,129) = JacC(123,129) + dw(171,129)
      JacC(129, 50) = JacC(129, 50) - dw(171, 50)
      JacC(129,129) = JacC(129,129) - dw(171,129)
      JacC( 32, 32) = JacC( 32, 32) - dw(172, 32)
      JacC( 32, 97) = JacC( 32, 97) - dw(172, 97)
      JacC( 86, 32) = JacC( 86, 32)+ 0.3700000000000000D+00*dw(172, 32)
      JacC( 86, 97) = JacC( 86, 97)+ 0.3700000000000000D+00*dw(172, 97)
      JacC( 97, 32) = JacC( 97, 32) - dw(172, 32)
      JacC( 97, 97) = JacC( 97, 97) - dw(172, 97)
      JacC(113, 32) = JacC(113, 32)+ 0.4300000000000000D+00*dw(172, 32)
      JacC(113, 97) = JacC(113, 97)+ 0.4300000000000000D+00*dw(172, 97)
      JacC(128, 32) = JacC(128, 32) + dw(172, 32)
      JacC(128, 97) = JacC(128, 97) + dw(172, 97)
      JacC(130, 32) = JacC(130, 32)+ 0.2600000000000000D+00*dw(172, 32)
      JacC(130, 97) = JacC(130, 97)+ 0.2600000000000000D+00*dw(172, 97)
      JacC(131, 32) = JacC(131, 32)+ 0.1200000000000000D+00*dw(172, 32)
      JacC(131, 97) = JacC(131, 97)+ 0.1200000000000000D+00*dw(172, 97)
      JacC( 42, 42) = JacC( 42, 42) - dw(173, 42)
      JacC( 42, 97) = JacC( 42, 97) - dw(173, 97)
      JacC( 43, 42) = JacC( 43, 42)+ 0.6000000000000000D-01*dw(173, 42)
      JacC( 43, 97) = JacC( 43, 97)+ 0.6000000000000000D-01*dw(173, 97)
      JacC( 44, 42) = JacC( 44, 42)+ 0.3000000000000000D-01*dw(173, 42)
      JacC( 44, 97) = JacC( 44, 97)+ 0.3000000000000000D-01*dw(173, 97)
      JacC( 52, 42) = JacC( 52, 42)+ 0.8000000000000000D-02*dw(173, 42)
      JacC( 52, 97) = JacC( 52, 97)+ 0.8000000000000000D-02*dw(173, 97)
      JacC( 53, 42) = JacC( 53, 42)+ 0.6000000000000000D-02*dw(173, 42)
      JacC( 53, 97) = JacC( 53, 97)+ 0.6000000000000000D-02*dw(173, 97)
      JacC( 86, 42) = JacC( 86, 42)+ 0.1400000000000000D+00*dw(173, 42)
      JacC( 86, 97) = JacC( 86, 97)+ 0.1400000000000000D+00*dw(173, 97)
      JacC( 97, 42) = JacC( 97, 42) - dw(173, 42)
      JacC( 97, 97) = JacC( 97, 97) - dw(173, 97)
      JacC(113, 42) = JacC(113, 42)+ 0.3700000000000000D+00*dw(173, 42)
      JacC(113, 97) = JacC(113, 97)+ 0.3700000000000000D+00*dw(173, 97)
      JacC(114, 42) = JacC(114, 42)+ 0.3000000000000000D-01*dw(173, 42)
      JacC(114, 97) = JacC(114, 97)+ 0.3000000000000000D-01*dw(173, 97)
      JacC(115, 42) = JacC(115, 42)+ 0.1000000000000000D+00*dw(173, 42)
      JacC(115, 97) = JacC(115, 97)+ 0.1000000000000000D+00*dw(173, 97)
      JacC(116, 42) = JacC(116, 42)+ 0.3000000000000000D-01*dw(173, 42)
      JacC(116, 97) = JacC(116, 97)+ 0.3000000000000000D-01*dw(173, 97)
      JacC(119, 42) = JacC(119, 42)+ 0.4400000000000000D+00*dw(173, 42)
      JacC(119, 97) = JacC(119, 97)+ 0.4400000000000000D+00*dw(173, 97)
      JacC(121, 42) = JacC(121, 42)+ 0.1000000000000000D+00*dw(173, 42)
      JacC(121, 97) = JacC(121, 97)+ 0.1000000000000000D+00*dw(173, 97)
      JacC(122, 42) = JacC(122, 42)+ 0.1900000000000000D+00*dw(173, 42)
      JacC(122, 97) = JacC(122, 97)+ 0.1900000000000000D+00*dw(173, 97)
      JacC(128, 42) = JacC(128, 42)+ 0.6400000000000000D+00*dw(173, 42)
      JacC(128, 97) = JacC(128, 97)+ 0.6400000000000000D+00*dw(173, 97)
      JacC(130, 42) = JacC(130, 42)+ 0.2500000000000000D+00*dw(173, 42)
      JacC(130, 97) = JacC(130, 97)+ 0.2500000000000000D+00*dw(173, 97)
      JacC(131, 42) = JacC(131, 42)+ 0.4000000000000000D+00*dw(173, 42)
      JacC(131, 97) = JacC(131, 97)+ 0.4000000000000000D+00*dw(173, 97)
      JacC( 43, 80) = JacC( 43, 80)+ 0.7000000000000001D-01*dw(174, 80)
      JacC( 43, 97) = JacC( 43, 97)+ 0.7000000000000001D-01*dw(174, 97)
      JacC( 44, 80) = JacC( 44, 80)+ 0.6000000000000000D-01*dw(174, 80)
      JacC( 44, 97) = JacC( 44, 97)+ 0.6000000000000000D-01*dw(174, 97)
      JacC( 52, 80) = JacC( 52, 80)+ 0.8000000000000000D-02*dw(174, 80)
      JacC( 52, 97) = JacC( 52, 97)+ 0.8000000000000000D-02*dw(174, 97)
      JacC( 53, 80) = JacC( 53, 80)+ 0.1100000000000000D-01*dw(174, 80)
      JacC( 53, 97) = JacC( 53, 97)+ 0.1100000000000000D-01*dw(174, 97)
      JacC( 80, 80) = JacC( 80, 80) - dw(174, 80)
      JacC( 80, 97) = JacC( 80, 97) - dw(174, 97)
      JacC( 97, 80) = JacC( 97, 80) - dw(174, 80)
      JacC( 97, 97) = JacC( 97, 97) - dw(174, 97)
      JacC(113, 80) = JacC(113, 80)+ 0.3000000000000000D+00*dw(174, 80)
      JacC(113, 97) = JacC(113, 97)+ 0.3000000000000000D+00*dw(174, 97)
      JacC(114, 80) = JacC(114, 80)+ 0.1200000000000000D+00*dw(174, 80)
      JacC(114, 97) = JacC(114, 97)+ 0.1200000000000000D+00*dw(174, 97)
      JacC(115, 80) = JacC(115, 80)+ 0.1400000000000000D+00*dw(174, 80)
      JacC(115, 97) = JacC(115, 97)+ 0.1400000000000000D+00*dw(174, 97)
      JacC(116, 80) = JacC(116, 80)+ 0.1600000000000000D+00*dw(174, 80)
      JacC(116, 97) = JacC(116, 97)+ 0.1600000000000000D+00*dw(174, 97)
      JacC(119, 80) = JacC(119, 80)+ 0.9900000000000000D+00*dw(174, 80)
      JacC(119, 97) = JacC(119, 97)+ 0.9900000000000000D+00*dw(174, 97)
      JacC(121, 80) = JacC(121, 80)+ 0.1800000000000000D+00*dw(174, 80)
      JacC(121, 97) = JacC(121, 97)+ 0.1800000000000000D+00*dw(174, 97)
      JacC(122, 80) = JacC(122, 80)+ 0.2300000000000000D+00*dw(174, 80)
      JacC(122, 97) = JacC(122, 97)+ 0.2300000000000000D+00*dw(174, 97)
      JacC(128, 80) = JacC(128, 80)+ 0.2000000000000000D-01*dw(174, 80)
      JacC(128, 97) = JacC(128, 97)+ 0.2000000000000000D-01*dw(174, 97)
      JacC(130, 80) = JacC(130, 80)+ 0.2200000000000000D+00*dw(174, 80)
      JacC(130, 97) = JacC(130, 97)+ 0.2200000000000000D+00*dw(174, 97)
      JacC(131, 80) = JacC(131, 80)+ 0.6300000000000000D+00*dw(174, 80)
      JacC(131, 97) = JacC(131, 97)+ 0.6300000000000000D+00*dw(174, 97)
      JacC( 29, 29) = JacC( 29, 29) - dw(175, 29)
      JacC( 29, 97) = JacC( 29, 97) - dw(175, 97)
      JacC( 42, 29) = JacC( 42, 29)+ 0.3500000000000000D+00*dw(175, 29)
      JacC( 42, 97) = JacC( 42, 97)+ 0.3500000000000000D+00*dw(175, 97)
      JacC( 51, 29) = JacC( 51, 29)+ 0.9000000000000000D-01*dw(175, 29)
      JacC( 51, 97) = JacC( 51, 97)+ 0.9000000000000000D-01*dw(175, 97)
      JacC( 53, 29) = JacC( 53, 29)+ 0.1000000000000000D-02*dw(175, 29)
      JacC( 53, 97) = JacC( 53, 97)+ 0.1000000000000000D-02*dw(175, 97)
      JacC( 86, 29) = JacC( 86, 29)+ 0.1500000000000000D+00*dw(175, 29)
      JacC( 86, 97) = JacC( 86, 97)+ 0.1500000000000000D+00*dw(175, 97)
      JacC( 96, 29) = JacC( 96, 29)+ 0.3900000000000000D+00*dw(175, 29)
      JacC( 96, 97) = JacC( 96, 97)+ 0.3900000000000000D+00*dw(175, 97)
      JacC( 97, 29) = JacC( 97, 29) - dw(175, 29)
      JacC( 97, 97) = JacC( 97, 97) - dw(175, 97)
      JacC(113, 29) = JacC(113, 29)+ 0.3600000000000000D+00*dw(175, 29)
      JacC(113, 97) = JacC(113, 97)+ 0.3600000000000000D+00*dw(175, 97)
      JacC(114, 29) = JacC(114, 29)+ 0.2000000000000000D-01*dw(175, 29)
      JacC(114, 97) = JacC(114, 97)+ 0.2000000000000000D-01*dw(175, 97)
      JacC(122, 29) = JacC(122, 29)+ 0.3000000000000000D-01*dw(175, 29)
      JacC(122, 97) = JacC(122, 97)+ 0.3000000000000000D-01*dw(175, 97)
      JacC(124, 29) = JacC(124, 29)+ 0.1500000000000000D+00*dw(175, 29)
      JacC(124, 97) = JacC(124, 97)+ 0.1500000000000000D+00*dw(175, 97)
      JacC(127, 29) = JacC(127, 29)+ 0.1300000000000000D+00*dw(175, 29)
      JacC(127, 97) = JacC(127, 97)+ 0.1300000000000000D+00*dw(175, 97)
      JacC(128, 29) = JacC(128, 29)+ 0.9000000000000000D+00*dw(175, 29)
      JacC(128, 97) = JacC(128, 97)+ 0.9000000000000000D+00*dw(175, 97)
      JacC(130, 29) = JacC(130, 29)+ 0.3000000000000000D+00*dw(175, 29)
      JacC(130, 97) = JacC(130, 97)+ 0.3000000000000000D+00*dw(175, 97)
      JacC(131, 29) = JacC(131, 29)+ 0.2800000000000000D+00*dw(175, 29)
      JacC(131, 97) = JacC(131, 97)+ 0.2800000000000000D+00*dw(175, 97)
      JacC( 35, 35) = JacC( 35, 35) - dw(176, 35)
      JacC( 35, 97) = JacC( 35, 97) - dw(176, 97)
      JacC( 53, 35) = JacC( 53, 35)+ 0.9000000000000000D-01*dw(176, 35)
      JacC( 53, 97) = JacC( 53, 97)+ 0.9000000000000000D-01*dw(176, 97)
      JacC( 84, 35) = JacC( 84, 35)+ 0.1890000000000000D+00*dw(176, 35)
      JacC( 84, 97) = JacC( 84, 97)+ 0.1890000000000000D+00*dw(176, 97)
      JacC( 86, 35) = JacC( 86, 35)+ 0.2800000000000000D+00*dw(176, 35)
      JacC( 86, 97) = JacC( 86, 97)+ 0.2800000000000000D+00*dw(176, 97)
      JacC( 96, 35) = JacC( 96, 35)+ 0.4610000000000000D+00*dw(176, 35)
      JacC( 96, 97) = JacC( 96, 97)+ 0.4610000000000000D+00*dw(176, 97)
      JacC( 97, 35) = JacC( 97, 35) - dw(176, 35)
      JacC( 97, 97) = JacC( 97, 97) - dw(176, 97)
      JacC(109, 35) = JacC(109, 35)+ 0.1000000000000000D+00*dw(176, 35)
      JacC(109, 97) = JacC(109, 97)+ 0.1000000000000000D+00*dw(176, 97)
      JacC(113, 35) = JacC(113, 35)+ 0.1400000000000000D+00*dw(176, 35)
      JacC(113, 97) = JacC(113, 97)+ 0.1400000000000000D+00*dw(176, 97)
      JacC(122, 35) = JacC(122, 35)+ 0.8000000000000000D-01*dw(176, 35)
      JacC(122, 97) = JacC(122, 97)+ 0.8000000000000000D-01*dw(176, 97)
      JacC(124, 35) = JacC(124, 35)+ 0.1000000000000000D+00*dw(176, 35)
      JacC(124, 97) = JacC(124, 97)+ 0.1000000000000000D+00*dw(176, 97)
      JacC(128, 35) = JacC(128, 35)+ 0.5800000000000000D+00*dw(176, 35)
      JacC(128, 97) = JacC(128, 97)+ 0.5800000000000000D+00*dw(176, 97)
      JacC(130, 35) = JacC(130, 35)+ 0.2500000000000000D+00*dw(176, 35)
      JacC(130, 97) = JacC(130, 97)+ 0.2500000000000000D+00*dw(176, 97)
      JacC(131, 35) = JacC(131, 35)+ 0.2500000000000000D+00*dw(176, 35)
      JacC(131, 97) = JacC(131, 97)+ 0.2500000000000000D+00*dw(176, 97)
      JacC( 86, 96) = JacC( 86, 96)+ 0.4500000000000000D+00*dw(177, 96)
      JacC( 86, 97) = JacC( 86, 97)+ 0.4500000000000000D+00*dw(177, 97)
      JacC( 96, 96) = JacC( 96, 96) - dw(177, 96)
      JacC( 96, 97) = JacC( 96, 97) - dw(177, 97)
      JacC( 97, 96) = JacC( 97, 96) - dw(177, 96)
      JacC( 97, 97) = JacC( 97, 97) - dw(177, 97)
      JacC(110, 96) = JacC(110, 96)+ 0.9000000000000000D+00*dw(177, 96)
      JacC(110, 97) = JacC(110, 97)+ 0.9000000000000000D+00*dw(177, 97)
      JacC(113, 96) = JacC(113, 96)+ 0.2200000000000000D+00*dw(177, 96)
      JacC(113, 97) = JacC(113, 97)+ 0.2200000000000000D+00*dw(177, 97)
      JacC(124, 96) = JacC(124, 96)+ 0.1000000000000000D+00*dw(177, 96)
      JacC(124, 97) = JacC(124, 97)+ 0.1000000000000000D+00*dw(177, 97)
      JacC(130, 96) = JacC(130, 96)+ 0.3200000000000000D+00*dw(177, 96)
      JacC(130, 97) = JacC(130, 97)+ 0.3200000000000000D+00*dw(177, 97)
      JacC(131, 96) = JacC(131, 96)+ 0.1900000000000000D+00*dw(177, 96)
      JacC(131, 97) = JacC(131, 97)+ 0.1900000000000000D+00*dw(177, 97)
      JacC( 84, 84) = JacC( 84, 84) - dw(178, 84)
      JacC( 84, 97) = JacC( 84, 97) - dw(178, 97)
      JacC( 86, 84) = JacC( 86, 84)+ 0.6700000000000000D+00*dw(178, 84)
      JacC( 86, 97) = JacC( 86, 97)+ 0.6700000000000000D+00*dw(178, 97)
      JacC( 97, 84) = JacC( 97, 84) - dw(178, 84)
      JacC( 97, 97) = JacC( 97, 97) - dw(178, 97)
      JacC(110, 84) = JacC(110, 84)+ 0.9500000000000000D+00*dw(178, 84)
      JacC(110, 97) = JacC(110, 97)+ 0.9500000000000000D+00*dw(178, 97)
      JacC(113, 84) = JacC(113, 84)+ 0.1100000000000000D+00*dw(178, 84)
      JacC(113, 97) = JacC(113, 97)+ 0.1100000000000000D+00*dw(178, 97)
      JacC(124, 84) = JacC(124, 84)+ 0.5000000000000000D-01*dw(178, 84)
      JacC(124, 97) = JacC(124, 97)+ 0.5000000000000000D-01*dw(178, 97)
      JacC(127, 84) = JacC(127, 84)+ 0.5000000000000000D-01*dw(178, 84)
      JacC(127, 97) = JacC(127, 97)+ 0.5000000000000000D-01*dw(178, 97)
      JacC(128, 84) = JacC(128, 84)+ 0.1000000000000000D+00*dw(178, 84)
      JacC(128, 97) = JacC(128, 97)+ 0.1000000000000000D+00*dw(178, 97)
      JacC(130, 84) = JacC(130, 84)+ 0.1100000000000000D+00*dw(178, 84)
      JacC(130, 97) = JacC(130, 97)+ 0.1100000000000000D+00*dw(178, 97)
      JacC(131, 84) = JacC(131, 84)+ 0.1600000000000000D+00*dw(178, 84)
      JacC(131, 97) = JacC(131, 97)+ 0.1600000000000000D+00*dw(178, 97)
      JacC( 85, 85) = JacC( 85, 85) - dw(179, 85)
      JacC( 85, 97) = JacC( 85, 97) - dw(179, 97)
      JacC( 86, 85) = JacC( 86, 85)+ 0.4400000000000000D-01*dw(179, 85)
      JacC( 86, 97) = JacC( 86, 97)+ 0.4400000000000000D-01*dw(179, 97)
      JacC( 97, 85) = JacC( 97, 85) - dw(179, 85)
      JacC( 97, 97) = JacC( 97, 97) - dw(179, 97)
      JacC(108, 85) = JacC(108, 85)+ 0.3100000000000000D-01*dw(179, 85)
      JacC(108, 97) = JacC(108, 97)+ 0.3100000000000000D-01*dw(179, 97)
      JacC(110, 85) = JacC(110, 85)+ 0.6530000000000000D+00*dw(179, 85)
      JacC(110, 97) = JacC(110, 97)+ 0.6530000000000000D+00*dw(179, 97)
      JacC(113, 85) = JacC(113, 85)+ 0.2430000000000000D+00*dw(179, 85)
      JacC(113, 97) = JacC(113, 97)+ 0.2430000000000000D+00*dw(179, 97)
      JacC(116, 85) = JacC(116, 85)+ 0.2780000000000000D+00*dw(179, 85)
      JacC(116, 97) = JacC(116, 97)+ 0.2780000000000000D+00*dw(179, 97)
      JacC(119, 85) = JacC(119, 85)+ 0.6200000000000000D-01*dw(179, 85)
      JacC(119, 97) = JacC(119, 97)+ 0.6200000000000000D-01*dw(179, 97)
      JacC(122, 85) = JacC(122, 85)+ 0.1680000000000000D+00*dw(179, 85)
      JacC(122, 97) = JacC(122, 97)+ 0.1680000000000000D+00*dw(179, 97)
      JacC(124, 85) = JacC(124, 85)+ 0.2370000000000000D+00*dw(179, 85)
      JacC(124, 97) = JacC(124, 97)+ 0.2370000000000000D+00*dw(179, 97)
      JacC(127, 85) = JacC(127, 85)+ 0.1000000000000000D+00*dw(179, 85)
      JacC(127, 97) = JacC(127, 97)+ 0.1000000000000000D+00*dw(179, 97)
      JacC(128, 85) = JacC(128, 85)+ 0.2180000000000000D+00*dw(179, 85)
      JacC(128, 97) = JacC(128, 97)+ 0.2180000000000000D+00*dw(179, 97)
      JacC(130, 85) = JacC(130, 85)+ 0.7199999999999999D-01*dw(179, 85)
      JacC(130, 97) = JacC(130, 97)+ 0.7199999999999999D-01*dw(179, 97)
      JacC(131, 85) = JacC(131, 85)+ 0.4760000000000000D+00*dw(179, 85)
      JacC(131, 97) = JacC(131, 97)+ 0.4760000000000000D+00*dw(179, 97)
      JacC( 25, 25) = JacC( 25, 25) - dw(180, 25)
      JacC( 25, 97) = JacC( 25, 97) - dw(180, 97)
      JacC( 26, 25) = JacC( 26, 25)+ 0.2160000000000000D-01*dw(180, 25)
      JacC( 26, 97) = JacC( 26, 97)+ 0.2160000000000000D-01*dw(180, 97)
      JacC( 27, 25) = JacC( 27, 25)+ 0.1860000000000000D+00*dw(180, 25)
      JacC( 27, 97) = JacC( 27, 97)+ 0.1860000000000000D+00*dw(180, 97)
      JacC( 53, 25) = JacC( 53, 25)+ 0.2000000000000000D-01*dw(180, 25)
      JacC( 53, 97) = JacC( 53, 97)+ 0.2000000000000000D-01*dw(180, 97)
      JacC( 97, 25) = JacC( 97, 25) - dw(180, 25)
      JacC( 97, 97) = JacC( 97, 97) - dw(180, 97)
      JacC(113, 25) = JacC(113, 25)+ 0.1400000000000000D+00*dw(180, 25)
      JacC(113, 97) = JacC(113, 97)+ 0.1400000000000000D+00*dw(180, 97)
      JacC(114, 25) = JacC(114, 25)+ 0.4200000000000000D+00*dw(180, 25)
      JacC(114, 97) = JacC(114, 97)+ 0.4200000000000000D+00*dw(180, 97)
      JacC(116, 25) = JacC(116, 25)+ 0.5300000000000000D+00*dw(180, 25)
      JacC(116, 97) = JacC(116, 97)+ 0.5300000000000000D+00*dw(180, 97)
      JacC(119, 25) = JacC(119, 25)+ 0.6500000000000000D+00*dw(180, 25)
      JacC(119, 97) = JacC(119, 97)+ 0.6500000000000000D+00*dw(180, 97)
      JacC(121, 25) = JacC(121, 25)+ 0.2000000000000000D+00*dw(180, 25)
      JacC(121, 97) = JacC(121, 97)+ 0.2000000000000000D+00*dw(180, 97)
      JacC(130, 25) = JacC(130, 25)+ 0.1000000000000000D+00*dw(180, 25)
      JacC(130, 97) = JacC(130, 97)+ 0.1000000000000000D+00*dw(180, 97)
      JacC(131, 25) = JacC(131, 25)+ 0.8500000000000000D+00*dw(180, 25)
      JacC(131, 97) = JacC(131, 97)+ 0.8500000000000000D+00*dw(180, 97)
      JacC( 36, 36) = JacC( 36, 36) - dw(181, 36)
      JacC( 36, 97) = JacC( 36, 97) - dw(181, 97)
      JacC( 37, 36) = JacC( 37, 36)+ 0.1260000000000000D+00*dw(181, 36)
      JacC( 37, 97) = JacC( 37, 97)+ 0.1260000000000000D+00*dw(181, 97)
      JacC( 38, 36) = JacC( 38, 36)+ 0.1910000000000000D+00*dw(181, 36)
      JacC( 38, 97) = JacC( 38, 97)+ 0.1910000000000000D+00*dw(181, 97)
      JacC( 42, 36) = JacC( 42, 36)+ 0.4600000000000000D+00*dw(181, 36)
      JacC( 42, 97) = JacC( 42, 97)+ 0.4600000000000000D+00*dw(181, 97)
      JacC( 53, 36) = JacC( 53, 36)+ 0.2000000000000000D-01*dw(181, 36)
      JacC( 53, 97) = JacC( 53, 97)+ 0.2000000000000000D-01*dw(181, 97)
      JacC( 86, 36) = JacC( 86, 36)+ 0.1000000000000000D-01*dw(181, 36)
      JacC( 86, 97) = JacC( 86, 97)+ 0.1000000000000000D-01*dw(181, 97)
      JacC( 96, 36) = JacC( 96, 36)+ 0.7900000000000000D+00*dw(181, 36)
      JacC( 96, 97) = JacC( 96, 97)+ 0.7900000000000000D+00*dw(181, 97)
      JacC( 97, 36) = JacC( 97, 36) - dw(181, 36)
      JacC( 97, 97) = JacC( 97, 97) - dw(181, 97)
      JacC(113, 36) = JacC(113, 36)+ 0.1400000000000000D+00*dw(181, 36)
      JacC(113, 97) = JacC(113, 97)+ 0.1400000000000000D+00*dw(181, 97)
      JacC(114, 36) = JacC(114, 36)+ 0.4200000000000000D+00*dw(181, 36)
      JacC(114, 97) = JacC(114, 97)+ 0.4200000000000000D+00*dw(181, 97)
      JacC(115, 36) = JacC(115, 36)+ 0.7000000000000001D-01*dw(181, 36)
      JacC(115, 97) = JacC(115, 97)+ 0.7000000000000001D-01*dw(181, 97)
      JacC(121, 36) = JacC(121, 36)+ 0.1600000000000000D+00*dw(181, 36)
      JacC(121, 97) = JacC(121, 97)+ 0.1600000000000000D+00*dw(181, 97)
      JacC(128, 36) = JacC(128, 36)+ 0.4000000000000000D-01*dw(181, 36)
      JacC(128, 97) = JacC(128, 97)+ 0.4000000000000000D-01*dw(181, 97)
      JacC(130, 36) = JacC(130, 36)+ 0.1000000000000000D+00*dw(181, 36)
      JacC(130, 97) = JacC(130, 97)+ 0.1000000000000000D+00*dw(181, 97)
      JacC(131, 36) = JacC(131, 36)+ 0.8500000000000000D+00*dw(181, 36)
      JacC(131, 97) = JacC(131, 97)+ 0.8500000000000000D+00*dw(181, 97)
      JacC( 31, 31) = JacC( 31, 31) - dw(182, 31)
      JacC( 31, 97) = JacC( 31, 97) - dw(182, 97)
      JacC( 97, 31) = JacC( 97, 31) - dw(182, 31)
      JacC( 97, 97) = JacC( 97, 97) - dw(182, 97)
      JacC(108, 31) = JacC(108, 31) + dw(182, 31)
      JacC(108, 97) = JacC(108, 97) + dw(182, 97)
      JacC(113, 31) = JacC(113, 31)+ 0.1500000000000000D+01*dw(182, 31)
      JacC(113, 97) = JacC(113, 97)+ 0.1500000000000000D+01*dw(182, 97)
      JacC(130, 31) = JacC(130, 31)+ 0.1500000000000000D+01*dw(182, 31)
      JacC(130, 97) = JacC(130, 97)+ 0.1500000000000000D+01*dw(182, 97)
      JacC(131, 31) = JacC(131, 31)+ 0.5000000000000000D+00*dw(182, 31)
      JacC(131, 97) = JacC(131, 97)+ 0.5000000000000000D+00*dw(182, 97)
      JacC( 74, 98) = JacC( 74, 98)+ 0.1100000000000000D+00*dw(183, 98)
      JacC( 74, 97) = JacC( 74, 97)+ 0.1100000000000000D+00*dw(183, 97)
      JacC( 86, 98) = JacC( 86, 98)+ 0.2500000000000000D+00*dw(183, 98)
      JacC( 86, 97) = JacC( 86, 97)+ 0.2500000000000000D+00*dw(183, 97)
      JacC( 97, 98) = JacC( 97, 98) - dw(183, 98)
      JacC( 97, 97) = JacC( 97, 97) - dw(183, 97)
      JacC( 98, 98) = JacC( 98, 98) - dw(183, 98)
      JacC( 98, 97) = JacC( 98, 97) - dw(183, 97)
      JacC(110, 98) = JacC(110, 98)+ 0.2480000000000000D+01*dw(183, 98)
      JacC(110, 97) = JacC(110, 97)+ 0.2480000000000000D+01*dw(183, 97)
      JacC(113, 98) = JacC(113, 98)+ 0.1500000000000000D+01*dw(183, 98)
      JacC(113, 97) = JacC(113, 97)+ 0.1500000000000000D+01*dw(183, 97)
      JacC(115, 98) = JacC(115, 98)+ 0.2500000000000000D+00*dw(183, 98)
      JacC(115, 97) = JacC(115, 97)+ 0.2500000000000000D+00*dw(183, 97)
      JacC(130, 98) = JacC(130, 98) + dw(183, 98)
      JacC(130, 97) = JacC(130, 97) + dw(183, 97)
      JacC(131, 98) = JacC(131, 98)+ 0.5000000000000000D+00*dw(183, 98)
      JacC(131, 97) = JacC(131, 97)+ 0.5000000000000000D+00*dw(183, 97)
      JacC( 64, 64) = JacC( 64, 64) - dw(184, 64)
      JacC( 64,123) = JacC( 64,123) - dw(184,123)
      JacC(118, 64) = JacC(118, 64) + dw(184, 64)
      JacC(118,123) = JacC(118,123) + dw(184,123)
      JacC(123, 64) = JacC(123, 64) - dw(184, 64)
      JacC(123,123) = JacC(123,123) - dw(184,123)
      JacC( 46,124) = JacC( 46,124) + dw(185,124)
      JacC( 46,123) = JacC( 46,123) + dw(185,123)
      JacC(123,124) = JacC(123,124) - dw(185,124)
      JacC(123,123) = JacC(123,123) - dw(185,123)
      JacC(124,124) = JacC(124,124) - dw(185,124)
      JacC(124,123) = JacC(124,123) - dw(185,123)
      JacC( 47,120) = JacC( 47,120) + dw(186,120)
      JacC( 47,123) = JacC( 47,123) + dw(186,123)
      JacC(120,120) = JacC(120,120) - dw(186,120)
      JacC(120,123) = JacC(120,123) - dw(186,123)
      JacC(123,120) = JacC(123,120) - dw(186,120)
      JacC(123,123) = JacC(123,123) - dw(186,123)
      JacC( 46, 46) = JacC( 46, 46) - dw(187, 46)
      JacC(123, 46) = JacC(123, 46) + dw(187, 46)
      JacC(124, 46) = JacC(124, 46) + dw(187, 46)
      JacC( 47, 47) = JacC( 47, 47) - dw(188, 47)
      JacC(120, 47) = JacC(120, 47) + dw(188, 47)
      JacC(123, 47) = JacC(123, 47) + dw(188, 47)
      JacC( 50,109) = JacC( 50,109) + dw(189,109)
      JacC( 50,123) = JacC( 50,123) + dw(189,123)
      JacC(109,109) = JacC(109,109) - dw(189,109)
      JacC(109,123) = JacC(109,123) - dw(189,123)
      JacC(123,109) = JacC(123,109) - dw(189,109)
      JacC(123,123) = JacC(123,123) - dw(189,123)
      JacC( 50, 50) = JacC( 50, 50) - dw(190, 50)
      JacC(109, 50) = JacC(109, 50) + dw(190, 50)
      JacC(123, 50) = JacC(123, 50) + dw(190, 50)
      JacC(122,122) = JacC(122,122) - dw(191,122)
      JacC(122,125) = JacC(122,125) - dw(191,125)
      JacC(123,122) = JacC(123,122) + dw(191,122)
      JacC(123,125) = JacC(123,125) + dw(191,125)
      JacC(125,122) = JacC(125,122) - dw(191,122)
      JacC(125,125) = JacC(125,125) - dw(191,125)
      JacC(128,122) = JacC(128,122) + dw(191,122)
      JacC(128,125) = JacC(128,125) + dw(191,125)
      JacC(130,122) = JacC(130,122) + dw(191,122)
      JacC(130,125) = JacC(130,125) + dw(191,125)
      JacC( 95,121) = JacC( 95,121) + dw(192,121)
      JacC( 95,125) = JacC( 95,125) + dw(192,125)
      JacC(121,121) = JacC(121,121) - dw(192,121)
      JacC(121,125) = JacC(121,125) - dw(192,125)
      JacC(123,121) = JacC(123,121) + dw(192,121)
      JacC(123,125) = JacC(123,125) + dw(192,125)
      JacC(125,121) = JacC(125,121) - dw(192,121)
      JacC(125,125) = JacC(125,125) - dw(192,125)
      JacC(130,121) = JacC(130,121) + dw(192,121)
      JacC(130,125) = JacC(130,125) + dw(192,125)
      JacC( 78,117) = JacC( 78,117)+ 0.6230000000000000D+00*dw(193,117)
      JacC( 78,125) = JacC( 78,125)+ 0.6230000000000000D+00*dw(193,125)
      JacC(108,117) = JacC(108,117)+ 0.6300000000000000D-01*dw(193,117)
      JacC(108,125) = JacC(108,125)+ 0.6300000000000000D-01*dw(193,125)
      JacC(117,117) = JacC(117,117) - dw(193,117)
      JacC(117,125) = JacC(117,125) - dw(193,125)
      JacC(118,117) = JacC(118,117)+ 0.5900000000000000D-01*dw(193,117)
      JacC(118,125) = JacC(118,125)+ 0.5900000000000000D-01*dw(193,125)
      JacC(119,117) = JacC(119,117)+ 0.2330000000000000D+00*dw(193,117)
      JacC(119,125) = JacC(119,125)+ 0.2330000000000000D+00*dw(193,125)
      JacC(121,117) = JacC(121,117)+ 0.4800000000000000D-01*dw(193,117)
      JacC(121,125) = JacC(121,125)+ 0.4800000000000000D-01*dw(193,125)
      JacC(122,117) = JacC(122,117)+ 0.1500000000000000D+00*dw(193,117)
      JacC(122,125) = JacC(122,125)+ 0.1500000000000000D+00*dw(193,125)
      JacC(123,117) = JacC(123,117)+ 0.9409999999999999D+00*dw(193,117)
      JacC(123,125) = JacC(123,125)+ 0.9409999999999999D+00*dw(193,125)
      JacC(125,117) = JacC(125,117) - dw(193,117)
      JacC(125,125) = JacC(125,125) - dw(193,125)
      JacC(127,117) = JacC(127,117)+ 0.4800000000000000D-01*dw(193,117)
      JacC(127,125) = JacC(127,125)+ 0.4800000000000000D-01*dw(193,125)
      JacC(128,117) = JacC(128,117)+ 0.4700000000000000D-01*dw(193,117)
      JacC(128,125) = JacC(128,125)+ 0.4700000000000000D-01*dw(193,125)
      JacC(130,117) = JacC(130,117)+ 0.7420000000000000D+00*dw(193,117)
      JacC(130,125) = JacC(130,125)+ 0.7420000000000000D+00*dw(193,125)
      JacC( 41, 92) = JacC( 41, 92)+ 0.1220000000000000D+00*dw(194, 92)
      JacC( 41,125) = JacC( 41,125)+ 0.1220000000000000D+00*dw(194,125)
      JacC( 78, 92) = JacC( 78, 92)+ 0.1000000000000000D+00*dw(194, 92)
      JacC( 78,125) = JacC( 78,125)+ 0.1000000000000000D+00*dw(194,125)
      JacC( 92, 92) = JacC( 92, 92) - dw(194, 92)
      JacC( 92,125) = JacC( 92,125) - dw(194,125)
      JacC(116, 92) = JacC(116, 92)+ 0.5000000000000000D+00*dw(194, 92)
      JacC(116,125) = JacC(116,125)+ 0.5000000000000000D+00*dw(194,125)
      JacC(118, 92) = JacC(118, 92)+ 0.1240000000000000D+00*dw(194, 92)
      JacC(118,125) = JacC(118,125)+ 0.1240000000000000D+00*dw(194,125)
      JacC(119, 92) = JacC(119, 92)+ 0.2110000000000000D+00*dw(194, 92)
      JacC(119,125) = JacC(119,125)+ 0.2110000000000000D+00*dw(194,125)
      JacC(121, 92) = JacC(121, 92)+ 0.2450000000000000D+00*dw(194, 92)
      JacC(121,125) = JacC(121,125)+ 0.2450000000000000D+00*dw(194,125)
      JacC(122, 92) = JacC(122, 92)+ 0.3100000000000000D-01*dw(194, 92)
      JacC(122,125) = JacC(122,125)+ 0.3100000000000000D-01*dw(194,125)
      JacC(123, 92) = JacC(123, 92)+ 0.8760000000000000D+00*dw(194, 92)
      JacC(123,125) = JacC(123,125)+ 0.8760000000000000D+00*dw(194,125)
      JacC(125, 92) = JacC(125, 92) - dw(194, 92)
      JacC(125,125) = JacC(125,125) - dw(194,125)
      JacC(127, 92) = JacC(127, 92)+ 0.3340000000000000D+00*dw(194, 92)
      JacC(127,125) = JacC(127,125)+ 0.3340000000000000D+00*dw(194,125)
      JacC(128, 92) = JacC(128, 92)+ 0.2100000000000000D-01*dw(194, 92)
      JacC(128,125) = JacC(128,125)+ 0.2100000000000000D-01*dw(194,125)
      JacC(130, 92) = JacC(130, 92)+ 0.5990000000000000D+00*dw(194, 92)
      JacC(130,125) = JacC(130,125)+ 0.5990000000000000D+00*dw(194,125)
      JacC( 69, 69) = JacC( 69, 69) - dw(195, 69)
      JacC( 69,125) = JacC( 69,125) - dw(195,125)
      JacC(116, 69) = JacC(116, 69)+ 0.6420000000000000D+00*dw(195, 69)
      JacC(116,125) = JacC(116,125)+ 0.6420000000000000D+00*dw(195,125)
      JacC(118, 69) = JacC(118, 69)+ 0.2610000000000000D+00*dw(195, 69)
      JacC(118,125) = JacC(118,125)+ 0.2610000000000000D+00*dw(195,125)
      JacC(119, 69) = JacC(119, 69)+ 0.1500000000000000D+00*dw(195, 69)
      JacC(119,125) = JacC(119,125)+ 0.1500000000000000D+00*dw(195,125)
      JacC(121, 69) = JacC(121, 69)+ 0.1330000000000000D+00*dw(195, 69)
      JacC(121,125) = JacC(121,125)+ 0.1330000000000000D+00*dw(195,125)
      JacC(123, 69) = JacC(123, 69)+ 0.7390000000000000D+00*dw(195, 69)
      JacC(123,125) = JacC(123,125)+ 0.7390000000000000D+00*dw(195,125)
      JacC(125, 69) = JacC(125, 69) - dw(195, 69)
      JacC(125,125) = JacC(125,125) - dw(195,125)
      JacC(127, 69) = JacC(127, 69)+ 0.4160000000000000D+00*dw(195, 69)
      JacC(127,125) = JacC(127,125)+ 0.4160000000000000D+00*dw(195,125)
      JacC(130, 69) = JacC(130, 69)+ 0.6060000000000000D+00*dw(195, 69)
      JacC(130,125) = JacC(130,125)+ 0.6060000000000000D+00*dw(195,125)
      JacC( 73, 73) = JacC( 73, 73) - dw(196, 73)
      JacC( 73,125) = JacC( 73,125) - dw(196,125)
      JacC(119, 73) = JacC(119, 73)+ 0.2000000000000000D+00*dw(196, 73)
      JacC(119,125) = JacC(119,125)+ 0.2000000000000000D+00*dw(196,125)
      JacC(123, 73) = JacC(123, 73) + dw(196, 73)
      JacC(123,125) = JacC(123,125) + dw(196,125)
      JacC(125, 73) = JacC(125, 73) - dw(196, 73)
      JacC(125,125) = JacC(125,125) - dw(196,125)
      JacC(128, 73) = JacC(128, 73)+ 0.1600000000000000D+01*dw(196, 73)
      JacC(128,125) = JacC(128,125)+ 0.1600000000000000D+01*dw(196,125)
      JacC(130, 73) = JacC(130, 73) + dw(196, 73)
      JacC(130,125) = JacC(130,125) + dw(196,125)
      JacC( 72, 72) = JacC( 72, 72) - dw(197, 72)
      JacC( 72,125) = JacC( 72,125) - dw(197,125)
      JacC(116, 72) = JacC(116, 72)+ 0.6000000000000000D-01*dw(197, 72)
      JacC(116,125) = JacC(116,125)+ 0.6000000000000000D-01*dw(197,125)
      JacC(119, 72) = JacC(119, 72)+ 0.9399999999999999D+00*dw(197, 72)
      JacC(119,125) = JacC(119,125)+ 0.9399999999999999D+00*dw(197,125)
      JacC(123, 72) = JacC(123, 72) + dw(197, 72)
      JacC(123,125) = JacC(123,125) + dw(197,125)
      JacC(125, 72) = JacC(125, 72) - dw(197, 72)
      JacC(125,125) = JacC(125,125) - dw(197,125)
      JacC(128, 72) = JacC(128, 72) + dw(197, 72)
      JacC(128,125) = JacC(128,125) + dw(197,125)
      JacC(130, 72) = JacC(130, 72) + dw(197, 72)
      JacC(130,125) = JacC(130,125) + dw(197,125)
      JacC(101,101) = JacC(101,101) - dw(198,101)
      JacC(101,125) = JacC(101,125) - dw(198,125)
      JacC(116,101) = JacC(116,101)+ 0.2900000000000000D+00*dw(198,101)
      JacC(116,125) = JacC(116,125)+ 0.2900000000000000D+00*dw(198,125)
      JacC(119,101) = JacC(119,101)+ 0.1710000000000000D+01*dw(198,101)
      JacC(119,125) = JacC(119,125)+ 0.1710000000000000D+01*dw(198,125)
      JacC(123,101) = JacC(123,101) + dw(198,101)
      JacC(123,125) = JacC(123,125) + dw(198,125)
      JacC(125,101) = JacC(125,101) - dw(198,101)
      JacC(125,125) = JacC(125,125) - dw(198,125)
      JacC(130,101) = JacC(130,101) + dw(198,101)
      JacC(130,125) = JacC(130,125) + dw(198,125)
      JacC( 49, 83) = JacC( 49, 83)+ 0.4600000000000000D-01*dw(199, 83)
      JacC( 49,125) = JacC( 49,125)+ 0.4600000000000000D-01*dw(199,125)
      JacC( 83, 83) = JacC( 83, 83) - dw(199, 83)
      JacC( 83,125) = JacC( 83,125) - dw(199,125)
      JacC( 84, 83) = JacC( 84, 83)+ 0.5820000000000000D+00*dw(199, 83)
      JacC( 84,125) = JacC( 84,125)+ 0.5820000000000000D+00*dw(199,125)
      JacC( 96, 83) = JacC( 96, 83)+ 0.4180000000000000D+00*dw(199, 83)
      JacC( 96,125) = JacC( 96,125)+ 0.4180000000000000D+00*dw(199,125)
      JacC(123, 83) = JacC(123, 83)+ 0.9540000000000000D+00*dw(199, 83)
      JacC(123,125) = JacC(123,125)+ 0.9540000000000000D+00*dw(199,125)
      JacC(125, 83) = JacC(125, 83) - dw(199, 83)
      JacC(125,125) = JacC(125,125) - dw(199,125)
      JacC(128, 83) = JacC(128, 83) + dw(199, 83)
      JacC(128,125) = JacC(128,125) + dw(199,125)
      JacC(130, 83) = JacC(130, 83)+ 0.9540000000000000D+00*dw(199, 83)
      JacC(130,125) = JacC(130,125)+ 0.9540000000000000D+00*dw(199,125)
      JacC( 89,109) = JacC( 89,109)+ 0.2500000000000000D+00*dw(200,109)
      JacC( 89,125) = JacC( 89,125)+ 0.2500000000000000D+00*dw(200,125)
      JacC(109,109) = JacC(109,109) - dw(200,109)
      JacC(109,125) = JacC(109,125) - dw(200,125)
      JacC(110,109) = JacC(110,109)+ 0.5000000000000000D+00*dw(200,109)
      JacC(110,125) = JacC(110,125)+ 0.5000000000000000D+00*dw(200,125)
      JacC(113,109) = JacC(113,109)+ 0.2500000000000000D+00*dw(200,109)
      JacC(113,125) = JacC(113,125)+ 0.2500000000000000D+00*dw(200,125)
      JacC(123,109) = JacC(123,109) + dw(200,109)
      JacC(123,125) = JacC(123,125) + dw(200,125)
      JacC(124,109) = JacC(124,109)+ 0.2500000000000000D+00*dw(200,109)
      JacC(124,125) = JacC(124,125)+ 0.2500000000000000D+00*dw(200,125)
      JacC(125,109) = JacC(125,109) - dw(200,109)
      JacC(125,125) = JacC(125,125) - dw(200,125)
      JacC(128,109) = JacC(128,109)+ 0.7500000000000000D+00*dw(200,109)
      JacC(128,125) = JacC(128,125)+ 0.7500000000000000D+00*dw(200,125)
      JacC(130,109) = JacC(130,109)+ 0.7500000000000000D+00*dw(200,109)
      JacC(130,125) = JacC(130,125)+ 0.7500000000000000D+00*dw(200,125)
      JacC( 88, 88) = JacC( 88, 88) - dw(201, 88)
      JacC( 88,125) = JacC( 88,125) - dw(201,125)
      JacC(110, 88) = JacC(110, 88)+ 0.3000000000000000D+00*dw(201, 88)
      JacC(110,125) = JacC(110,125)+ 0.3000000000000000D+00*dw(201,125)
      JacC(119, 88) = JacC(119, 88)+ 0.7000000000000000D+00*dw(201, 88)
      JacC(119,125) = JacC(119,125)+ 0.7000000000000000D+00*dw(201,125)
      JacC(123, 88) = JacC(123, 88) + dw(201, 88)
      JacC(123,125) = JacC(123,125) + dw(201,125)
      JacC(124, 88) = JacC(124, 88)+ 0.7000000000000000D+00*dw(201, 88)
      JacC(124,125) = JacC(124,125)+ 0.7000000000000000D+00*dw(201,125)
      JacC(125, 88) = JacC(125, 88) - dw(201, 88)
      JacC(125,125) = JacC(125,125) - dw(201,125)
      JacC(127, 88) = JacC(127, 88)+ 0.7000000000000000D+00*dw(201, 88)
      JacC(127,125) = JacC(127,125)+ 0.7000000000000000D+00*dw(201,125)
      JacC(128, 88) = JacC(128, 88)+ 0.3000000000000000D+00*dw(201, 88)
      JacC(128,125) = JacC(128,125)+ 0.3000000000000000D+00*dw(201,125)
      JacC(130, 88) = JacC(130, 88)+ 0.3000000000000000D+00*dw(201, 88)
      JacC(130,125) = JacC(130,125)+ 0.3000000000000000D+00*dw(201,125)
      JacC( 70, 70) = JacC( 70, 70) - dw(202, 70)
      JacC( 70,125) = JacC( 70,125) - dw(202,125)
      JacC( 76, 70) = JacC( 76, 70)+ 0.6700000000000000D+00*dw(202, 70)
      JacC( 76,125) = JacC( 76,125)+ 0.6700000000000000D+00*dw(202,125)
      JacC(123, 70) = JacC(123, 70) + dw(202, 70)
      JacC(123,125) = JacC(123,125) + dw(202,125)
      JacC(125, 70) = JacC(125, 70) - dw(202, 70)
      JacC(125,125) = JacC(125,125) - dw(202,125)
      JacC(128, 70) = JacC(128, 70)+ 0.3300000000000000D+00*dw(202, 70)
      JacC(128,125) = JacC(128,125)+ 0.3300000000000000D+00*dw(202,125)
      JacC(130, 70) = JacC(130, 70)+ 0.6700000000000000D+00*dw(202, 70)
      JacC(130,125) = JacC(130,125)+ 0.6700000000000000D+00*dw(202,125)
      JacC( 87, 87) = JacC( 87, 87) - dw(203, 87)
      JacC( 87,125) = JacC( 87,125) - dw(203,125)
      JacC(108, 87) = JacC(108, 87)+ 0.1800000000000000D+00*dw(203, 87)
      JacC(108,125) = JacC(108,125)+ 0.1800000000000000D+00*dw(203,125)
      JacC(110, 87) = JacC(110, 87)+ 0.2100000000000000D+00*dw(203, 87)
      JacC(110,125) = JacC(110,125)+ 0.2100000000000000D+00*dw(203,125)
      JacC(113, 87) = JacC(113, 87)+ 0.6100000000000000D+00*dw(203, 87)
      JacC(113,125) = JacC(113,125)+ 0.6100000000000000D+00*dw(203,125)
      JacC(116, 87) = JacC(116, 87)+ 0.7000000000000000D+00*dw(203, 87)
      JacC(116,125) = JacC(116,125)+ 0.7000000000000000D+00*dw(203,125)
      JacC(119, 87) = JacC(119, 87)+ 0.2700000000000000D+00*dw(203, 87)
      JacC(119,125) = JacC(119,125)+ 0.2700000000000000D+00*dw(203,125)
      JacC(123, 87) = JacC(123, 87) + dw(203, 87)
      JacC(123,125) = JacC(123,125) + dw(203,125)
      JacC(125, 87) = JacC(125, 87) - dw(203, 87)
      JacC(125,125) = JacC(125,125) - dw(203,125)
      JacC(128, 87) = JacC(128, 87)+ 0.3000000000000000D-01*dw(203, 87)
      JacC(128,125) = JacC(128,125)+ 0.3000000000000000D-01*dw(203,125)
      JacC(130, 87) = JacC(130, 87) + dw(203, 87)
      JacC(130,125) = JacC(130,125) + dw(203,125)
      JacC( 78, 93) = JacC( 78, 93)+ 0.1100000000000000D+00*dw(204, 93)
      JacC( 78,125) = JacC( 78,125)+ 0.1100000000000000D+00*dw(204,125)
      JacC( 86, 93) = JacC( 86, 93)+ 0.7000000000000001D-01*dw(204, 93)
      JacC( 86,125) = JacC( 86,125)+ 0.7000000000000001D-01*dw(204,125)
      JacC( 93, 93) = JacC( 93, 93) - dw(204, 93)
      JacC( 93,125) = JacC( 93,125) - dw(204,125)
      JacC(116, 93) = JacC(116, 93)+ 0.4400000000000000D+00*dw(204, 93)
      JacC(116,125) = JacC(116,125)+ 0.4400000000000000D+00*dw(204,125)
      JacC(118, 93) = JacC(118, 93)+ 0.1800000000000000D+00*dw(204, 93)
      JacC(118,125) = JacC(118,125)+ 0.1800000000000000D+00*dw(204,125)
      JacC(119, 93) = JacC(119, 93)+ 0.4300000000000000D+00*dw(204, 93)
      JacC(119,125) = JacC(119,125)+ 0.4300000000000000D+00*dw(204,125)
      JacC(123, 93) = JacC(123, 93)+ 0.8200000000000000D+00*dw(204, 93)
      JacC(123,125) = JacC(123,125)+ 0.8200000000000000D+00*dw(204,125)
      JacC(125, 93) = JacC(125, 93) - dw(204, 93)
      JacC(125,125) = JacC(125,125) - dw(204,125)
      JacC(128, 93) = JacC(128, 93)+ 0.2300000000000000D+00*dw(204, 93)
      JacC(128,125) = JacC(128,125)+ 0.2300000000000000D+00*dw(204,125)
      JacC(130, 93) = JacC(130, 93)+ 0.8200000000000000D+00*dw(204, 93)
      JacC(130,125) = JacC(130,125)+ 0.8200000000000000D+00*dw(204,125)
      JacC( 77, 77) = JacC( 77, 77) - dw(205, 77)
      JacC( 77,125) = JacC( 77,125) - dw(205,125)
      JacC( 78, 77) = JacC( 78, 77)+ 0.3000000000000000D-01*dw(205, 77)
      JacC( 78,125) = JacC( 78,125)+ 0.3000000000000000D-01*dw(205,125)
      JacC( 96, 77) = JacC( 96, 77)+ 0.2500000000000000D+00*dw(205, 77)
      JacC( 96,125) = JacC( 96,125)+ 0.2500000000000000D+00*dw(205,125)
      JacC(116, 77) = JacC(116, 77)+ 0.2500000000000000D+00*dw(205, 77)
      JacC(116,125) = JacC(116,125)+ 0.2500000000000000D+00*dw(205,125)
      JacC(118, 77) = JacC(118, 77)+ 0.1000000000000000D+00*dw(205, 77)
      JacC(118,125) = JacC(118,125)+ 0.1000000000000000D+00*dw(205,125)
      JacC(123, 77) = JacC(123, 77)+ 0.9000000000000000D+00*dw(205, 77)
      JacC(123,125) = JacC(123,125)+ 0.9000000000000000D+00*dw(205,125)
      JacC(125, 77) = JacC(125, 77) - dw(205, 77)
      JacC(125,125) = JacC(125,125) - dw(205,125)
      JacC(130, 77) = JacC(130, 77)+ 0.9000000000000000D+00*dw(205, 77)
      JacC(130,125) = JacC(130,125)+ 0.9000000000000000D+00*dw(205,125)
      JacC( 71, 71) = JacC( 71, 71) - dw(206, 71)
      JacC( 71,125) = JacC( 71,125) - dw(206,125)
      JacC( 80, 71) = JacC( 80, 71)+ 0.4590000000000000D+00*dw(206, 71)
      JacC( 80,125) = JacC( 80,125)+ 0.4590000000000000D+00*dw(206,125)
      JacC( 85, 71) = JacC( 85, 71)+ 0.4590000000000000D+00*dw(206, 71)
      JacC( 85,125) = JacC( 85,125)+ 0.4590000000000000D+00*dw(206,125)
      JacC(108, 71) = JacC(108, 71)+ 0.9180000000000000D+00*dw(206, 71)
      JacC(108,125) = JacC(108,125)+ 0.9180000000000000D+00*dw(206,125)
      JacC(118, 71) = JacC(118, 71)+ 0.8200000000000000D-01*dw(206, 71)
      JacC(118,125) = JacC(118,125)+ 0.8200000000000000D-01*dw(206,125)
      JacC(123, 71) = JacC(123, 71)+ 0.9180000000000000D+00*dw(206, 71)
      JacC(123,125) = JacC(123,125)+ 0.9180000000000000D+00*dw(206,125)
      JacC(125, 71) = JacC(125, 71) - dw(206, 71)
      JacC(125,125) = JacC(125,125) - dw(206,125)
      JacC(130, 71) = JacC(130, 71)+ 0.9180000000000000D+00*dw(206, 71)
      JacC(130,125) = JacC(130,125)+ 0.9180000000000000D+00*dw(206,125)
      JacC( 65, 65) = JacC( 65, 65) - dw(207, 65)
      JacC( 65,125) = JacC( 65,125) - dw(207,125)
      JacC( 68, 65) = JacC( 68, 65)+ 0.7300000000000000D-01*dw(207, 65)
      JacC( 68,125) = JacC( 68,125)+ 0.7300000000000000D-01*dw(207,125)
      JacC( 76, 65) = JacC( 76, 65)+ 0.7000000000000000D+00*dw(207, 65)
      JacC( 76,125) = JacC( 76,125)+ 0.7000000000000000D+00*dw(207,125)
      JacC( 98, 65) = JacC( 98, 65)+ 0.1770000000000000D+00*dw(207, 65)
      JacC( 98,125) = JacC( 98,125)+ 0.1770000000000000D+00*dw(207,125)
      JacC(108, 65) = JacC(108, 65)+ 0.3500000000000000D+00*dw(207, 65)
      JacC(108,125) = JacC(108,125)+ 0.3500000000000000D+00*dw(207,125)
      JacC(110, 65) = JacC(110, 65)+ 0.6000000000000000D+00*dw(207, 65)
      JacC(110,125) = JacC(110,125)+ 0.6000000000000000D+00*dw(207,125)
      JacC(118, 65) = JacC(118, 65)+ 0.5000000000000000D-01*dw(207, 65)
      JacC(118,125) = JacC(118,125)+ 0.5000000000000000D-01*dw(207,125)
      JacC(123, 65) = JacC(123, 65)+ 0.9500000000000000D+00*dw(207, 65)
      JacC(123,125) = JacC(123,125)+ 0.9500000000000000D+00*dw(207,125)
      JacC(125, 65) = JacC(125, 65) - dw(207, 65)
      JacC(125,125) = JacC(125,125) - dw(207,125)
      JacC(130, 65) = JacC(130, 65)+ 0.9500000000000000D+00*dw(207, 65)
      JacC(130,125) = JacC(130,125)+ 0.9500000000000000D+00*dw(207,125)
      JacC( 75,104) = JacC( 75,104)+ 0.3200000000000000D+00*dw(208,104)
      JacC( 75,125) = JacC( 75,125)+ 0.3200000000000000D+00*dw(208,125)
      JacC(104,104) = JacC(104,104) - dw(208,104)
      JacC(104,125) = JacC(104,125) - dw(208,125)
      JacC(108,104) = JacC(108,104)+ 0.6800000000000000D+00*dw(208,104)
      JacC(108,125) = JacC(108,125)+ 0.6800000000000000D+00*dw(208,125)
      JacC(123,104) = JacC(123,104) + dw(208,104)
      JacC(123,125) = JacC(123,125) + dw(208,125)
      JacC(125,104) = JacC(125,104) - dw(208,104)
      JacC(125,125) = JacC(125,125) - dw(208,125)
      JacC(126,104) = JacC(126,104)+ 0.6800000000000000D+00*dw(208,104)
      JacC(126,125) = JacC(126,125)+ 0.6800000000000000D+00*dw(208,125)
      JacC(130,104) = JacC(130,104) + dw(208,104)
      JacC(130,125) = JacC(130,125) + dw(208,125)
      JacC(122,124) = JacC(122,124) + dw(209,124)
      JacC(122,125) = JacC(122,125) + dw(209,125)
      JacC(123,124) = JacC(123,124) + dw(209,124)
      JacC(123,125) = JacC(123,125) + dw(209,125)
      JacC(124,124) = JacC(124,124) - dw(209,124)
      JacC(124,125) = JacC(124,125) - dw(209,125)
      JacC(125,124) = JacC(125,124) - dw(209,124)
      JacC(125,125) = JacC(125,125) - dw(209,125)
      JacC(120,120) = JacC(120,120) - dw(210,120)
      JacC(120,125) = JacC(120,125) - dw(210,125)
      JacC(121,120) = JacC(121,120) + dw(210,120)
      JacC(121,125) = JacC(121,125) + dw(210,125)
      JacC(123,120) = JacC(123,120) + dw(210,120)
      JacC(123,125) = JacC(123,125) + dw(210,125)
      JacC(125,120) = JacC(125,120) - dw(210,120)
      JacC(125,125) = JacC(125,125) - dw(210,125)
      JacC(110,114) = JacC(110,114)+ 0.5400000000000000D+00*dw(211,114)
      JacC(110,125) = JacC(110,125)+ 0.5400000000000000D+00*dw(211,125)
      JacC(114,114) = JacC(114,114) - dw(211,114)
      JacC(114,125) = JacC(114,125) - dw(211,125)
      JacC(119,114) = JacC(119,114)+ 0.4600000000000000D+00*dw(211,114)
      JacC(119,125) = JacC(119,125)+ 0.4600000000000000D+00*dw(211,125)
      JacC(123,114) = JacC(123,114) + dw(211,114)
      JacC(123,125) = JacC(123,125) + dw(211,125)
      JacC(124,114) = JacC(124,114)+ 0.2300000000000000D+00*dw(211,114)
      JacC(124,125) = JacC(124,125)+ 0.2300000000000000D+00*dw(211,125)
      JacC(125,114) = JacC(125,114) - dw(211,114)
      JacC(125,125) = JacC(125,125) - dw(211,125)
      JacC(127,114) = JacC(127,114)+ 0.1600000000000000D+00*dw(211,114)
      JacC(127,125) = JacC(127,125)+ 0.1600000000000000D+00*dw(211,125)
      JacC(130,114) = JacC(130,114)+ 0.7700000000000000D+00*dw(211,114)
      JacC(130,125) = JacC(130,125)+ 0.7700000000000000D+00*dw(211,125)
      JacC( 79, 79) = JacC( 79, 79) - dw(212, 79)
      JacC( 79,125) = JacC( 79,125) - dw(212,125)
      JacC(123, 79) = JacC(123, 79) + dw(212, 79)
      JacC(123,125) = JacC(123,125) + dw(212,125)
      JacC(124, 79) = JacC(124, 79) + dw(212, 79)
      JacC(124,125) = JacC(124,125) + dw(212,125)
      JacC(125, 79) = JacC(125, 79) - dw(212, 79)
      JacC(125,125) = JacC(125,125) - dw(212,125)
      JacC(128, 79) = JacC(128, 79) + dw(212, 79)
      JacC(128,125) = JacC(128,125) + dw(212,125)
      JacC( 82, 82) = JacC( 82, 82) - dw(213, 82)
      JacC( 82,125) = JacC( 82,125) - dw(213,125)
      JacC(118, 82) = JacC(118, 82) + dw(213, 82)
      JacC(118,125) = JacC(118,125) + dw(213,125)
      JacC(123, 82) = JacC(123, 82) + dw(213, 82)
      JacC(123,125) = JacC(123,125) + dw(213,125)
      JacC(125, 82) = JacC(125, 82) - dw(213, 82)
      JacC(125,125) = JacC(125,125) - dw(213,125)
      JacC(130, 82) = JacC(130, 82) + dw(213, 82)
      JacC(130,125) = JacC(130,125) + dw(213,125)
      JacC( 81, 81) = JacC( 81, 81) - dw(214, 81)
      JacC( 81,125) = JacC( 81,125) - dw(214,125)
      JacC(116, 81) = JacC(116, 81)+ 0.4640000000000000D+00*dw(214, 81)
      JacC(116,125) = JacC(116,125)+ 0.4640000000000000D+00*dw(214,125)
      JacC(119, 81) = JacC(119, 81)+ 0.1240000000000000D+01*dw(214, 81)
      JacC(119,125) = JacC(119,125)+ 0.1240000000000000D+01*dw(214,125)
      JacC(123, 81) = JacC(123, 81)+ 0.2000000000000000D+01*dw(214, 81)
      JacC(123,125) = JacC(123,125)+ 0.2000000000000000D+01*dw(214,125)
      JacC(125, 81) = JacC(125, 81) - dw(214, 81)
      JacC(125,125) = JacC(125,125) - dw(214,125)
      JacC(128, 81) = JacC(128, 81)+ 0.2870000000000000D+00*dw(214, 81)
      JacC(128,125) = JacC(128,125)+ 0.2870000000000000D+00*dw(214,125)
      JacC( 45,122) = JacC( 45,122) + dw(215,122)
      JacC( 45,130) = JacC( 45,130) + dw(215,130)
      JacC(122,122) = JacC(122,122) - dw(215,122)
      JacC(122,130) = JacC(122,130) - dw(215,130)
      JacC(130,122) = JacC(130,122) - dw(215,122)
      JacC(130,130) = JacC(130,130) - dw(215,130)
      JacC(121,121) = JacC(121,121) - dw(216,121)
      JacC(121,130) = JacC(121,130) - dw(216,130)
      JacC(126,121) = JacC(126,121) + dw(216,121)
      JacC(126,130) = JacC(126,130) + dw(216,130)
      JacC(130,121) = JacC(130,121) - dw(216,121)
      JacC(130,130) = JacC(130,130) - dw(216,130)
      JacC(117,117) = JacC(117,117) - dw(217,117)
      JacC(117,130) = JacC(117,130) - dw(217,130)
      JacC(126,117) = JacC(126,117) + dw(217,117)
      JacC(126,130) = JacC(126,130) + dw(217,130)
      JacC(130,117) = JacC(130,117) - dw(217,117)
      JacC(130,130) = JacC(130,130) - dw(217,130)
      JacC( 92, 92) = JacC( 92, 92) - dw(218, 92)
      JacC( 92,130) = JacC( 92,130) - dw(218,130)
      JacC(126, 92) = JacC(126, 92) + dw(218, 92)
      JacC(126,130) = JacC(126,130) + dw(218,130)
      JacC(130, 92) = JacC(130, 92) - dw(218, 92)
      JacC(130,130) = JacC(130,130) - dw(218,130)
      JacC( 69, 69) = JacC( 69, 69) - dw(219, 69)
      JacC( 69,130) = JacC( 69,130) - dw(219,130)
      JacC(126, 69) = JacC(126, 69) + dw(219, 69)
      JacC(126,130) = JacC(126,130) + dw(219,130)
      JacC(130, 69) = JacC(130, 69) - dw(219, 69)
      JacC(130,130) = JacC(130,130) - dw(219,130)
      JacC( 73, 73) = JacC( 73, 73) - dw(220, 73)
      JacC( 73,130) = JacC( 73,130) - dw(220,130)
      JacC(126, 73) = JacC(126, 73) + dw(220, 73)
      JacC(126,130) = JacC(126,130) + dw(220,130)
      JacC(130, 73) = JacC(130, 73) - dw(220, 73)
      JacC(130,130) = JacC(130,130) - dw(220,130)
      JacC( 72, 72) = JacC( 72, 72) - dw(221, 72)
      JacC( 72,130) = JacC( 72,130) - dw(221,130)
      JacC(126, 72) = JacC(126, 72) + dw(221, 72)
      JacC(126,130) = JacC(126,130) + dw(221,130)
      JacC(130, 72) = JacC(130, 72) - dw(221, 72)
      JacC(130,130) = JacC(130,130) - dw(221,130)
      JacC(101,101) = JacC(101,101) - dw(222,101)
      JacC(101,130) = JacC(101,130) - dw(222,130)
      JacC(126,101) = JacC(126,101) + dw(222,101)
      JacC(126,130) = JacC(126,130) + dw(222,130)
      JacC(130,101) = JacC(130,101) - dw(222,101)
      JacC(130,130) = JacC(130,130) - dw(222,130)
      JacC( 34, 83) = JacC( 34, 83) + dw(223, 83)
      JacC( 34,130) = JacC( 34,130) + dw(223,130)
      JacC( 83, 83) = JacC( 83, 83) - dw(223, 83)
      JacC( 83,130) = JacC( 83,130) - dw(223,130)
      JacC(130, 83) = JacC(130, 83) - dw(223, 83)
      JacC(130,130) = JacC(130,130) - dw(223,130)
      JacC( 39,109) = JacC( 39,109) + dw(224,109)
      JacC( 39,130) = JacC( 39,130) + dw(224,130)
      JacC(109,109) = JacC(109,109) - dw(224,109)
      JacC(109,130) = JacC(109,130) - dw(224,130)
      JacC(130,109) = JacC(130,109) - dw(224,109)
      JacC(130,130) = JacC(130,130) - dw(224,130)
      JacC( 88, 88) = JacC( 88, 88) - dw(225, 88)
      JacC( 88,130) = JacC( 88,130) - dw(225,130)
      JacC(126, 88) = JacC(126, 88) + dw(225, 88)
      JacC(126,130) = JacC(126,130) + dw(225,130)
      JacC(130, 88) = JacC(130, 88) - dw(225, 88)
      JacC(130,130) = JacC(130,130) - dw(225,130)
      JacC( 87, 87) = JacC( 87, 87) - dw(226, 87)
      JacC( 87,130) = JacC( 87,130) - dw(226,130)
      JacC(126, 87) = JacC(126, 87) + dw(226, 87)
      JacC(126,130) = JacC(126,130) + dw(226,130)
      JacC(130, 87) = JacC(130, 87) - dw(226, 87)
      JacC(130,130) = JacC(130,130) - dw(226,130)
      JacC( 93, 93) = JacC( 93, 93) - dw(227, 93)
      JacC( 93,130) = JacC( 93,130) - dw(227,130)
      JacC(126, 93) = JacC(126, 93) + dw(227, 93)
      JacC(126,130) = JacC(126,130) + dw(227,130)
      JacC(130, 93) = JacC(130, 93) - dw(227, 93)
      JacC(130,130) = JacC(130,130) - dw(227,130)
      JacC( 77, 77) = JacC( 77, 77) - dw(228, 77)
      JacC( 77,130) = JacC( 77,130) - dw(228,130)
      JacC(126, 77) = JacC(126, 77) + dw(228, 77)
      JacC(126,130) = JacC(126,130) + dw(228,130)
      JacC(130, 77) = JacC(130, 77) - dw(228, 77)
      JacC(130,130) = JacC(130,130) - dw(228,130)
      JacC( 71, 71) = JacC( 71, 71) - dw(229, 71)
      JacC( 71,130) = JacC( 71,130) - dw(229,130)
      JacC(126, 71) = JacC(126, 71) + dw(229, 71)
      JacC(126,130) = JacC(126,130) + dw(229,130)
      JacC(130, 71) = JacC(130, 71) - dw(229, 71)
      JacC(130,130) = JacC(130,130) - dw(229,130)
      JacC( 58, 58) = JacC( 58, 58) - dw(230, 58)
      JacC( 58,130) = JacC( 58,130) - dw(230,130)
      JacC(126, 58) = JacC(126, 58) + dw(230, 58)
      JacC(126,130) = JacC(126,130) + dw(230,130)
      JacC(130, 58) = JacC(130, 58) - dw(230, 58)
      JacC(130,130) = JacC(130,130) - dw(230,130)
      JacC( 60, 60) = JacC( 60, 60) - dw(231, 60)
      JacC( 60,130) = JacC( 60,130) - dw(231,130)
      JacC(126, 60) = JacC(126, 60) + dw(231, 60)
      JacC(126,130) = JacC(126,130) + dw(231,130)
      JacC(130, 60) = JacC(130, 60) - dw(231, 60)
      JacC(130,130) = JacC(130,130) - dw(231,130)
      JacC( 65, 65) = JacC( 65, 65) - dw(232, 65)
      JacC( 65,130) = JacC( 65,130) - dw(232,130)
      JacC(126, 65) = JacC(126, 65) + dw(232, 65)
      JacC(126,130) = JacC(126,130) + dw(232,130)
      JacC(130, 65) = JacC(130, 65) - dw(232, 65)
      JacC(130,130) = JacC(130,130) - dw(232,130)
      JacC(104,104) = JacC(104,104) - dw(233,104)
      JacC(104,130) = JacC(104,130) - dw(233,130)
      JacC(126,104) = JacC(126,104) + dw(233,104)
      JacC(126,130) = JacC(126,130) + dw(233,130)
      JacC(130,104) = JacC(130,104) - dw(233,104)
      JacC(130,130) = JacC(130,130) - dw(233,130)
      JacC( 62, 64) = JacC( 62, 64) + dw(234, 64)
      JacC( 62,130) = JacC( 62,130) + dw(234,130)
      JacC( 64, 64) = JacC( 64, 64) - dw(234, 64)
      JacC( 64,130) = JacC( 64,130) - dw(234,130)
      JacC(130, 64) = JacC(130, 64) - dw(234, 64)
      JacC(130,130) = JacC(130,130) - dw(234,130)
      JacC( 74,124) = JacC( 74,124)+ 0.4000000000000000D+00*dw(235,124)
      JacC( 74,130) = JacC( 74,130)+ 0.4000000000000000D+00*dw(235,130)
      JacC(115,124) = JacC(115,124)+ 0.2000000000000000D+00*dw(235,124)
      JacC(115,130) = JacC(115,130)+ 0.2000000000000000D+00*dw(235,130)
      JacC(122,124) = JacC(122,124)+ 0.4000000000000000D+00*dw(235,124)
      JacC(122,130) = JacC(122,130)+ 0.4000000000000000D+00*dw(235,130)
      JacC(124,124) = JacC(124,124) - dw(235,124)
      JacC(124,130) = JacC(124,130) - dw(235,130)
      JacC(130,124) = JacC(130,124) - dw(235,124)
      JacC(130,130) = JacC(130,130) - dw(235,130)
      JacC(131,124) = JacC(131,124)+ 0.4000000000000000D+00*dw(235,124)
      JacC(131,130) = JacC(131,130)+ 0.4000000000000000D+00*dw(235,130)
      JacC( 74,120) = JacC( 74,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC( 74,130) = JacC( 74,130)+ 0.4000000000000000D+00*dw(236,130)
      JacC(115,120) = JacC(115,120)+ 0.2000000000000000D+00*dw(236,120)
      JacC(115,130) = JacC(115,130)+ 0.2000000000000000D+00*dw(236,130)
      JacC(120,120) = JacC(120,120) - dw(236,120)
      JacC(120,130) = JacC(120,130) - dw(236,130)
      JacC(121,120) = JacC(121,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC(121,130) = JacC(121,130)+ 0.4000000000000000D+00*dw(236,130)
      JacC(130,120) = JacC(130,120) - dw(236,120)
      JacC(130,130) = JacC(130,130) - dw(236,130)
      JacC(131,120) = JacC(131,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC(131,130) = JacC(131,130)+ 0.4000000000000000D+00*dw(236,130)
      JacC( 79, 79) = JacC( 79, 79) - dw(237, 79)
      JacC( 79,130) = JacC( 79,130) - dw(237,130)
      JacC(124, 79) = JacC(124, 79)+ 0.6700000000000000D+00*dw(237, 79)
      JacC(124,130) = JacC(124,130)+ 0.6700000000000000D+00*dw(237,130)
      JacC(126, 79) = JacC(126, 79)+ 0.3300000000000000D+00*dw(237, 79)
      JacC(126,130) = JacC(126,130)+ 0.3300000000000000D+00*dw(237,130)
      JacC(128, 79) = JacC(128, 79)+ 0.6700000000000000D+00*dw(237, 79)
      JacC(128,130) = JacC(128,130)+ 0.6700000000000000D+00*dw(237,130)
      JacC(130, 79) = JacC(130, 79) - dw(237, 79)
      JacC(130,130) = JacC(130,130) - dw(237,130)
      JacC(131, 79) = JacC(131, 79)+ 0.6700000000000000D+00*dw(237, 79)
      JacC(131,130) = JacC(131,130)+ 0.6700000000000000D+00*dw(237,130)
      JacC( 70, 70) = JacC( 70, 70) - dw(238, 70)
      JacC( 70,130) = JacC( 70,130) - dw(238,130)
      JacC(126, 70) = JacC(126, 70) + dw(238, 70)
      JacC(126,130) = JacC(126,130) + dw(238,130)
      JacC(130, 70) = JacC(130, 70) - dw(238, 70)
      JacC(130,130) = JacC(130,130) - dw(238,130)
      JacC(114,114) = JacC(114,114) - dw(239,114)
      JacC(114,130) = JacC(114,130) - dw(239,130)
      JacC(126,114) = JacC(126,114) + dw(239,114)
      JacC(126,130) = JacC(126,130) + dw(239,130)
      JacC(130,114) = JacC(130,114) - dw(239,114)
      JacC(130,130) = JacC(130,130) - dw(239,130)
      JacC( 82, 82) = JacC( 82, 82) - dw(240, 82)
      JacC( 82,130) = JacC( 82,130) - dw(240,130)
      JacC(118, 82) = JacC(118, 82) + dw(240, 82)
      JacC(118,130) = JacC(118,130) + dw(240,130)
      JacC(130, 82) = JacC(130, 82) - dw(240, 82)
      JacC(130,130) = JacC(130,130) - dw(240,130)
      JacC( 81, 81) = JacC( 81, 81) - dw(241, 81)
      JacC( 81,130) = JacC( 81,130) - dw(241,130)
      JacC(118, 81) = JacC(118, 81) + dw(241, 81)
      JacC(118,130) = JacC(118,130) + dw(241,130)
      JacC(130, 81) = JacC(130, 81) - dw(241, 81)
      JacC(130,130) = JacC(130,130) - dw(241,130)
      JacC(102,122) = JacC(102,122)+ 0.6300000000000000D+00*dw(242,122)
      JacC(102,122) = JacC(102,122)+ 0.6300000000000000D+00*dw(242,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(242,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(242,122)
      JacC(128,122) = JacC(128,122)+ 0.1370000000000000D+01*dw(242,122)
      JacC(128,122) = JacC(128,122)+ 0.1370000000000000D+01*dw(242,122)
      JacC(130,122) = JacC(130,122)+ 0.7400000000000000D+00*dw(242,122)
      JacC(130,122) = JacC(130,122)+ 0.7400000000000000D+00*dw(242,122)
      JacC( 30,121) = JacC( 30,121)+ 0.2500000000000000D+00*dw(243,121)
      JacC( 30,122) = JacC( 30,122)+ 0.2500000000000000D+00*dw(243,122)
      JacC( 95,121) = JacC( 95,121)+ 0.7500000000000000D+00*dw(243,121)
      JacC( 95,122) = JacC( 95,122)+ 0.7500000000000000D+00*dw(243,122)
      JacC(102,121) = JacC(102,121)+ 0.2500000000000000D+00*dw(243,121)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(243,122)
      JacC(121,121) = JacC(121,121) - dw(243,121)
      JacC(121,122) = JacC(121,122) - dw(243,122)
      JacC(122,121) = JacC(122,121) - dw(243,121)
      JacC(122,122) = JacC(122,122) - dw(243,122)
      JacC(128,121) = JacC(128,121)+ 0.7500000000000000D+00*dw(243,121)
      JacC(128,122) = JacC(128,122)+ 0.7500000000000000D+00*dw(243,122)
      JacC(130,121) = JacC(130,121) + dw(243,121)
      JacC(130,122) = JacC(130,122) + dw(243,122)
      JacC( 94,117) = JacC( 94,117)+ 0.2500000000000000D+00*dw(244,117)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(244,122)
      JacC(102,117) = JacC(102,117)+ 0.2500000000000000D+00*dw(244,117)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(244,122)
      JacC(108,117) = JacC(108,117)+ 0.5000000000000000D-01*dw(244,117)
      JacC(108,122) = JacC(108,122)+ 0.5000000000000000D-01*dw(244,122)
      JacC(116,117) = JacC(116,117)+ 0.4970000000000000D+00*dw(244,117)
      JacC(116,122) = JacC(116,122)+ 0.4970000000000000D+00*dw(244,122)
      JacC(117,117) = JacC(117,117) - dw(244,117)
      JacC(117,122) = JacC(117,122) - dw(244,122)
      JacC(119,117) = JacC(119,117)+ 0.1980000000000000D+00*dw(244,117)
      JacC(119,122) = JacC(119,122)+ 0.1980000000000000D+00*dw(244,122)
      JacC(121,117) = JacC(121,117)+ 0.2600000000000000D-01*dw(244,117)
      JacC(121,122) = JacC(121,122)+ 0.2600000000000000D-01*dw(244,122)
      JacC(122,117) = JacC(122,117)- 0.9200000000000000D+00*dw(244,117)
      JacC(122,122) = JacC(122,122)- 0.9200000000000000D+00*dw(244,122)
      JacC(127,117) = JacC(127,117)+ 0.2600000000000000D-01*dw(244,117)
      JacC(127,122) = JacC(127,122)+ 0.2600000000000000D-01*dw(244,122)
      JacC(128,117) = JacC(128,117)+ 0.8270000000000000D+00*dw(244,117)
      JacC(128,122) = JacC(128,122)+ 0.8270000000000000D+00*dw(244,122)
      JacC(130,117) = JacC(130,117)+ 0.8940000000000000D+00*dw(244,117)
      JacC(130,122) = JacC(130,122)+ 0.8940000000000000D+00*dw(244,122)
      JacC( 92, 92) = JacC( 92, 92) - dw(245, 92)
      JacC( 92,122) = JacC( 92,122) - dw(245,122)
      JacC( 94, 92) = JacC( 94, 92)+ 0.2500000000000000D+00*dw(245, 92)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(245,122)
      JacC(102, 92) = JacC(102, 92)+ 0.2500000000000000D+00*dw(245, 92)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(245,122)
      JacC(116, 92) = JacC(116, 92)+ 0.6180000000000000D+00*dw(245, 92)
      JacC(116,122) = JacC(116,122)+ 0.6180000000000000D+00*dw(245,122)
      JacC(119, 92) = JacC(119, 92)+ 0.2510000000000000D+00*dw(245, 92)
      JacC(119,122) = JacC(119,122)+ 0.2510000000000000D+00*dw(245,122)
      JacC(121, 92) = JacC(121, 92)+ 0.1400000000000000D+00*dw(245, 92)
      JacC(121,122) = JacC(121,122)+ 0.1400000000000000D+00*dw(245,122)
      JacC(122, 92) = JacC(122, 92)- 0.9820000000000000D+00*dw(245, 92)
      JacC(122,122) = JacC(122,122)- 0.9820000000000000D+00*dw(245,122)
      JacC(127, 92) = JacC(127, 92)+ 0.1910000000000000D+00*dw(245, 92)
      JacC(127,122) = JacC(127,122)+ 0.1910000000000000D+00*dw(245,122)
      JacC(128, 92) = JacC(128, 92)+ 0.7770000000000000D+00*dw(245, 92)
      JacC(128,122) = JacC(128,122)+ 0.7770000000000000D+00*dw(245,122)
      JacC(130, 92) = JacC(130, 92)+ 0.8420000000000000D+00*dw(245, 92)
      JacC(130,122) = JacC(130,122)+ 0.8420000000000000D+00*dw(245,122)
      JacC( 69, 69) = JacC( 69, 69) - dw(246, 69)
      JacC( 69,122) = JacC( 69,122) - dw(246,122)
      JacC( 94, 69) = JacC( 94, 69)+ 0.2500000000000000D+00*dw(246, 69)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(246,122)
      JacC(102, 69) = JacC(102, 69)+ 0.2500000000000000D+00*dw(246, 69)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(246,122)
      JacC(116, 69) = JacC(116, 69)+ 0.6520000000000000D+00*dw(246, 69)
      JacC(116,122) = JacC(116,122)+ 0.6520000000000000D+00*dw(246,122)
      JacC(119, 69) = JacC(119, 69)+ 0.1970000000000000D+00*dw(246, 69)
      JacC(119,122) = JacC(119,122)+ 0.1970000000000000D+00*dw(246,122)
      JacC(121, 69) = JacC(121, 69)+ 0.9000000000000000D-01*dw(246, 69)
      JacC(121,122) = JacC(121,122)+ 0.9000000000000000D-01*dw(246,122)
      JacC(122, 69) = JacC(122, 69) - dw(246, 69)
      JacC(122,122) = JacC(122,122) - dw(246,122)
      JacC(127, 69) = JacC(127, 69)+ 0.2810000000000000D+00*dw(246, 69)
      JacC(127,122) = JacC(127,122)+ 0.2810000000000000D+00*dw(246,122)
      JacC(128, 69) = JacC(128, 69)+ 0.7500000000000000D+00*dw(246, 69)
      JacC(128,122) = JacC(128,122)+ 0.7500000000000000D+00*dw(246,122)
      JacC(130, 69) = JacC(130, 69)+ 0.9100000000000000D+00*dw(246, 69)
      JacC(130,122) = JacC(130,122)+ 0.9100000000000000D+00*dw(246,122)
      JacC( 33, 73) = JacC( 33, 73)+ 0.2500000000000000D+00*dw(247, 73)
      JacC( 33,122) = JacC( 33,122)+ 0.2500000000000000D+00*dw(247,122)
      JacC( 73, 73) = JacC( 73, 73) - dw(247, 73)
      JacC( 73,122) = JacC( 73,122) - dw(247,122)
      JacC(102, 73) = JacC(102, 73)+ 0.2500000000000000D+00*dw(247, 73)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(247,122)
      JacC(119, 73) = JacC(119, 73)+ 0.1500000000000000D+00*dw(247, 73)
      JacC(119,122) = JacC(119,122)+ 0.1500000000000000D+00*dw(247,122)
      JacC(122, 73) = JacC(122, 73) - dw(247, 73)
      JacC(122,122) = JacC(122,122) - dw(247,122)
      JacC(128, 73) = JacC(128, 73)+ 0.1950000000000000D+01*dw(247, 73)
      JacC(128,122) = JacC(128,122)+ 0.1950000000000000D+01*dw(247,122)
      JacC(130, 73) = JacC(130, 73) + dw(247, 73)
      JacC(130,122) = JacC(130,122) + dw(247,122)
      JacC( 72, 72) = JacC( 72, 72) - dw(248, 72)
      JacC( 72,122) = JacC( 72,122) - dw(248,122)
      JacC( 94, 72) = JacC( 94, 72)+ 0.2500000000000000D+00*dw(248, 72)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(248,122)
      JacC(102, 72) = JacC(102, 72)+ 0.2500000000000000D+00*dw(248, 72)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(248,122)
      JacC(116, 72) = JacC(116, 72)+ 0.4500000000000000D-01*dw(248, 72)
      JacC(116,122) = JacC(116,122)+ 0.4500000000000000D-01*dw(248,122)
      JacC(119, 72) = JacC(119, 72)+ 0.7050000000000000D+00*dw(248, 72)
      JacC(119,122) = JacC(119,122)+ 0.7050000000000000D+00*dw(248,122)
      JacC(122, 72) = JacC(122, 72) - dw(248, 72)
      JacC(122,122) = JacC(122,122) - dw(248,122)
      JacC(128, 72) = JacC(128, 72)+ 0.1500000000000000D+01*dw(248, 72)
      JacC(128,122) = JacC(128,122)+ 0.1500000000000000D+01*dw(248,122)
      JacC(130, 72) = JacC(130, 72) + dw(248, 72)
      JacC(130,122) = JacC(130,122) + dw(248,122)
      JacC( 94,101) = JacC( 94,101)+ 0.2500000000000000D+00*dw(249,101)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(249,122)
      JacC(101,101) = JacC(101,101) - dw(249,101)
      JacC(101,122) = JacC(101,122) - dw(249,122)
      JacC(102,101) = JacC(102,101)+ 0.2500000000000000D+00*dw(249,101)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(249,122)
      JacC(116,101) = JacC(116,101)+ 0.2180000000000000D+00*dw(249,101)
      JacC(116,122) = JacC(116,122)+ 0.2180000000000000D+00*dw(249,122)
      JacC(119,101) = JacC(119,101)+ 0.1280000000000000D+01*dw(249,101)
      JacC(119,122) = JacC(119,122)+ 0.1280000000000000D+01*dw(249,122)
      JacC(122,101) = JacC(122,101) - dw(249,101)
      JacC(122,122) = JacC(122,122) - dw(249,122)
      JacC(128,101) = JacC(128,101)+ 0.7500000000000000D+00*dw(249,101)
      JacC(128,122) = JacC(128,122)+ 0.7500000000000000D+00*dw(249,122)
      JacC(130,101) = JacC(130,101) + dw(249,101)
      JacC(130,122) = JacC(130,122) + dw(249,122)
      JacC( 83, 83) = JacC( 83, 83) - dw(250, 83)
      JacC( 83,122) = JacC( 83,122) - dw(250,122)
      JacC( 84, 83) = JacC( 84, 83)+ 0.3050000000000000D+00*dw(250, 83)
      JacC( 84,122) = JacC( 84,122)+ 0.3050000000000000D+00*dw(250,122)
      JacC( 94, 83) = JacC( 94, 83)+ 0.2500000000000000D+00*dw(250, 83)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(250,122)
      JacC( 96, 83) = JacC( 96, 83)+ 0.2190000000000000D+00*dw(250, 83)
      JacC( 96,122) = JacC( 96,122)+ 0.2190000000000000D+00*dw(250,122)
      JacC(102, 83) = JacC(102, 83)+ 0.2500000000000000D+00*dw(250, 83)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(250,122)
      JacC(122, 83) = JacC(122, 83) - dw(250, 83)
      JacC(122,122) = JacC(122,122) - dw(250,122)
      JacC(128, 83) = JacC(128, 83)+ 0.1540000000000000D+01*dw(250, 83)
      JacC(128,122) = JacC(128,122)+ 0.1540000000000000D+01*dw(250,122)
      JacC(130, 83) = JacC(130, 83) + dw(250, 83)
      JacC(130,122) = JacC(130,122) + dw(250,122)
      JacC( 89,109) = JacC( 89,109)+ 0.1670000000000000D+00*dw(251,109)
      JacC( 89,122) = JacC( 89,122)+ 0.1670000000000000D+00*dw(251,122)
      JacC( 94,109) = JacC( 94,109)+ 0.2500000000000000D+00*dw(251,109)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(251,122)
      JacC(102,109) = JacC(102,109)+ 0.2500000000000000D+00*dw(251,109)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(251,122)
      JacC(109,109) = JacC(109,109) - dw(251,109)
      JacC(109,122) = JacC(109,122) - dw(251,122)
      JacC(110,109) = JacC(110,109)+ 0.3330000000000000D+00*dw(251,109)
      JacC(110,122) = JacC(110,122)+ 0.3330000000000000D+00*dw(251,122)
      JacC(113,109) = JacC(113,109)+ 0.1670000000000000D+00*dw(251,109)
      JacC(113,122) = JacC(113,122)+ 0.1670000000000000D+00*dw(251,122)
      JacC(115,109) = JacC(115,109)+ 0.4200000000000000D-01*dw(251,109)
      JacC(115,122) = JacC(115,122)+ 0.4200000000000000D-01*dw(251,122)
      JacC(122,109) = JacC(122,109) - dw(251,109)
      JacC(122,122) = JacC(122,122) - dw(251,122)
      JacC(124,109) = JacC(124,109)+ 0.1670000000000000D+00*dw(251,109)
      JacC(124,122) = JacC(124,122)+ 0.1670000000000000D+00*dw(251,122)
      JacC(128,109) = JacC(128,109)+ 0.1500000000000000D+01*dw(251,109)
      JacC(128,122) = JacC(128,122)+ 0.1500000000000000D+01*dw(251,122)
      JacC(130,109) = JacC(130,109) + dw(251,109)
      JacC(130,122) = JacC(130,122) + dw(251,122)
      JacC( 88, 88) = JacC( 88, 88) - dw(252, 88)
      JacC( 88,122) = JacC( 88,122) - dw(252,122)
      JacC( 94, 88) = JacC( 94, 88)+ 0.2500000000000000D+00*dw(252, 88)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(252,122)
      JacC(102, 88) = JacC(102, 88)+ 0.2500000000000000D+00*dw(252, 88)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(252,122)
      JacC(110, 88) = JacC(110, 88)+ 0.5000000000000000D+00*dw(252, 88)
      JacC(110,122) = JacC(110,122)+ 0.5000000000000000D+00*dw(252,122)
      JacC(115, 88) = JacC(115, 88)+ 0.2920000000000000D+00*dw(252, 88)
      JacC(115,122) = JacC(115,122)+ 0.2920000000000000D+00*dw(252,122)
      JacC(119, 88) = JacC(119, 88)+ 0.1750000000000000D+01*dw(252, 88)
      JacC(119,122) = JacC(119,122)+ 0.1750000000000000D+01*dw(252,122)
      JacC(122, 88) = JacC(122, 88) - dw(252, 88)
      JacC(122,122) = JacC(122,122) - dw(252,122)
      JacC(124, 88) = JacC(124, 88)+ 0.1160000000000000D+01*dw(252, 88)
      JacC(124,122) = JacC(124,122)+ 0.1160000000000000D+01*dw(252,122)
      JacC(127, 88) = JacC(127, 88)+ 0.1160000000000000D+01*dw(252, 88)
      JacC(127,122) = JacC(127,122)+ 0.1160000000000000D+01*dw(252,122)
      JacC(128, 88) = JacC(128, 88)+ 0.1500000000000000D+01*dw(252, 88)
      JacC(128,122) = JacC(128,122)+ 0.1500000000000000D+01*dw(252,122)
      JacC(130, 88) = JacC(130, 88) + dw(252, 88)
      JacC(130,122) = JacC(130,122) + dw(252,122)
      JacC( 87, 87) = JacC( 87, 87) - dw(253, 87)
      JacC( 87,122) = JacC( 87,122) - dw(253,122)
      JacC( 94, 87) = JacC( 94, 87)+ 0.2500000000000000D+00*dw(253, 87)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(253,122)
      JacC(102, 87) = JacC(102, 87)+ 0.2500000000000000D+00*dw(253, 87)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(253,122)
      JacC(108, 87) = JacC(108, 87)+ 0.1350000000000000D+00*dw(253, 87)
      JacC(108,122) = JacC(108,122)+ 0.1350000000000000D+00*dw(253,122)
      JacC(110, 87) = JacC(110, 87)+ 0.1050000000000000D+00*dw(253, 87)
      JacC(110,122) = JacC(110,122)+ 0.1050000000000000D+00*dw(253,122)
      JacC(113, 87) = JacC(113, 87)+ 0.3050000000000000D+00*dw(253, 87)
      JacC(113,122) = JacC(113,122)+ 0.3050000000000000D+00*dw(253,122)
      JacC(116, 87) = JacC(116, 87)+ 0.5250000000000000D+00*dw(253, 87)
      JacC(116,122) = JacC(116,122)+ 0.5250000000000000D+00*dw(253,122)
      JacC(119, 87) = JacC(119, 87)+ 0.2030000000000000D+00*dw(253, 87)
      JacC(119,122) = JacC(119,122)+ 0.2030000000000000D+00*dw(253,122)
      JacC(122, 87) = JacC(122, 87) - dw(253, 87)
      JacC(122,122) = JacC(122,122) - dw(253,122)
      JacC(128, 87) = JacC(128, 87)+ 0.7730000000000000D+00*dw(253, 87)
      JacC(128,122) = JacC(128,122)+ 0.7730000000000000D+00*dw(253,122)
      JacC(130, 87) = JacC(130, 87) + dw(253, 87)
      JacC(130,122) = JacC(130,122) + dw(253,122)
      JacC( 93, 93) = JacC( 93, 93) - dw(254, 93)
      JacC( 93,122) = JacC( 93,122) - dw(254,122)
      JacC( 94, 93) = JacC( 94, 93)+ 0.2500000000000000D+00*dw(254, 93)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(254,122)
      JacC(102, 93) = JacC(102, 93)+ 0.2500000000000000D+00*dw(254, 93)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(254,122)
      JacC(116, 93) = JacC(116, 93)+ 0.7500000000000000D+00*dw(254, 93)
      JacC(116,122) = JacC(116,122)+ 0.7500000000000000D+00*dw(254,122)
      JacC(119, 93) = JacC(119, 93)+ 0.7500000000000000D+00*dw(254, 93)
      JacC(119,122) = JacC(119,122)+ 0.7500000000000000D+00*dw(254,122)
      JacC(122, 93) = JacC(122, 93) - dw(254, 93)
      JacC(122,122) = JacC(122,122) - dw(254,122)
      JacC(128, 93) = JacC(128, 93)+ 0.7500000000000000D+00*dw(254, 93)
      JacC(128,122) = JacC(128,122)+ 0.7500000000000000D+00*dw(254,122)
      JacC(130, 93) = JacC(130, 93) + dw(254, 93)
      JacC(130,122) = JacC(130,122) + dw(254,122)
      JacC( 77, 77) = JacC( 77, 77) - dw(255, 77)
      JacC( 77,122) = JacC( 77,122) - dw(255,122)
      JacC( 80, 77) = JacC( 80, 77)+ 0.1920000000000000D+00*dw(255, 77)
      JacC( 80,122) = JacC( 80,122)+ 0.1920000000000000D+00*dw(255,122)
      JacC( 94, 77) = JacC( 94, 77)+ 0.2500000000000000D+00*dw(255, 77)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(255,122)
      JacC( 96, 77) = JacC( 96, 77)+ 0.3080000000000000D+00*dw(255, 77)
      JacC( 96,122) = JacC( 96,122)+ 0.3080000000000000D+00*dw(255,122)
      JacC(102, 77) = JacC(102, 77)+ 0.2500000000000000D+00*dw(255, 77)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(255,122)
      JacC(122, 77) = JacC(122, 77) - dw(255, 77)
      JacC(122,122) = JacC(122,122) - dw(255,122)
      JacC(128, 77) = JacC(128, 77)+ 0.1040000000000000D+01*dw(255, 77)
      JacC(128,122) = JacC(128,122)+ 0.1040000000000000D+01*dw(255,122)
      JacC(130, 77) = JacC(130, 77) + dw(255, 77)
      JacC(130,122) = JacC(130,122) + dw(255,122)
      JacC( 71, 71) = JacC( 71, 71) - dw(256, 71)
      JacC( 71,122) = JacC( 71,122) - dw(256,122)
      JacC( 80, 71) = JacC( 80, 71)+ 0.3000000000000000D+00*dw(256, 71)
      JacC( 80,122) = JacC( 80,122)+ 0.3000000000000000D+00*dw(256,122)
      JacC( 85, 71) = JacC( 85, 71)+ 0.7000000000000000D+00*dw(256, 71)
      JacC( 85,122) = JacC( 85,122)+ 0.7000000000000000D+00*dw(256,122)
      JacC(108, 71) = JacC(108, 71)+ 0.6000000000000000D+00*dw(256, 71)
      JacC(108,122) = JacC(108,122)+ 0.6000000000000000D+00*dw(256,122)
      JacC(122, 71) = JacC(122, 71) - dw(256, 71)
      JacC(122,122) = JacC(122,122) - dw(256,122)
      JacC(128, 71) = JacC(128, 71) + dw(256, 71)
      JacC(128,122) = JacC(128,122) + dw(256,122)
      JacC(130, 71) = JacC(130, 71)+ 0.2600000000000000D+01*dw(256, 71)
      JacC(130,122) = JacC(130,122)+ 0.2600000000000000D+01*dw(256,122)
      JacC( 58, 58) = JacC( 58, 58) - dw(257, 58)
      JacC( 58,122) = JacC( 58,122) - dw(257,122)
      JacC( 68, 58) = JacC( 68, 58) + dw(257, 58)
      JacC( 68,122) = JacC( 68,122) + dw(257,122)
      JacC(108, 58) = JacC(108, 58)+ 0.2710000000000000D+00*dw(257, 58)
      JacC(108,122) = JacC(108,122)+ 0.2710000000000000D+00*dw(257,122)
      JacC(122, 58) = JacC(122, 58) - dw(257, 58)
      JacC(122,122) = JacC(122,122) - dw(257,122)
      JacC(128, 58) = JacC(128, 58) + dw(257, 58)
      JacC(128,122) = JacC(128,122) + dw(257,122)
      JacC(130, 58) = JacC(130, 58)+ 0.2000000000000000D+01*dw(257, 58)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(257,122)
      JacC( 57, 57) = JacC( 57, 57) - dw(258, 57)
      JacC( 57,122) = JacC( 57,122) - dw(258,122)
      JacC( 66, 57) = JacC( 66, 57) + dw(258, 57)
      JacC( 66,122) = JacC( 66,122) + dw(258,122)
      JacC(122, 57) = JacC(122, 57) - dw(258, 57)
      JacC(122,122) = JacC(122,122) - dw(258,122)
      JacC(128, 57) = JacC(128, 57) + dw(258, 57)
      JacC(128,122) = JacC(128,122) + dw(258,122)
      JacC(130, 57) = JacC(130, 57) + dw(258, 57)
      JacC(130,122) = JacC(130,122) + dw(258,122)
      JacC( 56, 56) = JacC( 56, 56) - dw(259, 56)
      JacC( 56,122) = JacC( 56,122) - dw(259,122)
      JacC( 76, 56) = JacC( 76, 56) + dw(259, 56)
      JacC( 76,122) = JacC( 76,122) + dw(259,122)
      JacC(110, 56) = JacC(110, 56) + dw(259, 56)
      JacC(110,122) = JacC(110,122) + dw(259,122)
      JacC(122, 56) = JacC(122, 56) - dw(259, 56)
      JacC(122,122) = JacC(122,122) - dw(259,122)
      JacC(128, 56) = JacC(128, 56) + dw(259, 56)
      JacC(128,122) = JacC(128,122) + dw(259,122)
      JacC(130, 56) = JacC(130, 56)+ 0.2000000000000000D+01*dw(259, 56)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(259,122)
      JacC( 65, 65) = JacC( 65, 65) - dw(260, 65)
      JacC( 65,122) = JacC( 65,122) - dw(260,122)
      JacC( 68, 65) = JacC( 68, 65)+ 0.7700000000000000D-01*dw(260, 65)
      JacC( 68,122) = JacC( 68,122)+ 0.7700000000000000D-01*dw(260,122)
      JacC( 76, 65) = JacC( 76, 65)+ 0.7370000000000000D+00*dw(260, 65)
      JacC( 76,122) = JacC( 76,122)+ 0.7370000000000000D+00*dw(260,122)
      JacC( 98, 65) = JacC( 98, 65)+ 0.1860000000000000D+00*dw(260, 65)
      JacC( 98,122) = JacC( 98,122)+ 0.1860000000000000D+00*dw(260,122)
      JacC(108, 65) = JacC(108, 65)+ 0.3680000000000000D+00*dw(260, 65)
      JacC(108,122) = JacC(108,122)+ 0.3680000000000000D+00*dw(260,122)
      JacC(110, 65) = JacC(110, 65)+ 0.6320000000000000D+00*dw(260, 65)
      JacC(110,122) = JacC(110,122)+ 0.6320000000000000D+00*dw(260,122)
      JacC(122, 65) = JacC(122, 65) - dw(260, 65)
      JacC(122,122) = JacC(122,122) - dw(260,122)
      JacC(128, 65) = JacC(128, 65) + dw(260, 65)
      JacC(128,122) = JacC(128,122) + dw(260,122)
      JacC(130, 65) = JacC(130, 65)+ 0.2000000000000000D+01*dw(260, 65)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(260,122)
      JacC( 59, 59) = JacC( 59, 59) - dw(261, 59)
      JacC( 59,122) = JacC( 59,122) - dw(261,122)
      JacC( 66, 59) = JacC( 66, 59) + dw(261, 59)
      JacC( 66,122) = JacC( 66,122) + dw(261,122)
      JacC(122, 59) = JacC(122, 59) - dw(261, 59)
      JacC(122,122) = JacC(122,122) - dw(261,122)
      JacC(128, 59) = JacC(128, 59) + dw(261, 59)
      JacC(128,122) = JacC(128,122) + dw(261,122)
      JacC(130, 59) = JacC(130, 59) + dw(261, 59)
      JacC(130,122) = JacC(130,122) + dw(261,122)
      JacC( 60, 60) = JacC( 60, 60) - dw(262, 60)
      JacC( 60,122) = JacC( 60,122) - dw(262,122)
      JacC( 68, 60) = JacC( 68, 60) + dw(262, 60)
      JacC( 68,122) = JacC( 68,122) + dw(262,122)
      JacC(122, 60) = JacC(122, 60) - dw(262, 60)
      JacC(122,122) = JacC(122,122) - dw(262,122)
      JacC(128, 60) = JacC(128, 60) + dw(262, 60)
      JacC(128,122) = JacC(128,122) + dw(262,122)
      JacC(130, 60) = JacC(130, 60)+ 0.2000000000000000D+01*dw(262, 60)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(262,122)
      JacC( 61, 61) = JacC( 61, 61) - dw(263, 61)
      JacC( 61,122) = JacC( 61,122) - dw(263,122)
      JacC( 76, 61) = JacC( 76, 61) + dw(263, 61)
      JacC( 76,122) = JacC( 76,122) + dw(263,122)
      JacC( 98, 61) = JacC( 98, 61)+ 0.2050000000000000D+01*dw(263, 61)
      JacC( 98,122) = JacC( 98,122)+ 0.2050000000000000D+01*dw(263,122)
      JacC(110, 61) = JacC(110, 61) + dw(263, 61)
      JacC(110,122) = JacC(110,122) + dw(263,122)
      JacC(122, 61) = JacC(122, 61) - dw(263, 61)
      JacC(122,122) = JacC(122,122) - dw(263,122)
      JacC(128, 61) = JacC(128, 61) + dw(263, 61)
      JacC(128,122) = JacC(128,122) + dw(263,122)
      JacC(130, 61) = JacC(130, 61)+ 0.2000000000000000D+01*dw(263, 61)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(263,122)
      JacC( 54, 67) = JacC( 54, 67) + dw(264, 67)
      JacC( 54,122) = JacC( 54,122) + dw(264,122)
      JacC( 67, 67) = JacC( 67, 67) - dw(264, 67)
      JacC( 67,122) = JacC( 67,122) - dw(264,122)
      JacC(122, 67) = JacC(122, 67) - dw(264, 67)
      JacC(122,122) = JacC(122,122) - dw(264,122)
      JacC(128, 67) = JacC(128, 67) + dw(264, 67)
      JacC(128,122) = JacC(128,122) + dw(264,122)
      JacC(130, 67) = JacC(130, 67) + dw(264, 67)
      JacC(130,122) = JacC(130,122) + dw(264,122)
      JacC( 54, 54) = JacC( 54, 54) - dw(265, 54)
      JacC( 54,122) = JacC( 54,122) - dw(265,122)
      JacC( 55, 54) = JacC( 55, 54) + dw(265, 54)
      JacC( 55,122) = JacC( 55,122) + dw(265,122)
      JacC(122, 54) = JacC(122, 54) - dw(265, 54)
      JacC(122,122) = JacC(122,122) - dw(265,122)
      JacC(128, 54) = JacC(128, 54) + dw(265, 54)
      JacC(128,122) = JacC(128,122) + dw(265,122)
      JacC(130, 54) = JacC(130, 54) + dw(265, 54)
      JacC(130,122) = JacC(130,122) + dw(265,122)
      JacC( 75,104) = JacC( 75,104)+ 0.3200000000000000D+00*dw(266,104)
      JacC( 75,122) = JacC( 75,122)+ 0.3200000000000000D+00*dw(266,122)
      JacC(104,104) = JacC(104,104) - dw(266,104)
      JacC(104,122) = JacC(104,122) - dw(266,122)
      JacC(108,104) = JacC(108,104)+ 0.6800000000000000D+00*dw(266,104)
      JacC(108,122) = JacC(108,122)+ 0.6800000000000000D+00*dw(266,122)
      JacC(122,104) = JacC(122,104) - dw(266,104)
      JacC(122,122) = JacC(122,122) - dw(266,122)
      JacC(126,104) = JacC(126,104)+ 0.6800000000000000D+00*dw(266,104)
      JacC(126,122) = JacC(126,122)+ 0.6800000000000000D+00*dw(266,122)
      JacC(128,104) = JacC(128,104) + dw(266,104)
      JacC(128,122) = JacC(128,122) + dw(266,122)
      JacC(130,104) = JacC(130,104)+ 0.2000000000000000D+01*dw(266,104)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(266,122)
      JacC(115,124) = JacC(115,124)+ 0.1000000000000000D+00*dw(267,124)
      JacC(115,122) = JacC(115,122)+ 0.1000000000000000D+00*dw(267,122)
      JacC(122,124) = JacC(122,124)- 0.9999999999999998D-01*dw(267,124)
      JacC(122,122) = JacC(122,122)- 0.9999999999999998D-01*dw(267,122)
      JacC(124,124) = JacC(124,124) - dw(267,124)
      JacC(124,122) = JacC(124,122) - dw(267,122)
      JacC(128,124) = JacC(128,124) + dw(267,124)
      JacC(128,122) = JacC(128,122) + dw(267,122)
      JacC(130,124) = JacC(130,124)+ 0.9000000000000000D+00*dw(267,124)
      JacC(130,122) = JacC(130,122)+ 0.9000000000000000D+00*dw(267,122)
      JacC(115,120) = JacC(115,120)+ 0.1000000000000000D+00*dw(268,120)
      JacC(115,122) = JacC(115,122)+ 0.1000000000000000D+00*dw(268,122)
      JacC(120,120) = JacC(120,120) - dw(268,120)
      JacC(120,122) = JacC(120,122) - dw(268,122)
      JacC(122,120) = JacC(122,120)- 0.9999999999999998D-01*dw(268,120)
      JacC(122,122) = JacC(122,122)- 0.9999999999999998D-01*dw(268,122)
      JacC(128,120) = JacC(128,120) + dw(268,120)
      JacC(128,122) = JacC(128,122) + dw(268,122)
      JacC(130,120) = JacC(130,120)+ 0.9000000000000000D+00*dw(268,120)
      JacC(130,122) = JacC(130,122)+ 0.9000000000000000D+00*dw(268,122)
      JacC( 79, 79) = JacC( 79, 79) - dw(269, 79)
      JacC( 79,122) = JacC( 79,122) - dw(269,122)
      JacC( 94, 79) = JacC( 94, 79)+ 0.2500000000000000D+00*dw(269, 79)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(269,122)
      JacC(102, 79) = JacC(102, 79)+ 0.2500000000000000D+00*dw(269, 79)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(269,122)
      JacC(115, 79) = JacC(115, 79)+ 0.1250000000000000D+00*dw(269, 79)
      JacC(115,122) = JacC(115,122)+ 0.1250000000000000D+00*dw(269,122)
      JacC(122, 79) = JacC(122, 79) - dw(269, 79)
      JacC(122,122) = JacC(122,122) - dw(269,122)
      JacC(124, 79) = JacC(124, 79)+ 0.5000000000000000D+00*dw(269, 79)
      JacC(124,122) = JacC(124,122)+ 0.5000000000000000D+00*dw(269,122)
      JacC(128, 79) = JacC(128, 79)+ 0.1500000000000000D+01*dw(269, 79)
      JacC(128,122) = JacC(128,122)+ 0.1500000000000000D+01*dw(269,122)
      JacC(130, 79) = JacC(130, 79)+ 0.5000000000000000D+00*dw(269, 79)
      JacC(130,122) = JacC(130,122)+ 0.5000000000000000D+00*dw(269,122)
      JacC( 70, 70) = JacC( 70, 70) - dw(270, 70)
      JacC( 70,122) = JacC( 70,122) - dw(270,122)
      JacC( 76, 70) = JacC( 76, 70)+ 0.3340000000000000D+00*dw(270, 70)
      JacC( 76,122) = JacC( 76,122)+ 0.3340000000000000D+00*dw(270,122)
      JacC( 94, 70) = JacC( 94, 70)+ 0.2500000000000000D+00*dw(270, 70)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(270,122)
      JacC(102, 70) = JacC(102, 70)+ 0.2500000000000000D+00*dw(270, 70)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(270,122)
      JacC(122, 70) = JacC(122, 70) - dw(270, 70)
      JacC(122,122) = JacC(122,122) - dw(270,122)
      JacC(128, 70) = JacC(128, 70) + dw(270, 70)
      JacC(128,122) = JacC(128,122) + dw(270,122)
      JacC(130, 70) = JacC(130, 70)+ 0.8340000000000000D+00*dw(270, 70)
      JacC(130,122) = JacC(130,122)+ 0.8340000000000000D+00*dw(270,122)
      JacC( 76,114) = JacC( 76,114)+ 0.5000000000000000D+00*dw(271,114)
      JacC( 76,122) = JacC( 76,122)+ 0.5000000000000000D+00*dw(271,122)
      JacC( 94,114) = JacC( 94,114)+ 0.2500000000000000D+00*dw(271,114)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(271,122)
      JacC(102,114) = JacC(102,114)+ 0.2500000000000000D+00*dw(271,114)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(271,122)
      JacC(114,114) = JacC(114,114) - dw(271,114)
      JacC(114,122) = JacC(114,122) - dw(271,122)
      JacC(122,114) = JacC(122,114) - dw(271,114)
      JacC(122,122) = JacC(122,122) - dw(271,122)
      JacC(128,114) = JacC(128,114)+ 0.7500000000000000D+00*dw(271,114)
      JacC(128,122) = JacC(128,122)+ 0.7500000000000000D+00*dw(271,122)
      JacC(130,114) = JacC(130,114) + dw(271,114)
      JacC(130,122) = JacC(130,122) + dw(271,122)
      JacC( 82, 82) = JacC( 82, 82) - dw(272, 82)
      JacC( 82,122) = JacC( 82,122) - dw(272,122)
      JacC(118, 82) = JacC(118, 82) + dw(272, 82)
      JacC(118,122) = JacC(118,122) + dw(272,122)
      JacC(122, 82) = JacC(122, 82) - dw(272, 82)
      JacC(122,122) = JacC(122,122) - dw(272,122)
      JacC(128, 82) = JacC(128, 82) + dw(272, 82)
      JacC(128,122) = JacC(128,122) + dw(272,122)
      JacC(130, 82) = JacC(130, 82)+ 0.2000000000000000D+01*dw(272, 82)
      JacC(130,122) = JacC(130,122)+ 0.2000000000000000D+01*dw(272,122)
      JacC( 81, 81) = JacC( 81, 81) - dw(273, 81)
      JacC( 81,122) = JacC( 81,122) - dw(273,122)
      JacC( 94, 81) = JacC( 94, 81)+ 0.2500000000000000D+00*dw(273, 81)
      JacC( 94,122) = JacC( 94,122)+ 0.2500000000000000D+00*dw(273,122)
      JacC(102, 81) = JacC(102, 81)+ 0.2500000000000000D+00*dw(273, 81)
      JacC(102,122) = JacC(102,122)+ 0.2500000000000000D+00*dw(273,122)
      JacC(116, 81) = JacC(116, 81)+ 0.3480000000000000D+00*dw(273, 81)
      JacC(116,122) = JacC(116,122)+ 0.3480000000000000D+00*dw(273,122)
      JacC(118, 81) = JacC(118, 81)+ 0.5000000000000000D+00*dw(273, 81)
      JacC(118,122) = JacC(118,122)+ 0.5000000000000000D+00*dw(273,122)
      JacC(119, 81) = JacC(119, 81)+ 0.9300000000000000D+00*dw(273, 81)
      JacC(119,122) = JacC(119,122)+ 0.9300000000000000D+00*dw(273,122)
      JacC(122, 81) = JacC(122, 81) - dw(273, 81)
      JacC(122,122) = JacC(122,122) - dw(273,122)
      JacC(123, 81) = JacC(123, 81)+ 0.5000000000000000D+00*dw(273, 81)
      JacC(123,122) = JacC(123,122)+ 0.5000000000000000D+00*dw(273,122)
      JacC(128, 81) = JacC(128, 81)+ 0.9650000000000000D+00*dw(273, 81)
      JacC(128,122) = JacC(128,122)+ 0.9650000000000000D+00*dw(273,122)
      JacC(130, 81) = JacC(130, 81)+ 0.5000000000000000D+00*dw(273, 81)
      JacC(130,122) = JacC(130,122)+ 0.5000000000000000D+00*dw(273,122)
      JacC( 95,121) = JacC( 95,121) + dw(274,121)
      JacC( 95,124) = JacC( 95,124) + dw(274,124)
      JacC(115,121) = JacC(115,121)+ 0.5000000000000000D+00*dw(274,121)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(274,124)
      JacC(121,121) = JacC(121,121) - dw(274,121)
      JacC(121,124) = JacC(121,124) - dw(274,124)
      JacC(122,121) = JacC(122,121)+ 0.5000000000000000D+00*dw(274,121)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(274,124)
      JacC(124,121) = JacC(124,121) - dw(274,121)
      JacC(124,124) = JacC(124,124) - dw(274,124)
      JacC(130,121) = JacC(130,121)+ 0.5000000000000000D+00*dw(274,121)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(274,124)
      JacC(108,117) = JacC(108,117)+ 0.6700000000000000D-01*dw(275,117)
      JacC(108,124) = JacC(108,124)+ 0.6700000000000000D-01*dw(275,124)
      JacC(115,117) = JacC(115,117)+ 0.5000000000000000D+00*dw(275,117)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(275,124)
      JacC(116,117) = JacC(116,117)+ 0.6620000000000000D+00*dw(275,117)
      JacC(116,124) = JacC(116,124)+ 0.6620000000000000D+00*dw(275,124)
      JacC(117,117) = JacC(117,117) - dw(275,117)
      JacC(117,124) = JacC(117,124) - dw(275,124)
      JacC(119,117) = JacC(119,117)+ 0.2730000000000000D+00*dw(275,117)
      JacC(119,124) = JacC(119,124)+ 0.2730000000000000D+00*dw(275,124)
      JacC(121,117) = JacC(121,117)+ 0.2600000000000000D-01*dw(275,117)
      JacC(121,124) = JacC(121,124)+ 0.2600000000000000D-01*dw(275,124)
      JacC(122,117) = JacC(122,117)+ 0.5800000000000000D+00*dw(275,117)
      JacC(122,124) = JacC(122,124)+ 0.5800000000000000D+00*dw(275,124)
      JacC(124,117) = JacC(124,117) - dw(275,117)
      JacC(124,124) = JacC(124,124) - dw(275,124)
      JacC(127,117) = JacC(127,117)+ 0.2600000000000000D-01*dw(275,117)
      JacC(127,124) = JacC(127,124)+ 0.2600000000000000D-01*dw(275,124)
      JacC(128,117) = JacC(128,117)+ 0.1300000000000000D+00*dw(275,117)
      JacC(128,124) = JacC(128,124)+ 0.1300000000000000D+00*dw(275,124)
      JacC(130,117) = JacC(130,117)+ 0.3940000000000000D+00*dw(275,117)
      JacC(130,124) = JacC(130,124)+ 0.3940000000000000D+00*dw(275,124)
      JacC( 92, 92) = JacC( 92, 92) - dw(276, 92)
      JacC( 92,124) = JacC( 92,124) - dw(276,124)
      JacC(115, 92) = JacC(115, 92)+ 0.5000000000000000D+00*dw(276, 92)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(276,124)
      JacC(116, 92) = JacC(116, 92)+ 0.8240000000000000D+00*dw(276, 92)
      JacC(116,124) = JacC(116,124)+ 0.8240000000000000D+00*dw(276,124)
      JacC(119, 92) = JacC(119, 92)+ 0.3810000000000000D+00*dw(276, 92)
      JacC(119,124) = JacC(119,124)+ 0.3810000000000000D+00*dw(276,124)
      JacC(121, 92) = JacC(121, 92)+ 0.1400000000000000D+00*dw(276, 92)
      JacC(121,124) = JacC(121,124)+ 0.1400000000000000D+00*dw(276,124)
      JacC(122, 92) = JacC(122, 92)+ 0.5180000000000000D+00*dw(276, 92)
      JacC(122,124) = JacC(122,124)+ 0.5180000000000000D+00*dw(276,124)
      JacC(124, 92) = JacC(124, 92) - dw(276, 92)
      JacC(124,124) = JacC(124,124) - dw(276,124)
      JacC(127, 92) = JacC(127, 92)+ 0.1910000000000000D+00*dw(276, 92)
      JacC(127,124) = JacC(127,124)+ 0.1910000000000000D+00*dw(276,124)
      JacC(128, 92) = JacC(128, 92)+ 0.4200000000000000D-01*dw(276, 92)
      JacC(128,124) = JacC(128,124)+ 0.4200000000000000D-01*dw(276,124)
      JacC(130, 92) = JacC(130, 92)+ 0.3420000000000000D+00*dw(276, 92)
      JacC(130,124) = JacC(130,124)+ 0.3420000000000000D+00*dw(276,124)
      JacC( 69, 69) = JacC( 69, 69) - dw(277, 69)
      JacC( 69,124) = JacC( 69,124) - dw(277,124)
      JacC(115, 69) = JacC(115, 69)+ 0.4950000000000000D+00*dw(277, 69)
      JacC(115,124) = JacC(115,124)+ 0.4950000000000000D+00*dw(277,124)
      JacC(116, 69) = JacC(116, 69)+ 0.6420000000000000D+00*dw(277, 69)
      JacC(116,124) = JacC(116,124)+ 0.6420000000000000D+00*dw(277,124)
      JacC(119, 69) = JacC(119, 69)+ 0.2170000000000000D+00*dw(277, 69)
      JacC(119,124) = JacC(119,124)+ 0.2170000000000000D+00*dw(277,124)
      JacC(121, 69) = JacC(121, 69)+ 0.6700000000000000D-01*dw(277, 69)
      JacC(121,124) = JacC(121,124)+ 0.6700000000000000D-01*dw(277,124)
      JacC(122, 69) = JacC(122, 69)+ 0.5000000000000000D+00*dw(277, 69)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(277,124)
      JacC(124, 69) = JacC(124, 69) - dw(277, 69)
      JacC(124,124) = JacC(124,124) - dw(277,124)
      JacC(127, 69) = JacC(127, 69)+ 0.2080000000000000D+00*dw(277, 69)
      JacC(127,124) = JacC(127,124)+ 0.2080000000000000D+00*dw(277,124)
      JacC(130, 69) = JacC(130, 69)+ 0.3030000000000000D+00*dw(277, 69)
      JacC(130,124) = JacC(130,124)+ 0.3030000000000000D+00*dw(277,124)
      JacC( 73, 73) = JacC( 73, 73) - dw(278, 73)
      JacC( 73,124) = JacC( 73,124) - dw(278,124)
      JacC(115, 73) = JacC(115, 73)+ 0.5000000000000000D+00*dw(278, 73)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(278,124)
      JacC(119, 73) = JacC(119, 73)+ 0.2000000000000000D+00*dw(278, 73)
      JacC(119,124) = JacC(119,124)+ 0.2000000000000000D+00*dw(278,124)
      JacC(122, 73) = JacC(122, 73)+ 0.5000000000000000D+00*dw(278, 73)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(278,124)
      JacC(124, 73) = JacC(124, 73) - dw(278, 73)
      JacC(124,124) = JacC(124,124) - dw(278,124)
      JacC(128, 73) = JacC(128, 73)+ 0.1600000000000000D+01*dw(278, 73)
      JacC(128,124) = JacC(128,124)+ 0.1600000000000000D+01*dw(278,124)
      JacC(130, 73) = JacC(130, 73)+ 0.5000000000000000D+00*dw(278, 73)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(278,124)
      JacC( 72, 72) = JacC( 72, 72) - dw(279, 72)
      JacC( 72,124) = JacC( 72,124) - dw(279,124)
      JacC(115, 72) = JacC(115, 72)+ 0.5000000000000000D+00*dw(279, 72)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(279,124)
      JacC(116, 72) = JacC(116, 72)+ 0.6000000000000000D-01*dw(279, 72)
      JacC(116,124) = JacC(116,124)+ 0.6000000000000000D-01*dw(279,124)
      JacC(119, 72) = JacC(119, 72)+ 0.9399999999999999D+00*dw(279, 72)
      JacC(119,124) = JacC(119,124)+ 0.9399999999999999D+00*dw(279,124)
      JacC(122, 72) = JacC(122, 72)+ 0.5000000000000000D+00*dw(279, 72)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(279,124)
      JacC(124, 72) = JacC(124, 72) - dw(279, 72)
      JacC(124,124) = JacC(124,124) - dw(279,124)
      JacC(128, 72) = JacC(128, 72) + dw(279, 72)
      JacC(128,124) = JacC(128,124) + dw(279,124)
      JacC(130, 72) = JacC(130, 72)+ 0.5000000000000000D+00*dw(279, 72)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(279,124)
      JacC(101,101) = JacC(101,101) - dw(280,101)
      JacC(101,124) = JacC(101,124) - dw(280,124)
      JacC(115,101) = JacC(115,101)+ 0.5000000000000000D+00*dw(280,101)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(280,124)
      JacC(116,101) = JacC(116,101)+ 0.2900000000000000D+00*dw(280,101)
      JacC(116,124) = JacC(116,124)+ 0.2900000000000000D+00*dw(280,124)
      JacC(119,101) = JacC(119,101)+ 0.1710000000000000D+01*dw(280,101)
      JacC(119,124) = JacC(119,124)+ 0.1710000000000000D+01*dw(280,124)
      JacC(122,101) = JacC(122,101)+ 0.5000000000000000D+00*dw(280,101)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(280,124)
      JacC(124,101) = JacC(124,101) - dw(280,101)
      JacC(124,124) = JacC(124,124) - dw(280,124)
      JacC(130,101) = JacC(130,101)+ 0.5000000000000000D+00*dw(280,101)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(280,124)
      JacC( 83, 83) = JacC( 83, 83) - dw(281, 83)
      JacC( 83,124) = JacC( 83,124) - dw(281,124)
      JacC( 84, 83) = JacC( 84, 83)+ 0.3050000000000000D+00*dw(281, 83)
      JacC( 84,124) = JacC( 84,124)+ 0.3050000000000000D+00*dw(281,124)
      JacC( 96, 83) = JacC( 96, 83)+ 0.2190000000000000D+00*dw(281, 83)
      JacC( 96,124) = JacC( 96,124)+ 0.2190000000000000D+00*dw(281,124)
      JacC(115, 83) = JacC(115, 83)+ 0.5000000000000000D+00*dw(281, 83)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(281,124)
      JacC(122, 83) = JacC(122, 83)+ 0.5000000000000000D+00*dw(281, 83)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(281,124)
      JacC(124, 83) = JacC(124, 83) - dw(281, 83)
      JacC(124,124) = JacC(124,124) - dw(281,124)
      JacC(128, 83) = JacC(128, 83)+ 0.1048000000000000D+01*dw(281, 83)
      JacC(128,124) = JacC(128,124)+ 0.1048000000000000D+01*dw(281,124)
      JacC(130, 83) = JacC(130, 83)+ 0.5000000000000000D+00*dw(281, 83)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(281,124)
      JacC( 89,109) = JacC( 89,109)+ 0.1670000000000000D+00*dw(282,109)
      JacC( 89,124) = JacC( 89,124)+ 0.1670000000000000D+00*dw(282,124)
      JacC(109,109) = JacC(109,109) - dw(282,109)
      JacC(109,124) = JacC(109,124) - dw(282,124)
      JacC(110,109) = JacC(110,109)+ 0.3300000000000000D+00*dw(282,109)
      JacC(110,124) = JacC(110,124)+ 0.3300000000000000D+00*dw(282,124)
      JacC(113,109) = JacC(113,109)+ 0.1670000000000000D+00*dw(282,109)
      JacC(113,124) = JacC(113,124)+ 0.1670000000000000D+00*dw(282,124)
      JacC(115,109) = JacC(115,109)+ 0.5830000000000000D+00*dw(282,109)
      JacC(115,124) = JacC(115,124)+ 0.5830000000000000D+00*dw(282,124)
      JacC(122,109) = JacC(122,109)+ 0.5000000000000000D+00*dw(282,109)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(282,124)
      JacC(124,109) = JacC(124,109)- 0.8330000000000000D+00*dw(282,109)
      JacC(124,124) = JacC(124,124)- 0.8330000000000000D+00*dw(282,124)
      JacC(128,109) = JacC(128,109) + dw(282,109)
      JacC(128,124) = JacC(128,124) + dw(282,124)
      JacC(130,109) = JacC(130,109)+ 0.5000000000000000D+00*dw(282,109)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(282,124)
      JacC( 88, 88) = JacC( 88, 88) - dw(283, 88)
      JacC( 88,124) = JacC( 88,124) - dw(283,124)
      JacC(110, 88) = JacC(110, 88)+ 0.5000000000000000D+00*dw(283, 88)
      JacC(110,124) = JacC(110,124)+ 0.5000000000000000D+00*dw(283,124)
      JacC(115, 88) = JacC(115, 88)+ 0.1083000000000000D+01*dw(283, 88)
      JacC(115,124) = JacC(115,124)+ 0.1083000000000000D+01*dw(283,124)
      JacC(119, 88) = JacC(119, 88)+ 0.2300000000000000D+01*dw(283, 88)
      JacC(119,124) = JacC(119,124)+ 0.2300000000000000D+01*dw(283,124)
      JacC(122, 88) = JacC(122, 88)+ 0.5000000000000000D+00*dw(283, 88)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(283,124)
      JacC(124, 88) = JacC(124, 88)+ 0.1599999999999999D+00*dw(283, 88)
      JacC(124,124) = JacC(124,124)+ 0.1599999999999999D+00*dw(283,124)
      JacC(127, 88) = JacC(127, 88)+ 0.1160000000000000D+01*dw(283, 88)
      JacC(127,124) = JacC(127,124)+ 0.1160000000000000D+01*dw(283,124)
      JacC(128, 88) = JacC(128, 88) + dw(283, 88)
      JacC(128,124) = JacC(128,124) + dw(283,124)
      JacC(130, 88) = JacC(130, 88)+ 0.5000000000000000D+00*dw(283, 88)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(283,124)
      JacC( 87, 87) = JacC( 87, 87) - dw(284, 87)
      JacC( 87,124) = JacC( 87,124) - dw(284,124)
      JacC(108, 87) = JacC(108, 87)+ 0.1800000000000000D+00*dw(284, 87)
      JacC(108,124) = JacC(108,124)+ 0.1800000000000000D+00*dw(284,124)
      JacC(110, 87) = JacC(110, 87)+ 0.1050000000000000D+00*dw(284, 87)
      JacC(110,124) = JacC(110,124)+ 0.1050000000000000D+00*dw(284,124)
      JacC(113, 87) = JacC(113, 87)+ 0.5000000000000000D+00*dw(284, 87)
      JacC(113,124) = JacC(113,124)+ 0.5000000000000000D+00*dw(284,124)
      JacC(115, 87) = JacC(115, 87)+ 0.5000000000000000D+00*dw(284, 87)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(284,124)
      JacC(116, 87) = JacC(116, 87)+ 0.7000000000000000D+00*dw(284, 87)
      JacC(116,124) = JacC(116,124)+ 0.7000000000000000D+00*dw(284,124)
      JacC(119, 87) = JacC(119, 87)+ 0.2700000000000000D+00*dw(284, 87)
      JacC(119,124) = JacC(119,124)+ 0.2700000000000000D+00*dw(284,124)
      JacC(122, 87) = JacC(122, 87)+ 0.5000000000000000D+00*dw(284, 87)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(284,124)
      JacC(124, 87) = JacC(124, 87) - dw(284, 87)
      JacC(124,124) = JacC(124,124) - dw(284,124)
      JacC(128, 87) = JacC(128, 87)+ 0.3000000000000000D-01*dw(284, 87)
      JacC(128,124) = JacC(128,124)+ 0.3000000000000000D-01*dw(284,124)
      JacC(130, 87) = JacC(130, 87)+ 0.5000000000000000D+00*dw(284, 87)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(284,124)
      JacC( 93, 93) = JacC( 93, 93) - dw(285, 93)
      JacC( 93,124) = JacC( 93,124) - dw(285,124)
      JacC(115, 93) = JacC(115, 93) + dw(285, 93)
      JacC(115,124) = JacC(115,124) + dw(285,124)
      JacC(116, 93) = JacC(116, 93) + dw(285, 93)
      JacC(116,124) = JacC(116,124) + dw(285,124)
      JacC(119, 93) = JacC(119, 93) + dw(285, 93)
      JacC(119,124) = JacC(119,124) + dw(285,124)
      JacC(122, 93) = JacC(122, 93)+ 0.5000000000000000D+00*dw(285, 93)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(285,124)
      JacC(124, 93) = JacC(124, 93) - dw(285, 93)
      JacC(124,124) = JacC(124,124) - dw(285,124)
      JacC(130, 93) = JacC(130, 93)+ 0.5000000000000000D+00*dw(285, 93)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(285,124)
      JacC( 77, 77) = JacC( 77, 77) - dw(286, 77)
      JacC( 77,124) = JacC( 77,124) - dw(286,124)
      JacC( 80, 77) = JacC( 80, 77)+ 0.1920000000000000D+00*dw(286, 77)
      JacC( 80,124) = JacC( 80,124)+ 0.1920000000000000D+00*dw(286,124)
      JacC( 96, 77) = JacC( 96, 77)+ 0.3080000000000000D+00*dw(286, 77)
      JacC( 96,124) = JacC( 96,124)+ 0.3080000000000000D+00*dw(286,124)
      JacC(115, 77) = JacC(115, 77)+ 0.5000000000000000D+00*dw(286, 77)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(286,124)
      JacC(122, 77) = JacC(122, 77)+ 0.5000000000000000D+00*dw(286, 77)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(286,124)
      JacC(124, 77) = JacC(124, 77) - dw(286, 77)
      JacC(124,124) = JacC(124,124) - dw(286,124)
      JacC(128, 77) = JacC(128, 77)+ 0.3850000000000000D+00*dw(286, 77)
      JacC(128,124) = JacC(128,124)+ 0.3850000000000000D+00*dw(286,124)
      JacC(130, 77) = JacC(130, 77)+ 0.5000000000000000D+00*dw(286, 77)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(286,124)
      JacC( 71, 71) = JacC( 71, 71) - dw(287, 71)
      JacC( 71,124) = JacC( 71,124) - dw(287,124)
      JacC( 80, 71) = JacC( 80, 71)+ 0.3000000000000000D+00*dw(287, 71)
      JacC( 80,124) = JacC( 80,124)+ 0.3000000000000000D+00*dw(287,124)
      JacC( 85, 71) = JacC( 85, 71)+ 0.7000000000000000D+00*dw(287, 71)
      JacC( 85,124) = JacC( 85,124)+ 0.7000000000000000D+00*dw(287,124)
      JacC(108, 71) = JacC(108, 71)+ 0.6000000000000000D+00*dw(287, 71)
      JacC(108,124) = JacC(108,124)+ 0.6000000000000000D+00*dw(287,124)
      JacC(122, 71) = JacC(122, 71) + dw(287, 71)
      JacC(122,124) = JacC(122,124) + dw(287,124)
      JacC(124, 71) = JacC(124, 71) - dw(287, 71)
      JacC(124,124) = JacC(124,124) - dw(287,124)
      JacC(130, 71) = JacC(130, 71)+ 0.6000000000000000D+00*dw(287, 71)
      JacC(130,124) = JacC(130,124)+ 0.6000000000000000D+00*dw(287,124)
      JacC( 58, 58) = JacC( 58, 58) - dw(288, 58)
      JacC( 58,124) = JacC( 58,124) - dw(288,124)
      JacC( 68, 58) = JacC( 68, 58) + dw(288, 58)
      JacC( 68,124) = JacC( 68,124) + dw(288,124)
      JacC(122, 58) = JacC(122, 58) + dw(288, 58)
      JacC(122,124) = JacC(122,124) + dw(288,124)
      JacC(124, 58) = JacC(124, 58) - dw(288, 58)
      JacC(124,124) = JacC(124,124) - dw(288,124)
      JacC(130, 58) = JacC(130, 58) + dw(288, 58)
      JacC(130,124) = JacC(130,124) + dw(288,124)
      JacC( 57, 57) = JacC( 57, 57) - dw(289, 57)
      JacC( 57,124) = JacC( 57,124) - dw(289,124)
      JacC( 66, 57) = JacC( 66, 57) + dw(289, 57)
      JacC( 66,124) = JacC( 66,124) + dw(289,124)
      JacC(122, 57) = JacC(122, 57) + dw(289, 57)
      JacC(122,124) = JacC(122,124) + dw(289,124)
      JacC(124, 57) = JacC(124, 57) - dw(289, 57)
      JacC(124,124) = JacC(124,124) - dw(289,124)
      JacC( 56, 56) = JacC( 56, 56) - dw(290, 56)
      JacC( 56,124) = JacC( 56,124) - dw(290,124)
      JacC( 76, 56) = JacC( 76, 56) + dw(290, 56)
      JacC( 76,124) = JacC( 76,124) + dw(290,124)
      JacC(110, 56) = JacC(110, 56) + dw(290, 56)
      JacC(110,124) = JacC(110,124) + dw(290,124)
      JacC(122, 56) = JacC(122, 56) + dw(290, 56)
      JacC(122,124) = JacC(122,124) + dw(290,124)
      JacC(124, 56) = JacC(124, 56) - dw(290, 56)
      JacC(124,124) = JacC(124,124) - dw(290,124)
      JacC(130, 56) = JacC(130, 56) + dw(290, 56)
      JacC(130,124) = JacC(130,124) + dw(290,124)
      JacC( 61, 61) = JacC( 61, 61) - dw(291, 61)
      JacC( 61,124) = JacC( 61,124) - dw(291,124)
      JacC( 76, 61) = JacC( 76, 61) + dw(291, 61)
      JacC( 76,124) = JacC( 76,124) + dw(291,124)
      JacC( 98, 61) = JacC( 98, 61)+ 0.2050000000000000D+01*dw(291, 61)
      JacC( 98,124) = JacC( 98,124)+ 0.2050000000000000D+01*dw(291,124)
      JacC(110, 61) = JacC(110, 61) + dw(291, 61)
      JacC(110,124) = JacC(110,124) + dw(291,124)
      JacC(122, 61) = JacC(122, 61) + dw(291, 61)
      JacC(122,124) = JacC(122,124) + dw(291,124)
      JacC(124, 61) = JacC(124, 61) - dw(291, 61)
      JacC(124,124) = JacC(124,124) - dw(291,124)
      JacC(130, 61) = JacC(130, 61) + dw(291, 61)
      JacC(130,124) = JacC(130,124) + dw(291,124)
      JacC( 54, 67) = JacC( 54, 67) + dw(292, 67)
      JacC( 54,124) = JacC( 54,124) + dw(292,124)
      JacC( 67, 67) = JacC( 67, 67) - dw(292, 67)
      JacC( 67,124) = JacC( 67,124) - dw(292,124)
      JacC(122, 67) = JacC(122, 67) + dw(292, 67)
      JacC(122,124) = JacC(122,124) + dw(292,124)
      JacC(124, 67) = JacC(124, 67) - dw(292, 67)
      JacC(124,124) = JacC(124,124) - dw(292,124)
      JacC( 54, 54) = JacC( 54, 54) - dw(293, 54)
      JacC( 54,124) = JacC( 54,124) - dw(293,124)
      JacC( 55, 54) = JacC( 55, 54) + dw(293, 54)
      JacC( 55,124) = JacC( 55,124) + dw(293,124)
      JacC(122, 54) = JacC(122, 54) + dw(293, 54)
      JacC(122,124) = JacC(122,124) + dw(293,124)
      JacC(124, 54) = JacC(124, 54) - dw(293, 54)
      JacC(124,124) = JacC(124,124) - dw(293,124)
      JacC( 65, 65) = JacC( 65, 65) - dw(294, 65)
      JacC( 65,124) = JacC( 65,124) - dw(294,124)
      JacC( 68, 65) = JacC( 68, 65)+ 0.7700000000000000D-01*dw(294, 65)
      JacC( 68,124) = JacC( 68,124)+ 0.7700000000000000D-01*dw(294,124)
      JacC( 76, 65) = JacC( 76, 65)+ 0.7370000000000000D+00*dw(294, 65)
      JacC( 76,124) = JacC( 76,124)+ 0.7370000000000000D+00*dw(294,124)
      JacC( 98, 65) = JacC( 98, 65)+ 0.1860000000000000D+00*dw(294, 65)
      JacC( 98,124) = JacC( 98,124)+ 0.1860000000000000D+00*dw(294,124)
      JacC(108, 65) = JacC(108, 65)+ 0.3680000000000000D+00*dw(294, 65)
      JacC(108,124) = JacC(108,124)+ 0.3680000000000000D+00*dw(294,124)
      JacC(110, 65) = JacC(110, 65)+ 0.6320000000000000D+00*dw(294, 65)
      JacC(110,124) = JacC(110,124)+ 0.6320000000000000D+00*dw(294,124)
      JacC(122, 65) = JacC(122, 65) + dw(294, 65)
      JacC(122,124) = JacC(122,124) + dw(294,124)
      JacC(124, 65) = JacC(124, 65) - dw(294, 65)
      JacC(124,124) = JacC(124,124) - dw(294,124)
      JacC(130, 65) = JacC(130, 65) + dw(294, 65)
      JacC(130,124) = JacC(130,124) + dw(294,124)
      JacC( 59, 59) = JacC( 59, 59) - dw(295, 59)
      JacC( 59,124) = JacC( 59,124) - dw(295,124)
      JacC( 66, 59) = JacC( 66, 59) + dw(295, 59)
      JacC( 66,124) = JacC( 66,124) + dw(295,124)
      JacC(122, 59) = JacC(122, 59) + dw(295, 59)
      JacC(122,124) = JacC(122,124) + dw(295,124)
      JacC(124, 59) = JacC(124, 59) - dw(295, 59)
      JacC(124,124) = JacC(124,124) - dw(295,124)
      JacC( 60, 60) = JacC( 60, 60) - dw(296, 60)
      JacC( 60,124) = JacC( 60,124) - dw(296,124)
      JacC( 68, 60) = JacC( 68, 60) + dw(296, 60)
      JacC( 68,124) = JacC( 68,124) + dw(296,124)
      JacC(122, 60) = JacC(122, 60) + dw(296, 60)
      JacC(122,124) = JacC(122,124) + dw(296,124)
      JacC(124, 60) = JacC(124, 60) - dw(296, 60)
      JacC(124,124) = JacC(124,124) - dw(296,124)
      JacC(130, 60) = JacC(130, 60) + dw(296, 60)
      JacC(130,124) = JacC(130,124) + dw(296,124)
      JacC( 75,104) = JacC( 75,104)+ 0.3200000000000000D+00*dw(297,104)
      JacC( 75,124) = JacC( 75,124)+ 0.3200000000000000D+00*dw(297,124)
      JacC(104,104) = JacC(104,104) - dw(297,104)
      JacC(104,124) = JacC(104,124) - dw(297,124)
      JacC(108,104) = JacC(108,104)+ 0.6800000000000000D+00*dw(297,104)
      JacC(108,124) = JacC(108,124)+ 0.6800000000000000D+00*dw(297,124)
      JacC(122,104) = JacC(122,104) + dw(297,104)
      JacC(122,124) = JacC(122,124) + dw(297,124)
      JacC(124,104) = JacC(124,104) - dw(297,104)
      JacC(124,124) = JacC(124,124) - dw(297,124)
      JacC(126,104) = JacC(126,104)+ 0.6800000000000000D+00*dw(297,104)
      JacC(126,124) = JacC(126,124)+ 0.6800000000000000D+00*dw(297,124)
      JacC(130,104) = JacC(130,104)+ 0.2000000000000000D+01*dw(297,104)
      JacC(130,124) = JacC(130,124)+ 0.2000000000000000D+01*dw(297,124)
      JacC(122,124) = JacC(122,124)+ 0.2000000000000000D+01*dw(298,124)
      JacC(122,124) = JacC(122,124)+ 0.2000000000000000D+01*dw(298,124)
      JacC(124,124) = JacC(124,124)- 0.2000000000000000D+01*dw(298,124)
      JacC(124,124) = JacC(124,124)- 0.2000000000000000D+01*dw(298,124)
      JacC(120,120) = JacC(120,120)- 0.2000000000000000D+01*dw(299,120)
      JacC(120,120) = JacC(120,120)- 0.2000000000000000D+01*dw(299,120)
      JacC(121,120) = JacC(121,120)+ 0.2000000000000000D+01*dw(299,120)
      JacC(121,120) = JacC(121,120)+ 0.2000000000000000D+01*dw(299,120)
      JacC( 76,114) = JacC( 76,114)+ 0.5000000000000000D+00*dw(300,114)
      JacC( 76,124) = JacC( 76,124)+ 0.5000000000000000D+00*dw(300,124)
      JacC(114,114) = JacC(114,114) - dw(300,114)
      JacC(114,124) = JacC(114,124) - dw(300,124)
      JacC(115,114) = JacC(115,114)+ 0.5000000000000000D+00*dw(300,114)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(300,124)
      JacC(122,114) = JacC(122,114)+ 0.5000000000000000D+00*dw(300,114)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(300,124)
      JacC(124,114) = JacC(124,114) - dw(300,114)
      JacC(124,124) = JacC(124,124) - dw(300,124)
      JacC(130,114) = JacC(130,114)+ 0.5000000000000000D+00*dw(300,114)
      JacC(130,124) = JacC(130,124)+ 0.5000000000000000D+00*dw(300,124)
      JacC( 79, 79) = JacC( 79, 79) - dw(301, 79)
      JacC( 79,124) = JacC( 79,124) - dw(301,124)
      JacC(115, 79) = JacC(115, 79)+ 0.7500000000000000D+00*dw(301, 79)
      JacC(115,124) = JacC(115,124)+ 0.7500000000000000D+00*dw(301,124)
      JacC(122, 79) = JacC(122, 79)+ 0.5000000000000000D+00*dw(301, 79)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(301,124)
      JacC(124, 79) = JacC(124, 79)- 0.5000000000000000D+00*dw(301, 79)
      JacC(124,124) = JacC(124,124)- 0.5000000000000000D+00*dw(301,124)
      JacC(128, 79) = JacC(128, 79) + dw(301, 79)
      JacC(128,124) = JacC(128,124) + dw(301,124)
      JacC( 70, 70) = JacC( 70, 70) - dw(302, 70)
      JacC( 70,124) = JacC( 70,124) - dw(302,124)
      JacC( 76, 70) = JacC( 76, 70)+ 0.3340000000000000D+00*dw(302, 70)
      JacC( 76,124) = JacC( 76,124)+ 0.3340000000000000D+00*dw(302,124)
      JacC(115, 70) = JacC(115, 70)+ 0.5000000000000000D+00*dw(302, 70)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(302,124)
      JacC(122, 70) = JacC(122, 70)+ 0.5000000000000000D+00*dw(302, 70)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(302,124)
      JacC(124, 70) = JacC(124, 70) - dw(302, 70)
      JacC(124,124) = JacC(124,124) - dw(302,124)
      JacC(128, 70) = JacC(128, 70)+ 0.3300000000000000D+00*dw(302, 70)
      JacC(128,124) = JacC(128,124)+ 0.3300000000000000D+00*dw(302,124)
      JacC(130, 70) = JacC(130, 70)+ 0.3300000000000000D+00*dw(302, 70)
      JacC(130,124) = JacC(130,124)+ 0.3300000000000000D+00*dw(302,124)
      JacC( 82, 82) = JacC( 82, 82) - dw(303, 82)
      JacC( 82,124) = JacC( 82,124) - dw(303,124)
      JacC(118, 82) = JacC(118, 82) + dw(303, 82)
      JacC(118,124) = JacC(118,124) + dw(303,124)
      JacC(122, 82) = JacC(122, 82) + dw(303, 82)
      JacC(122,124) = JacC(122,124) + dw(303,124)
      JacC(124, 82) = JacC(124, 82) - dw(303, 82)
      JacC(124,124) = JacC(124,124) - dw(303,124)
      JacC(130, 82) = JacC(130, 82) + dw(303, 82)
      JacC(130,124) = JacC(130,124) + dw(303,124)
      JacC( 81, 81) = JacC( 81, 81) - dw(304, 81)
      JacC( 81,124) = JacC( 81,124) - dw(304,124)
      JacC(115, 81) = JacC(115, 81)+ 0.5000000000000000D+00*dw(304, 81)
      JacC(115,124) = JacC(115,124)+ 0.5000000000000000D+00*dw(304,124)
      JacC(116, 81) = JacC(116, 81)+ 0.4640000000000000D+00*dw(304, 81)
      JacC(116,124) = JacC(116,124)+ 0.4640000000000000D+00*dw(304,124)
      JacC(119, 81) = JacC(119, 81)+ 0.1240000000000000D+01*dw(304, 81)
      JacC(119,124) = JacC(119,124)+ 0.1240000000000000D+01*dw(304,124)
      JacC(122, 81) = JacC(122, 81)+ 0.5000000000000000D+00*dw(304, 81)
      JacC(122,124) = JacC(122,124)+ 0.5000000000000000D+00*dw(304,124)
      JacC(123, 81) = JacC(123, 81) + dw(304, 81)
      JacC(123,124) = JacC(123,124) + dw(304,124)
      JacC(124, 81) = JacC(124, 81) - dw(304, 81)
      JacC(124,124) = JacC(124,124) - dw(304,124)
      JacC(128, 81) = JacC(128, 81)+ 0.2870000000000000D+00*dw(304, 81)
      JacC(128,124) = JacC(128,124)+ 0.2870000000000000D+00*dw(304,124)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(305, 82)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(305, 82)
      JacC(118, 82) = JacC(118, 82)+ 0.2000000000000000D+01*dw(305, 82)
      JacC(118, 82) = JacC(118, 82)+ 0.2000000000000000D+01*dw(305, 82)
      JacC(130, 82) = JacC(130, 82) + dw(305, 82)
      JacC(130, 82) = JacC(130, 82) + dw(305, 82)
      JacC( 81, 82) = JacC( 81, 82) - dw(306, 82)
      JacC( 81, 81) = JacC( 81, 81) - dw(306, 81)
      JacC( 82, 82) = JacC( 82, 82) - dw(306, 82)
      JacC( 82, 81) = JacC( 82, 81) - dw(306, 81)
      JacC(116, 82) = JacC(116, 82)+ 0.1490000000000000D+00*dw(306, 82)
      JacC(116, 81) = JacC(116, 81)+ 0.1490000000000000D+00*dw(306, 81)
      JacC(118, 82) = JacC(118, 82)+ 0.1500000000000000D+01*dw(306, 82)
      JacC(118, 81) = JacC(118, 81)+ 0.1500000000000000D+01*dw(306, 81)
      JacC(119, 82) = JacC(119, 82)+ 0.6400000000000000D+00*dw(306, 82)
      JacC(119, 81) = JacC(119, 81)+ 0.6400000000000000D+00*dw(306, 81)
      JacC(123, 82) = JacC(123, 82)+ 0.5000000000000000D+00*dw(306, 82)
      JacC(123, 81) = JacC(123, 81)+ 0.5000000000000000D+00*dw(306, 81)
      JacC(128, 82) = JacC(128, 82)+ 0.2020000000000000D+00*dw(306, 82)
      JacC(128, 81) = JacC(128, 81)+ 0.2020000000000000D+00*dw(306, 81)
      JacC(130, 82) = JacC(130, 82)+ 0.5000000000000000D+00*dw(306, 82)
      JacC(130, 81) = JacC(130, 81)+ 0.5000000000000000D+00*dw(306, 81)
      JacC( 81, 81) = JacC( 81, 81)- 0.2000000000000000D+01*dw(307, 81)
      JacC( 81, 81) = JacC( 81, 81)- 0.2000000000000000D+01*dw(307, 81)
      JacC(116, 81) = JacC(116, 81)+ 0.2850000000000000D+00*dw(307, 81)
      JacC(116, 81) = JacC(116, 81)+ 0.2850000000000000D+00*dw(307, 81)
      JacC(118, 81) = JacC(118, 81) + dw(307, 81)
      JacC(118, 81) = JacC(118, 81) + dw(307, 81)
      JacC(119, 81) = JacC(119, 81)+ 0.1210000000000000D+01*dw(307, 81)
      JacC(119, 81) = JacC(119, 81)+ 0.1210000000000000D+01*dw(307, 81)
      JacC(123, 81) = JacC(123, 81) + dw(307, 81)
      JacC(123, 81) = JacC(123, 81) + dw(307, 81)
      JacC(128, 81) = JacC(128, 81)+ 0.5040000000000000D+00*dw(307, 81)
      JacC(128, 81) = JacC(128, 81)+ 0.5040000000000000D+00*dw(307, 81)
      JacC(122,122) = JacC(122,122) - dw(308,122)
      JacC(122,129) = JacC(122,129) - dw(308,129)
      JacC(123,122) = JacC(123,122) + dw(308,122)
      JacC(123,129) = JacC(123,129) + dw(308,129)
      JacC(128,122) = JacC(128,122) + dw(308,122)
      JacC(128,129) = JacC(128,129) + dw(308,129)
      JacC(129,122) = JacC(129,122) - dw(308,122)
      JacC(129,129) = JacC(129,129) - dw(308,129)
      JacC(130,122) = JacC(130,122) + dw(308,122)
      JacC(130,129) = JacC(130,129) + dw(308,129)
      JacC( 95,121) = JacC( 95,121) + dw(309,121)
      JacC( 95,129) = JacC( 95,129) + dw(309,129)
      JacC(121,121) = JacC(121,121) - dw(309,121)
      JacC(121,129) = JacC(121,129) - dw(309,129)
      JacC(123,121) = JacC(123,121) + dw(309,121)
      JacC(123,129) = JacC(123,129) + dw(309,129)
      JacC(129,121) = JacC(129,121) - dw(309,121)
      JacC(129,129) = JacC(129,129) - dw(309,129)
      JacC(130,121) = JacC(130,121) + dw(309,121)
      JacC(130,129) = JacC(130,129) + dw(309,129)
      JacC(108,117) = JacC(108,117)+ 0.6700000000000000D-01*dw(310,117)
      JacC(108,129) = JacC(108,129)+ 0.6700000000000000D-01*dw(310,129)
      JacC(116,117) = JacC(116,117)+ 0.6620000000000000D+00*dw(310,117)
      JacC(116,129) = JacC(116,129)+ 0.6620000000000000D+00*dw(310,129)
      JacC(117,117) = JacC(117,117) - dw(310,117)
      JacC(117,129) = JacC(117,129) - dw(310,129)
      JacC(119,117) = JacC(119,117)+ 0.2480000000000000D+00*dw(310,117)
      JacC(119,129) = JacC(119,129)+ 0.2480000000000000D+00*dw(310,129)
      JacC(121,117) = JacC(121,117)+ 0.5100000000000000D-01*dw(310,117)
      JacC(121,129) = JacC(121,129)+ 0.5100000000000000D-01*dw(310,129)
      JacC(122,117) = JacC(122,117)+ 0.1590000000000000D+00*dw(310,117)
      JacC(122,129) = JacC(122,129)+ 0.1590000000000000D+00*dw(310,129)
      JacC(123,117) = JacC(123,117) + dw(310,117)
      JacC(123,129) = JacC(123,129) + dw(310,129)
      JacC(127,117) = JacC(127,117)+ 0.5100000000000000D-01*dw(310,117)
      JacC(127,129) = JacC(127,129)+ 0.5100000000000000D-01*dw(310,129)
      JacC(128,117) = JacC(128,117)+ 0.5000000000000000D-01*dw(310,117)
      JacC(128,129) = JacC(128,129)+ 0.5000000000000000D-01*dw(310,129)
      JacC(129,117) = JacC(129,117) - dw(310,117)
      JacC(129,129) = JacC(129,129) - dw(310,129)
      JacC(130,117) = JacC(130,117)+ 0.7890000000000000D+00*dw(310,117)
      JacC(130,129) = JacC(130,129)+ 0.7890000000000000D+00*dw(310,129)
      JacC( 92, 92) = JacC( 92, 92) - dw(311, 92)
      JacC( 92,129) = JacC( 92,129) - dw(311,129)
      JacC(116, 92) = JacC(116, 92)+ 0.8240000000000000D+00*dw(311, 92)
      JacC(116,129) = JacC(116,129)+ 0.8240000000000000D+00*dw(311,129)
      JacC(119, 92) = JacC(119, 92)+ 0.2410000000000000D+00*dw(311, 92)
      JacC(119,129) = JacC(119,129)+ 0.2410000000000000D+00*dw(311,129)
      JacC(121, 92) = JacC(121, 92)+ 0.2800000000000000D+00*dw(311, 92)
      JacC(121,129) = JacC(121,129)+ 0.2800000000000000D+00*dw(311,129)
      JacC(122, 92) = JacC(122, 92)+ 0.3500000000000000D-01*dw(311, 92)
      JacC(122,129) = JacC(122,129)+ 0.3500000000000000D-01*dw(311,129)
      JacC(123, 92) = JacC(123, 92) + dw(311, 92)
      JacC(123,129) = JacC(123,129) + dw(311,129)
      JacC(127, 92) = JacC(127, 92)+ 0.3810000000000000D+00*dw(311, 92)
      JacC(127,129) = JacC(127,129)+ 0.3810000000000000D+00*dw(311,129)
      JacC(128, 92) = JacC(128, 92)+ 0.2400000000000000D-01*dw(311, 92)
      JacC(128,129) = JacC(128,129)+ 0.2400000000000000D-01*dw(311,129)
      JacC(129, 92) = JacC(129, 92) - dw(311, 92)
      JacC(129,129) = JacC(129,129) - dw(311,129)
      JacC(130, 92) = JacC(130, 92)+ 0.6840000000000001D+00*dw(311, 92)
      JacC(130,129) = JacC(130,129)+ 0.6840000000000001D+00*dw(311,129)
      JacC( 69, 69) = JacC( 69, 69) - dw(312, 69)
      JacC( 69,129) = JacC( 69,129) - dw(312,129)
      JacC(116, 69) = JacC(116, 69)+ 0.8690000000000000D+00*dw(312, 69)
      JacC(116,129) = JacC(116,129)+ 0.8690000000000000D+00*dw(312,129)
      JacC(119, 69) = JacC(119, 69)+ 0.2030000000000000D+00*dw(312, 69)
      JacC(119,129) = JacC(119,129)+ 0.2030000000000000D+00*dw(312,129)
      JacC(121, 69) = JacC(121, 69)+ 0.1800000000000000D+00*dw(312, 69)
      JacC(121,129) = JacC(121,129)+ 0.1800000000000000D+00*dw(312,129)
      JacC(123, 69) = JacC(123, 69) + dw(312, 69)
      JacC(123,129) = JacC(123,129) + dw(312,129)
      JacC(127, 69) = JacC(127, 69)+ 0.5629999999999999D+00*dw(312, 69)
      JacC(127,129) = JacC(127,129)+ 0.5629999999999999D+00*dw(312,129)
      JacC(129, 69) = JacC(129, 69) - dw(312, 69)
      JacC(129,129) = JacC(129,129) - dw(312,129)
      JacC(130, 69) = JacC(130, 69)+ 0.8200000000000000D+00*dw(312, 69)
      JacC(130,129) = JacC(130,129)+ 0.8200000000000000D+00*dw(312,129)
      JacC( 73, 73) = JacC( 73, 73) - dw(313, 73)
      JacC( 73,129) = JacC( 73,129) - dw(313,129)
      JacC(119, 73) = JacC(119, 73)+ 0.2000000000000000D+00*dw(313, 73)
      JacC(119,129) = JacC(119,129)+ 0.2000000000000000D+00*dw(313,129)
      JacC(123, 73) = JacC(123, 73) + dw(313, 73)
      JacC(123,129) = JacC(123,129) + dw(313,129)
      JacC(128, 73) = JacC(128, 73)+ 0.1600000000000000D+01*dw(313, 73)
      JacC(128,129) = JacC(128,129)+ 0.1600000000000000D+01*dw(313,129)
      JacC(129, 73) = JacC(129, 73) - dw(313, 73)
      JacC(129,129) = JacC(129,129) - dw(313,129)
      JacC(130, 73) = JacC(130, 73) + dw(313, 73)
      JacC(130,129) = JacC(130,129) + dw(313,129)
      JacC( 72, 72) = JacC( 72, 72) - dw(314, 72)
      JacC( 72,129) = JacC( 72,129) - dw(314,129)
      JacC(116, 72) = JacC(116, 72)+ 0.6000000000000000D-01*dw(314, 72)
      JacC(116,129) = JacC(116,129)+ 0.6000000000000000D-01*dw(314,129)
      JacC(119, 72) = JacC(119, 72)+ 0.9399999999999999D+00*dw(314, 72)
      JacC(119,129) = JacC(119,129)+ 0.9399999999999999D+00*dw(314,129)
      JacC(123, 72) = JacC(123, 72) + dw(314, 72)
      JacC(123,129) = JacC(123,129) + dw(314,129)
      JacC(128, 72) = JacC(128, 72) + dw(314, 72)
      JacC(128,129) = JacC(128,129) + dw(314,129)
      JacC(129, 72) = JacC(129, 72) - dw(314, 72)
      JacC(129,129) = JacC(129,129) - dw(314,129)
      JacC(130, 72) = JacC(130, 72) + dw(314, 72)
      JacC(130,129) = JacC(130,129) + dw(314,129)
      JacC(101,101) = JacC(101,101) - dw(315,101)
      JacC(101,129) = JacC(101,129) - dw(315,129)
      JacC(116,101) = JacC(116,101)+ 0.2900000000000000D+00*dw(315,101)
      JacC(116,129) = JacC(116,129)+ 0.2900000000000000D+00*dw(315,129)
      JacC(119,101) = JacC(119,101)+ 0.1710000000000000D+01*dw(315,101)
      JacC(119,129) = JacC(119,129)+ 0.1710000000000000D+01*dw(315,129)
      JacC(123,101) = JacC(123,101) + dw(315,101)
      JacC(123,129) = JacC(123,129) + dw(315,129)
      JacC(129,101) = JacC(129,101) - dw(315,101)
      JacC(129,129) = JacC(129,129) - dw(315,129)
      JacC(130,101) = JacC(130,101) + dw(315,101)
      JacC(130,129) = JacC(130,129) + dw(315,129)
      JacC( 83, 83) = JacC( 83, 83) - dw(316, 83)
      JacC( 83,129) = JacC( 83,129) - dw(316,129)
      JacC( 84, 83) = JacC( 84, 83)+ 0.6100000000000000D+00*dw(316, 83)
      JacC( 84,129) = JacC( 84,129)+ 0.6100000000000000D+00*dw(316,129)
      JacC( 96, 83) = JacC( 96, 83)+ 0.4380000000000000D+00*dw(316, 83)
      JacC( 96,129) = JacC( 96,129)+ 0.4380000000000000D+00*dw(316,129)
      JacC(123, 83) = JacC(123, 83) + dw(316, 83)
      JacC(123,129) = JacC(123,129) + dw(316,129)
      JacC(128, 83) = JacC(128, 83)+ 0.1050000000000000D+01*dw(316, 83)
      JacC(128,129) = JacC(128,129)+ 0.1050000000000000D+01*dw(316,129)
      JacC(129, 83) = JacC(129, 83) - dw(316, 83)
      JacC(129,129) = JacC(129,129) - dw(316,129)
      JacC(130, 83) = JacC(130, 83) + dw(316, 83)
      JacC(130,129) = JacC(130,129) + dw(316,129)
      JacC( 93, 93) = JacC( 93, 93) - dw(317, 93)
      JacC( 93,129) = JacC( 93,129) - dw(317,129)
      JacC(116, 93) = JacC(116, 93) + dw(317, 93)
      JacC(116,129) = JacC(116,129) + dw(317,129)
      JacC(119, 93) = JacC(119, 93) + dw(317, 93)
      JacC(119,129) = JacC(119,129) + dw(317,129)
      JacC(123, 93) = JacC(123, 93) + dw(317, 93)
      JacC(123,129) = JacC(123,129) + dw(317,129)
      JacC(129, 93) = JacC(129, 93) - dw(317, 93)
      JacC(129,129) = JacC(129,129) - dw(317,129)
      JacC(130, 93) = JacC(130, 93) + dw(317, 93)
      JacC(130,129) = JacC(130,129) + dw(317,129)
      JacC( 77, 77) = JacC( 77, 77) - dw(318, 77)
      JacC( 77,129) = JacC( 77,129) - dw(318,129)
      JacC( 80, 77) = JacC( 80, 77)+ 0.3850000000000000D+00*dw(318, 77)
      JacC( 80,129) = JacC( 80,129)+ 0.3850000000000000D+00*dw(318,129)
      JacC( 96, 77) = JacC( 96, 77)+ 0.6150000000000000D+00*dw(318, 77)
      JacC( 96,129) = JacC( 96,129)+ 0.6150000000000000D+00*dw(318,129)
      JacC(123, 77) = JacC(123, 77) + dw(318, 77)
      JacC(123,129) = JacC(123,129) + dw(318,129)
      JacC(128, 77) = JacC(128, 77)+ 0.3850000000000000D+00*dw(318, 77)
      JacC(128,129) = JacC(128,129)+ 0.3850000000000000D+00*dw(318,129)
      JacC(129, 77) = JacC(129, 77) - dw(318, 77)
      JacC(129,129) = JacC(129,129) - dw(318,129)
      JacC(130, 77) = JacC(130, 77) + dw(318, 77)
      JacC(130,129) = JacC(130,129) + dw(318,129)
      JacC( 71, 71) = JacC( 71, 71) - dw(319, 71)
      JacC( 71,129) = JacC( 71,129) - dw(319,129)
      JacC( 80, 71) = JacC( 80, 71)+ 0.5000000000000000D+00*dw(319, 71)
      JacC( 80,129) = JacC( 80,129)+ 0.5000000000000000D+00*dw(319,129)
      JacC( 85, 71) = JacC( 85, 71)+ 0.5000000000000000D+00*dw(319, 71)
      JacC( 85,129) = JacC( 85,129)+ 0.5000000000000000D+00*dw(319,129)
      JacC(108, 71) = JacC(108, 71) + dw(319, 71)
      JacC(108,129) = JacC(108,129) + dw(319,129)
      JacC(123, 71) = JacC(123, 71) + dw(319, 71)
      JacC(123,129) = JacC(123,129) + dw(319,129)
      JacC(129, 71) = JacC(129, 71) - dw(319, 71)
      JacC(129,129) = JacC(129,129) - dw(319,129)
      JacC(130, 71) = JacC(130, 71) + dw(319, 71)
      JacC(130,129) = JacC(130,129) + dw(319,129)
      JacC( 65, 65) = JacC( 65, 65) - dw(320, 65)
      JacC( 65,129) = JacC( 65,129) - dw(320,129)
      JacC( 68, 65) = JacC( 68, 65)+ 0.7700000000000000D-01*dw(320, 65)
      JacC( 68,129) = JacC( 68,129)+ 0.7700000000000000D-01*dw(320,129)
      JacC( 76, 65) = JacC( 76, 65)+ 0.7370000000000000D+00*dw(320, 65)
      JacC( 76,129) = JacC( 76,129)+ 0.7370000000000000D+00*dw(320,129)
      JacC( 98, 65) = JacC( 98, 65)+ 0.1860000000000000D+00*dw(320, 65)
      JacC( 98,129) = JacC( 98,129)+ 0.1860000000000000D+00*dw(320,129)
      JacC(108, 65) = JacC(108, 65)+ 0.3680000000000000D+00*dw(320, 65)
      JacC(108,129) = JacC(108,129)+ 0.3680000000000000D+00*dw(320,129)
      JacC(110, 65) = JacC(110, 65)+ 0.6320000000000000D+00*dw(320, 65)
      JacC(110,129) = JacC(110,129)+ 0.6320000000000000D+00*dw(320,129)
      JacC(123, 65) = JacC(123, 65) + dw(320, 65)
      JacC(123,129) = JacC(123,129) + dw(320,129)
      JacC(129, 65) = JacC(129, 65) - dw(320, 65)
      JacC(129,129) = JacC(129,129) - dw(320,129)
      JacC(130, 65) = JacC(130, 65) + dw(320, 65)
      JacC(130,129) = JacC(130,129) + dw(320,129)
      JacC( 75,104) = JacC( 75,104)+ 0.3200000000000000D+00*dw(321,104)
      JacC( 75,129) = JacC( 75,129)+ 0.3200000000000000D+00*dw(321,129)
      JacC(104,104) = JacC(104,104) - dw(321,104)
      JacC(104,129) = JacC(104,129) - dw(321,129)
      JacC(108,104) = JacC(108,104)+ 0.6800000000000000D+00*dw(321,104)
      JacC(108,129) = JacC(108,129)+ 0.6800000000000000D+00*dw(321,129)
      JacC(123,104) = JacC(123,104) + dw(321,104)
      JacC(123,129) = JacC(123,129) + dw(321,129)
      JacC(126,104) = JacC(126,104)+ 0.6800000000000000D+00*dw(321,104)
      JacC(126,129) = JacC(126,129)+ 0.6800000000000000D+00*dw(321,129)
      JacC(129,104) = JacC(129,104) - dw(321,104)
      JacC(129,129) = JacC(129,129) - dw(321,129)
      JacC(130,104) = JacC(130,104) + dw(321,104)
      JacC(130,129) = JacC(130,129) + dw(321,129)
      JacC(122,124) = JacC(122,124) + dw(322,124)
      JacC(122,129) = JacC(122,129) + dw(322,129)
      JacC(123,124) = JacC(123,124) + dw(322,124)
      JacC(123,129) = JacC(123,129) + dw(322,129)
      JacC(124,124) = JacC(124,124) - dw(322,124)
      JacC(124,129) = JacC(124,129) - dw(322,129)
      JacC(129,124) = JacC(129,124) - dw(322,124)
      JacC(129,129) = JacC(129,129) - dw(322,129)
      JacC(120,120) = JacC(120,120) - dw(323,120)
      JacC(120,129) = JacC(120,129) - dw(323,129)
      JacC(121,120) = JacC(121,120) + dw(323,120)
      JacC(121,129) = JacC(121,129) + dw(323,129)
      JacC(123,120) = JacC(123,120) + dw(323,120)
      JacC(123,129) = JacC(123,129) + dw(323,129)
      JacC(129,120) = JacC(129,120) - dw(323,120)
      JacC(129,129) = JacC(129,129) - dw(323,129)
      JacC( 70, 70) = JacC( 70, 70) - dw(324, 70)
      JacC( 70,129) = JacC( 70,129) - dw(324,129)
      JacC( 76, 70) = JacC( 76, 70)+ 0.6700000000000000D+00*dw(324, 70)
      JacC( 76,129) = JacC( 76,129)+ 0.6700000000000000D+00*dw(324,129)
      JacC(123, 70) = JacC(123, 70) + dw(324, 70)
      JacC(123,129) = JacC(123,129) + dw(324,129)
      JacC(128, 70) = JacC(128, 70)+ 0.3300000000000000D+00*dw(324, 70)
      JacC(128,129) = JacC(128,129)+ 0.3300000000000000D+00*dw(324,129)
      JacC(129, 70) = JacC(129, 70) - dw(324, 70)
      JacC(129,129) = JacC(129,129) - dw(324,129)
      JacC(130, 70) = JacC(130, 70)+ 0.6700000000000000D+00*dw(324, 70)
      JacC(130,129) = JacC(130,129)+ 0.6700000000000000D+00*dw(324,129)
      JacC( 76,114) = JacC( 76,114) + dw(325,114)
      JacC( 76,129) = JacC( 76,129) + dw(325,129)
      JacC(114,114) = JacC(114,114) - dw(325,114)
      JacC(114,129) = JacC(114,129) - dw(325,129)
      JacC(123,114) = JacC(123,114) + dw(325,114)
      JacC(123,129) = JacC(123,129) + dw(325,129)
      JacC(129,114) = JacC(129,114) - dw(325,114)
      JacC(129,129) = JacC(129,129) - dw(325,129)
      JacC(130,114) = JacC(130,114) + dw(325,114)
      JacC(130,129) = JacC(130,129) + dw(325,129)
      JacC( 79, 79) = JacC( 79, 79) - dw(326, 79)
      JacC( 79,129) = JacC( 79,129) - dw(326,129)
      JacC(123, 79) = JacC(123, 79) + dw(326, 79)
      JacC(123,129) = JacC(123,129) + dw(326,129)
      JacC(124, 79) = JacC(124, 79) + dw(326, 79)
      JacC(124,129) = JacC(124,129) + dw(326,129)
      JacC(128, 79) = JacC(128, 79) + dw(326, 79)
      JacC(128,129) = JacC(128,129) + dw(326,129)
      JacC(129, 79) = JacC(129, 79) - dw(326, 79)
      JacC(129,129) = JacC(129,129) - dw(326,129)
      JacC( 82, 82) = JacC( 82, 82) - dw(327, 82)
      JacC( 82,129) = JacC( 82,129) - dw(327,129)
      JacC(118, 82) = JacC(118, 82) + dw(327, 82)
      JacC(118,129) = JacC(118,129) + dw(327,129)
      JacC(123, 82) = JacC(123, 82) + dw(327, 82)
      JacC(123,129) = JacC(123,129) + dw(327,129)
      JacC(129, 82) = JacC(129, 82) - dw(327, 82)
      JacC(129,129) = JacC(129,129) - dw(327,129)
      JacC(130, 82) = JacC(130, 82) + dw(327, 82)
      JacC(130,129) = JacC(130,129) + dw(327,129)
      JacC( 81, 81) = JacC( 81, 81) - dw(328, 81)
      JacC( 81,129) = JacC( 81,129) - dw(328,129)
      JacC(116, 81) = JacC(116, 81)+ 0.4640000000000000D+00*dw(328, 81)
      JacC(116,129) = JacC(116,129)+ 0.4640000000000000D+00*dw(328,129)
      JacC(119, 81) = JacC(119, 81)+ 0.1240000000000000D+01*dw(328, 81)
      JacC(119,129) = JacC(119,129)+ 0.1240000000000000D+01*dw(328,129)
      JacC(123, 81) = JacC(123, 81)+ 0.2000000000000000D+01*dw(328, 81)
      JacC(123,129) = JacC(123,129)+ 0.2000000000000000D+01*dw(328,129)
      JacC(128, 81) = JacC(128, 81)+ 0.2870000000000000D+00*dw(328, 81)
      JacC(128,129) = JacC(128,129)+ 0.2870000000000000D+00*dw(328,129)
      JacC(129, 81) = JacC(129, 81) - dw(328, 81)
      JacC(129,129) = JacC(129,129) - dw(328,129)
      JacC( 88, 88) = JacC( 88, 88) - dw(329, 88)
      JacC( 88,129) = JacC( 88,129) - dw(329,129)
      JacC(110, 88) = JacC(110, 88) + dw(329, 88)
      JacC(110,129) = JacC(110,129) + dw(329,129)
      JacC(119, 88) = JacC(119, 88)+ 0.7000000000000000D+00*dw(329, 88)
      JacC(119,129) = JacC(119,129)+ 0.7000000000000000D+00*dw(329,129)
      JacC(123, 88) = JacC(123, 88) + dw(329, 88)
      JacC(123,129) = JacC(123,129) + dw(329,129)
      JacC(124, 88) = JacC(124, 88)+ 0.2300000000000000D+01*dw(329, 88)
      JacC(124,129) = JacC(124,129)+ 0.2300000000000000D+01*dw(329,129)
      JacC(127, 88) = JacC(127, 88)+ 0.2300000000000000D+01*dw(329, 88)
      JacC(127,129) = JacC(127,129)+ 0.2300000000000000D+01*dw(329,129)
      JacC(128, 88) = JacC(128, 88)+ 0.3000000000000000D+00*dw(329, 88)
      JacC(128,129) = JacC(128,129)+ 0.3000000000000000D+00*dw(329,129)
      JacC(129, 88) = JacC(129, 88) - dw(329, 88)
      JacC(129,129) = JacC(129,129) - dw(329,129)
      JacC(130, 88) = JacC(130, 88) + dw(329, 88)
      JacC(130,129) = JacC(130,129) + dw(329,129)
      JacC( 89,109) = JacC( 89,109)+ 0.3300000000000000D+00*dw(330,109)
      JacC( 89,129) = JacC( 89,129)+ 0.3300000000000000D+00*dw(330,129)
      JacC(109,109) = JacC(109,109) - dw(330,109)
      JacC(109,129) = JacC(109,129) - dw(330,129)
      JacC(110,109) = JacC(110,109)+ 0.6670000000000000D+00*dw(330,109)
      JacC(110,129) = JacC(110,129)+ 0.6670000000000000D+00*dw(330,129)
      JacC(113,109) = JacC(113,109)+ 0.3300000000000000D+00*dw(330,109)
      JacC(113,129) = JacC(113,129)+ 0.3300000000000000D+00*dw(330,129)
      JacC(123,109) = JacC(123,109) + dw(330,109)
      JacC(123,129) = JacC(123,129) + dw(330,129)
      JacC(124,109) = JacC(124,109)+ 0.3300000000000000D+00*dw(330,109)
      JacC(124,129) = JacC(124,129)+ 0.3300000000000000D+00*dw(330,129)
      JacC(128,109) = JacC(128,109) + dw(330,109)
      JacC(128,129) = JacC(128,129) + dw(330,129)
      JacC(129,109) = JacC(129,109) - dw(330,109)
      JacC(129,129) = JacC(129,129) - dw(330,129)
      JacC(130,109) = JacC(130,109) + dw(330,109)
      JacC(130,129) = JacC(130,129) + dw(330,129)
      JacC( 57, 57) = JacC( 57, 57) - dw(331, 57)
      JacC( 57,129) = JacC( 57,129) - dw(331,129)
      JacC( 66, 57) = JacC( 66, 57) + dw(331, 57)
      JacC( 66,129) = JacC( 66,129) + dw(331,129)
      JacC(123, 57) = JacC(123, 57) + dw(331, 57)
      JacC(123,129) = JacC(123,129) + dw(331,129)
      JacC(129, 57) = JacC(129, 57) - dw(331, 57)
      JacC(129,129) = JacC(129,129) - dw(331,129)
      JacC( 58, 58) = JacC( 58, 58) - dw(332, 58)
      JacC( 58,129) = JacC( 58,129) - dw(332,129)
      JacC( 68, 58) = JacC( 68, 58) + dw(332, 58)
      JacC( 68,129) = JacC( 68,129) + dw(332,129)
      JacC(123, 58) = JacC(123, 58) + dw(332, 58)
      JacC(123,129) = JacC(123,129) + dw(332,129)
      JacC(129, 58) = JacC(129, 58) - dw(332, 58)
      JacC(129,129) = JacC(129,129) - dw(332,129)
      JacC(130, 58) = JacC(130, 58) + dw(332, 58)
      JacC(130,129) = JacC(130,129) + dw(332,129)
      JacC( 56, 56) = JacC( 56, 56) - dw(333, 56)
      JacC( 56,129) = JacC( 56,129) - dw(333,129)
      JacC( 76, 56) = JacC( 76, 56) + dw(333, 56)
      JacC( 76,129) = JacC( 76,129) + dw(333,129)
      JacC(110, 56) = JacC(110, 56) + dw(333, 56)
      JacC(110,129) = JacC(110,129) + dw(333,129)
      JacC(123, 56) = JacC(123, 56) + dw(333, 56)
      JacC(123,129) = JacC(123,129) + dw(333,129)
      JacC(129, 56) = JacC(129, 56) - dw(333, 56)
      JacC(129,129) = JacC(129,129) - dw(333,129)
      JacC(130, 56) = JacC(130, 56) + dw(333, 56)
      JacC(130,129) = JacC(130,129) + dw(333,129)
      JacC( 59, 59) = JacC( 59, 59) - dw(334, 59)
      JacC( 59,129) = JacC( 59,129) - dw(334,129)
      JacC( 66, 59) = JacC( 66, 59) + dw(334, 59)
      JacC( 66,129) = JacC( 66,129) + dw(334,129)
      JacC(123, 59) = JacC(123, 59) + dw(334, 59)
      JacC(123,129) = JacC(123,129) + dw(334,129)
      JacC(129, 59) = JacC(129, 59) - dw(334, 59)
      JacC(129,129) = JacC(129,129) - dw(334,129)
      JacC( 60, 60) = JacC( 60, 60) - dw(335, 60)
      JacC( 60,129) = JacC( 60,129) - dw(335,129)
      JacC( 68, 60) = JacC( 68, 60) + dw(335, 60)
      JacC( 68,129) = JacC( 68,129) + dw(335,129)
      JacC(123, 60) = JacC(123, 60) + dw(335, 60)
      JacC(123,129) = JacC(123,129) + dw(335,129)
      JacC(129, 60) = JacC(129, 60) - dw(335, 60)
      JacC(129,129) = JacC(129,129) - dw(335,129)
      JacC(130, 60) = JacC(130, 60) + dw(335, 60)
      JacC(130,129) = JacC(130,129) + dw(335,129)
      JacC( 61, 61) = JacC( 61, 61) - dw(336, 61)
      JacC( 61,129) = JacC( 61,129) - dw(336,129)
      JacC( 76, 61) = JacC( 76, 61) + dw(336, 61)
      JacC( 76,129) = JacC( 76,129) + dw(336,129)
      JacC( 98, 61) = JacC( 98, 61)+ 0.2050000000000000D+01*dw(336, 61)
      JacC( 98,129) = JacC( 98,129)+ 0.2050000000000000D+01*dw(336,129)
      JacC(110, 61) = JacC(110, 61) + dw(336, 61)
      JacC(110,129) = JacC(110,129) + dw(336,129)
      JacC(123, 61) = JacC(123, 61) + dw(336, 61)
      JacC(123,129) = JacC(123,129) + dw(336,129)
      JacC(129, 61) = JacC(129, 61) - dw(336, 61)
      JacC(129,129) = JacC(129,129) - dw(336,129)
      JacC(130, 61) = JacC(130, 61) + dw(336, 61)
      JacC(130,129) = JacC(130,129) + dw(336,129)
      JacC( 54, 67) = JacC( 54, 67) + dw(337, 67)
      JacC( 54,129) = JacC( 54,129) + dw(337,129)
      JacC( 67, 67) = JacC( 67, 67) - dw(337, 67)
      JacC( 67,129) = JacC( 67,129) - dw(337,129)
      JacC(123, 67) = JacC(123, 67) + dw(337, 67)
      JacC(123,129) = JacC(123,129) + dw(337,129)
      JacC(129, 67) = JacC(129, 67) - dw(337, 67)
      JacC(129,129) = JacC(129,129) - dw(337,129)
      JacC( 54, 54) = JacC( 54, 54) - dw(338, 54)
      JacC( 54,129) = JacC( 54,129) - dw(338,129)
      JacC( 55, 54) = JacC( 55, 54) + dw(338, 54)
      JacC( 55,129) = JacC( 55,129) + dw(338,129)
      JacC(123, 54) = JacC(123, 54) + dw(338, 54)
      JacC(123,129) = JacC(123,129) + dw(338,129)
      JacC(129, 54) = JacC(129, 54) - dw(338, 54)
      JacC(129,129) = JacC(129,129) - dw(338,129)
      JacC( 87, 87) = JacC( 87, 87) - dw(339, 87)
      JacC( 87,129) = JacC( 87,129) - dw(339,129)
      JacC(108, 87) = JacC(108, 87)+ 0.1800000000000000D+00*dw(339, 87)
      JacC(108,129) = JacC(108,129)+ 0.1800000000000000D+00*dw(339,129)
      JacC(110, 87) = JacC(110, 87)+ 0.2100000000000000D+00*dw(339, 87)
      JacC(110,129) = JacC(110,129)+ 0.2100000000000000D+00*dw(339,129)
      JacC(113, 87) = JacC(113, 87)+ 0.6100000000000000D+00*dw(339, 87)
      JacC(113,129) = JacC(113,129)+ 0.6100000000000000D+00*dw(339,129)
      JacC(116, 87) = JacC(116, 87)+ 0.7000000000000000D+00*dw(339, 87)
      JacC(116,129) = JacC(116,129)+ 0.7000000000000000D+00*dw(339,129)
      JacC(119, 87) = JacC(119, 87)+ 0.2700000000000000D+00*dw(339, 87)
      JacC(119,129) = JacC(119,129)+ 0.2700000000000000D+00*dw(339,129)
      JacC(123, 87) = JacC(123, 87) + dw(339, 87)
      JacC(123,129) = JacC(123,129) + dw(339,129)
      JacC(128, 87) = JacC(128, 87)+ 0.3000000000000000D-01*dw(339, 87)
      JacC(128,129) = JacC(128,129)+ 0.3000000000000000D-01*dw(339,129)
      JacC(129, 87) = JacC(129, 87) - dw(339, 87)
      JacC(129,129) = JacC(129,129) - dw(339,129)
      JacC(130, 87) = JacC(130, 87) + dw(339, 87)
      JacC(130,129) = JacC(130,129) + dw(339,129)
      JacC(126,127) = JacC(126,127) + dw(340,127)
      JacC(126,130) = JacC(126,130) + dw(340,130)
      JacC(127,127) = JacC(127,127) - dw(340,127)
      JacC(127,130) = JacC(127,130) - dw(340,130)
      JacC(130,127) = JacC(130,127) - dw(340,127)
      JacC(130,130) = JacC(130,130) - dw(340,130)
      JacC(122,127) = JacC(122,127) - dw(341,127)
      JacC(122,122) = JacC(122,122) - dw(341,122)
      JacC(127,127) = JacC(127,127) - dw(341,127)
      JacC(127,122) = JacC(127,122) - dw(341,122)
      JacC(128,127) = JacC(128,127) + dw(341,127)
      JacC(128,122) = JacC(128,122) + dw(341,122)
      JacC(130,127) = JacC(130,127) + dw(341,127)
      JacC(130,122) = JacC(130,122) + dw(341,122)
      JacC(122,127) = JacC(122,127) + dw(342,127)
      JacC(122,124) = JacC(122,124) + dw(342,124)
      JacC(124,127) = JacC(124,127) - dw(342,127)
      JacC(124,124) = JacC(124,124) - dw(342,124)
      JacC(127,127) = JacC(127,127) - dw(342,127)
      JacC(127,124) = JacC(127,124) - dw(342,124)
      JacC(127,127) = JacC(127,127)- 0.2000000000000000D+01*dw(343,127)
      JacC(127,127) = JacC(127,127)- 0.2000000000000000D+01*dw(343,127)
      JacC(123,127) = JacC(123,127) + dw(344,127)
      JacC(123,125) = JacC(123,125) + dw(344,125)
      JacC(125,127) = JacC(125,127) - dw(344,127)
      JacC(125,125) = JacC(125,125) - dw(344,125)
      JacC(127,127) = JacC(127,127) - dw(344,127)
      JacC(127,125) = JacC(127,125) - dw(344,125)
      JacC(123,127) = JacC(123,127) + dw(345,127)
      JacC(123,129) = JacC(123,129) + dw(345,129)
      JacC(127,127) = JacC(127,127) - dw(345,127)
      JacC(127,129) = JacC(127,129) - dw(345,129)
      JacC(129,127) = JacC(129,127) - dw(345,127)
      JacC(129,129) = JacC(129,129) - dw(345,129)
      JacC(108,112) = JacC(108,112) + dw(346,112)
      JacC(108,125) = JacC(108,125) + dw(346,125)
      JacC(112,112) = JacC(112,112) - dw(346,112)
      JacC(112,125) = JacC(112,125) - dw(346,125)
      JacC(123,112) = JacC(123,112) + dw(346,112)
      JacC(123,125) = JacC(123,125) + dw(346,125)
      JacC(125,112) = JacC(125,112) - dw(346,112)
      JacC(125,125) = JacC(125,125) - dw(346,125)
      JacC(130,112) = JacC(130,112) + dw(346,112)
      JacC(130,125) = JacC(130,125) + dw(346,125)
      JacC(112,112) = JacC(112,112) - dw(347,112)
      JacC(112,130) = JacC(112,130) - dw(347,130)
      JacC(126,112) = JacC(126,112) + dw(347,112)
      JacC(126,130) = JacC(126,130) + dw(347,130)
      JacC(130,112) = JacC(130,112) - dw(347,112)
      JacC(130,130) = JacC(130,130) - dw(347,130)
      JacC(108,112) = JacC(108,112) + dw(348,112)
      JacC(108,122) = JacC(108,122) + dw(348,122)
      JacC(112,112) = JacC(112,112) - dw(348,112)
      JacC(112,122) = JacC(112,122) - dw(348,122)
      JacC(122,112) = JacC(122,112) - dw(348,112)
      JacC(122,122) = JacC(122,122) - dw(348,122)
      JacC(128,112) = JacC(128,112) + dw(348,112)
      JacC(128,122) = JacC(128,122) + dw(348,122)
      JacC(130,112) = JacC(130,112) + dw(348,112)
      JacC(130,122) = JacC(130,122) + dw(348,122)
      JacC(108,112) = JacC(108,112) + dw(349,112)
      JacC(108,124) = JacC(108,124) + dw(349,124)
      JacC(112,112) = JacC(112,112) - dw(349,112)
      JacC(112,124) = JacC(112,124) - dw(349,124)
      JacC(122,112) = JacC(122,112) + dw(349,112)
      JacC(122,124) = JacC(122,124) + dw(349,124)
      JacC(124,112) = JacC(124,112) - dw(349,112)
      JacC(124,124) = JacC(124,124) - dw(349,124)
      JacC(108,112) = JacC(108,112) + dw(350,112)
      JacC(108,129) = JacC(108,129) + dw(350,129)
      JacC(112,112) = JacC(112,112) - dw(350,112)
      JacC(112,129) = JacC(112,129) - dw(350,129)
      JacC(123,112) = JacC(123,112) + dw(350,112)
      JacC(123,129) = JacC(123,129) + dw(350,129)
      JacC(129,112) = JacC(129,112) - dw(350,112)
      JacC(129,129) = JacC(129,129) - dw(350,129)
      JacC(130,112) = JacC(130,112) + dw(350,112)
      JacC(130,129) = JacC(130,129) + dw(350,129)
      JacC(120,120) = JacC(120,120) - dw(351,120)
      JacC(120,124) = JacC(120,124) - dw(351,124)
      JacC(121,120) = JacC(121,120) + dw(351,120)
      JacC(121,124) = JacC(121,124) + dw(351,124)
      JacC(122,120) = JacC(122,120) + dw(351,120)
      JacC(122,124) = JacC(122,124) + dw(351,124)
      JacC(124,120) = JacC(124,120) - dw(351,120)
      JacC(124,124) = JacC(124,124) - dw(351,124)
      JacC( 53,130) = JacC( 53,130)+ 0.5000000000000000D+00*dw(352,130)
      JacC(130,130) = JacC(130,130) - dw(352,130)
      JacC( 28,123) = JacC( 28,123)+ 0.5000000000000000D+00*dw(353,123)
      JacC(111,123) = JacC(111,123)+ 0.5000000000000000D+00*dw(353,123)
      JacC(123,123) = JacC(123,123) - dw(353,123)
      JacC(111,129) = JacC(111,129) + dw(354,129)
      JacC(129,129) = JacC(129,129) - dw(354,129)
      JacC( 20, 20) = JacC( 20, 20) - dw(355, 20)
      JacC(111, 20) = JacC(111, 20)+ 0.2000000000000000D+01*dw(355, 20)
      JacC( 18, 18) = JacC( 18, 18) - dw(356, 18)
      JacC( 18,131) = JacC( 18,131) - dw(356,131)
      JacC( 19, 18) = JacC( 19, 18) + dw(356, 18)
      JacC( 19,131) = JacC( 19,131) + dw(356,131)
      JacC(131, 18) = JacC(131, 18) - dw(356, 18)
      JacC(131,131) = JacC(131,131) - dw(356,131)
      JacC( 90,105) = JacC( 90,105)+ 0.1380000000000000D+00*dw(357,105)
      JacC( 90,125) = JacC( 90,125)+ 0.1380000000000000D+00*dw(357,125)
      JacC( 91,105) = JacC( 91,105)+ 0.3820000000000000D+00*dw(357,105)
      JacC( 91,125) = JacC( 91,125)+ 0.3820000000000000D+00*dw(357,125)
      JacC(105,105) = JacC(105,105) - dw(357,105)
      JacC(105,125) = JacC(105,125) - dw(357,125)
      JacC( 90,105) = JacC( 90,105)+ 0.1380000000000000D+00*dw(358,105)
      JacC( 90,129) = JacC( 90,129)+ 0.1380000000000000D+00*dw(358,129)
      JacC( 91,105) = JacC( 91,105)+ 0.3820000000000000D+00*dw(358,105)
      JacC( 91,129) = JacC( 91,129)+ 0.3820000000000000D+00*dw(358,129)
      JacC(105,105) = JacC(105,105) - dw(358,105)
      JacC(105,129) = JacC(105,129) - dw(358,129)
      JacC(103,105) = JacC(103,105)+ 0.7800000000000000D+00*dw(359,105)
      JacC(103,130) = JacC(103,130)+ 0.7800000000000000D+00*dw(359,130)
      JacC(105,105) = JacC(105,105) - dw(359,105)
      JacC(105,130) = JacC(105,130) - dw(359,130)
      JacC(103,105) = JacC(103,105)+ 0.7800000000000000D+00*dw(360,105)
      JacC(103,122) = JacC(103,122)+ 0.7800000000000000D+00*dw(360,122)
      JacC(105,105) = JacC(105,105) - dw(360,105)
      JacC(105,122) = JacC(105,122) - dw(360,122)
      JacC(103,105) = JacC(103,105)+ 0.7800000000000000D+00*dw(361,105)
      JacC(103,124) = JacC(103,124)+ 0.7800000000000000D+00*dw(361,124)
      JacC(105,105) = JacC(105,105) - dw(361,105)
      JacC(105,124) = JacC(105,124) - dw(361,124)
      JacC( 90,106) = JacC( 90,106)+ 0.1280000000000000D+00*dw(362,106)
      JacC( 90,125) = JacC( 90,125)+ 0.1280000000000000D+00*dw(362,125)
      JacC( 91,106) = JacC( 91,106)+ 0.3460000000000000D+00*dw(362,106)
      JacC( 91,125) = JacC( 91,125)+ 0.3460000000000000D+00*dw(362,125)
      JacC(106,106) = JacC(106,106) - dw(362,106)
      JacC(106,125) = JacC(106,125) - dw(362,125)
      JacC( 90,106) = JacC( 90,106)+ 0.1280000000000000D+00*dw(363,106)
      JacC( 90,129) = JacC( 90,129)+ 0.1280000000000000D+00*dw(363,129)
      JacC( 91,106) = JacC( 91,106)+ 0.3460000000000000D+00*dw(363,106)
      JacC( 91,129) = JacC( 91,129)+ 0.3460000000000000D+00*dw(363,129)
      JacC(106,106) = JacC(106,106) - dw(363,106)
      JacC(106,129) = JacC(106,129) - dw(363,129)
      JacC(103,106) = JacC(103,106)+ 0.7100000000000000D+00*dw(364,106)
      JacC(103,130) = JacC(103,130)+ 0.7100000000000000D+00*dw(364,130)
      JacC(106,106) = JacC(106,106) - dw(364,106)
      JacC(106,130) = JacC(106,130) - dw(364,130)
      JacC(103,106) = JacC(103,106)+ 0.7100000000000000D+00*dw(365,106)
      JacC(103,122) = JacC(103,122)+ 0.7100000000000000D+00*dw(365,122)
      JacC(106,106) = JacC(106,106) - dw(365,106)
      JacC(106,122) = JacC(106,122) - dw(365,122)
      JacC(103,106) = JacC(103,106)+ 0.7100000000000000D+00*dw(366,106)
      JacC(103,124) = JacC(103,124)+ 0.7100000000000000D+00*dw(366,124)
      JacC(106,106) = JacC(106,106) - dw(366,106)
      JacC(106,124) = JacC(106,124) - dw(366,124)
      JacC( 90,107) = JacC( 90,107)+ 0.1280000000000000D+00*dw(367,107)
      JacC( 90,125) = JacC( 90,125)+ 0.1280000000000000D+00*dw(367,125)
      JacC( 91,107) = JacC( 91,107)+ 0.3460000000000000D+00*dw(367,107)
      JacC( 91,125) = JacC( 91,125)+ 0.3460000000000000D+00*dw(367,125)
      JacC(107,107) = JacC(107,107) - dw(367,107)
      JacC(107,125) = JacC(107,125) - dw(367,125)
      JacC( 90,107) = JacC( 90,107)+ 0.1280000000000000D+00*dw(368,107)
      JacC( 90,129) = JacC( 90,129)+ 0.1280000000000000D+00*dw(368,129)
      JacC( 91,107) = JacC( 91,107)+ 0.3460000000000000D+00*dw(368,107)
      JacC( 91,129) = JacC( 91,129)+ 0.3460000000000000D+00*dw(368,129)
      JacC(107,107) = JacC(107,107) - dw(368,107)
      JacC(107,129) = JacC(107,129) - dw(368,129)
      JacC(103,107) = JacC(103,107)+ 0.7100000000000000D+00*dw(369,107)
      JacC(103,130) = JacC(103,130)+ 0.7100000000000000D+00*dw(369,130)
      JacC(107,107) = JacC(107,107) - dw(369,107)
      JacC(107,130) = JacC(107,130) - dw(369,130)
      JacC(103,107) = JacC(103,107)+ 0.7100000000000000D+00*dw(370,107)
      JacC(103,122) = JacC(103,122)+ 0.7100000000000000D+00*dw(370,122)
      JacC(107,107) = JacC(107,107) - dw(370,107)
      JacC(107,122) = JacC(107,122) - dw(370,122)
      JacC(103,107) = JacC(103,107)+ 0.7100000000000000D+00*dw(371,107)
      JacC(103,124) = JacC(103,124)+ 0.7100000000000000D+00*dw(371,124)
      JacC(107,107) = JacC(107,107) - dw(371,107)
      JacC(107,124) = JacC(107,124) - dw(371,124)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
