C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine kinetic                        (
     $    Ns,Nbin_aer,nr,IHETER,ICLD,rk,temp,xlw,
     $    Press,azi,att,lwctmp,granulo,WetDiam,dsf_aero,ispeclost,
     $    Wmol,LWCmin,option_photolysis)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2_SORGAM_isop_tp
C     Species: _ciRACM2_SORGAM_iso2
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     NR: reaction number.
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C     lwctmp: Liquid Water Content ([g.m-3])
C     WetDiam: Bins wet Diameter ([mu m])
C     granulo: Particles number in each bin.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     RK: kinetic rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer Ns,Nbin_aer,nr
      double precision rk352,rk353,rk354,rk355
      double precision lwctmp
      double precision WetDiam(Nbin_aer)
      double precision granulo(Nbin_aer)
      double precision dsf_aero(Nbin_aer)
      integer ICLD,IHETER
      integer ispeclost(4)
      double precision Wmol(Ns),LWCmin
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,facteur,SumM,azi,att
      double precision YlH2O
      integer option_photolysis
 
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
 
      SumM = Press * 7.243D16 / temp
 
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
 
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
 
C     For the zenithal angle at tropics
 
      azi=abs(azi)
 
C
      if(option_photolysis.eq.2) then
       rk(  1)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  1)=-0.1302720567168795D-07
       rk(  1)=-0.7822279432831311D-06+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.9310260000000001D-02+(azi- 0.00D+00) * rk(  1)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  1)= 0.3771617015067078D-08
       rk(  1)=-0.1173044113433769D-05+(azi- 0.10D+02) * rk(  1)
       rk(  1)=-0.1955272056716901D-04+(azi- 0.10D+02) * rk(  1)
       rk(  1)= 0.9219010000000000D-02+(azi- 0.10D+02) * rk(  1)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  1)=-0.5859262388581815D-08
       rk(  1)=-0.1059895602981758D-05+(azi- 0.20D+02) * rk(  1)
       rk(  1)=-0.4188211773132428D-04+(azi- 0.20D+02) * rk(  1)
       rk(  1)= 0.8909950000000000D-02+(azi- 0.20D+02) * rk(  1)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  1)=-0.7024567460738029D-08
       rk(  1)=-0.1235673474639213D-05+(azi- 0.30D+02) * rk(  1)
       rk(  1)=-0.6483780850753392D-04+(azi- 0.30D+02) * rk(  1)
       rk(  1)= 0.8379279999999999D-02+(azi- 0.30D+02) * rk(  1)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  1)=-0.9202467768466835D-08
       rk(  1)=-0.1446410498461367D-05+(azi- 0.40D+02) * rk(  1)
       rk(  1)=-0.9165864823853972D-04+(azi- 0.40D+02) * rk(  1)
       rk(  1)= 0.7600310000000000D-02+(azi- 0.40D+02) * rk(  1)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  1)=-0.1612556146540100D-07
       rk(  1)=-0.1722484531515342D-05+(azi- 0.50D+02) * rk(  1)
       rk(  1)=-0.1233475985383066D-03+(azi- 0.50D+02) * rk(  1)
       rk(  1)= 0.6529880000000000D-02+(azi- 0.50D+02) * rk(  1)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  1)= 0.3226471363007382D-07
       rk(  1)=-0.2206251375477548D-05+(azi- 0.60D+02) * rk(  1)
       rk(  1)=-0.1626349576082332D-03+(azi- 0.60D+02) * rk(  1)
       rk(  1)= 0.5108030000000000D-02+(azi- 0.60D+02) * rk(  1)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  1)= 0.2027078243961372D-06
       rk(  1)=-0.1238309966574737D-05+(azi- 0.70D+02) * rk(  1)
       rk(  1)=-0.1970805710287543D-03+(azi- 0.70D+02) * rk(  1)
       rk(  1)= 0.3293320000000000D-02+(azi- 0.70D+02) * rk(  1)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  1)=-0.7448311471194499D-07
       rk(  1)= 0.3626677818932555D-05+(azi- 0.78D+02) * rk(  1)
       rk(  1)=-0.1779736282099126D-03+(azi- 0.78D+02) * rk(  1)
       rk(  1)= 0.1741210000000000D-02+(azi- 0.78D+02) * rk(  1)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  1)= 0.2490309929270573D-05
       rk(  1)= 0.1839083065842406D-05+(azi- 0.86D+02) * rk(  1)
       rk(  1)=-0.1342475411316713D-03+(azi- 0.86D+02) * rk(  1)
       rk(  1)= 0.5113930000000000D-03+(azi- 0.86D+02) * rk(  1)
      elseif(azi.ge.90.D0)then
       rk(  1)= 0.1632080000000000D-03
      endif
      if(att.lt.0.99999) rk(  1) = rk(  1) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  2)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  2)=-0.8776629099833464D-10
       rk(  2)=-0.1165033709001661D-07+(azi- 0.00D+00) * rk(  2)
       rk(  2)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  2)
       rk(  2)= 0.3523480000000000D-04+(azi- 0.00D+00) * rk(  2)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  2)= 0.1474988729949909D-09
       rk(  2)=-0.1428332581996665D-07+(azi- 0.10D+02) * rk(  2)
       rk(  2)=-0.2593366290998327D-06+(azi- 0.10D+02) * rk(  2)
       rk(  2)= 0.3398200000000000D-04+(azi- 0.10D+02) * rk(  2)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  2)= 0.1300707990183827D-09
       rk(  2)=-0.9858359630116941D-08+(azi- 0.20D+02) * rk(  2)
       rk(  2)=-0.5007534836006686D-06+(azi- 0.20D+02) * rk(  2)
       rk(  2)= 0.3010780000000000D-04+(azi- 0.20D+02) * rk(  2)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  2)= 0.1988179309314732D-09
       rk(  2)=-0.5956235659565481D-08+(azi- 0.30D+02) * rk(  2)
       rk(  2)=-0.6588994364974921D-06+(azi- 0.30D+02) * rk(  2)
       rk(  2)= 0.2424450000000000D-04+(azi- 0.30D+02) * rk(  2)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  2)= 0.2219574772557277D-09
       rk(  2)= 0.8302268378835231D-11+(azi- 0.40D+02) * rk(  2)
       rk(  2)=-0.7183787704093613D-06+(azi- 0.40D+02) * rk(  2)
       rk(  2)= 0.1725870000000000D-04+(azi- 0.40D+02) * rk(  2)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  2)= 0.1913521600455895D-09
       rk(  2)= 0.6667026586050136D-08+(azi- 0.50D+02) * rk(  2)
       rk(  2)=-0.6516254818650674D-06+(azi- 0.50D+02) * rk(  2)
       rk(  2)= 0.1029770000000000D-04+(azi- 0.50D+02) * rk(  2)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  2)= 0.1602388256152816D-10
       rk(  2)= 0.1240759138741867D-07+(azi- 0.60D+02) * rk(  2)
       rk(  2)=-0.4608793021303539D-06+(azi- 0.60D+02) * rk(  2)
       rk(  2)= 0.4639500000000000D-05+(azi- 0.60D+02) * rk(  2)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  2)=-0.3089359890783960D-09
       rk(  2)= 0.1288830786428400D-07+(azi- 0.70D+02) * rk(  2)
       rk(  2)=-0.2079203096133002D-06+(azi- 0.70D+02) * rk(  2)
       rk(  2)= 0.1287490000000000D-05+(azi- 0.70D+02) * rk(  2)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  2)=-0.2034952628632162D-09
       rk(  2)= 0.5473844126395715D-08+(azi- 0.78D+02) * rk(  2)
       rk(  2)=-0.6102309368797090D-07+(azi- 0.78D+02) * rk(  2)
       rk(  2)= 0.2908040000000000D-06+(azi- 0.78D+02) * rk(  2)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  2)= 0.1623544916128788D-09
       rk(  2)= 0.5899578175158973D-09+(azi- 0.86D+02) * rk(  2)
       rk(  2)=-0.1251267813581064D-07+(azi- 0.86D+02) * rk(  2)
       rk(  2)= 0.4875570000000000D-07+(azi- 0.86D+02) * rk(  2)
      elseif(azi.ge.90.D0)then
       rk(  2)= 0.1853500000000000D-07
      endif
      if(att.lt.0.99999) rk(  2) = rk(  2) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  3)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  3)=-0.5928286648807996D-09
       rk(  3)=-0.3096171335119280D-07+(azi- 0.00D+00) * rk(  3)
       rk(  3)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  3)
       rk(  3)= 0.4927580000000000D-03+(azi- 0.00D+00) * rk(  3)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  3)= 0.1444859946426876D-09
       rk(  3)=-0.4874657329761677D-07+(azi- 0.10D+02) * rk(  3)
       rk(  3)=-0.7970828664880956D-06+(azi- 0.10D+02) * rk(  3)
       rk(  3)= 0.4890690000000000D-03+(azi- 0.10D+02) * rk(  3)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  3)=-0.5511531369012520D-10
       rk(  3)=-0.4441199345833616D-07+(azi- 0.20D+02) * rk(  3)
       rk(  3)=-0.1728668534047625D-05+(azi- 0.20D+02) * rk(  3)
       rk(  3)= 0.4763680000000000D-03+(azi- 0.20D+02) * rk(  3)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  3)=-0.3000247398821449D-09
       rk(  3)=-0.4606545286904014D-07+(azi- 0.30D+02) * rk(  3)
       rk(  3)=-0.2633442997321385D-05+(azi- 0.30D+02) * rk(  3)
       rk(  3)= 0.4545850000000000D-03+(azi- 0.30D+02) * rk(  3)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  3)=-0.2397857267812366D-09
       rk(  3)=-0.5506619506550444D-07+(azi- 0.40D+02) * rk(  3)
       rk(  3)=-0.3644759476666826D-05+(azi- 0.40D+02) * rk(  3)
       rk(  3)= 0.4233440000000000D-03+(azi- 0.40D+02) * rk(  3)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  3)=-0.1844832352993067D-08
       rk(  3)=-0.6225976686893995D-07+(azi- 0.50D+02) * rk(  3)
       rk(  3)=-0.4818019096011278D-05+(azi- 0.50D+02) * rk(  3)
       rk(  3)= 0.3811500000000000D-03+(azi- 0.50D+02) * rk(  3)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  3)= 0.1101151387530619D-09
       rk(  3)=-0.1176047374587370D-06+(azi- 0.60D+02) * rk(  3)
       rk(  3)=-0.6616664139287950D-05+(azi- 0.60D+02) * rk(  3)
       rk(  3)= 0.3248990000000000D-03+(azi- 0.60D+02) * rk(  3)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  3)=-0.1557211541866474D-07
       rk(  3)=-0.1143012832961418D-06+(azi- 0.70D+02) * rk(  3)
       rk(  3)=-0.8935724346837023D-05+(azi- 0.70D+02) * rk(  3)
       rk(  3)= 0.2470820000000000D-03+(azi- 0.70D+02) * rk(  3)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  3)= 0.4048472604232427D-07
       rk(  3)=-0.4880320533439059D-06+(azi- 0.78D+02) * rk(  3)
       rk(  3)=-0.1375439103995816D-04+(azi- 0.78D+02) * rk(  3)
       rk(  3)= 0.1603080000000000D-03+(azi- 0.78D+02) * rk(  3)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  3)= 0.2066880316654862D-06
       rk(  3)= 0.4836013716715513D-06+(azi- 0.86D+02) * rk(  3)
       rk(  3)=-0.1378983649333310D-04+(azi- 0.86D+02) * rk(  3)
       rk(  3)= 0.3976700000000000D-04+(azi- 0.86D+02) * rk(  3)
      elseif(azi.ge.90.D0)then
       rk(  3)= 0.5573310000000000D-05
      endif
      if(att.lt.0.99999) rk(  3) = rk(  3) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  4)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  4)=-0.2887225450832658D-08
       rk(  4)=-0.1810277454916759D-06+(azi- 0.00D+00) * rk(  4)
       rk(  4)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  4)
       rk(  4)= 0.2046710000000000D-02+(azi- 0.00D+00) * rk(  4)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  4)= 0.8216763524985595D-09
       rk(  4)=-0.2676445090166556D-06+(azi- 0.10D+02) * rk(  4)
       rk(  4)=-0.4486722545083316D-05+(azi- 0.10D+02) * rk(  4)
       rk(  4)= 0.2025720000000000D-02+(azi- 0.10D+02) * rk(  4)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  4)=-0.1309479959161308D-08
       rk(  4)=-0.2429942184416991D-06+(azi- 0.20D+02) * rk(  4)
       rk(  4)=-0.9593109819666860D-05+(azi- 0.20D+02) * rk(  4)
       rk(  4)= 0.1954910000000000D-02+(azi- 0.20D+02) * rk(  4)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  4)=-0.1523756515853649D-08
       rk(  4)=-0.2822786172165394D-06+(azi- 0.30D+02) * rk(  4)
       rk(  4)=-0.1484583817624924D-04+(azi- 0.30D+02) * rk(  4)
       rk(  4)= 0.1833370000000000D-02+(azi- 0.30D+02) * rk(  4)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  4)=-0.1745493977424016D-08
       rk(  4)=-0.3279913126921461D-06+(azi- 0.40D+02) * rk(  4)
       rk(  4)=-0.2094853747533609D-04+(azi- 0.40D+02) * rk(  4)
       rk(  4)= 0.1655160000000000D-02+(azi- 0.40D+02) * rk(  4)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  4)=-0.2754267574450560D-08
       rk(  4)=-0.3803561320148624D-06+(azi- 0.50D+02) * rk(  4)
       rk(  4)=-0.2803201192240625D-04+(azi- 0.50D+02) * rk(  4)
       rk(  4)= 0.1411130000000000D-02+(azi- 0.50D+02) * rk(  4)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  4)= 0.1037656427523324D-07
       rk(  4)=-0.4629841592484096D-06+(azi- 0.60D+02) * rk(  4)
       rk(  4)=-0.3646541483503878D-04+(azi- 0.60D+02) * rk(  4)
       rk(  4)= 0.1090020000000000D-02+(azi- 0.60D+02) * rk(  4)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  4)= 0.4335158727139456D-07
       rk(  4)=-0.1516872309913989D-06+(azi- 0.70D+02) * rk(  4)
       rk(  4)=-0.4261212873743828D-04+(azi- 0.70D+02) * rk(  4)
       rk(  4)= 0.6894440000000000D-03+(azi- 0.70D+02) * rk(  4)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  4)=-0.2976581610911796D-07
       rk(  4)= 0.8887508635220705D-06+(azi- 0.78D+02) * rk(  4)
       rk(  4)=-0.3671561967719464D-04+(azi- 0.78D+02) * rk(  4)
       rk(  4)= 0.3610350000000000D-03+(azi- 0.78D+02) * rk(  4)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  4)= 0.5586598403857848D-06
       rk(  4)= 0.1743712769036732D-06+(azi- 0.86D+02) * rk(  4)
       rk(  4)=-0.2821064255377481D-04+(azi- 0.86D+02) * rk(  4)
       rk(  4)= 0.1089500000000000D-03+(azi- 0.86D+02) * rk(  4)
      elseif(azi.ge.90.D0)then
       rk(  4)= 0.3465160000000000D-04
      endif
      if(att.lt.0.99999) rk(  4) = rk(  4) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  5)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  5)=-0.1532025548735494D-11
       rk(  5)=-0.1605297445126457D-09+(azi- 0.00D+00) * rk(  5)
       rk(  5)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  5)
       rk(  5)= 0.7475310000000001D-06+(azi- 0.00D+00) * rk(  5)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  5)= 0.1499076646206637D-11
       rk(  5)=-0.2064905109747105D-09+(azi- 0.10D+02) * rk(  5)
       rk(  5)=-0.3670202554873561D-08+(azi- 0.10D+02) * rk(  5)
       rk(  5)= 0.7299460000000000D-06+(azi- 0.10D+02) * rk(  5)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  5)= 0.8827189639089728D-12
       rk(  5)=-0.1615182115885116D-09+(azi- 0.20D+02) * rk(  5)
       rk(  5)=-0.7350289780505779D-08+(azi- 0.20D+02) * rk(  5)
       rk(  5)= 0.6740940000000000D-06+(azi- 0.20D+02) * rk(  5)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  5)= 0.1742047498157359D-11
       rk(  5)=-0.1350366426712420D-09+(azi- 0.30D+02) * rk(  5)
       rk(  5)=-0.1031583832310330D-07+(azi- 0.30D+02) * rk(  5)
       rk(  5)= 0.5853220000000000D-06+(azi- 0.30D+02) * rk(  5)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  5)= 0.2513091043461601D-11
       rk(  5)=-0.8277521772651622D-10+(azi- 0.40D+02) * rk(  5)
       rk(  5)=-0.1249395692708094D-07+(azi- 0.40D+02) * rk(  5)
       rk(  5)= 0.4704020000000000D-06+(azi- 0.40D+02) * rk(  5)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  5)= 0.3194588327996089D-11
       rk(  5)=-0.7382486422669833D-11+(azi- 0.50D+02) * rk(  5)
       rk(  5)=-0.1339553396857280D-07+(azi- 0.50D+02) * rk(  5)
       rk(  5)= 0.3396980000000000D-06+(azi- 0.50D+02) * rk(  5)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  5)= 0.5281855644545232D-11
       rk(  5)= 0.8845516341719630D-10+(azi- 0.60D+02) * rk(  5)
       rk(  5)=-0.1258480719862726D-07+(azi- 0.60D+02) * rk(  5)
       rk(  5)= 0.2081990000000000D-06+(azi- 0.60D+02) * rk(  5)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  5)=-0.2756160173816243D-12
       rk(  5)= 0.2469108327538047D-09+(azi- 0.70D+02) * rk(  5)
       rk(  5)=-0.9231147236917937D-08+(azi- 0.70D+02) * rk(  5)
       rk(  5)= 0.9647830000000000D-07+(azi- 0.70D+02) * rk(  5)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  5)=-0.5270116382809120D-11
       rk(  5)= 0.2402960483368575D-09+(azi- 0.78D+02) * rk(  5)
       rk(  5)=-0.5333492188194333D-08+(azi- 0.78D+02) * rk(  5)
       rk(  5)= 0.3829030000000000D-07+(azi- 0.78D+02) * rk(  5)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  5)= 0.3312732748114380D-10
       rk(  5)= 0.1138132551494386D-09+(azi- 0.86D+02) * rk(  5)
       rk(  5)=-0.2500617760290411D-08+(azi- 0.86D+02) * rk(  5)
       rk(  5)= 0.8303010000000000D-08+(azi- 0.86D+02) * rk(  5)
      elseif(azi.ge.90.D0)then
       rk(  5)= 0.2241700000000000D-08
      endif
      if(att.lt.0.99999) rk(  5) = rk(  5) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  6)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  6)=-0.1022637521258300D-10
       rk(  6)=-0.1047636247874169D-08+(azi- 0.00D+00) * rk(  6)
       rk(  6)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  6)
       rk(  6)= 0.5038360000000000D-05+(azi- 0.00D+00) * rk(  6)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  6)= 0.9289125637748400D-11
       rk(  6)=-0.1354427504251659D-08+(azi- 0.10D+02) * rk(  6)
       rk(  6)=-0.2402063752125827D-07+(azi- 0.10D+02) * rk(  6)
       rk(  6)= 0.4923370000000000D-05+(azi- 0.10D+02) * rk(  6)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  6)= 0.4979872661590682D-11
       rk(  6)=-0.1075753735119207D-08+(azi- 0.20D+02) * rk(  6)
       rk(  6)=-0.4832244991496692D-07+(azi- 0.20D+02) * rk(  6)
       rk(  6)= 0.4557010000000000D-05+(azi- 0.20D+02) * rk(  6)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  6)= 0.1055138371588688D-10
       rk(  6)=-0.9263575552714849D-09+(azi- 0.30D+02) * rk(  6)
       rk(  6)=-0.6834356281887375D-07+(azi- 0.30D+02) * rk(  6)
       rk(  6)= 0.3971190000000000D-05+(azi- 0.30D+02) * rk(  6)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  6)= 0.1620459247486068D-10
       rk(  6)=-0.6098160437948834D-09+(azi- 0.40D+02) * rk(  6)
       rk(  6)=-0.8370529880953754D-07+(azi- 0.40D+02) * rk(  6)
       rk(  6)= 0.3205670000000000D-05+(azi- 0.40D+02) * rk(  6)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  6)= 0.2215024638467897D-10
       rk(  6)=-0.1236782695490497D-09+(azi- 0.50D+02) * rk(  6)
       rk(  6)=-0.9104024194297703D-07+(azi- 0.50D+02) * rk(  6)
       rk(  6)= 0.2323840000000000D-05+(azi- 0.50D+02) * rk(  6)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  6)= 0.3999042198642357D-10
       rk(  6)= 0.5408291219911870D-09+(azi- 0.60D+02) * rk(  6)
       rk(  6)=-0.8686873341855619D-07+(azi- 0.60D+02) * rk(  6)
       rk(  6)= 0.1423220000000000D-05+(azi- 0.60D+02) * rk(  6)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  6)=-0.2067341717000215D-11
       rk(  6)= 0.1740541781586012D-08+(azi- 0.70D+02) * rk(  6)
       rk(  6)=-0.6405502438280072D-07+(azi- 0.70D+02) * rk(  6)
       rk(  6)= 0.6486060000000000D-06+(azi- 0.70D+02) * rk(  6)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  6)=-0.2916729149837185D-10
       rk(  6)= 0.1690925580378854D-08+(azi- 0.78D+02) * rk(  6)
       rk(  6)=-0.3660328548710213D-07+(azi- 0.78D+02) * rk(  6)
       rk(  6)= 0.2465020000000000D-06+(azi- 0.78D+02) * rk(  6)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  6)= 0.1504439894534147D-09
       rk(  6)= 0.9909105844077646D-09+(azi- 0.86D+02) * rk(  6)
       rk(  6)=-0.1514859616880918D-07+(azi- 0.86D+02) * rk(  6)
       rk(  6)= 0.4696130000000000D-07+(azi- 0.86D+02) * rk(  6)
      elseif(azi.ge.90.D0)then
       rk(  6)= 0.1184990000000000D-07
      endif
      if(att.lt.0.99999) rk(  6) = rk(  6) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  7)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  7)=-0.3691161034363460D-07
       rk(  7)=-0.1177883896563626D-05+(azi- 0.00D+00) * rk(  7)
       rk(  7)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  7)
       rk(  7)= 0.2656490000000000D-01+(azi- 0.00D+00) * rk(  7)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  7)= 0.1703483103089462D-07
       rk(  7)=-0.2285232206872663D-05+(azi- 0.10D+02) * rk(  7)
       rk(  7)=-0.3463116103436289D-04+(azi- 0.10D+02) * rk(  7)
       rk(  7)= 0.2641020000000000D-01+(azi- 0.10D+02) * rk(  7)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  7)=-0.1532771377994130D-07
       rk(  7)=-0.1774187275945825D-05+(azi- 0.20D+02) * rk(  7)
       rk(  7)=-0.7522535586254776D-04+(azi- 0.20D+02) * rk(  7)
       rk(  7)= 0.2585240000000000D-01+(azi- 0.20D+02) * rk(  7)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  7)=-0.1372397591112858D-07
       rk(  7)=-0.2234018689344064D-05+(azi- 0.30D+02) * rk(  7)
       rk(  7)=-0.1153074155154466D-03+(azi- 0.30D+02) * rk(  7)
       rk(  7)= 0.2490740000000000D-01+(azi- 0.30D+02) * rk(  7)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  7)=-0.2747638257554304D-07
       rk(  7)=-0.2645737966677932D-05+(azi- 0.40D+02) * rk(  7)
       rk(  7)=-0.1641049820756665D-03+(azi- 0.40D+02) * rk(  7)
       rk(  7)= 0.2351720000000000D-01+(azi- 0.40D+02) * rk(  7)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  7)=-0.1322704937867030D-06
       rk(  7)=-0.3470029443944237D-05+(azi- 0.50D+02) * rk(  7)
       rk(  7)=-0.2252626561818883D-03+(azi- 0.50D+02) * rk(  7)
       rk(  7)= 0.2158410000000000D-01+(azi- 0.50D+02) * rk(  7)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  7)=-0.2304164227760796D-07
       rk(  7)=-0.7438144257545598D-05+(azi- 0.60D+02) * rk(  7)
       rk(  7)=-0.3343443931967845D-03+(azi- 0.60D+02) * rk(  7)
       rk(  7)= 0.1885220000000000D-01+(azi- 0.60D+02) * rk(  7)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  7)=-0.1151055949407016D-05
       rk(  7)=-0.8129393525872428D-05+(azi- 0.70D+02) * rk(  7)
       rk(  7)=-0.4900197710309764D-03+(azi- 0.70D+02) * rk(  7)
       rk(  7)= 0.1474190000000000D-01+(azi- 0.70D+02) * rk(  7)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  7)= 0.3051007034753431D-05
       rk(  7)=-0.3575473631163908D-04+(azi- 0.78D+02) * rk(  7)
       rk(  7)=-0.8410928097310894D-03+(azi- 0.78D+02) * rk(  7)
       rk(  7)= 0.9712119999999999D-02+(azi- 0.78D+02) * rk(  7)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  7)= 0.1099207874719760D-04
       rk(  7)= 0.3746943252241897D-04+(azi- 0.86D+02) * rk(  7)
       rk(  7)=-0.8273752400447254D-03+(azi- 0.86D+02) * rk(  7)
       rk(  7)= 0.2257190000000000D-02+(azi- 0.86D+02) * rk(  7)
      elseif(azi.ge.90.D0)then
       rk(  7)= 0.2506930000000000D-03
      endif
      if(att.lt.0.99999) rk(  7) = rk(  7) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  8)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  8)=-0.1926445199576598D-06
       rk(  8)=-0.1114355480042343D-04+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.2129960000000000D+00+(azi- 0.00D+00) * rk(  8)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  8)=-0.3806644012699938D-07
       rk(  8)=-0.1692289039915322D-04+(azi- 0.10D+02) * rk(  8)
       rk(  8)=-0.2806644519957665D-03+(azi- 0.10D+02) * rk(  8)
       rk(  8)= 0.2116890000000000D+00+(azi- 0.10D+02) * rk(  8)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  8)= 0.3591028046562922D-07
       rk(  8)=-0.1806488360296321D-04+(azi- 0.20D+02) * rk(  8)
       rk(  8)=-0.6305421920169308D-03+(azi- 0.20D+02) * rk(  8)
       rk(  8)= 0.2071520000000000D+00+(azi- 0.20D+02) * rk(  8)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  8)=-0.2185746817355116D-06
       rk(  8)=-0.1698757518899435D-04+(azi- 0.30D+02) * rk(  8)
       rk(  8)=-0.9810667799365058D-03+(azi- 0.30D+02) * rk(  8)
       rk(  8)= 0.1990760000000000D+00+(azi- 0.30D+02) * rk(  8)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  8)=-0.2006115535235656D-06
       rk(  8)=-0.2354481564105959D-04+(azi- 0.40D+02) * rk(  8)
       rk(  8)=-0.1386390688237046D-02+(azi- 0.40D+02) * rk(  8)
       rk(  8)= 0.1873480000000000D+00+(azi- 0.40D+02) * rk(  8)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  8)=-0.1055979104170267D-05
       rk(  8)=-0.2956316224676618D-04+(azi- 0.50D+02) * rk(  8)
       rk(  8)=-0.1917470467115309D-02+(azi- 0.50D+02) * rk(  8)
       rk(  8)= 0.1709290000000000D+00+(azi- 0.50D+02) * rk(  8)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  8)=-0.3204720297952934D-06
       rk(  8)=-0.6124253537187832D-04+(azi- 0.60D+02) * rk(  8)
       rk(  8)=-0.2825527443301723D-02+(azi- 0.60D+02) * rk(  8)
       rk(  8)= 0.1477420000000000D+00+(azi- 0.60D+02) * rk(  8)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  8)=-0.6785572971821502D-05
       rk(  8)=-0.7085669626571978D-04+(azi- 0.70D+02) * rk(  8)
       rk(  8)=-0.4146519759677725D-02+(azi- 0.70D+02) * rk(  8)
       rk(  8)= 0.1130420000000000D+00+(azi- 0.70D+02) * rk(  8)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  8)= 0.2349184361304102D-04
       rk(  8)=-0.2337104475894081D-03+(azi- 0.78D+02) * rk(  8)
       rk(  8)=-0.6583056910518970D-02+(azi- 0.78D+02) * rk(  8)
       rk(  8)= 0.7186080000000000D-01+(azi- 0.78D+02) * rk(  8)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  8)= 0.6606749385962285D-04
       rk(  8)= 0.3300937991232988D-03+(azi- 0.86D+02) * rk(  8)
       rk(  8)=-0.5811990098247399D-02+(azi- 0.86D+02) * rk(  8)
       rk(  8)= 0.1626670000000000D-01+(azi- 0.86D+02) * rk(  8)
      elseif(azi.ge.90.D0)then
       rk(  8)= 0.2528560000000000D-02
      endif
      if(att.lt.0.99999) rk(  8) = rk(  8) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  9)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  9)=-0.1441479345432039D-10
       rk(  9)=-0.1242452065456794D-08+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.8394580000000000D-05+(azi- 0.00D+00) * rk(  9)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  9)= 0.8244380362960478D-11
       rk(  9)=-0.1674895869086405D-08+(azi- 0.10D+02) * rk(  9)
       rk(  9)=-0.2917347934543199D-07+(azi- 0.10D+02) * rk(  9)
       rk(  9)= 0.8255920000000000D-05+(azi- 0.10D+02) * rk(  9)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  9)= 0.1172720024787734D-12
       rk(  9)=-0.1427564458197592D-08+(azi- 0.20D+02) * rk(  9)
       rk(  9)=-0.6019808261827194D-07+(azi- 0.20D+02) * rk(  9)
       rk(  9)= 0.7804940000000000D-05+(azi- 0.20D+02) * rk(  9)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  9)= 0.4506531627127201D-11
       rk(  9)=-0.1424046298123240D-08+(azi- 0.30D+02) * rk(  9)
       rk(  9)=-0.8871419018148013D-07+(azi- 0.30D+02) * rk(  9)
       rk(  9)= 0.7060320000000000D-05+(azi- 0.30D+02) * rk(  9)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  9)= 0.1086660148900755D-10
       rk(  9)=-0.1288850349309390D-08+(azi- 0.40D+02) * rk(  9)
       rk(  9)=-0.1158431566558070D-06+(azi- 0.40D+02) * rk(  9)
       rk(  9)= 0.6035280000000000D-05+(azi- 0.40D+02) * rk(  9)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  9)= 0.1803706241686108D-10
       rk(  9)=-0.9628523046392104D-09+(azi- 0.50D+02) * rk(  9)
       rk(  9)=-0.1383601831952927D-06+(azi- 0.50D+02) * rk(  9)
       rk(  9)= 0.4758830000000000D-05+(azi- 0.50D+02) * rk(  9)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  9)= 0.7329514884355585D-10
       rk(  9)=-0.4217404321336693D-09+(azi- 0.60D+02) * rk(  9)
       rk(  9)=-0.1522061105630206D-06+(azi- 0.60D+02) * rk(  9)
       rk(  9)= 0.3296980000000000D-05+(azi- 0.60D+02) * rk(  9)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  9)= 0.6172011386267615D-10
       rk(  9)= 0.1777114033174383D-08+(azi- 0.70D+02) * rk(  9)
       rk(  9)=-0.1386523745526241D-06+(azi- 0.70D+02) * rk(  9)
       rk(  9)= 0.1806040000000000D-05+(azi- 0.70D+02) * rk(  9)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  9)=-0.8279704635596216D-10
       rk(  9)= 0.3258396765877763D-08+(azi- 0.78D+02) * rk(  9)
       rk(  9)=-0.9836828816022045D-07+(azi- 0.78D+02) * rk(  9)
       rk(  9)= 0.8421570000000000D-06+(azi- 0.78D+02) * rk(  9)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  9)= 0.1082517324572734D-08
       rk(  9)= 0.1271267653334671D-08+(azi- 0.86D+02) * rk(  9)
       rk(  9)=-0.6213097280649386D-07+(azi- 0.86D+02) * rk(  9)
       rk(  9)= 0.2213560000000000D-06+(azi- 0.86D+02) * rk(  9)
      elseif(azi.ge.90.D0)then
       rk(  9)= 0.6245350000000000D-07
      endif
      if(att.lt.0.99999) rk(  9) = rk(  9) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 10)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 10)=-0.7261045436751545D-10
       rk( 10)=-0.5576895456324842D-08+(azi- 0.00D+00) * rk( 10)
       rk( 10)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 10)
       rk( 10)= 0.4669460000000000D-04+(azi- 0.00D+00) * rk( 10)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 10)= 0.2853136310254372D-10
       rk( 10)=-0.7755209087350302D-08+(azi- 0.10D+02) * rk( 10)
       rk( 10)=-0.1333210454367515D-06+(azi- 0.10D+02) * rk( 10)
       rk( 10)= 0.4606430000000000D-04+(azi- 0.10D+02) * rk( 10)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 10)=-0.1901499804265726D-10
       rk( 10)=-0.6899268194273995D-08+(azi- 0.20D+02) * rk( 10)
       rk( 10)=-0.2798658182529944D-06+(azi- 0.20D+02) * rk( 10)
       rk( 10)= 0.4398410000000000D-04+(azi- 0.20D+02) * rk( 10)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 10)=-0.9471370931908783D-11
       rk( 10)=-0.7469718135553710D-08+(azi- 0.30D+02) * rk( 10)
       rk( 10)=-0.4235556815512711D-06+(azi- 0.30D+02) * rk( 10)
       rk( 10)= 0.4047650000000000D-04+(azi- 0.30D+02) * rk( 10)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 10)= 0.1440048177028887D-10
       rk( 10)=-0.7753859263510966D-08+(azi- 0.40D+02) * rk( 10)
       rk( 10)=-0.5757914555419174D-06+(azi- 0.40D+02) * rk( 10)
       rk( 10)= 0.3548450000000000D-04+(azi- 0.40D+02) * rk( 10)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 10)= 0.3856944385081257D-10
       rk( 10)=-0.7321844810402538D-08+(azi- 0.50D+02) * rk( 10)
       rk( 10)=-0.7265484962810543D-06+(azi- 0.50D+02) * rk( 10)
       rk( 10)= 0.2896560000000000D-04+(azi- 0.50D+02) * rk( 10)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 10)= 0.4136217428262900D-09
       rk( 10)=-0.6164761494878585D-08+(azi- 0.60D+02) * rk( 10)
       rk( 10)=-0.8614145593338596D-06+(azi- 0.60D+02) * rk( 10)
       rk( 10)= 0.2100650000000000D-04+(azi- 0.60D+02) * rk( 10)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 10)= 0.5376701572532502D-09
       rk( 10)= 0.6243890789914774D-08+(azi- 0.70D+02) * rk( 10)
       rk( 10)=-0.8606232663835604D-06+(azi- 0.70D+02) * rk( 10)
       rk( 10)= 0.1218950000000000D-04+(azi- 0.70D+02) * rk( 10)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 10)=-0.5508273899935273D-09
       rk( 10)= 0.1914797456399955D-07+(azi- 0.78D+02) * rk( 10)
       rk( 10)=-0.6574883435524898D-06+(azi- 0.78D+02) * rk( 10)
       rk( 10)= 0.5979410000000000D-05+(azi- 0.78D+02) * rk( 10)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 10)= 0.8530305661922505D-08
       rk( 10)= 0.5928117204100688D-08+(azi- 0.86D+02) * rk( 10)
       rk( 10)=-0.4568796094072541D-06+(azi- 0.86D+02) * rk( 10)
       rk( 10)= 0.1662950000000000D-05+(azi- 0.86D+02) * rk( 10)
      elseif(azi.ge.90.D0)then
       rk( 10)= 0.4762210000000000D-06
      endif
      if(att.lt.0.99999) rk( 10) = rk( 10) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 11)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 11)=-0.5816837387219519D-10
       rk( 11)=-0.5184316261278087D-08+(azi- 0.00D+00) * rk( 11)
       rk( 11)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 11)
       rk( 11)= 0.3220560000000000D-04+(azi- 0.00D+00) * rk( 11)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 11)= 0.3450512161659949D-10
       rk( 11)=-0.6929367477443941D-08+(azi- 0.10D+02) * rk( 11)
       rk( 11)=-0.1211368373872203D-06+(azi- 0.10D+02) * rk( 11)
       rk( 11)= 0.3162900000000000D-04+(azi- 0.10D+02) * rk( 11)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 11)= 0.3647887405787883D-11
       rk( 11)=-0.5894213828945960D-08+(azi- 0.20D+02) * rk( 11)
       rk( 11)=-0.2493726504511192D-06+(azi- 0.20D+02) * rk( 11)
       rk( 11)= 0.2975920000000000D-04+(azi- 0.20D+02) * rk( 11)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 11)= 0.2530332876025029D-10
       rk( 11)=-0.5784777206772343D-08+(azi- 0.30D+02) * rk( 11)
       rk( 11)=-0.3661625608083018D-06+(azi- 0.30D+02) * rk( 11)
       rk( 11)= 0.2667970000000000D-04+(azi- 0.30D+02) * rk( 11)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 11)= 0.6013879755321277D-10
       rk( 11)=-0.5025677343964861D-08+(azi- 0.40D+02) * rk( 11)
       rk( 11)=-0.4742671063156733D-06+(azi- 0.40D+02) * rk( 11)
       rk( 11)= 0.2246490000000000D-04+(azi- 0.40D+02) * rk( 11)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 11)= 0.1004414810269593D-09
       rk( 11)=-0.3221513417368319D-08+(azi- 0.50D+02) * rk( 11)
       rk( 11)=-0.5567390139290089D-06+(azi- 0.50D+02) * rk( 11)
       rk( 11)= 0.1727980000000000D-04+(azi- 0.50D+02) * rk( 11)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 11)= 0.3107352783389442D-09
       rk( 11)=-0.2082689865616575D-09+(azi- 0.60D+02) * rk( 11)
       rk( 11)=-0.5910368379682989D-06+(azi- 0.60D+02) * rk( 11)
       rk( 11)= 0.1149070000000000D-04+(azi- 0.60D+02) * rk( 11)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 11)= 0.1345128013872392D-09
       rk( 11)= 0.9113789363612173D-08+(azi- 0.70D+02) * rk( 11)
       rk( 11)=-0.5019816341977565D-06+(azi- 0.70D+02) * rk( 11)
       rk( 11)= 0.5870240000000000D-05+(azi- 0.70D+02) * rk( 11)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 11)=-0.1960445509611151D-09
       rk( 11)= 0.1234209659691269D-07+(azi- 0.78D+02) * rk( 11)
       rk( 11)=-0.3303345465135304D-06+(azi- 0.78D+02) * rk( 11)
       rk( 11)= 0.2506540000000000D-05+(azi- 0.78D+02) * rk( 11)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 11)= 0.2279277828298341D-08
       rk( 11)= 0.7637027373778166D-08+(azi- 0.86D+02) * rk( 11)
       rk( 11)=-0.1705015547476783D-06+(azi- 0.86D+02) * rk( 11)
       rk( 11)= 0.5533830000000000D-06+(azi- 0.86D+02) * rk( 11)
      elseif(azi.ge.90.D0)then
       rk( 11)= 0.1394430000000000D-06
      endif
      if(att.lt.0.99999) rk( 11) = rk( 11) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 12)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 12)=-0.1292568102250478D-10
       rk( 12)=-0.1349143189774952D-08+(azi- 0.00D+00) * rk( 12)
       rk( 12)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 12)
       rk( 12)= 0.6105070000000000D-05+(azi- 0.00D+00) * rk( 12)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 12)= 0.1221704306751377D-10
       rk( 12)=-0.1736913620450095D-08+(azi- 0.10D+02) * rk( 12)
       rk( 12)=-0.3086056810225046D-07+(azi- 0.10D+02) * rk( 12)
       rk( 12)= 0.5957230000000000D-05+(azi- 0.10D+02) * rk( 12)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 12)= 0.7227508752451222D-11
       rk( 12)=-0.1370402328424685D-08+(azi- 0.20D+02) * rk( 12)
       rk( 12)=-0.6193372759099823D-07+(azi- 0.20D+02) * rk( 12)
       rk( 12)= 0.5487150000000000D-05+(azi- 0.20D+02) * rk( 12)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 12)= 0.1521292192268060D-10
       rk( 12)=-0.1153577065851153D-08+(azi- 0.30D+02) * rk( 12)
       rk( 12)=-0.8717352153375648D-07+(azi- 0.30D+02) * rk( 12)
       rk( 12)= 0.4738000000000000D-05+(azi- 0.30D+02) * rk( 12)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 12)= 0.2301080355683006D-10
       rk( 12)=-0.6971894081707449D-09+(azi- 0.40D+02) * rk( 12)
       rk( 12)=-0.1056811862739754D-06+(azi- 0.40D+02) * rk( 12)
       rk( 12)= 0.3766120000000000D-05+(azi- 0.40D+02) * rk( 12)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 12)= 0.3106386384999131D-10
       rk( 12)=-0.6865301465823343D-11+(azi- 0.50D+02) * rk( 12)
       rk( 12)=-0.1127217333703412D-06+(azi- 0.50D+02) * rk( 12)
       rk( 12)= 0.2662600000000000D-05+(azi- 0.50D+02) * rk( 12)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 12)= 0.4531874104319860D-10
       rk( 12)= 0.9250506140339690D-09+(azi- 0.60D+02) * rk( 12)
       rk( 12)=-0.1035398802446585D-06+(azi- 0.60D+02) * rk( 12)
       rk( 12)= 0.1565760000000000D-05+(azi- 0.60D+02) * rk( 12)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 12)=-0.1303761111962380D-10
       rk( 12)= 0.2284612845330880D-08+(azi- 0.70D+02) * rk( 12)
       rk( 12)=-0.7144324565100488D-07+(azi- 0.70D+02) * rk( 12)
       rk( 12)= 0.6681850000000000D-06+(azi- 0.70D+02) * rk( 12)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 12)=-0.4077238229824927D-10
       rk( 12)= 0.1971710178462450D-08+(azi- 0.78D+02) * rk( 12)
       rk( 12)=-0.3739266146067857D-07+(azi- 0.78D+02) * rk( 12)
       rk( 12)= 0.2361790000000000D-06+(azi- 0.78D+02) * rk( 12)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 12)= 0.1193377495821847D-09
       rk( 12)= 0.9931730033112436D-09+(azi- 0.86D+02) * rk( 12)
       rk( 12)=-0.1367359600643481D-07+(azi- 0.86D+02) * rk( 12)
       rk( 12)= 0.4235170000000000D-07+(azi- 0.86D+02) * rk( 12)
      elseif(azi.ge.90.D0)then
       rk( 12)= 0.1118570000000000D-07
      endif
      if(att.lt.0.99999) rk( 12) = rk( 12) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 13)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 13)= 0.2169057613109728D-09
       rk( 13)=-0.1039805761310975D-07+(azi- 0.00D+00) * rk( 13)
       rk( 13)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 13)
       rk( 13)= 0.3332300000000000D-04+(azi- 0.00D+00) * rk( 13)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 13)=-0.1103172839329133D-09
       rk( 13)=-0.3890884773780563D-08+(azi- 0.10D+02) * rk( 13)
       rk( 13)=-0.1428894238689031D-06+(azi- 0.10D+02) * rk( 13)
       rk( 13)= 0.3250010000000000D-04+(azi- 0.10D+02) * rk( 13)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 13)=-0.1052366255793189D-09
       rk( 13)=-0.7200403291767967D-08+(azi- 0.20D+02) * rk( 13)
       rk( 13)=-0.2538023045243883D-06+(azi- 0.20D+02) * rk( 13)
       rk( 13)= 0.3057180000000000D-04+(azi- 0.20D+02) * rk( 13)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 13)= 0.4405637862501873D-09
       rk( 13)=-0.1035750205914756D-07+(azi- 0.30D+02) * rk( 13)
       rk( 13)=-0.4293813580335427D-06+(azi- 0.30D+02) * rk( 13)
       rk( 13)= 0.2720850000000000D-04+(azi- 0.30D+02) * rk( 13)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 13)=-0.5541851942145191D-10
       rk( 13)= 0.2859411528358024D-08+(azi- 0.40D+02) * rk( 13)
       rk( 13)=-0.5043622633414362D-06+(azi- 0.40D+02) * rk( 13)
       rk( 13)= 0.2231950000000000D-04+(azi- 0.40D+02) * rk( 13)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 13)= 0.1613102914356187D-09
       rk( 13)= 0.1196855945714626D-08+(azi- 0.50D+02) * rk( 13)
       rk( 13)=-0.4637995886007127D-06+(azi- 0.50D+02) * rk( 13)
       rk( 13)= 0.1750640000000000D-04+(azi- 0.50D+02) * rk( 13)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 13)=-0.9282226463212424D-09
       rk( 13)= 0.6036164688783398D-08+(azi- 0.60D+02) * rk( 13)
       rk( 13)=-0.3914693822557367D-06+(azi- 0.60D+02) * rk( 13)
       rk( 13)= 0.1314940000000000D-04+(azi- 0.60D+02) * rk( 13)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 13)= 0.3422746093483607D-08
       rk( 13)=-0.2181051470084540D-07+(azi- 0.70D+02) * rk( 13)
       rk( 13)=-0.5492128823763568D-06+(azi- 0.70D+02) * rk( 13)
       rk( 13)= 0.8910100000000000D-05+(azi- 0.70D+02) * rk( 13)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 13)=-0.5336179917194198D-08
       rk( 13)= 0.6033539154276795D-07+(azi- 0.78D+02) * rk( 13)
       rk( 13)=-0.2410138676411933D-06+(azi- 0.78D+02) * rk( 13)
       rk( 13)= 0.4872970000000000D-05+(azi- 0.78D+02) * rk( 13)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 13)= 0.1754286580872609D-07
       rk( 13)=-0.6773292647002833D-07+(azi- 0.86D+02) * rk( 13)
       rk( 13)=-0.3001941470586258D-06+(azi- 0.86D+02) * rk( 13)
       rk( 13)= 0.4074200000000000D-05+(azi- 0.86D+02) * rk( 13)
      elseif(azi.ge.90.D0)then
       rk( 13)= 0.2912440000000000D-05
      endif
      if(att.lt.0.99999) rk( 13) = rk( 13) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 14)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 14)= 0.3702842534013247D-10
       rk( 14)=-0.1767884253401326D-08+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.3755470000000000D-05+(azi- 0.00D+00) * rk( 14)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 14)=-0.1653527602039684D-10
       rk( 14)=-0.6570314931973512D-09+(azi- 0.10D+02) * rk( 14)
       rk( 14)=-0.2424915746598677D-07+(azi- 0.10D+02) * rk( 14)
       rk( 14)= 0.3615710000000000D-05+(azi- 0.10D+02) * rk( 14)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 14)=-0.8297321258545909D-11
       rk( 14)=-0.1153089773809258D-08+(azi- 0.20D+02) * rk( 14)
       rk( 14)=-0.4235037013605284D-07+(azi- 0.20D+02) * rk( 14)
       rk( 14)= 0.3290980000000000D-05+(azi- 0.20D+02) * rk( 14)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 14)= 0.8708456105458385D-10
       rk( 14)=-0.1402009411565654D-08+(azi- 0.30D+02) * rk( 14)
       rk( 14)=-0.6790136198980171D-07+(azi- 0.30D+02) * rk( 14)
       rk( 14)= 0.2743870000000000D-05+(azi- 0.30D+02) * rk( 14)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 14)=-0.1638092295978651D-10
       rk( 14)= 0.1210527420071857D-08+(azi- 0.40D+02) * rk( 14)
       rk( 14)=-0.6981618190473992D-07+(azi- 0.40D+02) * rk( 14)
       rk( 14)= 0.2011740000000000D-05+(azi- 0.40D+02) * rk( 14)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 14)= 0.4446130784568245D-11
       rk( 14)= 0.7190997312782550D-09+(azi- 0.50D+02) * rk( 14)
       rk( 14)=-0.5051991039123922D-07+(azi- 0.50D+02) * rk( 14)
       rk( 14)= 0.1418250000000000D-05+(azi- 0.50D+02) * rk( 14)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 14)=-0.1038676001785416D-09
       rk( 14)= 0.8524836548153023D-09+(azi- 0.60D+02) * rk( 14)
       rk( 14)=-0.3480407653030026D-07+(azi- 0.60D+02) * rk( 14)
       rk( 14)= 0.9894070000000000D-06+(azi- 0.60D+02) * rk( 14)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 14)= 0.3391255983099452D-09
       rk( 14)=-0.2263544350540204D-08+(azi- 0.70D+02) * rk( 14)
       rk( 14)=-0.4891468348755182D-07+(azi- 0.70D+02) * rk( 14)
       rk( 14)= 0.6227470000000000D-06+(azi- 0.70D+02) * rk( 14)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 14)=-0.4794137789154078D-09
       rk( 14)= 0.5875470008910339D-08+(azi- 0.78D+02) * rk( 14)
       rk( 14)=-0.2001927822066528D-07+(azi- 0.78D+02) * rk( 14)
       rk( 14)= 0.2601950000000000D-06+(azi- 0.78D+02) * rk( 14)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 14)= 0.1314643523125177D-08
       rk( 14)=-0.5630460685066225D-08+(azi- 0.86D+02) * rk( 14)
       rk( 14)=-0.1805920362969553D-07+(azi- 0.86D+02) * rk( 14)
       rk( 14)= 0.2306110000000000D-06+(azi- 0.86D+02) * rk( 14)
      elseif(azi.ge.90.D0)then
       rk( 14)= 0.1524240000000000D-06
      endif
      if(att.lt.0.99999) rk( 14) = rk( 14) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 15)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 15)= 0.1540638709820811D-09
       rk( 15)=-0.7396638709820810D-08+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.2320940000000000D-04+(azi- 0.00D+00) * rk( 15)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 15)=-0.7839161294624251D-10
       rk( 15)=-0.2774722580358376D-08+(azi- 0.10D+02) * rk( 15)
       rk( 15)=-0.1017136129017918D-06+(azi- 0.10D+02) * rk( 15)
       rk( 15)= 0.2262380000000000D-04+(azi- 0.10D+02) * rk( 15)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 15)=-0.7469741919711187D-10
       rk( 15)=-0.5126470968745659D-08+(azi- 0.20D+02) * rk( 15)
       rk( 15)=-0.1807255483928321D-06+(azi- 0.20D+02) * rk( 15)
       rk( 15)= 0.2125080000000000D-04+(azi- 0.20D+02) * rk( 15)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 15)= 0.3181812897346851D-09
       rk( 15)=-0.7367393544659005D-08+(azi- 0.30D+02) * rk( 15)
       rk( 15)=-0.3056641935268783D-06+(azi- 0.30D+02) * rk( 15)
       rk( 15)= 0.1885620000000000D-04+(azi- 0.30D+02) * rk( 15)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 15)=-0.3562773974161119D-10
       rk( 15)= 0.2178045147381548D-08+(azi- 0.40D+02) * rk( 15)
       rk( 15)=-0.3575576774996549D-06+(azi- 0.40D+02) * rk( 15)
       rk( 15)= 0.1538100000000000D-04+(azi- 0.40D+02) * rk( 15)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 15)= 0.1083696692317106D-09
       rk( 15)= 0.1109212955133239D-08+(azi- 0.50D+02) * rk( 15)
       rk( 15)=-0.3246850964745110D-06+(azi- 0.50D+02) * rk( 15)
       rk( 15)= 0.1198760000000000D-04+(azi- 0.50D+02) * rk( 15)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 15)=-0.6533409371851935D-09
       rk( 15)= 0.4360303032084769D-08+(azi- 0.60D+02) * rk( 15)
       rk( 15)=-0.2699899366023301D-06+(azi- 0.60D+02) * rk( 15)
       rk( 15)= 0.8960040000000000D-05+(azi- 0.60D+02) * rk( 15)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 15)= 0.2380575121622622D-08
       rk( 15)=-0.1523992508346849D-07+(azi- 0.70D+02) * rk( 15)
       rk( 15)=-0.3787861571161470D-06+(azi- 0.70D+02) * rk( 15)
       rk( 15)= 0.6042830000000000D-05+(azi- 0.70D+02) * rk( 15)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 15)=-0.3683949024741590D-08
       rk( 15)= 0.4189387783546088D-07+(azi- 0.78D+02) * rk( 15)
       rk( 15)=-0.1655545351001266D-06+(azi- 0.78D+02) * rk( 15)
       rk( 15)= 0.3256040000000000D-05+(azi- 0.78D+02) * rk( 15)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 15)= 0.1197370609476792D-07
       rk( 15)=-0.4652089875833727D-07+(azi- 0.86D+02) * rk( 15)
       rk( 15)=-0.2025707024830292D-06+(azi- 0.86D+02) * rk( 15)
       rk( 15)= 0.2726630000000000D-05+(azi- 0.86D+02) * rk( 15)
      elseif(azi.ge.90.D0)then
       rk( 15)= 0.1938330000000000D-05
      endif
      if(att.lt.0.99999) rk( 15) = rk( 15) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 16)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 16)=-0.2139600241835154D-11
       rk( 16)=-0.2151039975816482D-09+(azi- 0.00D+00) * rk( 16)
       rk( 16)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 16)
       rk( 16)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 16)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 16)= 0.1813800725505395D-11
       rk( 16)=-0.2792920048367028D-09+(azi- 0.10D+02) * rk( 16)
       rk( 16)=-0.4943960024183510D-08+(azi- 0.10D+02) * rk( 16)
       rk( 16)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 16)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 16)= 0.9033973398136872D-12
       rk( 16)=-0.2248779830715415D-09+(azi- 0.20D+02) * rk( 16)
       rk( 16)=-0.9985659903265952D-08+(azi- 0.20D+02) * rk( 16)
       rk( 16)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 16)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 16)= 0.2075609915239675D-11
       rk( 16)=-0.1977760628771301D-09+(azi- 0.30D+02) * rk( 16)
       rk( 16)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 16)
       rk( 16)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 16)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 16)= 0.3345162999227387D-11
       rk( 16)=-0.1355077654199368D-09+(azi- 0.40D+02) * rk( 16)
       rk( 16)=-0.1754503864572331D-07+(azi- 0.40D+02) * rk( 16)
       rk( 16)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 16)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 16)= 0.4733738087850787D-11
       rk( 16)=-0.3515287544311602D-10+(azi- 0.50D+02) * rk( 16)
       rk( 16)=-0.1925164505435384D-07+(azi- 0.50D+02) * rk( 16)
       rk( 16)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 16)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 16)= 0.8639884649373739D-11
       rk( 16)= 0.1068592671923679D-09+(azi- 0.60D+02) * rk( 16)
       rk( 16)=-0.1853458113686135D-07+(azi- 0.60D+02) * rk( 16)
       rk( 16)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 16)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 16)=-0.6489929990328960D-13
       rk( 16)= 0.3660558066739771D-09+(azi- 0.70D+02) * rk( 16)
       rk( 16)=-0.1380543039819970D-07+(azi- 0.70D+02) * rk( 16)
       rk( 16)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 16)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 16)=-0.7060744231510420D-11
       rk( 16)= 0.3644982234767217D-09+(azi- 0.78D+02) * rk( 16)
       rk( 16)=-0.7960998156995803D-08+(azi- 0.78D+02) * rk( 16)
       rk( 16)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 16)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 16)= 0.4009097038418610D-10
       rk( 16)= 0.1950403619196245D-09+(azi- 0.86D+02) * rk( 16)
       rk( 16)=-0.3484689473825034D-08+(azi- 0.86D+02) * rk( 16)
       rk( 16)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 16)
      elseif(azi.ge.90.D0)then
       rk( 16)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 16) = rk( 16) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 17)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 17)=-0.2139600241835154D-11
       rk( 17)=-0.2151039975816482D-09+(azi- 0.00D+00) * rk( 17)
       rk( 17)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 17)
       rk( 17)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 17)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 17)= 0.1813800725505395D-11
       rk( 17)=-0.2792920048367028D-09+(azi- 0.10D+02) * rk( 17)
       rk( 17)=-0.4943960024183510D-08+(azi- 0.10D+02) * rk( 17)
       rk( 17)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 17)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 17)= 0.9033973398136872D-12
       rk( 17)=-0.2248779830715415D-09+(azi- 0.20D+02) * rk( 17)
       rk( 17)=-0.9985659903265952D-08+(azi- 0.20D+02) * rk( 17)
       rk( 17)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 17)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 17)= 0.2075609915239675D-11
       rk( 17)=-0.1977760628771301D-09+(azi- 0.30D+02) * rk( 17)
       rk( 17)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 17)
       rk( 17)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 17)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 17)= 0.3345162999227387D-11
       rk( 17)=-0.1355077654199368D-09+(azi- 0.40D+02) * rk( 17)
       rk( 17)=-0.1754503864572331D-07+(azi- 0.40D+02) * rk( 17)
       rk( 17)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 17)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 17)= 0.4733738087850787D-11
       rk( 17)=-0.3515287544311602D-10+(azi- 0.50D+02) * rk( 17)
       rk( 17)=-0.1925164505435384D-07+(azi- 0.50D+02) * rk( 17)
       rk( 17)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 17)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 17)= 0.8639884649373739D-11
       rk( 17)= 0.1068592671923679D-09+(azi- 0.60D+02) * rk( 17)
       rk( 17)=-0.1853458113686135D-07+(azi- 0.60D+02) * rk( 17)
       rk( 17)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 17)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 17)=-0.6489929990328960D-13
       rk( 17)= 0.3660558066739771D-09+(azi- 0.70D+02) * rk( 17)
       rk( 17)=-0.1380543039819970D-07+(azi- 0.70D+02) * rk( 17)
       rk( 17)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 17)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 17)=-0.7060744231510420D-11
       rk( 17)= 0.3644982234767217D-09+(azi- 0.78D+02) * rk( 17)
       rk( 17)=-0.7960998156995803D-08+(azi- 0.78D+02) * rk( 17)
       rk( 17)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 17)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 17)= 0.4009097038418610D-10
       rk( 17)= 0.1950403619196245D-09+(azi- 0.86D+02) * rk( 17)
       rk( 17)=-0.3484689473825034D-08+(azi- 0.86D+02) * rk( 17)
       rk( 17)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 17)
      elseif(azi.ge.90.D0)then
       rk( 17)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 17) = rk( 17) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 18)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 18)=-0.2724056225766411D-11
       rk( 18)=-0.2068594377423350D-09+(azi- 0.00D+00) * rk( 18)
       rk( 18)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 18)
       rk( 18)= 0.1769770000000000D-05+(azi- 0.00D+00) * rk( 18)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 18)= 0.1042168677298912D-11
       rk( 18)=-0.2885811245153273D-09+(azi- 0.10D+02) * rk( 18)
       rk( 18)=-0.4954405622576623D-08+(azi- 0.10D+02) * rk( 18)
       rk( 18)= 0.1746360000000000D-05+(azi- 0.10D+02) * rk( 18)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 18)=-0.7346184834290850D-12
       rk( 18)=-0.2573160641963604D-09+(azi- 0.20D+02) * rk( 18)
       rk( 18)=-0.1041337750969350D-07+(azi- 0.20D+02) * rk( 18)
       rk( 18)= 0.1669000000000000D-05+(azi- 0.20D+02) * rk( 18)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 18)=-0.4136947435822000D-12
       rk( 18)=-0.2793546186992334D-09+(azi- 0.30D+02) * rk( 18)
       rk( 18)=-0.1578008433864942D-07+(azi- 0.30D+02) * rk( 18)
       rk( 18)= 0.1538400000000000D-05+(azi- 0.30D+02) * rk( 18)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 18)= 0.3593974577559286D-12
       rk( 18)=-0.2917654610066926D-09+(azi- 0.40D+02) * rk( 18)
       rk( 18)=-0.2149128513570870D-07+(azi- 0.40D+02) * rk( 18)
       rk( 18)= 0.1352250000000000D-05+(azi- 0.40D+02) * rk( 18)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 18)= 0.1158104912559730D-11
       rk( 18)=-0.2809835372740098D-09+(azi- 0.50D+02) * rk( 18)
       rk( 18)=-0.2721877511851595D-07+(azi- 0.50D+02) * rk( 18)
       rk( 18)= 0.1108520000000000D-05+(azi- 0.50D+02) * rk( 18)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 18)= 0.1481218289200588D-10
       rk( 18)=-0.2462403898971914D-09+(azi- 0.60D+02) * rk( 18)
       rk( 18)=-0.3249101439022863D-07+(azi- 0.60D+02) * rk( 18)
       rk( 18)= 0.8093920000000000D-06+(azi- 0.60D+02) * rk( 18)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 18)= 0.2251236790098139D-10
       rk( 18)= 0.1981250968631836D-09+(azi- 0.70D+02) * rk( 18)
       rk( 18)=-0.3297216732056966D-07+(azi- 0.70D+02) * rk( 18)
       rk( 18)= 0.4746700000000000D-06+(azi- 0.70D+02) * rk( 18)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 18)=-0.2282006684570455D-10
       rk( 18)= 0.7384219264865253D-09+(azi- 0.78D+02) * rk( 18)
       rk( 18)=-0.2547979113377114D-07+(azi- 0.78D+02) * rk( 18)
       rk( 18)= 0.2350990000000000D-06+(azi- 0.78D+02) * rk( 18)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 18)= 0.3441785534773510D-09
       rk( 18)= 0.1907403221845338D-09+(azi- 0.86D+02) * rk( 18)
       rk( 18)=-0.1804649314436201D-07+(azi- 0.86D+02) * rk( 18)
       rk( 18)= 0.6683580000000001D-07+(azi- 0.86D+02) * rk( 18)
      elseif(azi.ge.90.D0)then
       rk( 18)= 0.1972910000000000D-07
      endif
      if(att.lt.0.99999) rk( 18) = rk( 18) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 19)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 19)= 0.6904277703132783D-11
       rk( 19)=-0.3177427770313277D-09+(azi- 0.00D+00) * rk( 19)
       rk( 19)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 19)
       rk( 19)= 0.1612280000000000D-05+(azi- 0.00D+00) * rk( 19)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 19)=-0.3312833109398552D-11
       rk( 19)=-0.1106144459373441D-09+(azi- 0.10D+02) * rk( 19)
       rk( 19)=-0.4283572229686717D-08+(azi- 0.10D+02) * rk( 19)
       rk( 19)= 0.1587410000000000D-05+(azi- 0.10D+02) * rk( 19)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 19)=-0.4042945265538270D-11
       rk( 19)=-0.2099994392193006D-09+(azi- 0.20D+02) * rk( 19)
       rk( 19)=-0.7489711081253158D-08+(azi- 0.20D+02) * rk( 19)
       rk( 19)= 0.1530200000000000D-05+(azi- 0.20D+02) * rk( 19)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 19)= 0.7844614171551556D-11
       rk( 19)=-0.3312877971854490D-09+(azi- 0.30D+02) * rk( 19)
       rk( 19)=-0.1290258344530064D-07+(azi- 0.30D+02) * rk( 19)
       rk( 19)= 0.1430260000000000D-05+(azi- 0.30D+02) * rk( 19)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 19)=-0.4725511420668536D-11
       rk( 19)=-0.9594937203890317D-10+(azi- 0.40D+02) * rk( 19)
       rk( 19)=-0.1717495513754416D-07+(azi- 0.40D+02) * rk( 19)
       rk( 19)= 0.1275950000000000D-05+(azi- 0.40D+02) * rk( 19)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 19)= 0.1060843151112463D-10
       rk( 19)=-0.2377147146589427D-09+(azi- 0.50D+02) * rk( 19)
       rk( 19)=-0.2051159600452282D-07+(azi- 0.50D+02) * rk( 19)
       rk( 19)= 0.1089880000000000D-05+(azi- 0.50D+02) * rk( 19)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 19)=-0.3471521462382715D-10
       rk( 19)= 0.8053823067478953D-10+(azi- 0.60D+02) * rk( 19)
       rk( 19)=-0.2208336084436433D-07+(azi- 0.60D+02) * rk( 19)
       rk( 19)= 0.8716010000000000D-06+(azi- 0.60D+02) * rk( 19)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 19)= 0.1658243169115272D-09
       rk( 19)=-0.9609182080401574D-09+(azi- 0.70D+02) * rk( 19)
       rk( 19)=-0.3088716061801896D-07+(azi- 0.70D+02) * rk( 19)
       rk( 19)= 0.6241060000000000D-06+(azi- 0.70D+02) * rk( 19)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 19)=-0.2918978919224746D-09
       rk( 19)= 0.3018865397836071D-08+(azi- 0.78D+02) * rk( 19)
       rk( 19)=-0.1442358309965673D-07+(azi- 0.78D+02) * rk( 19)
       rk( 19)= 0.4004120000000000D-06+(azi- 0.78D+02) * rk( 19)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 19)= 0.1126241751036672D-08
       rk( 19)=-0.3986684008300777D-08+(azi- 0.86D+02) * rk( 19)
       rk( 19)=-0.2216613198336760D-07+(azi- 0.86D+02) * rk( 19)
       rk( 19)= 0.3287790000000000D-06+(azi- 0.86D+02) * rk( 19)
      elseif(azi.ge.90.D0)then
       rk( 19)= 0.2484070000000000D-06
      endif
      if(att.lt.0.99999) rk( 19) = rk( 19) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 20)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 20)= 0.6834268028295061D-10
       rk( 20)=-0.2952426802829534D-08+(azi- 0.00D+00) * rk( 20)
       rk( 20)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 20)
       rk( 20)= 0.2096400000000000D-04+(azi- 0.00D+00) * rk( 20)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 20)=-0.2912804084884234D-10
       rk( 20)=-0.9021463943410158D-09+(azi- 0.10D+02) * rk( 20)
       rk( 20)=-0.3854573197170551D-07+(azi- 0.10D+02) * rk( 20)
       rk( 20)= 0.2073710000000000D-04+(azi- 0.10D+02) * rk( 20)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 20)=-0.3643051688758642D-10
       rk( 20)=-0.1775987619806292D-08+(azi- 0.20D+02) * rk( 20)
       rk( 20)=-0.6532707211317854D-07+(azi- 0.20D+02) * rk( 20)
       rk( 20)= 0.2023230000000000D-04+(azi- 0.20D+02) * rk( 20)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 20)= 0.2095010839919488D-10
       rk( 20)=-0.2868903126433898D-08+(azi- 0.30D+02) * rk( 20)
       rk( 20)=-0.1117759795755802D-06+(azi- 0.30D+02) * rk( 20)
       rk( 20)= 0.1936500000000000D-04+(azi- 0.30D+02) * rk( 20)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 20)=-0.8946991670919155D-10
       rk( 20)=-0.2240399874458038D-08+(azi- 0.40D+02) * rk( 20)
       rk( 20)=-0.1628690095845000D-06+(azi- 0.40D+02) * rk( 20)
       rk( 20)= 0.1798130000000000D-04+(azi- 0.40D+02) * rk( 20)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 20)= 0.9302955843757136D-10
       rk( 20)=-0.4924497375733626D-08+(azi- 0.50D+02) * rk( 20)
       rk( 20)=-0.2345179820864196D-06+(azi- 0.50D+02) * rk( 20)
       rk( 20)= 0.1603910000000000D-04+(azi- 0.50D+02) * rk( 20)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 20)=-0.2505183170411419D-09
       rk( 20)=-0.2133610622606591D-08+(azi- 0.60D+02) * rk( 20)
       rk( 20)=-0.3050990620698210D-06+(azi- 0.60D+02) * rk( 20)
       rk( 20)= 0.1329450000000000D-04+(azi- 0.60D+02) * rk( 20)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 20)= 0.1930508604765915D-08
       rk( 20)=-0.9649160133840001D-08+(azi- 0.70D+02) * rk( 20)
       rk( 20)=-0.4229267696343191D-06+(azi- 0.70D+02) * rk( 20)
       rk( 20)= 0.9779630000000001D-05+(azi- 0.70D+02) * rk( 20)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 20)=-0.3807069396620624D-08
       rk( 20)= 0.3668304638054874D-07+(azi- 0.78D+02) * rk( 20)
       rk( 20)=-0.2066556796607305D-06+(azi- 0.78D+02) * rk( 20)
       rk( 20)= 0.6767090000000000D-05+(azi- 0.78D+02) * rk( 20)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 20)= 0.1642035864229821D-07
       rk( 20)=-0.5468661913837335D-07+(azi- 0.86D+02) * rk( 20)
       rk( 20)=-0.3506842617231106D-06+(azi- 0.86D+02) * rk( 20)
       rk( 20)= 0.5512340000000000D-05+(azi- 0.86D+02) * rk( 20)
      elseif(azi.ge.90.D0)then
       rk( 20)= 0.4285520000000000D-05
      endif
      if(att.lt.0.99999) rk( 20) = rk( 20) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 21)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 21)= 0.3444354995727030D-09
       rk( 21)=-0.1505435499572714D-07+(azi- 0.00D+00) * rk( 21)
       rk( 21)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 21)
       rk( 21)= 0.1053160000000000D-03+(azi- 0.00D+00) * rk( 21)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 21)=-0.1543064987180654D-09
       rk( 21)=-0.4721290008546052D-08+(azi- 0.10D+02) * rk( 21)
       rk( 21)=-0.1977564500427320D-06+(azi- 0.10D+02) * rk( 21)
       rk( 21)= 0.1041550000000000D-03+(azi- 0.10D+02) * rk( 21)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 21)=-0.1662095047004690D-09
       rk( 21)=-0.9350484970088024D-08+(azi- 0.20D+02) * rk( 21)
       rk( 21)=-0.3384741998290725D-06+(azi- 0.20D+02) * rk( 21)
       rk( 21)= 0.1015510000000000D-03+(azi- 0.20D+02) * rk( 21)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 21)= 0.1706445175199529D-09
       rk( 21)=-0.1433677011110213D-07+(azi- 0.30D+02) * rk( 21)
       rk( 21)=-0.5753467506409733D-06+(azi- 0.30D+02) * rk( 21)
       rk( 21)= 0.9706500000000001D-04+(azi- 0.30D+02) * rk( 21)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 21)=-0.2715685653793899D-09
       rk( 21)=-0.9217434585503460D-08+(azi- 0.40D+02) * rk( 21)
       rk( 21)=-0.8108887976070262D-06+(azi- 0.40D+02) * rk( 21)
       rk( 21)= 0.9004850000000000D-04+(azi- 0.40D+02) * rk( 21)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 21)=-0.2097702560023537D-09
       rk( 21)=-0.1736449154688521D-07+(azi- 0.50D+02) * rk( 21)
       rk( 21)=-0.1076708058930913D-05+(azi- 0.50D+02) * rk( 21)
       rk( 21)= 0.8074630000000000D-04+(azi- 0.50D+02) * rk( 21)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 21)=-0.2409504106111980D-09
       rk( 21)=-0.2365759922696027D-07+(azi- 0.60D+02) * rk( 21)
       rk( 21)=-0.1486928966669315D-05+(azi- 0.60D+02) * rk( 21)
       rk( 21)= 0.6803300000000000D-04+(azi- 0.60D+02) * rk( 21)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 21)= 0.7687577605530391D-08
       rk( 21)=-0.3088611154527588D-07+(azi- 0.70D+02) * rk( 21)
       rk( 21)=-0.2032366074391785D-05+(azi- 0.70D+02) * rk( 21)
       rk( 21)= 0.5055700000000000D-04+(azi- 0.70D+02) * rk( 21)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 21)=-0.1667007107883139D-07
       rk( 21)= 0.1536157509874942D-06+(azi- 0.78D+02) * rk( 21)
       rk( 21)=-0.1050528958854635D-05+(azi- 0.78D+02) * rk( 21)
       rk( 21)= 0.3625740000000000D-04+(azi- 0.78D+02) * rk( 21)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 21)= 0.7843871311307392D-07
       rk( 21)=-0.2464659549046219D-06+(azi- 0.86D+02) * rk( 21)
       rk( 21)=-0.1793330590190573D-05+(azi- 0.86D+02) * rk( 21)
       rk( 21)= 0.2914950000000000D-04+(azi- 0.86D+02) * rk( 21)
      elseif(azi.ge.90.D0)then
       rk( 21)= 0.2305280000000000D-04
      endif
      if(att.lt.0.99999) rk( 21) = rk( 21) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 22)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 22)= 0.5876548371323300D-10
       rk( 22)=-0.2772654837132327D-08+(azi- 0.00D+00) * rk( 22)
       rk( 22)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 22)
       rk( 22)= 0.1165620000000000D-04+(azi- 0.00D+00) * rk( 22)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 22)=-0.2939645113970085D-10
       rk( 22)=-0.1009690325735335D-08+(azi- 0.10D+02) * rk( 22)
       rk( 22)=-0.3782345162867663D-07+(azi- 0.10D+02) * rk( 22)
       rk( 22)= 0.1143770000000000D-04+(azi- 0.10D+02) * rk( 22)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 22)=-0.3397967915442759D-10
       rk( 22)=-0.1891583859926368D-08+(azi- 0.20D+02) * rk( 22)
       rk( 22)=-0.6683619348529359D-07+(azi- 0.20D+02) * rk( 22)
       rk( 22)= 0.1092910000000000D-04+(azi- 0.20D+02) * rk( 22)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 22)= 0.9175516775741275D-10
       rk( 22)=-0.2910974234559203D-08+(azi- 0.30D+02) * rk( 22)
       rk( 22)=-0.1148617744301492D-06+(azi- 0.30D+02) * rk( 22)
       rk( 22)= 0.1003760000000000D-04+(azi- 0.30D+02) * rk( 22)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 22)=-0.2486099187523408D-10
       rk( 22)=-0.1583192018367939D-09+(azi- 0.40D+02) * rk( 22)
       rk( 22)=-0.1455547087941088D-06+(azi- 0.40D+02) * rk( 22)
       rk( 22)= 0.8689640000000000D-05+(azi- 0.40D+02) * rk( 22)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 22)= 0.7536879974356486D-10
       rk( 22)=-0.9041489580938693D-09+(azi- 0.50D+02) * rk( 22)
       rk( 22)=-0.1561793903934174D-06+(azi- 0.50D+02) * rk( 22)
       rk( 22)= 0.7193400000000000D-05+(azi- 0.50D+02) * rk( 22)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 22)=-0.2934542070991260D-09
       rk( 22)= 0.1356915034212706D-08+(azi- 0.60D+02) * rk( 22)
       rk( 22)=-0.1516517296322257D-06+(azi- 0.60D+02) * rk( 22)
       rk( 22)= 0.5616560000000000D-05+(azi- 0.60D+02) * rk( 22)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 22)= 0.1223451257933528D-08
       rk( 22)=-0.7446711178759379D-08+(azi- 0.70D+02) * rk( 22)
       rk( 22)=-0.2125496910776806D-06+(azi- 0.70D+02) * rk( 22)
       rk( 22)= 0.3942280000000000D-05+(azi- 0.70D+02) * rk( 22)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 22)=-0.2041476932480193D-08
       rk( 22)= 0.2191611901165716D-07+(azi- 0.78D+02) * rk( 22)
       rk( 22)=-0.9679442841459317D-07+(azi- 0.78D+02) * rk( 22)
       rk( 22)= 0.2391700000000000D-05+(azi- 0.78D+02) * rk( 22)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 22)= 0.7390306545982522D-08
       rk( 22)=-0.2707932736788102D-07+(azi- 0.86D+02) * rk( 22)
       rk( 22)=-0.1381000952641129D-06+(azi- 0.86D+02) * rk( 22)
       rk( 22)= 0.1974740000000000D-05+(azi- 0.86D+02) * rk( 22)
      elseif(azi.ge.90.D0)then
       rk( 22)= 0.1462050000000000D-05
      endif
      if(att.lt.0.99999) rk( 22) = rk( 22) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 23)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 23)= 0.2223326554111431D-09
       rk( 23)=-0.1029132655411144D-07+(azi- 0.00D+00) * rk( 23)
       rk( 23)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 23)
       rk( 23)= 0.5054560000000000D-04+(azi- 0.00D+00) * rk( 23)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 23)=-0.1089979662334262D-09
       rk( 23)=-0.3621346891777139D-08+(azi- 0.10D+02) * rk( 23)
       rk( 23)=-0.1391267344588857D-06+(azi- 0.10D+02) * rk( 23)
       rk( 23)= 0.4973880000000000D-04+(azi- 0.10D+02) * rk( 23)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 23)=-0.1318407904774435D-09
       rk( 23)=-0.6891285878779934D-08+(azi- 0.20D+02) * rk( 23)
       rk( 23)=-0.2442530621644563D-06+(azi- 0.20D+02) * rk( 23)
       rk( 23)= 0.4787640000000000D-04+(azi- 0.20D+02) * rk( 23)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 23)= 0.2765611281432062D-09
       rk( 23)=-0.1084650959310323D-07+(azi- 0.30D+02) * rk( 23)
       rk( 23)=-0.4216310168832874D-06+(azi- 0.30D+02) * rk( 23)
       rk( 23)= 0.4461290000000000D-04+(azi- 0.30D+02) * rk( 23)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 23)=-0.1301037220953939D-09
       rk( 23)=-0.2549675748807266D-08+(azi- 0.40D+02) * rk( 23)
       rk( 23)=-0.5555928703023908D-06+(azi- 0.40D+02) * rk( 23)
       rk( 23)= 0.3958850000000000D-04+(azi- 0.40D+02) * rk( 23)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 23)= 0.2996537602383625D-09
       rk( 23)=-0.6452787411668395D-08+(azi- 0.50D+02) * rk( 23)
       rk( 23)=-0.6456175019071529D-06+(azi- 0.50D+02) * rk( 23)
       rk( 23)= 0.3364750000000000D-04+(azi- 0.50D+02) * rk( 23)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 23)=-0.1073911318858136D-08
       rk( 23)= 0.2536825395480999D-08+(azi- 0.60D+02) * rk( 23)
       rk( 23)=-0.6847771220690023D-06+(azi- 0.60D+02) * rk( 23)
       rk( 23)= 0.2684570000000000D-04+(azi- 0.60D+02) * rk( 23)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 23)= 0.5127470674666905D-08
       rk( 23)=-0.2968051417026564D-07+(azi- 0.70D+02) * rk( 23)
       rk( 23)=-0.9562140098167944D-06+(azi- 0.70D+02) * rk( 23)
       rk( 23)= 0.1917770000000000D-04+(azi- 0.70D+02) * rk( 23)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 23)=-0.8990271705772634D-08
       rk( 23)= 0.9337878202178075D-07+(azi- 0.78D+02) * rk( 23)
       rk( 23)=-0.4466278670047820D-06+(azi- 0.78D+02) * rk( 23)
       rk( 23)= 0.1225370000000000D-04+(azi- 0.78D+02) * rk( 23)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 23)= 0.3453752986452537D-07
       rk( 23)=-0.1223877389167896D-06+(azi- 0.86D+02) * rk( 23)
       rk( 23)=-0.6786995221637684D-06+(azi- 0.86D+02) * rk( 23)
       rk( 23)= 0.1005390000000000D-04+(azi- 0.86D+02) * rk( 23)
      elseif(azi.ge.90.D0)then
       rk( 23)= 0.7591300000000000D-05
      endif
      if(att.lt.0.99999) rk( 23) = rk( 23) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 24)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 24)=-0.1826021023809213D-09
       rk( 24)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk( 24)
       rk( 24)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 24)
       rk( 24)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 24)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 24)= 0.7680630714277358D-10
       rk( 24)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk( 24)
       rk( 24)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 24)
       rk( 24)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 24)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 24)=-0.4662312619017368D-10
       rk( 24)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk( 24)
       rk( 24)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk( 24)
       rk( 24)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 24)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 24)=-0.3391380238206294D-10
       rk( 24)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk( 24)
       rk( 24)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk( 24)
       rk( 24)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 24)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 24)=-0.3482166428159112D-10
       rk( 24)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk( 24)
       rk( 24)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk( 24)
       rk( 24)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 24)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 24)=-0.9419954049165213D-10
       rk( 24)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk( 24)
       rk( 24)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk( 24)
       rk( 24)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 24)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 24)= 0.4307198262473663D-09
       rk( 24)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk( 24)
       rk( 24)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk( 24)
       rk( 24)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 24)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 24)= 0.1932828429018806D-08
       rk( 24)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk( 24)
       rk( 24)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk( 24)
       rk( 24)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 24)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 24)= 0.7078805396671869D-10
       rk( 24)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk( 24)
       rk( 24)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk( 24)
       rk( 24)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 24)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 24)= 0.2551390080685143D-07
       rk( 24)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk( 24)
       rk( 24)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk( 24)
       rk( 24)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 24)
      elseif(azi.ge.90.D0)then
       rk( 24)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 24) = rk( 24) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 25)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 25)=-0.1826021023809213D-09
       rk( 25)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk( 25)
       rk( 25)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 25)
       rk( 25)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 25)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 25)= 0.7680630714277358D-10
       rk( 25)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk( 25)
       rk( 25)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 25)
       rk( 25)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 25)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 25)=-0.4662312619017368D-10
       rk( 25)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk( 25)
       rk( 25)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk( 25)
       rk( 25)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 25)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 25)=-0.3391380238206294D-10
       rk( 25)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk( 25)
       rk( 25)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk( 25)
       rk( 25)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 25)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 25)=-0.3482166428159112D-10
       rk( 25)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk( 25)
       rk( 25)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk( 25)
       rk( 25)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 25)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 25)=-0.9419954049165213D-10
       rk( 25)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk( 25)
       rk( 25)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk( 25)
       rk( 25)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 25)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 25)= 0.4307198262473663D-09
       rk( 25)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk( 25)
       rk( 25)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk( 25)
       rk( 25)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 25)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 25)= 0.1932828429018806D-08
       rk( 25)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk( 25)
       rk( 25)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk( 25)
       rk( 25)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 25)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 25)= 0.7078805396671869D-10
       rk( 25)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk( 25)
       rk( 25)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk( 25)
       rk( 25)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 25)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 25)= 0.2551390080685143D-07
       rk( 25)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk( 25)
       rk( 25)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk( 25)
       rk( 25)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 25)
      elseif(azi.ge.90.D0)then
       rk( 25)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 25) = rk( 25) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 26)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 26)=-0.1826021023809213D-09
       rk( 26)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk( 26)
       rk( 26)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 26)
       rk( 26)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 26)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 26)= 0.7680630714277358D-10
       rk( 26)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk( 26)
       rk( 26)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 26)
       rk( 26)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 26)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 26)=-0.4662312619017368D-10
       rk( 26)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk( 26)
       rk( 26)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk( 26)
       rk( 26)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 26)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 26)=-0.3391380238206294D-10
       rk( 26)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk( 26)
       rk( 26)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk( 26)
       rk( 26)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 26)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 26)=-0.3482166428159112D-10
       rk( 26)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk( 26)
       rk( 26)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk( 26)
       rk( 26)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 26)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 26)=-0.9419954049165213D-10
       rk( 26)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk( 26)
       rk( 26)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk( 26)
       rk( 26)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 26)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 26)= 0.4307198262473663D-09
       rk( 26)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk( 26)
       rk( 26)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk( 26)
       rk( 26)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 26)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 26)= 0.1932828429018806D-08
       rk( 26)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk( 26)
       rk( 26)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk( 26)
       rk( 26)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 26)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 26)= 0.7078805396671869D-10
       rk( 26)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk( 26)
       rk( 26)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk( 26)
       rk( 26)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 26)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 26)= 0.2551390080685143D-07
       rk( 26)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk( 26)
       rk( 26)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk( 26)
       rk( 26)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 26)
      elseif(azi.ge.90.D0)then
       rk( 26)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 26) = rk( 26) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 27)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 27)=-0.1826021023809213D-09
       rk( 27)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk( 27)
       rk( 27)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 27)
       rk( 27)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 27)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 27)= 0.7680630714277358D-10
       rk( 27)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk( 27)
       rk( 27)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 27)
       rk( 27)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 27)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 27)=-0.4662312619017368D-10
       rk( 27)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk( 27)
       rk( 27)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk( 27)
       rk( 27)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 27)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 27)=-0.3391380238206294D-10
       rk( 27)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk( 27)
       rk( 27)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk( 27)
       rk( 27)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 27)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 27)=-0.3482166428159112D-10
       rk( 27)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk( 27)
       rk( 27)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk( 27)
       rk( 27)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 27)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 27)=-0.9419954049165213D-10
       rk( 27)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk( 27)
       rk( 27)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk( 27)
       rk( 27)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 27)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 27)= 0.4307198262473663D-09
       rk( 27)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk( 27)
       rk( 27)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk( 27)
       rk( 27)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 27)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 27)= 0.1932828429018806D-08
       rk( 27)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk( 27)
       rk( 27)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk( 27)
       rk( 27)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 27)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 27)= 0.7078805396671869D-10
       rk( 27)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk( 27)
       rk( 27)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk( 27)
       rk( 27)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 27)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 27)= 0.2551390080685143D-07
       rk( 27)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk( 27)
       rk( 27)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk( 27)
       rk( 27)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 27)
      elseif(azi.ge.90.D0)then
       rk( 27)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 27) = rk( 27) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 28)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 28)= 0.2049234813070730D-09
       rk( 28)=-0.8887234813070748D-08+(azi- 0.00D+00) * rk( 28)
       rk( 28)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 28)
       rk( 28)= 0.6099510000000000D-04+(azi- 0.00D+00) * rk( 28)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 28)=-0.8627044392121314D-10
       rk( 28)=-0.2739530373858554D-08+(azi- 0.10D+02) * rk( 28)
       rk( 28)=-0.1162676518692930D-06+(azi- 0.10D+02) * rk( 28)
       rk( 28)= 0.6031130000000000D-04+(azi- 0.10D+02) * rk( 28)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 28)=-0.1084417056222228D-09
       rk( 28)=-0.5327643691494949D-08+(azi- 0.20D+02) * rk( 28)
       rk( 28)=-0.1969393925228280D-06+(azi- 0.20D+02) * rk( 28)
       rk( 28)= 0.5878840000000000D-04+(azi- 0.20D+02) * rk( 28)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 28)= 0.7463726641010532D-10
       rk( 28)=-0.8580894860161642D-08+(azi- 0.30D+02) * rk( 28)
       rk( 28)=-0.3360247780393935D-06+(azi- 0.30D+02) * rk( 28)
       rk( 28)= 0.5617780000000000D-04+(azi- 0.30D+02) * rk( 28)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 28)=-0.2596073600181797D-09
       rk( 28)=-0.6341776867858602D-08+(azi- 0.40D+02) * rk( 28)
       rk( 28)=-0.4852514953195950D-06+(azi- 0.40D+02) * rk( 28)
       rk( 28)= 0.5203410000000000D-04+(azi- 0.40D+02) * rk( 28)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 28)= 0.2934921736625323D-09
       rk( 28)=-0.1412999766840373D-07+(azi- 0.50D+02) * rk( 28)
       rk( 28)=-0.6899692406822168D-06+(azi- 0.50D+02) * rk( 28)
       rk( 28)= 0.4628780000000000D-04+(azi- 0.50D+02) * rk( 28)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 28)=-0.7880613346320685D-09
       rk( 28)=-0.5325232458527546D-08+(azi- 0.60D+02) * rk( 28)
       rk( 28)=-0.8845215419515262D-06+(azi- 0.60D+02) * rk( 28)
       rk( 28)= 0.3826860000000000D-04+(azi- 0.60D+02) * rk( 28)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 28)= 0.5694627679553248D-08
       rk( 28)=-0.2896707249748113D-07+(azi- 0.70D+02) * rk( 28)
       rk( 28)=-0.1227444591511630D-05+(azi- 0.70D+02) * rk( 28)
       rk( 28)= 0.2810280000000000D-04+(azi- 0.70D+02) * rk( 28)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 28)=-0.1111144839839243D-07
       rk( 28)= 0.1077039918118171D-06+(azi- 0.78D+02) * rk( 28)
       rk( 28)=-0.5975492369971044D-06+(azi- 0.78D+02) * rk( 28)
       rk( 28)= 0.1934500000000000D-04+(azi- 0.78D+02) * rk( 28)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 28)= 0.4748853371866826D-07
       rk( 28)=-0.1589707697496282D-06+(azi- 0.86D+02) * rk( 28)
       rk( 28)=-0.1007683460499485D-05+(azi- 0.86D+02) * rk( 28)
       rk( 28)= 0.1576860000000000D-04+(azi- 0.86D+02) * rk( 28)
      elseif(azi.ge.90.D0)then
       rk( 28)= 0.1223360000000000D-04
      endif
      if(att.lt.0.99999) rk( 28) = rk( 28) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 29)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 29)=-0.9639086891432908D-11
       rk( 29)=-0.8144091310856724D-09+(azi- 0.00D+00) * rk( 29)
       rk( 29)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 29)
       rk( 29)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 29)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 29)= 0.5287260674299008D-11
       rk( 29)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 29)
       rk( 29)=-0.1917990868914332D-07+(azi- 0.10D+02) * rk( 29)
       rk( 29)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 29)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 29)=-0.2699558057629897D-12
       rk( 29)=-0.9449639175996891D-09+(azi- 0.20D+02) * rk( 29)
       rk( 29)=-0.3966536524342679D-07+(azi- 0.20D+02) * rk( 29)
       rk( 29)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 29)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 29)= 0.2382562548753546D-11
       rk( 29)=-0.9530625917725825D-09+(azi- 0.30D+02) * rk( 29)
       rk( 29)=-0.5864563033714949D-07+(azi- 0.30D+02) * rk( 29)
       rk( 29)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 29)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 29)= 0.6319705610747424D-11
       rk( 29)=-0.8815857153099513D-09+(azi- 0.40D+02) * rk( 29)
       rk( 29)=-0.7699211340797505D-07+(azi- 0.40D+02) * rk( 29)
       rk( 29)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 29)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 29)= 0.1056861500825653D-10
       rk( 29)=-0.6919945469875881D-09+(azi- 0.50D+02) * rk( 29)
       rk( 29)=-0.9272791603094997D-07+(azi- 0.50D+02) * rk( 29)
       rk( 29)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 29)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 29)= 0.4850583435620618D-10
       rk( 29)=-0.3749360967397995D-09+(azi- 0.60D+02) * rk( 29)
       rk( 29)=-0.1033972224682254D-06+(azi- 0.60D+02) * rk( 29)
       rk( 29)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 29)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 29)= 0.4863918163365898D-10
       rk( 29)= 0.1080238933948239D-08+(azi- 0.70D+02) * rk( 29)
       rk( 29)=-0.9634419409614782D-07+(azi- 0.70D+02) * rk( 29)
       rk( 29)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 29)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 29)=-0.6023611040521017D-10
       rk( 29)= 0.2247579293157748D-08+(azi- 0.78D+02) * rk( 29)
       rk( 29)=-0.6972164827933041D-07+(azi- 0.78D+02) * rk( 29)
       rk( 29)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 29)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 29)= 0.8106335758155240D-09
       rk( 29)= 0.8019126434123756D-09+(azi- 0.86D+02) * rk( 29)
       rk( 29)=-0.4532571278666100D-07+(azi- 0.86D+02) * rk( 29)
       rk( 29)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 29)
      elseif(azi.ge.90.D0)then
       rk( 29)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 29) = rk( 29) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 30)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 30)=-0.9639086891432908D-11
       rk( 30)=-0.8144091310856724D-09+(azi- 0.00D+00) * rk( 30)
       rk( 30)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 30)
       rk( 30)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 30)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 30)= 0.5287260674299008D-11
       rk( 30)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 30)
       rk( 30)=-0.1917990868914332D-07+(azi- 0.10D+02) * rk( 30)
       rk( 30)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 30)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 30)=-0.2699558057629897D-12
       rk( 30)=-0.9449639175996891D-09+(azi- 0.20D+02) * rk( 30)
       rk( 30)=-0.3966536524342679D-07+(azi- 0.20D+02) * rk( 30)
       rk( 30)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 30)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 30)= 0.2382562548753546D-11
       rk( 30)=-0.9530625917725825D-09+(azi- 0.30D+02) * rk( 30)
       rk( 30)=-0.5864563033714949D-07+(azi- 0.30D+02) * rk( 30)
       rk( 30)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 30)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 30)= 0.6319705610747424D-11
       rk( 30)=-0.8815857153099513D-09+(azi- 0.40D+02) * rk( 30)
       rk( 30)=-0.7699211340797505D-07+(azi- 0.40D+02) * rk( 30)
       rk( 30)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 30)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 30)= 0.1056861500825653D-10
       rk( 30)=-0.6919945469875881D-09+(azi- 0.50D+02) * rk( 30)
       rk( 30)=-0.9272791603094997D-07+(azi- 0.50D+02) * rk( 30)
       rk( 30)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 30)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 30)= 0.4850583435620618D-10
       rk( 30)=-0.3749360967397995D-09+(azi- 0.60D+02) * rk( 30)
       rk( 30)=-0.1033972224682254D-06+(azi- 0.60D+02) * rk( 30)
       rk( 30)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 30)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 30)= 0.4863918163365898D-10
       rk( 30)= 0.1080238933948239D-08+(azi- 0.70D+02) * rk( 30)
       rk( 30)=-0.9634419409614782D-07+(azi- 0.70D+02) * rk( 30)
       rk( 30)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 30)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 30)=-0.6023611040521017D-10
       rk( 30)= 0.2247579293157748D-08+(azi- 0.78D+02) * rk( 30)
       rk( 30)=-0.6972164827933041D-07+(azi- 0.78D+02) * rk( 30)
       rk( 30)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 30)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 30)= 0.8106335758155240D-09
       rk( 30)= 0.8019126434123756D-09+(azi- 0.86D+02) * rk( 30)
       rk( 30)=-0.4532571278666100D-07+(azi- 0.86D+02) * rk( 30)
       rk( 30)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 30)
      elseif(azi.ge.90.D0)then
       rk( 30)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 30) = rk( 30) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 31)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 31)=-0.3832057510941250D-11
       rk( 31)=-0.3311794248905845D-09+(azi- 0.00D+00) * rk( 31)
       rk( 31)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 31)
       rk( 31)= 0.2224430000000000D-05+(azi- 0.00D+00) * rk( 31)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 31)= 0.2216172532822996D-11
       rk( 31)=-0.4461411502188222D-09+(azi- 0.10D+02) * rk( 31)
       rk( 31)=-0.7773205751094067D-08+(azi- 0.10D+02) * rk( 31)
       rk( 31)= 0.2187480000000000D-05+(azi- 0.10D+02) * rk( 31)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 31)= 0.5736737964910470D-13
       rk( 31)=-0.3796559742341328D-09+(azi- 0.20D+02) * rk( 31)
       rk( 31)=-0.1603117699562361D-07+(azi- 0.20D+02) * rk( 31)
       rk( 31)= 0.2067350000000000D-05+(azi- 0.20D+02) * rk( 31)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 31)= 0.1254357948581281D-11
       rk( 31)=-0.3779349528446593D-09+(azi- 0.30D+02) * rk( 31)
       rk( 31)=-0.2360708626641151D-07+(azi- 0.30D+02) * rk( 31)
       rk( 31)= 0.1869130000000000D-05+(azi- 0.30D+02) * rk( 31)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 31)= 0.2935200826025157D-11
       rk( 31)=-0.3403042143872213D-09+(azi- 0.40D+02) * rk( 31)
       rk( 31)=-0.3078947793873033D-07+(azi- 0.40D+02) * rk( 31)
       rk( 31)= 0.1596520000000000D-05+(azi- 0.40D+02) * rk( 31)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 31)= 0.4861838747321660D-11
       rk( 31)=-0.2522481896064666D-09+(azi- 0.50D+02) * rk( 31)
       rk( 31)=-0.3671500197866716D-07+(azi- 0.50D+02) * rk( 31)
       rk( 31)= 0.1257530000000000D-05+(azi- 0.50D+02) * rk( 31)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 31)= 0.1939344418469089D-10
       rk( 31)=-0.1063930271868565D-09+(azi- 0.60D+02) * rk( 31)
       rk( 31)=-0.4030141414660034D-07+(azi- 0.60D+02) * rk( 31)
       rk( 31)= 0.8700170000000000D-06+(azi- 0.60D+02) * rk( 31)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 31)= 0.1609506325143636D-10
       rk( 31)= 0.4754102983540026D-09+(azi- 0.70D+02) * rk( 31)
       rk( 31)=-0.3661124143492962D-07+(azi- 0.70D+02) * rk( 31)
       rk( 31)= 0.4757570000000000D-06+(azi- 0.70D+02) * rk( 31)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 31)=-0.2188667990824655D-10
       rk( 31)= 0.8616918163893223D-09+(azi- 0.78D+02) * rk( 31)
       rk( 31)=-0.2591442451698979D-07+(azi- 0.78D+02) * rk( 31)
       rk( 31)= 0.2215340000000000D-06+(azi- 0.78D+02) * rk( 31)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 31)= 0.2841313751779476D-09
       rk( 31)= 0.3364114985863228D-09+(azi- 0.86D+02) * rk( 31)
       rk( 31)=-0.1632959799716430D-07+(azi- 0.86D+02) * rk( 31)
       rk( 31)= 0.5816090000000000D-07+(azi- 0.86D+02) * rk( 31)
      elseif(azi.ge.90.D0)then
       rk( 31)= 0.1640950000000000D-07
      endif
      if(att.lt.0.99999) rk( 31) = rk( 31) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 32)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 32)=-0.6650705923705479D-11
       rk( 32)=-0.6611929407629450D-09+(azi- 0.00D+00) * rk( 32)
       rk( 32)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 32)
       rk( 32)= 0.3379090000000000D-05+(azi- 0.00D+00) * rk( 32)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 32)= 0.5602117771116236D-11
       rk( 32)=-0.8607141184741090D-09+(azi- 0.10D+02) * rk( 32)
       rk( 32)=-0.1521907059237054D-07+(azi- 0.10D+02) * rk( 32)
       rk( 32)= 0.3306320000000000D-05+(azi- 0.10D+02) * rk( 32)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 32)= 0.2622234839240618D-11
       rk( 32)=-0.6926505853406227D-09+(azi- 0.20D+02) * rk( 32)
       rk( 32)=-0.3075271763051784D-07+(azi- 0.20D+02) * rk( 32)
       rk( 32)= 0.3073660000000000D-05+(azi- 0.20D+02) * rk( 32)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 32)= 0.6018942871922055D-11
       rk( 32)=-0.6139835401634017D-09+(azi- 0.30D+02) * rk( 32)
       rk( 32)=-0.4381905888555809D-07+(azi- 0.30D+02) * rk( 32)
       rk( 32)= 0.2699490000000000D-05+(azi- 0.30D+02) * rk( 32)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 32)= 0.9631993673072422D-11
       rk( 32)=-0.4334152540057500D-09+(azi- 0.40D+02) * rk( 32)
       rk( 32)=-0.5429304682724973D-07+(azi- 0.40D+02) * rk( 32)
       rk( 32)= 0.2205920000000000D-05+(azi- 0.40D+02) * rk( 32)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 32)= 0.1346308243578111D-10
       rk( 32)=-0.1444554438135145D-09+(azi- 0.50D+02) * rk( 32)
       rk( 32)=-0.6007175380544298D-07+(azi- 0.50D+02) * rk( 32)
       rk( 32)= 0.1629280000000000D-05+(azi- 0.50D+02) * rk( 32)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 32)= 0.2754267658383055D-10
       rk( 32)= 0.2594370292596410D-09+(azi- 0.60D+02) * rk( 32)
       rk( 32)=-0.5892193795098066D-07+(azi- 0.60D+02) * rk( 32)
       rk( 32)= 0.1027580000000000D-05+(azi- 0.60D+02) * rk( 32)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 32)= 0.3078605881868256D-11
       rk( 32)= 0.1085717326774769D-08+(azi- 0.70D+02) * rk( 32)
       rk( 32)=-0.4547039439064206D-07+(azi- 0.70D+02) * rk( 32)
       rk( 32)= 0.4918470000000000D-06+(azi- 0.70D+02) * rk( 32)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 32)=-0.2153154079143221D-10
       rk( 32)= 0.1159603867942148D-08+(azi- 0.78D+02) * rk( 32)
       rk( 32)=-0.2750782483291689D-07+(azi- 0.78D+02) * rk( 32)
       rk( 32)= 0.1991460000000000D-06+(azi- 0.78D+02) * rk( 32)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 32)= 0.1655300763808969D-09
       rk( 32)= 0.6428468889409992D-09+(azi- 0.86D+02) * rk( 32)
       rk( 32)=-0.1308821877786526D-07+(azi- 0.86D+02) * rk( 32)
       rk( 32)= 0.4227390000000000D-07+(azi- 0.86D+02) * rk( 32)
      elseif(azi.ge.90.D0)then
       rk( 32)= 0.1080050000000000D-07
      endif
      if(att.lt.0.99999) rk( 32) = rk( 32) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 33)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 33)= 0.1513057696995555D-11
       rk( 33)=-0.1964405769699554D-09+(azi- 0.00D+00) * rk( 33)
       rk( 33)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 33)
       rk( 33)= 0.9319540000000000D-06+(azi- 0.00D+00) * rk( 33)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 33)=-0.4871730909867456D-12
       rk( 33)=-0.1510488460600888D-09+(azi- 0.10D+02) * rk( 33)
       rk( 33)=-0.3474894230300443D-08+(azi- 0.10D+02) * rk( 33)
       rk( 33)= 0.9138230000000000D-06+(azi- 0.10D+02) * rk( 33)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 33)=-0.3889365333048493D-11
       rk( 33)=-0.1656640387896911D-09+(azi- 0.20D+02) * rk( 33)
       rk( 33)=-0.6642023078798242D-08+(azi- 0.20D+02) * rk( 33)
       rk( 33)= 0.8634820000000000D-06+(azi- 0.20D+02) * rk( 33)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 33)= 0.1196563442318080D-10
       rk( 33)=-0.2823449987811465D-09+(azi- 0.30D+02) * rk( 33)
       rk( 33)=-0.1112211345450660D-07+(azi- 0.30D+02) * rk( 33)
       rk( 33)= 0.7766060000000000D-06+(azi- 0.30D+02) * rk( 33)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 33)=-0.2954172359674601D-11
       rk( 33)= 0.7662403391427662D-10+(azi- 0.40D+02) * rk( 33)
       rk( 33)=-0.1317932310317529D-07+(azi- 0.40D+02) * rk( 33)
       rk( 33)= 0.6491160000000000D-06+(azi- 0.40D+02) * rk( 33)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 33)= 0.4826055015516023D-11
       rk( 33)=-0.1200113687596224D-10+(azi- 0.50D+02) * rk( 33)
       rk( 33)=-0.1253309413279213D-07+(azi- 0.50D+02) * rk( 33)
       rk( 33)= 0.5220310000000001D-06+(azi- 0.50D+02) * rk( 33)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 33)=-0.2356004770237379D-10
       rk( 33)= 0.1327805135894423D-09+(azi- 0.60D+02) * rk( 33)
       rk( 33)=-0.1132530036565680D-07+(azi- 0.60D+02) * rk( 33)
       rk( 33)= 0.4003260000000000D-06+(azi- 0.60D+02) * rk( 33)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 33)= 0.9305073038176241D-10
       rk( 33)=-0.5740209174817715D-09+(azi- 0.70D+02) * rk( 33)
       rk( 33)=-0.1573770440458030D-07+(azi- 0.70D+02) * rk( 33)
       rk( 33)= 0.2767910000000000D-06+(azi- 0.70D+02) * rk( 33)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 33)=-0.1505980319134056D-09
       rk( 33)= 0.1659196611680738D-08+(azi- 0.78D+02) * rk( 33)
       rk( 33)=-0.7056298850989414D-08+(azi- 0.78D+02) * rk( 33)
       rk( 33)= 0.1617940000000000D-06+(azi- 0.78D+02) * rk( 33)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 33)= 0.5221921755275321D-09
       rk( 33)=-0.1955156154241844D-08+(azi- 0.86D+02) * rk( 33)
       rk( 33)=-0.9423975191454547D-08+(azi- 0.86D+02) * rk( 33)
       rk( 33)= 0.1344260000000000D-06+(azi- 0.86D+02) * rk( 33)
      elseif(azi.ge.90.D0)then
       rk( 33)= 0.9886790000000000D-07
      endif
      if(att.lt.0.99999) rk( 33) = rk( 33) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 34)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 34)= 0.2539178460041524D-11
       rk( 34)=-0.1518017846004148D-09+(azi- 0.00D+00) * rk( 34)
       rk( 34)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 34)
       rk( 34)= 0.6011940000000000D-06+(azi- 0.00D+00) * rk( 34)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 34)=-0.1150535380124798D-11
       rk( 34)=-0.7562643079916907D-10+(azi- 0.10D+02) * rk( 34)
       rk( 34)=-0.2274282153995839D-08+(azi- 0.10D+02) * rk( 34)
       rk( 34)= 0.5885530000000000D-06+(azi- 0.10D+02) * rk( 34)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 34)=-0.1996036939542015D-11
       rk( 34)=-0.1101424922029130D-09+(azi- 0.20D+02) * rk( 34)
       rk( 34)=-0.4131971384016661D-08+(azi- 0.20D+02) * rk( 34)
       rk( 34)= 0.5570969999999999D-06+(azi- 0.20D+02) * rk( 34)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 34)= 0.6889683138292623D-11
       rk( 34)=-0.1700236003891737D-09+(azi- 0.30D+02) * rk( 34)
       rk( 34)=-0.6933632309937518D-08+(azi- 0.30D+02) * rk( 34)
       rk( 34)= 0.5027670000000000D-06+(azi- 0.30D+02) * rk( 34)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 34)=-0.1713695613628228D-11
       rk( 34)= 0.3666689375960417D-10+(azi- 0.40D+02) * rk( 34)
       rk( 34)=-0.8267199376233226D-08+(azi- 0.40D+02) * rk( 34)
       rk( 34)= 0.4233180000000000D-06+(azi- 0.40D+02) * rk( 34)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 34)= 0.3217099316220888D-11
       rk( 34)=-0.1474397464925176D-10+(azi- 0.50D+02) * rk( 34)
       rk( 34)=-0.8047970185129656D-08+(azi- 0.50D+02) * rk( 34)
       rk( 34)= 0.3425990000000000D-06+(azi- 0.50D+02) * rk( 34)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 34)=-0.1521070165125414D-10
       rk( 34)= 0.8176900483737488D-10+(azi- 0.60D+02) * rk( 34)
       rk( 34)=-0.7377719883248147D-08+(azi- 0.60D+02) * rk( 34)
       rk( 34)= 0.2638620000000000D-06+(azi- 0.60D+02) * rk( 34)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 34)= 0.6076705686684552D-10
       rk( 34)=-0.3745520447001963D-09+(azi- 0.70D+02) * rk( 34)
       rk( 34)=-0.1030555028187705D-07+(azi- 0.70D+02) * rk( 34)
       rk( 34)= 0.1830510000000000D-06+(azi- 0.70D+02) * rk( 34)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 34)=-0.9890489034677335D-10
       rk( 34)= 0.1083857320104414D-08+(azi- 0.78D+02) * rk( 34)
       rk( 34)=-0.4631108078647543D-08+(azi- 0.78D+02) * rk( 34)
       rk( 34)= 0.1077480000000000D-06+(azi- 0.78D+02) * rk( 34)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 34)= 0.3457918810273488D-09
       rk( 34)=-0.1289860048217723D-08+(azi- 0.86D+02) * rk( 34)
       rk( 34)=-0.6279129903557406D-08+(azi- 0.86D+02) * rk( 34)
       rk( 34)= 0.8942669999999999D-07+(azi- 0.86D+02) * rk( 34)
      elseif(azi.ge.90.D0)then
       rk( 34)= 0.6580310000000000D-07
      endif
      if(att.lt.0.99999) rk( 34) = rk( 34) * att
      endif
C
      rk( 35) = SumM * 5.74d-34 * (temp/3.d2) 
     &         ** (-2.6d0)
      rk( 35) = rk( 35) * SumM * 0.2d0
      rk( 36) =  DEXP(-0.2555157957424871D+02
     & - (  0.2060000000000000D+04 )/temp)
      rk( 37) =  DEXP(-0.2474064935803238D+02
     & - ( -0.1070000000000000D+03 )/temp)
      rk( 37) = rk( 37) * SumM * 0.8d0
      rk( 38) =  DEXP(-0.2416528521312882D+02
     & - ( -0.6700000000000000D+02 )/temp)
      rk( 38) = rk( 38) * SumM * 0.2d0
      rk( 39) =  0.2200000000000000D-09
      rk( 39) = rk( 39) * YlH2O
      rk( 40) =  DEXP(-0.2710039286486638D+02
     & - (  0.9400000000000000D+03 )/temp)
      rk( 41) =  DEXP(-0.3223619130191664D+02
     & - (  0.4900000000000000D+03 )/temp)
      rk( 42) =  DEXP(-0.2375982010502066D+02
     & - ( -0.2500000000000000D+03 )/temp)
      rk( 43) =  DEXP(-0.2656631037893612D+02
     & - (  0.1600000000000000D+03 )/temp)
      rk( 44) = 2.2d-13 * dexp(600.0d0 / temp)
     &            + 1.9d-33* SumM * dexp(980.0d0 / temp)
      rk( 45) = 3.08d-34 * dexp(2800.0d0 / temp) + 
     &            2.59d-54 * SumM * dexp(3180.0d0 / temp)
      rk( 45) = rk( 45) * YlH2O
      Effko =  0.9000000000000000D-31* (temp / 3.d2)
     &           **(- ( 0.1500000000000000D+01))
      Rapk =  0.3000000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 46) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 47) =  DEXP(-0.2592627302369012D+02
     & - ( -0.1880000000000000D+03 )/temp)
      Effko =  0.2500000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.1800000000000000D+01))
      Rapk =  0.2200000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      rk( 48) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.7000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.2600000000000000D+01))
      Rapk =  0.3600000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.1000000000000000D+00))
      rk( 49) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 50) =  0.8680000000000000D+00
      Effko =  0.1800000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3000000000000000D+01))
      Rapk =  0.2800000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 50) = facteur * rk( 50)
      rk( 51) =  0.2000000000000000D-10
      rk( 52) =  DEXP(-0.2635008727046649D+02
     & - ( -0.2700000000000000D+03 )/temp)
      Effko =  0.2000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3400000000000000D+01))
      Rapk =  0.2900000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1100000000000000D+01))
      rk( 53) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 54) =  DEXP( 0.6142746008608852D+02
     & - (  0.1090000000000000D+05 )/temp)
      Effko =  0.2000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3400000000000000D+01))
      Rapk =  0.2900000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1100000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 54) = facteur * rk( 54)
      rk( 55) =  0.4000000000000000D-11
      rk( 56) =  DEXP(-0.2671473038405439D+02
     & - ( -0.2600000000000000D+03 )/temp)
      Effko = 2.4d-14 * dexp(460.0d0 / temp)
      Rapk = 2.7d-17 * dexp(2199.0d0 / temp)
      facteur =6.5d-34 * dexp(1335.0d0 / temp) * SumM
      rk( 57) = Effko + facteur/(1.0d0 + facteur / Rapk)
      rk( 58) =  DEXP(-0.2736865685146106D+02
     & - ( -0.3800000000000000D+03 )/temp)
      rk( 59) =  DEXP(-0.2729454887930734D+02
     & - (  0.1310000000000000D+04 )/temp)
      rk( 60) =  DEXP(-0.2959713397230138D+02
     & - (  0.2470000000000000D+04 )/temp)
      rk( 61) =  DEXP(-0.8860689615829534D+02
     & - ( -0.5300000000000000D+03 )/temp)
      rk( 61) = rk( 61) * SumM * 0.2d0
      rk( 62) =  DEXP(-0.2474064935803238D+02
     & - ( -0.1100000000000000D+03 )/temp)
      rk( 63) =  DEXP(-0.3073211390514037D+02
     & - (  0.1260000000000000D+04 )/temp)
      Effko =  0.2000000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.4400000000000000D+01))
      Rapk =  0.1400000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      rk( 64) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 65) =  DEXP( 0.6117554523749536D+02
     & - (  0.1100000000000000D+05 )/temp)
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3900000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 65) = facteur * rk( 65)
      rk( 66) =  0.1000000000000000D-21
      rk( 66) = rk( 66) * YlH2O
      rk( 67) =  DEXP(-0.2779354004542632D+02
     & - (  0.2450000000000000D+04 )/temp)
      rk( 68) =  DEXP(-0.2558980078706891D+02
     & - (  0.2100000000000000D+04 )/temp)
      rk( 68) = rk( 68) * SumM * 5.8d-7
      Effko =  0.3300000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.4300000000000000D+01))
      Rapk =  0.1600000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 69) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 70) = 1.44d-13 * (1.0d0 + 8.0d-1 * SumM / 
     & 4.0d19)
      rk( 71) =  DEXP(-0.2701583547683832D+02
     & - (  0.1690000000000000D+04 )/temp)
      rk( 72) =  DEXP(-0.2569949970432533D+02
     & - (  0.1000000000000000D+04 )/temp)
      rk( 73) =  DEXP(-0.2658370212164799D+02
     & - (  0.3450000000000000D+03 )/temp)
      rk( 74) =  DEXP(-0.2653240882726044D+02
     & - (  0.2000000000000000D+02 )/temp)
      rk( 75) =  DEXP(-0.2667550967090111D+02
     & - (  0.2000000000000000D+03 )/temp)
      Effko =  0.5500000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.0000000000000000D+00))
      Rapk =  0.8300000000000000D-12* (temp / 3.d2)
     &            **(- (-0.2000000000000000D+01))
      rk( 76) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 77) =  DEXP(-0.2559240156876897D+02
     & - (  0.3700000000000000D+03 )/temp)
      rk( 78) =  DEXP(-0.2531848569208134D+02
     & - (  0.2450000000000000D+03 )/temp)
      rk( 79) =  DEXP(-0.2429169913798448D+02
     & - (  0.2730000000000000D+03 )/temp)
      Effko =  0.1000000000000000D-27* (temp / 3.d2)
     &           **(- ( 0.4500000000000000D+01))
      Rapk =  0.8800000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.8500000000000000D+00))
      rk( 80) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 81) =  DEXP(-0.2588705231053684D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 82) =  DEXP(-0.2504325708070084D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 83) =  DEXP(-0.2493639393515848D+02
     & - ( -0.4480000000000000D+03 )/temp)
      rk( 84) =  DEXP(-0.2439627194190406D+02
     & - ( -0.4100000000000000D+03 )/temp)
      rk( 85) =  DEXP(-0.2513781566332585D+02
     & - ( -0.4400000000000000D+03 )/temp)
      rk( 86) =  DEXP(-0.2389335149764518D+02
     & - ( -0.4010000000000000D+03 )/temp)
      rk( 87) =  0.1000000000000000D-09
      rk( 88) =  0.1300000000000000D-10
      rk( 89) =  0.3000000000000000D-10
      rk( 90) =  0.3000000000000000D-11
      rk( 91) =  DEXP(-0.2590825451818744D+02
     & - ( -0.2700000000000000D+03 )/temp)
      rk( 92) =  0.1470000000000000D-10
      rk( 93) =  DEXP(-0.2678515284835094D+02
     & - (  0.1930000000000000D+03 )/temp)
      rk( 94) =  DEXP(-0.2703769427065081D+02
     & - ( -0.3540000000000000D+03 )/temp)
      rk( 95) =  0.4000000000000000D-11
      rk( 96) =  0.1000000000000000D+04
      rk( 97) =  0.1000000000000000D+04
      rk( 98) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk( 99) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(100) =  0.1370000000000000D-10
      rk(101) =  0.2130000000000000D-10
      rk(102) =  0.4000000000000000D-11
      rk(103) =  0.1000000000000000D+04
      rk(104) =  0.1000000000000000D+04
      rk(105) =  0.1000000000000000D+04
      rk(106) =  0.1000000000000000D+04
      rk(107) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(108) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(109) =  DEXP(-0.2595954781257500D+02
     & - ( -0.2430000000000000D+03 )/temp)
      rk(110) =  0.4000000000000000D-11
      rk(111) =  0.4000000000000000D-11
      rk(112) =  0.2000000000000000D-10
      rk(113) =  DEXP(-0.2572147861104411D+02
     & - ( -0.4050000000000000D+03 )/temp)
      rk(114) =  0.4650000000000000D-10
      rk(115) =  0.2050000000000000D-09
      rk(116) =  0.2010000000000000D-09
      rk(117) =  0.2860000000000000D-12
      rk(118) =  0.2080000000000000D-11
      rk(119) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(120) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(121) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(122) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(123) =  0.1200000000000000D-11
      rk(124) =  DEXP(-0.2592627302369012D+02
     & - ( -0.1250000000000000D+03 )/temp)
      rk(125) =  DEXP(-0.2615397239154019D+02
     & - ( -0.3660000000000000D+03 )/temp)
      rk(126) =  DEXP(-0.2600178057619827D+02
     & - ( -0.4050000000000000D+03 )/temp)
      rk(127) = 4.56d-14*(temp/300)**(3.65)
     &         *dexp(-427.0d0/temp)
      rk(128) =  DEXP(-0.2736865685146106D+02
     & - (  0.2500000000000000D+02 )/temp)
      rk(129) =  0.2800000000000000D-11
      rk(130) =  0.3000000000000000D-11
      rk(131) =  0.1100000000000000D-10
      rk(132) =  DEXP(-0.2770790216026451D+02
     & - ( -0.8300000000000000D+03 )/temp)
      rk(133) =  DEXP(-0.2470785953520939D+02
     & - ( -0.1760000000000000D+03 )/temp)
      rk(134) =  DEXP(-0.2667550967090111D+02
     & - ( -0.6100000000000000D+03 )/temp)
      rk(135) =  DEXP(-0.2587834903540854D+02
     & - ( -0.5330000000000000D+03 )/temp)
      rk(136) =  DEXP(-0.2429881660575334D+02
     & - ( -0.1750000000000000D+03 )/temp)
      rk(137) =  DEXP(-0.2429881660575334D+02
     & - ( -0.1750000000000000D+03 )/temp)
      rk(138) =  DEXP(-0.2429881660575334D+02
     & - ( -0.1750000000000000D+03 )/temp)
      rk(139) =  0.1000000000000000D-12
      rk(140) =  DEXP(-0.2656631037893612D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk(141) =  DEXP(-0.2640724568430643D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk(142) =  DEXP(-0.2655601869289957D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk(143) =  0.4000000000000000D-13
      rk(144) =  0.4000000000000000D-13
      rk(145) =  0.3200000000000000D-10
      rk(146) =  DEXP(-0.2596142928067470D+02
     & - (  0.2600000000000000D+03 )/temp)
      rk(147) =  0.4500000000000000D-12
      rk(148) =  DEXP(-0.3144773394155237D+02
     & - ( -0.1012000000000000D+04 )/temp)
      rk(149) =  DEXP(-0.2693787393536860D+02
     & - (  0.2440000000000000D+04 )/temp)
      rk(150) =  DEXP(-0.2729454887930734D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk(151) =  DEXP(-0.2630660215852674D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk(152) =  DEXP(-0.2656631037893612D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk(153) =  DEXP(-0.2630660215852674D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk(154) =  DEXP(-0.2887929417915106D+02
     & - (  0.1000000000000000D+04 )/temp)
      rk(155) =  0.3780000000000000D-11
      rk(156) =  0.1060000000000000D-11
      rk(157) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(158) =  0.1200000000000000D-11
      rk(159) =  0.3560000000000000D-13
      rk(160) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(161) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(162) =  DEXP(-0.3986138645402777D+02
     & + ( 0.2000000000000000D+01 * DLOG(temp))
     & -  0.2282000000000000D+04/temp)
      rk(163) =  DEXP(-0.2935139058906993D+02
     & - (  0.4500000000000000D+03 )/temp)
      rk(164) =  DEXP(-0.2777720362610663D+02
     & - ( -0.4500000000000000D+03 )/temp)
      rk(165) =  0.1000000000000000D-12
      rk(166) =  DEXP(-0.2652245849640727D+02
     & - (  0.4460000000000000D+03 )/temp)
      rk(167) =  0.3400000000000000D-11
      rk(168) =  DEXP(-0.2832017627521896D+02
     & - (  0.1076000000000000D+04 )/temp)
      rk(169) =  DEXP(-0.2745706780880511D+02
     & - ( -0.4900000000000000D+03 )/temp)
      rk(170) =  0.1220000000000000D-10
      rk(171) =  DEXP(-0.3144773394155237D+02
     & - (  0.5000000000000000D+03 )/temp)
      rk(172) =  DEXP(-0.3232611600944463D+02
     & - (  0.2580000000000000D+04 )/temp)
      rk(173) =  DEXP(-0.3307320885289629D+02
     & - (  0.1800000000000000D+04 )/temp)
      rk(174) =  DEXP(-0.3305717185398647D+02
     & - (  0.8450000000000000D+03 )/temp)
      rk(175) =  DEXP(-0.3194352168795382D+02
     & - (  0.2283000000000000D+04 )/temp)
      rk(176) =  DEXP(-0.3247698978846957D+02
     & - (  0.1913000000000000D+04 )/temp)
      rk(177) =  DEXP(-0.3423129169516272D+02
     & - (  0.2112000000000000D+04 )/temp)
      rk(178) =  DEXP(-0.3482512602212869D+02
     & - (  0.1520000000000000D+04 )/temp)
      rk(179) =  0.1660000000000000D-17
      rk(180) =  DEXP(-0.3523192357547063D+02
     & - (  0.5300000000000000D+03 )/temp)
      rk(181) =  DEXP(-0.3345697122455896D+02
     & - (  0.7830000000000000D+03 )/temp)
      rk(182) =  0.1000000000000000D-15
      rk(183) =  0.8000000000000001D-16
      rk(184) =  0.2000000000000000D-10
      Effko =  0.8500000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.6500000000000000D+01))
      Rapk =  0.1100000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.1000000000000000D+01))
      rk(185) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.8500000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.6500000000000000D+01))
      Rapk =  0.1100000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.1000000000000000D+01))
      rk(186) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(187) =  DEXP( 0.6462080260895155D+02
     & - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk(187) = facteur * rk(187)
      rk(188) =  DEXP( 0.6462080260895155D+02
     & - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk(188) = facteur * rk(188)
      rk(189) =  DEXP(-0.2660140169874739D+02
     & - ( -0.1810000000000000D+03 )/temp)
      rk(190) =  DEXP( 0.3731136511715047D+02
     & - (  0.1348600000000000D+05 )/temp)
      rk(191) =  DEXP(-0.2660140169874739D+02
     & - ( -0.3000000000000000D+03 )/temp)
      rk(192) =  DEXP(-0.2667550967090111D+02
     & - ( -0.3650000000000000D+03 )/temp)
      rk(193) =  0.4000000000000000D-11
      rk(194) =  0.4000000000000000D-11
      rk(195) =  0.4000000000000000D-11
      rk(196) =  0.9000000000000000D-11
      rk(197) =  0.4000000000000000D-11
      rk(198) =  0.4000000000000000D-11
      rk(199) =  DEXP(-0.2674312985857609D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(200) =  DEXP(-0.2669885703489810D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(201) =  DEXP(-0.2619593659063922D+02
     & - ( -0.1810000000000000D+03 )/temp)
      rk(202) =  0.4000000000000000D-11
      rk(203) =  DEXP(-0.2619593659063922D+02
     & - ( -0.1810000000000000D+03 )/temp)
      rk(204) =  0.4000000000000000D-11
      rk(205) =  0.4000000000000000D-11
      rk(206) =  DEXP(-0.2669885703489810D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(207) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(208) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(209) =  DEXP(-0.2553915705425015D+02
     & - ( -0.2700000000000000D+03 )/temp)
      rk(210) =  DEXP(-0.2553915705425015D+02
     & - ( -0.2700000000000000D+03 )/temp)
      rk(211) =  0.4000000000000000D-11
      rk(212) =  DEXP(-0.2656631037893612D+02
     & - ( -0.3000000000000000D+03 )/temp)
      rk(213) =  0.4000000000000000D-11
      rk(214) =  0.4000000000000000D-11
      rk(215) =  DEXP(-0.2852261923521233D+02
     & - ( -0.7500000000000000D+03 )/temp)
      rk(216) =  DEXP(-0.2791870318838033D+02
     & - ( -0.7000000000000000D+03 )/temp)
      rk(217) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(218) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(219) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(220) =  DEXP(-0.2929175232275020D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(221) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(222) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(223) =  DEXP(-0.2921576641577228D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(224) =  DEXP(-0.2933476970783389D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(225) =  DEXP(-0.3019497097305700D+02
     & - ( -0.1298000000000000D+04 )/temp)
      rk(226) =  DEXP(-0.3019497097305700D+02
     & - ( -0.1298000000000000D+04 )/temp)
      rk(227) =  0.1500000000000000D-10
      rk(228) =  0.1500000000000000D-10
      rk(229) =  DEXP(-0.2886545312773919D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(230) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(231) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(232) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(233) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(234) =  0.9999999999999999D-11
      rk(235) =  DEXP(-0.2847499118622308D+02
     & - ( -0.1040000000000000D+04 )/temp)
      rk(236) =  DEXP(-0.2847499118622308D+02
     & - ( -0.1040000000000000D+04 )/temp)
      rk(237) =  DEXP(-0.2979384426654743D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(238) =  DEXP(-0.2979384426654743D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(239) =  DEXP(-0.2979384426654743D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(240) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(241) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(242) =  DEXP(-0.2998489950331015D+02
     & - ( -0.3900000000000000D+03 )/temp)
      rk(243) =  DEXP(-0.2976809177044502D+02
     & - ( -0.1580000000000000D+03 )/temp)
      rk(244) =  DEXP(-0.2998911891885285D+02
     & - ( -0.4310000000000000D+03 )/temp)
      rk(245) =  DEXP(-0.2993360620892259D+02
     & - ( -0.4670000000000000D+03 )/temp)
      rk(246) =  DEXP(-0.3076831695380433D+02
     & - ( -0.6330000000000000D+03 )/temp)
      rk(247) =  DEXP(-0.2939711283840802D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(248) =  DEXP(-0.2955516977320235D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(249) =  DEXP(-0.3001916409728424D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(250) =  DEXP(-0.3101241587029453D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(251) =  DEXP(-0.3101241587029453D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(252) =  DEXP(-0.3101241587029453D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(253) =  DEXP(-0.3101241587029453D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(254) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(255) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(256) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(257) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(258) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(259) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(260) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(261) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(262) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(263) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(264) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(265) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(266) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(267) =  DEXP(-0.2463528884237456D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(268) =  DEXP(-0.2463528884237456D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(269) =  DEXP(-0.2791870318838033D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(270) =  DEXP(-0.2800063657114302D+02
     & - ( -0.5080000000000000D+03 )/temp)
      rk(271) =  DEXP(-0.2800063657114302D+02
     & - ( -0.5080000000000000D+03 )/temp)
      rk(272) =  DEXP(-0.2946360257967686D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(273) =  DEXP(-0.2996612940062816D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(274) =  DEXP(-0.2760146231368700D+02
     & - ( -0.2110000000000000D+03 )/temp)
      rk(275) =  DEXP(-0.2800208479731938D+02
     & - ( -0.4600000000000000D+03 )/temp)
      rk(276) =  DEXP(-0.2821262692175559D+02
     & - ( -0.5220000000000000D+03 )/temp)
      rk(277) =  DEXP(-0.2902938805828271D+02
     & - ( -0.6830000000000000D+03 )/temp)
      rk(278) =  DEXP(-0.2768442189265566D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(279) =  DEXP(-0.2784050834079527D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(280) =  DEXP(-0.2830632837836016D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(281) =  DEXP(-0.3010795959606737D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(282) =  DEXP(-0.3010795959606737D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(283) =  DEXP(-0.3010795959606737D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(284) =  DEXP(-0.3010795959606737D+02
     & - ( -0.2210000000000000D+03 )/temp)
      rk(285) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(286) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(287) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(288) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(289) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(290) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(291) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(292) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(293) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(294) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(295) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(296) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(297) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(298) =  DEXP(-0.2671473038405439D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(299) =  DEXP(-0.2671473038405439D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(300) =  DEXP(-0.2791737074314655D+02
     & - ( -0.5650000000000000D+03 )/temp)
      rk(301) =  DEXP(-0.2791737074314655D+02
     & - ( -0.5650000000000000D+03 )/temp)
      rk(302) =  DEXP(-0.2791737074314655D+02
     & - ( -0.5650000000000000D+03 )/temp)
      rk(303) =  DEXP(-0.2775318874990275D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(304) =  DEXP(-0.2825277830040182D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(305) =  DEXP(-0.3029028115286133D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(306) =  DEXP(-0.3078927231898031D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(307) =  DEXP(-0.3115100203358067D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(308) =  0.1200000000000000D-11
      rk(309) =  0.1200000000000000D-11
      rk(310) =  0.1200000000000000D-11
      rk(311) =  0.1200000000000000D-11
      rk(312) =  0.1200000000000000D-11
      rk(313) =  0.1200000000000000D-11
      rk(314) =  0.1200000000000000D-11
      rk(315) =  0.1200000000000000D-11
      rk(316) =  0.1200000000000000D-11
      rk(317) =  0.1200000000000000D-11
      rk(318) =  0.1200000000000000D-11
      rk(319) =  0.1200000000000000D-11
      rk(320) =  0.1200000000000000D-11
      rk(321) =  0.1200000000000000D-11
      rk(322) =  0.4000000000000000D-11
      rk(323) =  0.4000000000000000D-11
      rk(324) =  0.1200000000000000D-11
      rk(325) =  0.1200000000000000D-11
      rk(326) =  0.1200000000000000D-11
      rk(327) =  0.1200000000000000D-11
      rk(328) =  0.1200000000000000D-11
      rk(329) =  0.1200000000000000D-11
      rk(330) =  0.1200000000000000D-11
      rk(331) =  0.1200000000000000D-11
      rk(332) =  0.1200000000000000D-11
      rk(333) =  0.1200000000000000D-11
      rk(334) =  0.1200000000000000D-11
      rk(335) =  0.1200000000000000D-11
      rk(336) =  0.1200000000000000D-11
      rk(337) =  0.1200000000000000D-11
      rk(338) =  0.1200000000000000D-11
      rk(339) =  0.1200000000000000D-11
      rk(340) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(341) =  DEXP(-0.3274868498278332D+02
     & - ( -0.1510000000000000D+04 )/temp)
      rk(342) =  DEXP(-0.3101241587029453D+02
     & - ( -0.1560000000000000D+04 )/temp)
      rk(343) =  DEXP(-0.3717963534647257D+02
     & - ( -0.2950000000000000D+04 )/temp)
      rk(344) =  0.4000000000000000D-11
      rk(345) =  0.1200000000000000D-11
      rk(346) =  0.4000000000000000D-11
      rk(347) =  DEXP(-0.2979384426654743D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(348) =  DEXP(-0.2791870318838033D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(349) =  DEXP(-0.2791737074314655D+02
     & - ( -0.5650000000000000D+03 )/temp)
      rk(350) =  0.1200000000000000D-11
      rk(351) =  DEXP(-0.2671473038405439D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk(352) =  0.1200000000000000D-11
      rk(353) =  0.1200000000000000D-11
      rk(354) =  0.1200000000000000D-11
      rk(355) =  0.1200000000000000D-11
      rk(356) =  0.2930000000000000D-09
      rk(357) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(358) =  0.1200000000000000D-11
      rk(359) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(360) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(361) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(362) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(363) =  0.1200000000000000D-11
      rk(364) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(365) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(366) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(367) =  DEXP(-0.2663776934291826D+02
     & - ( -0.3600000000000000D+03 )/temp)
      rk(368) =  0.1200000000000000D-11
      rk(369) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(370) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(371) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
C    Heteroheneous Reactions on aerosol surface:
C
C    Reaction 352: HO2  -->  0.5 H2O2
C    Reaction 353: NO2  -->  0.5 HONO + 0.5 HNO3
C    Reaction 354: NO3  -->  HNO3
C    Reaction 355: N2O5 -->  2 HNO3
 
      rk352=0.D0
      rk353=0.D0
      rk354=0.D0
      rk355=0.D0
 
      if (IHETER.eq.1) then
         call HETRXN(Ns,Nbin_aer,temp,press,ICLD,lwctmp,
     &        WetDiam,granulo,rk352,rk353,rk354,rk355,
     &        dsf_aero,ispeclost,Wmol,LWCmin)
      endif
 
      rk(352) = rk352
      rk(353) = rk353
      rk(354) = rk354
      rk(355) = rk355
 
      RETURN
      END
 
